@@ -36,7 +36,7 @@ cp ./appdir/usr/share/icons/hicolor/256x256/apps/scribus.png ./appdir/
 sed -i -e 's|^Icon=.*|Icon=scribus|g' ./appdir/usr/share/applications/scribus.desktop
 
 ########################################################################
-# Bundle everyhting
+# Bundle everything
 # to allow the AppImage to run on older systems as well
 ########################################################################
 
@@ -108,4 +108,5 @@ chmod a+x linuxdeployqt-continuous-x86_64.AppImage
 ARCH=x86_64 VERSION=$SCRIBUS_VERSION ./linuxdeployqt-continuous-x86_64.AppImage --appimage-extract-and-run appdir/usr/share/applications/scribus.desktop \
                                                -appimage -unsupported-bundle-everything \
                                                -executable=appdir/usr/bin/python3.6 \
-                                               -executable=appdir/usr/lib/python3.6/lib-dynload/_tkinter.cpython-36m-x86_64-linux-gnu.so
+                                               -executable=appdir/usr/lib/python3.6/lib-dynload/_tkinter.cpython-36m-x86_64-linux-gnu.so \
+                                               -extra-plugins=platformthemes/libqgtk2.so,styles/libqgtk2style.so
