@@ -283,7 +283,6 @@ void AppModeHelper::setApplicationMode(ScribusMainWindow* scmw, ScribusDoc* doc,
 					a_actMgr->saveActionShortcutsPreEditMode();
 				if (currItem != nullptr)
 				{
-					currItem->itemText.setCursorPosition(0);
 					scmw->setTBvals(currItem);
 				}
 				(*a_scrActions)["editPaste"]->setEnabled(false);
@@ -991,7 +990,7 @@ void AppModeHelper::setModeActionsPerMode(int newMode)
 	(*a_scrActions)["toolsEditWithStoryEditor"]->setChecked(newMode == modeStoryEditor);
 	(*a_scrActions)["toolsLinkTextFrame"]->setChecked(newMode == modeLinkFrames);
 	(*a_scrActions)["toolsUnlinkTextFrame"]->setChecked(newMode == modeUnlinkFrames);
-//	(*a_scrActions)["toolsUnlinkTextFrameAndCutText"]->setChecked(newMode == modeUnlinkFrames);
+	//	(*a_scrActions)["toolsUnlinkTextFrameAndCutText"]->setChecked(newMode == modeUnlinkFrames);
 	(*a_scrActions)["toolsEyeDropper"]->setChecked(newMode == modeEyeDropper);
 	(*a_scrActions)["toolsMeasurements"]->setChecked(newMode == modeMeasurementTool);
 	(*a_scrActions)["toolsCopyProperties"]->setChecked(newMode == modeCopyProperties);
@@ -1618,7 +1617,7 @@ void AppModeHelper::mainWindowSwitchWin(const ScribusDoc *doc)
 	(*a_scrActions)["viewSnapToGrid"]->setChecked(doc->SnapGrid);
 	(*a_scrActions)["viewSnapToGuides"]->setChecked(doc->SnapGuides);
 	(*a_scrActions)["viewSnapToElements"]->setChecked(doc->SnapElement);
-	
+
 	enableExperimentalActions(doc);
 }
 
@@ -1808,6 +1807,7 @@ void AppModeHelper::enableTextActions(bool enabled, const QString& fontName)
 		(*a_scrActions)["insertMarkItem"]->setEnabled(false);
 		(*a_scrActions)["insertMark2Mark"]->setEnabled(false);
 		(*a_scrActions)["insertMarkNote"]->setEnabled(false);
+		(*a_scrActions)["insertMarkIndex"]->setEnabled(false);
 		(*a_scrActions)["editMark"]->setEnabled(false);
 	}
 }
@@ -1890,6 +1890,7 @@ void AppModeHelper::setStartupActionsEnabled(bool enabled)
 	(*a_scrActions)["insertMarkItem"]->setEnabled(false);
 	(*a_scrActions)["insertMark2Mark"]->setEnabled(false);
 	(*a_scrActions)["insertMarkNote"]->setEnabled(false);
+	(*a_scrActions)["insertMarkIndex"]->setEnabled(false);
 	(*a_scrActions)["toolsPreflightVerifier"]->setEnabled(false);
 	(*a_scrActions)["extrasHyphenateText"]->setEnabled(false);
 	(*a_scrActions)["extrasDeHyphenateText"]->setEnabled(false);
@@ -2018,6 +2019,7 @@ void AppModeHelper::enableExperimentalActions(const ScribusDoc *doc)
 	(*a_scrActions)["insertMarkItem"]->setEnabled(setter);
 	(*a_scrActions)["insertMark2Mark"]->setEnabled(setter);
 	(*a_scrActions)["insertMarkVariableText"]->setEnabled(setter);
+	(*a_scrActions)["insertMarkIndex"]->setEnabled(setter);
 	ScribusMainWindow *scMW = ScCore->primaryMainWindow();
 	scMW->scrMenuMgr->setMenuEnabled("Marks", setter);
 	scMW->scrMenuMgr->setMenuEnabled("InsertMark", setter);
