@@ -36,7 +36,6 @@
 #include "selection.h"
 #include "ui/hruler.h"
 #include "ui/vruler.h"
-#include "util.h"
 #include "util_math.h"
 #include "units.h"
 
@@ -103,50 +102,51 @@ void Canvas::setPreviewVisual(int mode)
 // Coordinate Conversion Routines:
 
 
-FPoint Canvas::localToCanvas(QPoint p) const
+FPoint Canvas::localToCanvas(QPointF p) const
 {
 
-/* Allow the user to select the exact coordinate represented by a ruler mark
-   when the mouse is lined up with the ruler, rather than returning the 
-   coordinate represented by the mathematical centre of the pixel which
-   may not be exactly the same as the coordinate represented by the ruler.
-*/
+	/* Allow the user to select the exact coordinate represented by a ruler mark
+	   when the mouse is lined up with the ruler, rather than returning the
+	   coordinate represented by the mathematical centre of the pixel which
+	   may not be exactly the same as the coordinate represented by the ruler.
+	*/
 
-// (xmin, xmax) = canvas top-left
+	// (xmin, xmax) = canvas top-left
 	double xmin = m_doc->minCanvasCoordinate.x();
 	double ymin = m_doc->minCanvasCoordinate.y();
 
-// (xoff, yoff) = ruler origin relative to canvas top-left
+	// (xoff, yoff) = ruler origin relative to canvas top-left
 	double xoff = m_doc->rulerXoffset - xmin;
 	double yoff = m_doc->rulerYoffset - ymin;
-	if (m_doc->guidesPrefs().rulerMode) {
+	if (m_doc->guidesPrefs().rulerMode)
+	{
 		xoff += m_doc->currentPage()->xOffset();
 		yoff += m_doc->currentPage()->yOffset();
 	}
-// (xsp, ysp) = spacing of ruler divisions
+	// (xsp, ysp) = spacing of ruler divisions
 	double xsp = m_doc->view()->horizRuler->ruleSpacing();
 	double ysp = m_doc->view()->vertRuler->ruleSpacing();
 
 	double sc = m_viewMode.scale;
 
-// number of ruler divisions from ruler origin to ruler mark closest to the
-// selected mouse coordinate
-	double xn = qRound((p.x()/sc - xoff)/xsp);
-	double yn = qRound((p.y()/sc - yoff)/ysp);
+	// number of ruler divisions from ruler origin to ruler mark closest to the
+	// selected mouse coordinate
+	double xn = qRound((p.x() / sc - xoff) / xsp);
+	double yn = qRound((p.y() / sc - yoff) / ysp);
 
-// xn*xsp + xoff, yn*ysp + yoff = distance in canvas coordinates
-// from canvas top-left to ruler mark closest to selected mouse coordinate
+	// xn*xsp + xoff, yn*ysp + yoff = distance in canvas coordinates
+	// from canvas top-left to ruler mark closest to selected mouse coordinate
 
-// If these round to the selected mouse coordinate, use these to define
-// (x,y), the coordinates of the desired point relative to the canvas top-left.
-// Otherwise, simply scale the mouse coordinates.
-	double x = ( qRound(sc*(xn*xsp + xoff)) == p.x() ? 
-	             xn * xsp + xoff : p.x() / sc );
-	double y = ( qRound(sc*(yn*ysp + yoff)) == p.y() ? 
-	             yn * ysp + yoff : p.y() / sc );
-		
-// Finally, add xmin,ymin to get the absolute canvas coordinates of the
-// desired point.
+	// If these round to the selected mouse coordinate, use these to define
+	// (x,y), the coordinates of the desired point relative to the canvas top-left.
+	// Otherwise, simply scale the mouse coordinates.
+	double x = (qRound(sc * (xn * xsp + xoff)) == p.x() ?
+		xn * xsp + xoff : p.x() / sc);
+	double y = (qRound(sc * (yn * ysp + yoff)) == p.y() ?
+		yn * ysp + yoff : p.y() / sc);
+
+	// Finally, add xmin,ymin to get the absolute canvas coordinates of the
+	// desired point.
 	return FPoint(x + xmin, y + ymin);
 }
 
@@ -156,12 +156,24 @@ QPoint Canvas::canvasToLocal(const FPoint& p) const
 	         qRound((p.y() - m_doc->minCanvasCoordinate.y()) * m_viewMode.scale) };
 }
 
+QPointF Canvas::canvasToLocalF(const FPoint& p) const
+{
+	return { ((p.x() - m_doc->minCanvasCoordinate.x()) * m_viewMode.scale),
+			 ((p.y() - m_doc->minCanvasCoordinate.y()) * m_viewMode.scale) };
+}
+
 QPoint Canvas::canvasToLocal(QPointF p) const
 {
 	return { qRound((p.x() - m_doc->minCanvasCoordinate.x()) * m_viewMode.scale),
 	         qRound((p.y() - m_doc->minCanvasCoordinate.y()) * m_viewMode.scale) };
 }
 
+QPointF Canvas::canvasToLocalF(QPointF p) const
+{
+	return { ((p.x() - m_doc->minCanvasCoordinate.x()) * m_viewMode.scale),
+			 ((p.y() - m_doc->minCanvasCoordinate.y()) * m_viewMode.scale) };
+}
+
 QRect Canvas::canvasToLocal(const QRectF& p) const
 {
 	return { qRound((p.x() - m_doc->minCanvasCoordinate.x()) * m_viewMode.scale),
@@ -178,25 +190,40 @@ QRectF Canvas::canvasToLocalF(const QRectF& p) const
 	         p.height() * m_viewMode.scale };
 }
 
+
 QPoint Canvas::canvasToGlobal(const FPoint& p) const
 {
 	return mapToParent(QPoint(0,0)) + parentWidget()->mapToGlobal(QPoint(0, 0)) + canvasToLocal(p);
 }
 
+
 QPoint Canvas::canvasToGlobal(QPointF p) const
 {
 	return mapToParent(QPoint(0,0)) + parentWidget()->mapToGlobal(QPoint(0, 0)) + canvasToLocal(p);
 }
 
+
+QPointF Canvas::canvasToGlobalF(QPointF p) const
+{
+	return mapToParent(QPointF(0, 0)) + parentWidget()->mapToGlobal(QPointF(0, 0)) + canvasToLocal(p);
+}
+
+
 QRect Canvas::canvasToGlobal(const QRectF& p) const
 {
 	return { mapToParent(QPoint(0,0) + canvasToLocal(p.topLeft())) + parentWidget()->mapToGlobal(QPoint(0, 0)),
 	         QSize(qRound(p.width() * m_viewMode.scale), qRound(p.height() * m_viewMode.scale)) };
 }
 
-FPoint Canvas::globalToCanvas(QPoint p) const
+QRectF Canvas::canvasToGlobalF(const QRectF& p) const
 {
-	return localToCanvas(p - (mapToParent(QPoint(0, 0)) + parentWidget()->mapToGlobal(QPoint(0, 0))));
+	return { mapToParent(QPointF(0,0) + canvasToLocal(p.topLeft())) + parentWidget()->mapToGlobal(QPointF(0, 0)),
+			 QSize(p.width() * m_viewMode.scale, p.height() * m_viewMode.scale) };
+}
+
+FPoint Canvas::globalToCanvas(QPointF p) const
+{
+	return localToCanvas(p.toPoint() - (mapToParent(QPoint(0, 0)) + parentWidget()->mapToGlobal(QPoint(0, 0))));
 }
 
 QRectF Canvas::globalToCanvas(QRect p) const
@@ -205,22 +232,27 @@ QRectF Canvas::globalToCanvas(QRect p) const
 	return { org.x(), org.y(), p.width() / m_viewMode.scale, p.height() / m_viewMode.scale };
 }
 
+QRectF Canvas::globalToCanvas(const QRectF& p) const
+{
+	FPoint org = globalToCanvas(p.topLeft());
+	return { org.x(), org.y(), p.width() / m_viewMode.scale, p.height() / m_viewMode.scale };
+}
+
 // ________________________
 // Tests for Finding Things:
 
-bool Canvas::hitsCanvasPoint(QPoint globalPoint, const FPoint& canvasPoint) const
+bool Canvas::hitsCanvasPoint(const QPointF& globalPoint, const FPoint& canvasPoint) const
 {
-	QPoint localPoint1 = globalPoint - (mapToParent(QPoint(0,0)) + parentWidget()->mapToGlobal(QPoint(0, 0)));
-	QPoint localPoint2 = canvasToLocal(canvasPoint);
+	QPointF localPoint1 = globalPoint - (mapToParent(QPointF(0, 0)) + parentWidget()->mapToGlobal(QPointF(0, 0)));
+	QPointF localPoint2 = canvasToLocalF(canvasPoint);
 	int radius = m_doc->guidesPrefs().grabRadius;
 	return qAbs(localPoint1.x() - localPoint2.x()) < radius && qAbs(localPoint1.y() - localPoint2.y()) < radius;
 }
 
-
-bool Canvas::hitsCanvasPoint(QPoint globalPoint, QPointF canvasPoint) const
+bool Canvas::hitsCanvasPoint(const QPointF& globalPoint, const QPointF& canvasPoint) const
 {
-	QPoint localPoint1 = globalPoint - (mapToParent(QPoint(0,0)) + parentWidget()->mapToGlobal(QPoint(0, 0)));
-	QPoint localPoint2 = canvasToLocal(canvasPoint);
+	QPointF localPoint1 = globalPoint - (mapToParent(QPointF(0, 0)) + parentWidget()->mapToGlobal(QPointF(0, 0)));
+	QPointF localPoint2 = canvasToLocalF(canvasPoint);
 	int radius = m_doc->guidesPrefs().grabRadius;
 	return qAbs(localPoint1.x() - localPoint2.x()) < radius && qAbs(localPoint1.y() - localPoint2.y()) < radius;
 }
@@ -367,14 +399,14 @@ Canvas::FrameHandle Canvas::frameHitTest(QPointF canvasPoint, const QRectF& fram
 }
 
 
-PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool allowInGroup, bool allowMasterItems) const
+PageItem* Canvas::itemUnderCursor(QPointF globalPos, PageItem* itemAbove, bool allowInGroup, bool allowMasterItems) const
 {
 	PageItem* currItem;
-	QRectF mouseArea = globalToCanvas(QRect(globalPos, QSize(2*m_doc->guidesPrefs().grabRadius, 2*m_doc->guidesPrefs().grabRadius)));
+	QRectF mouseArea = globalToCanvas(QRectF(globalPos, QSizeF(2 * m_doc->guidesPrefs().grabRadius, 2 * m_doc->guidesPrefs().grabRadius)));
 	// look for masterpage items first
 	if (allowMasterItems && !m_doc->masterPageMode() && m_doc->currentPage()->FromMaster.count() != 0)
 	{
-		ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[m_doc->currentPage()->masterPageName()]);
+		const ScPage* Mp = m_doc->MasterPages.at(m_doc->MasterNames[m_doc->currentPage()->masterPageName()]);
 		// if itemAbove is given, we expect to find it among the masterpage items of this page
 		int currNr = itemAbove ? m_doc->currentPage()->FromMaster.indexOf(itemAbove) - 1 : m_doc->currentPage()->FromMaster.count() - 1;
 		if (currNr < 0)
@@ -434,7 +466,7 @@ PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool al
 	while (currNr >= 0)
 	{
 		currItem = itemList->at(currNr);
-		if ((m_doc->masterPageMode())  && (!((currItem->OwnPage == -1) || (currItem->OwnPage == static_cast<int>(m_doc->currentPage()->pageNr())))))
+		if ((m_doc->masterPageMode())  && (!((currItem->OwnPage == -1) || (currItem->OwnPage == m_doc->currentPage()->pageNr()))))
 		{
 			--currNr;
 			continue;
@@ -488,7 +520,7 @@ PageItem* Canvas::itemUnderCursor(QPoint globalPos, PageItem* itemAbove, bool al
 	return nullptr;
 }
 
-bool Canvas::cursorOverTextFrameControl(QPoint globalPos, PageItem* frame)
+bool Canvas::cursorOverTextFrameControl(QPointF globalPos, const PageItem* frame) const
 {
 	FPoint mp = globalToCanvas(globalPos);
 	qreal sideLength = 10 / qMax(m_viewMode.scale, 1.0);
@@ -496,17 +528,17 @@ bool Canvas::cursorOverTextFrameControl(QPoint globalPos, PageItem* frame)
 	qreal right = left + sideLength;
 	qreal top   = frame->yPos() + frame->height() - sideLength;
 	qreal bottom = top + sideLength;
-	return mp.x()>left && mp.x()<right && mp.y()>top && mp.y()<bottom;
+	return mp.x() > left && mp.x() < right && mp.y() > top && mp.y() < bottom;
 }
 
-bool Canvas::cursorOverFrameControl(QPoint globalPos, const QRectF& targetRect, PageItem* frame)
+bool Canvas::cursorOverFrameControl(QPointF globalPos, const QRectF& targetRect, const PageItem* frame) const
 {
 	FPoint mp = globalToCanvas(globalPos);
 	QRectF tg = targetRect.translated(frame->xPos(), frame->yPos());
 	return tg.contains(QPointF(mp.x(), mp.y()));
 }
 
-PageItem* Canvas::itemInGroup(PageItem* group, const QRectF& mouseArea) const
+PageItem* Canvas::itemInGroup(const PageItem* group, const QRectF& mouseArea) const
 {
 	int currNr = group->groupItemList.count() - 1;
 	while (currNr >= 0)
@@ -538,7 +570,7 @@ PageItem* Canvas::itemInGroup(PageItem* group, const QRectF& mouseArea) const
 	return nullptr;
 }
 
-PageItem * Canvas::itemUnderItem(PageItem * item, int& index) const
+PageItem * Canvas::itemUnderItem(const PageItem * item, int& index) const
 {
 	int indice = qMin(index, m_doc->Items->count());
 	if (index < 0 || indice < 0)
@@ -927,11 +959,11 @@ void Canvas::drawContents(QPainter *psx, int clipx, int clipy, int clipw, int cl
 //	tim.start();
 // 	qDebug() << "Canvas::drawContents" << clipx << clipy << clipw << cliph<<m_viewMode.forceRedraw<<m_viewMode.operItemSelecting;
 	int docPagesCount = m_doc->Pages->count();
+	ScPainter *painter = nullptr;
 	QImage img(clipw * devicePixelRatioF(), cliph * devicePixelRatioF(), QImage::Format_ARGB32_Premultiplied);
 	img.setDevicePixelRatio(devicePixelRatioF());
-
-	auto* painter = new ScPainter(&img, img.width(), img.height(), 1.0, 0);
-	painter->clear(PrefsManager::instance().appPrefs.displayPrefs.scratchColor);	
+	painter = new ScPainter(&img, img.width(), img.height(), 1.0, 0);
+	painter->clear(PrefsManager::instance().appPrefs.displayPrefs.scratchColor);
 	painter->newPath();
 	painter->moveTo(0, 0);
 	painter->lineTo(clipw, 0);
@@ -1233,7 +1265,7 @@ void Canvas::drawControlsMovingItemsRect(QPainter* pp)
 /**
   draws the bezier curve in edit bezier mode
   */
-void Canvas::drawControlsBezierCurve(QPainter* pp, PageItem* currItem)
+void Canvas::drawControlsBezierCurve(QPainter* pp, const PageItem* currItem)
 {
 	pp->setBrush(Qt::NoBrush);
 	pp->setPen(QPen(Qt::black, 1.0 / m_viewMode.scale, Qt::DotLine, Qt::FlatCap, Qt::MiterJoin));
@@ -1316,7 +1348,7 @@ void Canvas::drawControlsFreehandLine(QPainter* pp)
 /**
   draws masterpage items of a specific layer
  */
-void Canvas::DrawMasterItems(ScPainter *painter, ScPage *page, ScLayer& layer, QRect clip)
+void Canvas::DrawMasterItems(ScPainter *painter, const ScPage *page, const ScLayer& layer, QRect clip)
 {
 	if ((m_viewMode.previewMode) && (!layer.isPrintable))
 		return;
@@ -1343,7 +1375,7 @@ void Canvas::DrawMasterItems(ScPainter *painter, ScPage *page, ScLayer& layer, Q
 		currItem = page->FromMaster.at(a);
 		if (currItem->m_layerID != layer.ID)
 			continue;
-		if ((currItem->OwnPage != -1) && (currItem->OwnPage != static_cast<int>(Mp->pageNr())))
+		if ((currItem->OwnPage != -1) && (currItem->OwnPage != Mp->pageNr()))
 			continue;
 		if ((m_viewMode.previewMode) && (!currItem->printEnabled()))
 			continue;
@@ -1416,7 +1448,7 @@ void Canvas::DrawMasterItems(ScPainter *painter, ScPage *page, ScLayer& layer, Q
 /**
   draws page items contained in a specific Layer
  */
-void Canvas::DrawPageItems(ScPainter *painter, ScLayer& layer, QRect clip, bool notesFramesPass)
+void Canvas::DrawPageItems(ScPainter *painter, const ScLayer& layer, QRect clip, bool notesFramesPass)
 {
 	if ((m_viewMode.previewMode) && (!layer.isPrintable))
 		return;
@@ -1429,10 +1461,10 @@ void Canvas::DrawPageItems(ScPainter *painter, ScLayer& layer, QRect clip, bool
 
 // 	qDebug()<<"Canvas::DrawPageItems"<<m_viewMode.forceRedraw<<m_viewMode.operItemSelecting;
 	FPoint orig = localToCanvas(clip.topLeft());
-	QRectF cullingArea (static_cast<int>(orig.x()), static_cast<int>(orig.y()), 
-	                    qRound(clip.width() / m_viewMode.scale + 0.5), qRound(clip.height() / m_viewMode.scale + 0.5));
+	QRectF cullingArea(static_cast<int>(orig.x()), static_cast<int>(orig.y()), 
+	                   qRound(clip.width() / m_viewMode.scale + 0.5), qRound(clip.height() / m_viewMode.scale + 0.5));
 
-	PageItem *currItem;
+	PageItem *currItem { nullptr };
 	int docCurrPageNo = m_doc->currentPageNumber();
 	if (((layer.blendMode != 0) || (layer.transparency != 1.0)) && (!layer.outlineMode))
 		painter->beginLayer(layer.transparency, layer.blendMode);
@@ -1555,11 +1587,10 @@ void Canvas::drawBackgroundPageOutlines(ScPainter* painter, int clipx, int clipy
 		painter->setBrush(QColor(128,128,128));
 		painter->setAntialiasing(false);
 		painter->setPen(Qt::black, 1.0 / m_viewMode.scale, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-		ScPage *actPg;
 		MarginStruct pageBleeds;
-		for (int a = 0; a < static_cast<int>(docPagesCount); ++a)
+		for (int a = 0; a < docPagesCount; ++a)
 		{
-			actPg = m_doc->Pages->at(a);
+			const ScPage* actPg = m_doc->Pages->at(a);
 			m_doc->getBleeds(actPg, pageBleeds);
 			if (m_viewMode.viewAsPreview)
 				pageBleeds.resetToZero();
@@ -1596,11 +1627,11 @@ void Canvas::drawBackgroundPageOutlines(ScPainter* painter, int clipx, int clipy
 		painter->setAntialiasing(true);
 	}
 	painter->setFillMode(ScPainter::Solid);
-	ScPage *actPg;
+
 	MarginStruct pageBleeds;
-	for (int a = 0; a < static_cast<int>(docPagesCount); ++a)
+	for (int a = 0; a < docPagesCount; ++a)
 	{
-		actPg = m_doc->Pages->at(a);
+		const ScPage* actPg = m_doc->Pages->at(a);
 		double x = actPg->xOffset();
 		double y = actPg->yOffset();
 		double w = actPg->width();
@@ -1702,8 +1733,8 @@ void Canvas::getClipPathForPages(FPointArray* PoLine)
 			0.0, 1.0, 0.0, 1.0, 0.0, 0.0, 0.0, 0.0};
 		for (int j = 0; j < 29; j += 4)
 		{
-			PoLine->addPoint(x + w * rect[j], y + h * rect[j+1]);
-			PoLine->addPoint(x + w * rect[j+2], y + h * rect[j+3]);
+			PoLine->addPoint(x + w * rect[j], y + h * rect[j + 1]);
+			PoLine->addPoint(x + w * rect[j + 2], y + h * rect[j + 3]);
 		}
 	}
 }
@@ -1711,7 +1742,7 @@ void Canvas::getClipPathForPages(FPointArray* PoLine)
 /**
   draws page border
   */
-void Canvas::DrawPageBorderSub(ScPainter *p, ScPage *page)
+void Canvas::DrawPageBorderSub(ScPainter *p, const ScPage *page)
 {
 	p->save();
 	p->setAntialiasing(false);
@@ -1731,7 +1762,7 @@ void Canvas::DrawPageBorder(ScPainter *p, const QRectF& clip, bool master)
 {
 	if (master)
 	{
-		ScPage *page = m_doc->currentPage();
+		const ScPage *page = m_doc->currentPage();
 		double x = m_doc->scratch()->left() * m_viewMode.scale;
 		double y = m_doc->scratch()->top() * m_viewMode.scale;
 		double w = page->width() * m_viewMode.scale;
@@ -1746,7 +1777,7 @@ void Canvas::DrawPageBorder(ScPainter *p, const QRectF& clip, bool master)
 		int docPagesCount = m_doc->Pages->count();
 		for (int a = 0; a < docPagesCount; ++a)
 		{
-			ScPage *page = m_doc->Pages->at(a);
+			const ScPage *page = m_doc->Pages->at(a);
 			QRectF drawRect(page->xOffset() * m_viewMode.scale, page->yOffset() * m_viewMode.scale, page->width() * m_viewMode.scale + 5, page->height() * m_viewMode.scale + 5);
 			drawRect.translate(-m_doc->minCanvasCoordinate.x() * m_viewMode.scale, -m_doc->minCanvasCoordinate.y() * m_viewMode.scale);
 			if (drawRect.intersects(clip))
@@ -1758,7 +1789,7 @@ void Canvas::DrawPageBorder(ScPainter *p, const QRectF& clip, bool master)
 /**
   draws margins
  */
-void Canvas::DrawPageMarginsGridSub(ScPainter *p, ScPage *page)
+void Canvas::DrawPageMarginsGridSub(ScPainter *p, const ScPage *page)
 {
 	p->save();
 	p->setAntialiasing(false);
@@ -1793,7 +1824,7 @@ void Canvas::DrawPageMargins(ScPainter *p, const QRectF& clip, bool master)
 {
 	if (master)
 	{
-		ScPage *page = m_doc->currentPage();
+		const ScPage *page = m_doc->currentPage();
 		double x = m_doc->scratch()->left() * m_viewMode.scale;
 		double y = m_doc->scratch()->top() * m_viewMode.scale;
 		double w = page->width() * m_viewMode.scale;
@@ -1808,7 +1839,7 @@ void Canvas::DrawPageMargins(ScPainter *p, const QRectF& clip, bool master)
 		int docPagesCount = m_doc->Pages->count();
 		for (int a = 0; a < docPagesCount; ++a)
 		{
-			ScPage *page = m_doc->Pages->at(a);
+			const ScPage *page = m_doc->Pages->at(a);
 			QRectF drawRect(page->xOffset() * m_viewMode.scale, page->yOffset() * m_viewMode.scale, page->width() * m_viewMode.scale + 5, page->height() * m_viewMode.scale + 5);
 			drawRect.translate(-m_doc->minCanvasCoordinate.x() * m_viewMode.scale, -m_doc->minCanvasCoordinate.y() * m_viewMode.scale);
 			if (drawRect.intersects(clip))
@@ -1820,7 +1851,7 @@ void Canvas::DrawPageMargins(ScPainter *p, const QRectF& clip, bool master)
 /**
   draws baseline grid
  */
-void Canvas::DrawPageBaselineGridSub(ScPainter *p, ScPage *page)
+void Canvas::DrawPageBaselineGridSub(ScPainter *p, const ScPage *page)
 {
 	if (!m_doc->guidesPrefs().baselineGridShown)
 		return;
@@ -1847,7 +1878,7 @@ void Canvas::DrawPageBaselineGrid(ScPainter *p, const QRectF& clip, bool master)
 
 	if (master)
 	{
-		ScPage *page = m_doc->currentPage();
+		const ScPage *page = m_doc->currentPage();
 		double x = m_doc->scratch()->left() * m_viewMode.scale;
 		double y = m_doc->scratch()->top() * m_viewMode.scale;
 		double w = page->width() * m_viewMode.scale;
@@ -1862,7 +1893,7 @@ void Canvas::DrawPageBaselineGrid(ScPainter *p, const QRectF& clip, bool master)
 		int docPagesCount = m_doc->Pages->count();
 		for (int a = 0; a < docPagesCount; ++a)
 		{
-			ScPage *page = m_doc->Pages->at(a);
+			const ScPage *page = m_doc->Pages->at(a);
 			QRectF drawRect(page->xOffset() * m_viewMode.scale, page->yOffset() * m_viewMode.scale, page->width() * m_viewMode.scale + 5, page->height() * m_viewMode.scale + 5);
 			drawRect.translate(-m_doc->minCanvasCoordinate.x() * m_viewMode.scale, -m_doc->minCanvasCoordinate.y() * m_viewMode.scale);
 			if (drawRect.intersects(clip))
@@ -1874,7 +1905,7 @@ void Canvas::DrawPageBaselineGrid(ScPainter *p, const QRectF& clip, bool master)
 /**
   draws grid
  */
-void Canvas::DrawPageGridSub(ScPainter *p, ScPage *page, const QRectF& clip)
+void Canvas::DrawPageGridSub(ScPainter *p, const ScPage *page, const QRectF& clip)
 {
 	if (!m_doc->guidesPrefs().gridShown)
 		return;
@@ -1975,7 +2006,7 @@ void Canvas::DrawPageGrid(ScPainter *p, const QRectF& clip, bool master)
 
 	if (master)
 	{
-		ScPage *page = m_doc->currentPage();
+		const ScPage *page = m_doc->currentPage();
 		double x = m_doc->scratch()->left() * m_viewMode.scale;
 		double y = m_doc->scratch()->top() * m_viewMode.scale;
 		double w = page->width() * m_viewMode.scale;
@@ -1990,7 +2021,7 @@ void Canvas::DrawPageGrid(ScPainter *p, const QRectF& clip, bool master)
 		int docPagesCount = m_doc->Pages->count();
 		for (int a = 0; a < docPagesCount; ++a)
 		{
-			ScPage *page = m_doc->Pages->at(a);
+			const ScPage *page = m_doc->Pages->at(a);
 			QRectF drawRect(page->xOffset() * m_viewMode.scale, page->yOffset() * m_viewMode.scale, page->width() * m_viewMode.scale + 5, page->height() * m_viewMode.scale + 5);
 			drawRect.translate(-m_doc->minCanvasCoordinate.x() * m_viewMode.scale, -m_doc->minCanvasCoordinate.y() * m_viewMode.scale);
 			if (drawRect.intersects(clip))
@@ -2002,7 +2033,7 @@ void Canvas::DrawPageGrid(ScPainter *p, const QRectF& clip, bool master)
 /**
   draws guides
  */
-void Canvas::DrawPageGuidesSub(ScPainter *p, ScPage *page)
+void Canvas::DrawPageGuidesSub(ScPainter *p, const ScPage *page)
 {
 	if (!m_doc->guidesPrefs().guidesShown)
 		return;
@@ -2026,7 +2057,7 @@ void Canvas::DrawPageGuides(ScPainter *p, const QRectF& clip, bool master)
 
 	if (master)
 	{
-		ScPage *page = m_doc->currentPage();
+		const ScPage *page = m_doc->currentPage();
 		double x = m_doc->scratch()->left() * m_viewMode.scale;
 		double y = m_doc->scratch()->top() * m_viewMode.scale;
 		double w = page->width() * m_viewMode.scale;
@@ -2041,7 +2072,7 @@ void Canvas::DrawPageGuides(ScPainter *p, const QRectF& clip, bool master)
 		int docPagesCount = m_doc->Pages->count();
 		for (int a = 0; a < docPagesCount; ++a)
 		{
-			ScPage *page = m_doc->Pages->at(a);
+			const ScPage *page = m_doc->Pages->at(a);
 			QRectF drawRect(page->xOffset() * m_viewMode.scale, page->yOffset() * m_viewMode.scale, page->width() * m_viewMode.scale + 5, page->height() * m_viewMode.scale + 5);
 			drawRect.translate(-m_doc->minCanvasCoordinate.x() * m_viewMode.scale, -m_doc->minCanvasCoordinate.y() * m_viewMode.scale);
 			if (drawRect.intersects(clip))
@@ -2053,7 +2084,7 @@ void Canvas::DrawPageGuides(ScPainter *p, const QRectF& clip, bool master)
 /**
   draws actual page indicator frame
  */
-void Canvas::DrawPageIndicatorSub(ScPainter *p, ScPage *page)
+void Canvas::DrawPageIndicatorSub(ScPainter *p, const ScPage *page)
 {
 	p->save();
 	int fm = p->fillMode();
@@ -2076,7 +2107,7 @@ void Canvas::DrawPageIndicator(ScPainter *p, const QRectF& clip, bool master)
 {
 	if (master)
 	{
-		ScPage *page = m_doc->currentPage();
+		const ScPage *page = m_doc->currentPage();
 		double x = m_doc->scratch()->left() * m_viewMode.scale;
 		double y = m_doc->scratch()->top() * m_viewMode.scale;
 		double w = page->width() * m_viewMode.scale;
@@ -2091,7 +2122,7 @@ void Canvas::DrawPageIndicator(ScPainter *p, const QRectF& clip, bool master)
 		int docPagesCount = m_doc->Pages->count();
 		for (int a = 0; a < docPagesCount; ++a)
 		{
-			ScPage *page = m_doc->Pages->at(a);
+			const ScPage *page = m_doc->Pages->at(a);
 			if (page == m_doc->currentPage())
 			{
 				QRectF drawRect(page->xOffset() * m_viewMode.scale, page->yOffset() * m_viewMode.scale, page->width() * m_viewMode.scale + 5, page->height() * m_viewMode.scale + 5);
@@ -2139,7 +2170,7 @@ void Canvas::drawFrameLinks(ScPainter* painter)
 			}
 		}
 	}
-	else if ((((m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames)) && (currItem != nullptr)))
+	else if (((m_doc->appMode == modeLinkFrames) || (m_doc->appMode == modeUnlinkFrames)) && (currItem != nullptr))
 	{
 		PageItem *nextItem = currItem->firstInChain();
 		while (nextItem != nullptr)
@@ -2162,7 +2193,7 @@ void Canvas::drawFrameLinks(ScPainter* painter)
 /**
   draws one linkline between textframes
   */
-void Canvas::drawLinkFrameLine(ScPainter* painter, FPoint &start, FPoint &end)
+void Canvas::drawLinkFrameLine(ScPainter* painter, const FPoint &start, const FPoint &end)
 {
 	//CB FIXME Add some checking that the painter is setup?
 	Q_ASSERT(painter != nullptr);
@@ -2232,26 +2263,26 @@ void Canvas::getGroupRectScreen(double *x, double *y, double *w, double *h)
 	QPoint out = contentsToViewport(in);
 	*x = static_cast<double>(out.x());
 	*y = static_cast<double>(out.y());
-	*w = gw* m_viewMode.scale;
-	*h = gh* m_viewMode.scale;
+	*w = gw * m_viewMode.scale;
+	*h = gh * m_viewMode.scale;
 }
 
 
-void Canvas::Transform(PageItem *currItem, QPainter *p)
+void Canvas::Transform(const PageItem *currItem, QPainter *p) const
 {
 	p->translate(currItem->xPos()*m_viewMode.scale, currItem->yPos()*m_viewMode.scale);
 	p->scale(m_viewMode.scale, m_viewMode.scale);
 	p->rotate(currItem->rotation());
 }
 
-void Canvas::Transform(PageItem *currItem, QTransform& m)
+void Canvas::Transform(const PageItem *currItem, QTransform& m) const
 {
 	m.translate(currItem->xPos()*m_viewMode.scale, currItem->yPos()*m_viewMode.scale);
 	m.scale(m_viewMode.scale, m_viewMode.scale);
 	m.rotate(currItem->rotation());
 }
 
-void Canvas::TransformM(PageItem *currItem, QPainter *p)
+void Canvas::TransformM(const PageItem *currItem, QPainter *p) const
 {
 	if (currItem->imageFlippedH())
 	{
@@ -2265,7 +2296,7 @@ void Canvas::TransformM(PageItem *currItem, QPainter *p)
 	}
 }
 
-void Canvas::calculateFrameLinkPoints(PageItem *pi1, PageItem *pi2, FPoint & start, FPoint & end)
+void Canvas::calculateFrameLinkPoints(const PageItem *pi1, const PageItem *pi2, FPoint & start, FPoint & end)
 {
 	if (pi1 == nullptr || pi2 == nullptr)
 		return;
@@ -2350,7 +2381,7 @@ void Canvas::calculateFrameLinkPoints(PageItem *pi1, PageItem *pi2, FPoint & sta
 	if (x21 > x12) { a1 = x12; a2 = x21; }
 	if (y22 < y11) { b1 = y11; b2 = y22; }
 	if (y21 > y12) { b1 = y12; b2 = y21; }
-
+					
 	if (x21 < x12 && x21 > x11) { a1 = x1mid; a2 = x2mid; }
 	if (x21 < x11 && x22 > x11) { a1 = x1mid; a2 = x2mid; }
 
@@ -2384,7 +2415,7 @@ void Canvas::drawPixmap(QPainter& painter, double x, double y, const QPixmap& pi
 	painter.drawPixmap(x, y, pixmap, sx, sy, sw, sh);
 }
 
-void Canvas::displayXYHUD(QPoint m)
+void Canvas::displayXYHUD(QPointF m)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
@@ -2429,7 +2460,7 @@ void Canvas::displayXYHUD(QPoint m)
 	displayXYHUD(m, gx, gy);
 }
 
-void Canvas::displayCorrectedXYHUD(QPoint m, double x, double y)
+void Canvas::displayCorrectedXYHUD(QPointF m, double x, double y)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
@@ -2442,10 +2473,12 @@ void Canvas::displayCorrectedXYHUD(QPoint m, double x, double y)
 	}
 	gx -= m_doc->rulerXoffset;
 	gy -= m_doc->rulerYoffset;
-	QToolTip::showText(m + QPoint(5, 5), tr("X: %1\nY: %2").arg(value2String(gx, m_doc->unitIndex(), true, true), value2String(gy, m_doc->unitIndex(), true, true)), this);
+
+	QPointF tooltipPos = m + QPointF(5.0, 5.0);
+	QToolTip::showText(tooltipPos.toPoint(), tr("X: %1\nY: %2").arg(value2String(gx, m_doc->unitIndex(), true, true), value2String(gy, m_doc->unitIndex(), true, true)), this);
 }
 
-void Canvas::displayCorrectedSingleHUD(QPoint m, double val, bool isX)
+void Canvas::displayCorrectedSingleHUD(QPointF m, double val, bool isX)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
@@ -2455,35 +2488,41 @@ void Canvas::displayCorrectedSingleHUD(QPoint m, double val, bool isX)
 		if (m_doc->guidesPrefs().rulerMode)
 			gx -= m_doc->currentPage()->xOffset();
 		gx -= m_doc->rulerXoffset;
-		QToolTip::showText(m + QPoint(5, 5), tr("X: %1").arg(value2String(gx, m_doc->unitIndex(), true, true)), this);
+		QPointF tooltipPos = m + QPointF(5.0, 5.0);
+		QToolTip::showText(tooltipPos.toPoint(), tr("X: %1").arg(value2String(gx, m_doc->unitIndex(), true, true)), this);
 	}
 	else
 	{
 		if (m_doc->guidesPrefs().rulerMode)
 			gx -= m_doc->currentPage()->yOffset();
 		gx -= m_doc->rulerYoffset;
-		QToolTip::showText(m + QPoint(5, 5), tr("Y: %1").arg(value2String(gx, m_doc->unitIndex(), true, true)), this);
+		QPointF tooltipPos = m + QPointF(5.0, 5.0);
+		QToolTip::showText(tooltipPos.toPoint(), tr("Y: %1").arg(value2String(gx, m_doc->unitIndex(), true, true)), this);
 	}
 }
 
-void Canvas::displayXYHUD(QPoint m, double x, double y)
+void Canvas::displayXYHUD(QPointF m, double x, double y)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
-	QToolTip::showText(m + QPoint(5, 5), tr("X: %1\nY: %2").arg(value2String(x, m_doc->unitIndex(), true, true), value2String(y, m_doc->unitIndex(), true, true)), this);
+
+	QPointF tooltipPos = m + QPointF(5.0, 5.0);
+	QToolTip::showText(tooltipPos.toPoint(), tr("X: %1\nY: %2").arg(value2String(x, m_doc->unitIndex(), true, true), value2String(y, m_doc->unitIndex(), true, true)), this);
 }
 
-void Canvas::displaySizeHUD(QPoint m, double x, double y, bool isLine)
+void Canvas::displaySizeHUD(QPointF m, double x, double y, bool isLine)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
+
+	QPointF tooltipPos = m + QPointF(5.0, 5.0);
 	if (isLine)
-		QToolTip::showText(m + QPoint(5, 5), tr("Length: %1\nAngle: %2").arg(value2String(x, m_doc->unitIndex(), true, true), value2String(y, SC_DEGREES, true, true)), this);
+		QToolTip::showText(tooltipPos.toPoint(), tr("Length: %1\nAngle: %2").arg(value2String(x, m_doc->unitIndex(), true, true), value2String(y, SC_DEGREES, true, true)), this);
 	else
-		QToolTip::showText(m + QPoint(5, 5), tr("Width: %1\nHeight: %2").arg(value2String(x, m_doc->unitIndex(), true, true), value2String(y, m_doc->unitIndex(), true, true)), this);
+		QToolTip::showText(tooltipPos.toPoint(), tr("Width: %1\nHeight: %2").arg(value2String(x, m_doc->unitIndex(), true, true), value2String(y, m_doc->unitIndex(), true, true)), this);
 }
 
-void Canvas::displayRotHUD(QPoint m, double rot)
+void Canvas::displayRotHUD(QPointF m, double rot)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
@@ -2492,21 +2531,24 @@ void Canvas::displayRotHUD(QPoint m, double rot)
 		r = rot * -1.0;
 	else
 		r = 360.0 - rot;
-	QToolTip::showText(m + QPoint(5, 5), tr("Angle: %1").arg(value2String(r, SC_DEGREES, true, true)), this);
+	QPointF tooltipPos = m + QPointF(5.0, 5.0);
+	QToolTip::showText(tooltipPos.toPoint(), tr("Angle: %1").arg(value2String(r, SC_DEGREES, true, true)), this);
 }
 
-void Canvas::displayRealRotHUD(QPoint m, double rot)
+void Canvas::displayRealRotHUD(QPointF m, double rot)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
-	QToolTip::showText(m + QPoint(5, 5), tr("Angle: %1").arg(value2String(rot, SC_DEGREES, true, true)), this);
+	QPointF tooltipPos = m + QPointF(5.0, 5.0);
+	QToolTip::showText(tooltipPos.toPoint(), tr("Angle: %1").arg(value2String(rot, SC_DEGREES, true, true)), this);
 }
 
-void Canvas::displayDoubleHUD(QPoint point, const QString& label, double value)
+void Canvas::displayDoubleHUD(QPointF point, const QString& label, double value)
 {
 	if (!PrefsManager::instance().appPrefs.displayPrefs.showMouseCoordinates)
 		return;
-	QToolTip::showText(point + QPoint(5, 5), QString("%1: %2").arg(label, value2String(value, m_doc->unitIndex(), true, true)), this);
+	QPointF tooltipPos = point + QPointF(5.0, 5.0);
+	QToolTip::showText(tooltipPos.toPoint(), QString("%1: %2").arg(label, value2String(value, m_doc->unitIndex(), true, true)), this);
 }
 
 void Canvas::setupEditHRuler(PageItem * item, bool forceAndReset)
