@@ -16,12 +16,10 @@
 #include <QEvent>
 #include <QMouseEvent>
 
-#include "canvasgesture_pan.h"
-
 #include "canvas.h"
-#include "scribusapp.h" // for qApp
-#include "scribusview.h"
+#include "canvasgesture_pan.h"
 #include "iconmanager.h"
+#include "scribusview.h"
 
 PanGesture::PanGesture (CanvasMode* parent) : CanvasGesture(parent)
 {
@@ -29,13 +27,15 @@ PanGesture::PanGesture (CanvasMode* parent) : CanvasGesture(parent)
 
 void PanGesture::activate(bool fromGesture)
 {
+	CanvasGesture::activate(fromGesture);
 	m_cursor = m_view->cursor();
 	m_view->setCursor(IconManager::instance().loadCursor("handc.png"));
 }
 
-void PanGesture::deactivate(bool forgesture)
+void PanGesture::deactivate(bool forGesture)
 {
 	m_view->setCursor(m_cursor);
+	CanvasGesture::deactivate(forGesture);
 }
 
 void PanGesture::drawControls(QPainter* p)
@@ -45,20 +45,20 @@ void PanGesture::drawControls(QPainter* p)
 
 void PanGesture::mousePressEvent(QMouseEvent* m)
 {
-	FPoint m_canvasPoint = m_canvas->globalToCanvas(m->globalPos());
+	FPoint m_canvasPoint = m_canvas->globalToCanvas(m->globalPosition());
 	m_canvasRefPoint = QPointF(m_canvasPoint.x(), m_canvasPoint.y());
 }
 
 void PanGesture::mouseMoveEvent(QMouseEvent* m)
 {
-	FPoint m_canvasPoint = m_canvas->globalToCanvas(m->globalPos());
+	FPoint m_canvasPoint = m_canvas->globalToCanvas(m->globalPosition());
 	double scale = m_canvas->scale();
 	double dx = (m_canvasRefPoint.x() - m_canvasPoint.x()) * scale;
 	double dy = (m_canvasRefPoint.y() - m_canvasPoint.y()) * scale;
 	m_view->scrollBy(dx, dy);
 }
 
-void PanGesture::mouseReleaseEvent(QMouseEvent* m)
+void PanGesture::mouseReleaseEvent(QMouseEvent* /*m*/)
 {
 	m_view->stopGesture();
 }
