@@ -122,7 +122,7 @@ void ResizeGesture::deactivate(bool forGesture)
 
 void ResizeGesture::drawControls(QPainter* p) 
 {
-	QColor drawColor = qApp->palette().color(QPalette::Active, QPalette::Highlight);
+	QColor drawColor = QApplication::palette().color(QPalette::Active, QPalette::Highlight);
 
 	QRectF localRect = m_canvas->canvasToLocal(m_bounds.normalized());
 	if (m_doc->m_Selection->isMultipleSelection())
@@ -146,7 +146,7 @@ void ResizeGesture::drawControls(QPainter* p)
 		if (m_doc->m_Selection->count() == 1)
 		{
 			p->setBrush(Qt::NoBrush);
-			QPen out = QPen(Qt::gray, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+			QPen out(Qt::gray, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
 			out.setCosmetic(true);
 			p->setPen(out);
 			PageItem *currItem = m_doc->m_Selection->itemAt(0);
@@ -176,7 +176,7 @@ void ResizeGesture::drawControls(QPainter* p)
 			double scx = localRect.width() / w;
 			double scy = localRect.height() / h;
 			uint docSelectionCount = m_doc->m_Selection->count();
-			if (docSelectionCount < m_canvas->moveWithBoxesOnlyThreshold)
+			if (docSelectionCount < Canvas::moveWithBoxesOnlyThreshold)
 			{
 				PageItem *currItem;
 				for (uint a = 0; a < docSelectionCount; ++a)
@@ -217,7 +217,7 @@ void ResizeGesture::mouseReleaseEvent(QMouseEvent *m)
 		//add action itemResizeToMargin for right click on item`s handlers
 		else if (m->button() == Qt::RightButton)
 		{
-			const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+			const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 			Canvas::FrameHandle fh = m_canvas->frameHitTest(QPointF(mousePointDoc.x(),mousePointDoc.y()), currItem);
 			m_doc->itemResizeToMargin(currItem, fh);
 		}
@@ -231,6 +231,7 @@ void ResizeGesture::mouseReleaseEvent(QMouseEvent *m)
 			m_doc->invalidateRegion(m_mousePressBounds.united(m_bounds));
 			m_doc->regionsChanged()->update(m_mousePressBounds.united(m_bounds));
 			m_doc->changed();
+			m_doc->changedPagePreview();
 		}
 	}
 	if (m_transaction.isStarted())
@@ -273,8 +274,8 @@ void ResizeGesture::doResize(bool scaleContent)
 	}
 	if (m_doc->m_Selection->isMultipleSelection())
 	{
-		int oldRotMode = m_doc->rotationMode();
-		m_doc->setRotationMode ( 0 );
+		AnchorPoint oldRotMode = m_doc->rotationMode();
+		m_doc->setRotationMode ( AnchorPoint::TopLeft );
 		double gx, gy, gh, gw;
 		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
 		QRectF oldBounds(gx, gy, gw, gh);
@@ -431,7 +432,7 @@ void ResizeGesture::doResize(bool scaleContent)
 void ResizeGesture::mouseMoveEvent(QMouseEvent *m)
 {
 	adjustBounds(m);
-	FPoint where = m_canvas->globalToCanvas(m->globalPos());
+	FPoint where = m_canvas->globalToCanvas(m->globalPosition());
 	if (// directly after a create the shape of an item isn't really usable, so we fix here
 		m_origBounds.width() < 20 || m_origBounds.height() < 20 ||
 		// and if we resize outside of the current canvas dimensions, we need to enlarge it
@@ -441,11 +442,11 @@ void ResizeGesture::mouseMoveEvent(QMouseEvent *m)
 		doResize(m->modifiers() & Qt::AltModifier);
 	}
 	m->accept();
-	QPoint point = m->globalPos() - (m_canvas->mapToParent(QPoint(0, 0)) + m_canvas->parentWidget()->mapToGlobal(QPoint(0, 0)));
-	m_view->ensureVisible(point.x(), point.y(), 20, 20);
-	m_canvas->repaint();
+	QPointF point = m->globalPosition() - (m_canvas->mapToParent(QPointF(0, 0)) + m_canvas->parentWidget()->mapToGlobal(QPointF(0, 0)));
+	m_view->ensureVisible(qRound(point.x()), qRound(point.y()), 20, 20);
+	m_canvas->update();
 	QRectF newBounds = m_bounds.normalized();
-	m_canvas->displaySizeHUD(m->globalPos(), newBounds.width() - m_extraWidth, newBounds.height() - m_extraHeight);
+	m_canvas->displaySizeHUD(m->globalPosition(), newBounds.width() - m_extraWidth, newBounds.height() - m_extraHeight);
 }
 
 
@@ -453,7 +454,7 @@ void ResizeGesture::mouseMoveEvent(QMouseEvent *m)
 void ResizeGesture::adjustBounds(QMouseEvent *m)
 {
 	QTransform rotation;
-	FPoint docPoint = m_canvas->globalToCanvas(m->globalPos());
+	FPoint docPoint = m_canvas->globalToCanvas(m->globalPosition());
 
 	// proportional resize
 	bool constrainRatio = ((m->modifiers() & Qt::ControlModifier) != Qt::NoModifier);
@@ -462,7 +463,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 	bool centerPivot = ((m->modifiers() & Qt::ShiftModifier) != Qt::NoModifier);
 
 /*
-	if (m_mousePressPoint == m->globalPos())
+	if (m_mousePressPoint == m->globalPosition())
 	{
 		m_bounds = m_mousePressBounds;
 		return;
@@ -493,7 +494,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 			docPoint = FPoint(x, docPoint.y());
 		else 
 			docPoint = FPoint(x,y);
-//		qDebug() << "resize snap grid/guides:" << m->globalPos() << "-->" << m_canvas->canvasToGlobal(docPoint);
+//		qDebug() << "resize snap grid/guides:" << m->globalPosition() << "-->" << m_canvas->canvasToGlobal(docPoint);
 	}
 	
 	// un-rotate point
@@ -505,7 +506,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 		rotation.rotate(m_rotation);
 		rotation.translate(-normalizedBounds.x(), -normalizedBounds.y());
 //		qDebug() << "resize rotated" << m_rotation << "°" << m_bounds << rotation << ":" << point-globalBounds.topLeft() << "-->" << rotation.map(point)-globalBounds.topLeft();
-		QPointF qp(docPoint.x(), docPoint.y());
+		QPointF qp = QPointF(docPoint.x(), docPoint.y());
 		qp = rotation.inverted().map(qp);
 		docPoint = FPoint(qp.x(), qp.y());
 	}
@@ -948,8 +949,8 @@ FPoint ResizeGesture::applyGuides(const FPoint& docPoint)
 
 void ResizeGesture::mousePressEvent(QMouseEvent *m)
 {
-	FPoint point = m_canvas->globalToCanvas(m->globalPos());
-	m_mousePressPoint = m->globalPos();
+	FPoint point = m_canvas->globalToCanvas(m->globalPosition());
+	m_mousePressPoint = m->globalPosition();
 	if (m_doc->m_Selection->isEmpty())
 	{
 		m_handle = Canvas::OUTSIDE;
