@@ -52,16 +52,12 @@
 #include "prefsmanager.h"
 #include "selection.h"
 #include "sccolorengine.h"
-#include "scpainter.h"
 #include "scraction.h"
 #include "scribus.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
-#include "ui/checkDocument.h"
 #include "ui/contextmenu.h"
-#include "ui/outlinepalette.h"
 #include "ui/pageselector.h"
-#include "ui/scrapbookpalette.h"
 #include "ui/scrspinbox.h"
 #include "ui/scresizecursor.h"
 #include "undomanager.h"
@@ -80,22 +76,7 @@ CanvasMode::CanvasMode (ScribusView* view) :
 	m_doc(view->m_doc),
 	undoManager(UndoManager::instance())
 {
-	m_pen["outline"]	= QPen(Qt::gray, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["outline"].setCosmetic(true);
-	m_pen["selection"]	= QPen(PrefsManager::instance().appPrefs.displayPrefs.frameColor, 1.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["selection"].setCosmetic(true);
-	m_pen["selection-group"] = QPen(Qt::red, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["selection-group"].setCosmetic(true);
-	m_pen["selection-group-inside"] = QPen(PrefsManager::instance().appPrefs.displayPrefs.frameGroupColor, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["selection-group-inside"].setCosmetic(true);
-	m_pen["handle"]		= QPen(PrefsManager::instance().appPrefs.displayPrefs.frameColor, 1.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["handle"].setCosmetic(true);
-	
-	m_brush["outline"]	= Qt::NoBrush;
-	m_brush["selection"]	= Qt::NoBrush;
-	m_brush["selection-group"] = QColor(255,0,0,10);
-	m_brush["selection-group-inside"] = Qt::NoBrush;
-	m_brush["handle"]	= PrefsManager::instance().appPrefs.displayPrefs.frameColor;
+	setStyle();
 }
 
 CanvasMode::~CanvasMode()
@@ -206,6 +187,7 @@ CanvasMode* CanvasMode::createForAppMode(ScribusView* view, int appMode)
 			result = new CanvasMode_Normal(view);
 			break;
 	}
+
 	return result;
 }
 
@@ -218,58 +200,38 @@ void CanvasMode::updateViewMode(CanvasViewMode* viewmode)
 
 void CanvasMode::drawSelectionHandles(QPainter *psx, QRectF selectionRect, bool background, bool insideGroup, double sx, double sy)
 {
-	m_pen["handle"]		= QPen(PrefsManager::instance().appPrefs.displayPrefs.frameColor, 1.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["handle"].setCosmetic(true);
-	m_pen["selection-group-inside"] = QPen(PrefsManager::instance().appPrefs.displayPrefs.frameGroupColor, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["selection-group-inside"].setCosmetic(true);
-	QPen ba = QPen(Qt::white, 3.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	ba.setCosmetic(true);
-	double markWidth = 4.0 / m_canvas->scale();
-	if (insideGroup)
-		markWidth /= qMax(sx, sy);
-	QRectF handleRect = QRectF(0, 0, markWidth, markWidth);
+//	double markWidth = 4.0 / m_canvas->scale();
+//	if (insideGroup)
+//		markWidth /= qMax(sx, sy);
+//	QRectF handleRect(0, 0, markWidth, markWidth);
 	double x = selectionRect.x();
 	double y = selectionRect.y();
 	double w = selectionRect.width();
 	double h = selectionRect.height();
-	psx->setBrush(Qt::white);
-	if (background)
-		psx->setPen(ba);
-	else
-	{
+//	psx->setBrush(Qt::white);
+
+	QPen p = m_pen["selection-handle"];
+
+//	if (background)
+//		p = m_pen["frame-outline"];
+//	else
+//	{
 		if (insideGroup)
-			psx->setPen(m_pen["selection-group-inside"]);
-		else
-			psx->setPen(m_pen["handle"]);
-	}
-	handleRect.moveCenter(QPointF(x, y));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x+w/2.0, y));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x+w, y));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x+w, y+h/2.0));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x+w, y+h));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x+w/2.0, y+h));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x, y+h));
-	psx->drawRect(handleRect);
-	handleRect.moveCenter(QPointF(x, y+h/2.0));
-	psx->drawRect(handleRect);
+			p = m_pen["selection-group-inside"];
+//	}
+
+	drawSelectionHandle(psx, QPointF(x, y), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x+w/2.0, y), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x+w, y), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x+w, y+h/2.0), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x+w, y+h), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x+w/2.0, y+h), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x, y+h), p, m_canvas->scale());
+	drawSelectionHandle(psx, QPointF(x, y+h/2.0), p, m_canvas->scale());
 }
 
 void CanvasMode::drawSelection(QPainter* psx, bool drawHandles)
 {
-	m_pen["selection"]	= QPen(PrefsManager::instance().appPrefs.displayPrefs.frameColor, 1.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["selection"].setCosmetic(true);
-	m_pen["selection-group-inside"] = QPen(PrefsManager::instance().appPrefs.displayPrefs.frameGroupColor, 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	m_pen["selection-group-inside"].setCosmetic(true);
-	QPen ba = QPen(Qt::white, 3.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	ba.setCosmetic(true);
-	QPen bb = QPen(Qt::black, 1.0, Qt::DotLine, Qt::FlatCap, Qt::MiterJoin);
-	bb.setCosmetic(true);
 	psx->scale(m_canvas->scale(), m_canvas->scale());
 	psx->translate(-m_doc->minCanvasCoordinate.x(), -m_doc->minCanvasCoordinate.y());
 	psx->setClipping(true);
@@ -312,9 +274,9 @@ void CanvasMode::drawSelection(QPainter* psx, bool drawHandles)
 					x = 0;
 					y = 0;
 				}
-				psx->setBrush(Qt::NoBrush);
-				psx->setPen(ba);
-				psx->drawRect(QRectF(x, y, w, h));
+//				psx->setBrush(Qt::NoBrush);
+//				psx->setPen(m_pen["frame-outline"]);
+//				psx->drawRect(QRectF(x, y, w, h));
 				psx->setPen(m_pen["selection-group-inside"]);
 				psx->setBrush(m_brush["selection-group-inside"]);
 				psx->drawRect(QRectF(x, y, w, h));
@@ -330,11 +292,11 @@ void CanvasMode::drawSelection(QPainter* psx, bool drawHandles)
 		x = 0;
 		y = 0;
 
-		psx->setBrush(Qt::NoBrush);
-		psx->setPen(ba);
-		psx->drawRect(QRectF(x, y, w, h));
-		if (drawHandles)
-			drawSelectionHandles(psx, QRectF(x, y, w, h), true);
+//		psx->setBrush(Qt::NoBrush);
+//		psx->setPen(m_pen["frame-outline"]);
+//		psx->drawRect(QRectF(x, y, w, h));
+//		if (drawHandles)
+//			drawSelectionHandles(psx, QRectF(x, y, w, h), true);
 		psx->setPen(m_pen["selection-group"]);
 		psx->setBrush(m_brush["selection-group"]);
 		psx->drawRect(QRectF(x, y, w, h));
@@ -363,23 +325,23 @@ void CanvasMode::drawSelection(QPainter* psx, bool drawHandles)
 				h = currItem->visualHeight();
 				x = currItem->asLine() ? 0 : (-currItem->visualLineWidth() / 2.0);
 				y = -currItem->visualLineWidth() / 2.0;
-				psx->setBrush(Qt::NoBrush);
+//				psx->setBrush(Qt::NoBrush);
 				QRectF drRect = QRectF(x, y, w, h).normalized();
 				if (m_doc->drawAsPreview && !m_doc->editOnPreview)
 				{
 					if (!currItem->annotation().IsOpen())
 					{
-						psx->setPen(bb);
+						psx->setPen(m_pen["frame-preview"]);
 						psx->setBrush(Qt::NoBrush);
 						psx->drawRect(drRect.adjusted(-1, -1, 1, 1));
 					}
 				}
 				else
 				{
-					psx->setPen(ba);
-					psx->drawRect(drRect);
-					if (drawHandles)
-						drawSelectionHandles(psx, QRectF(x, y, w, h), true, true, sx, sy);
+//					psx->setPen(m_pen["frame-outline"]);
+//					psx->drawRect(drRect);
+//					if (drawHandles)
+//						drawSelectionHandles(psx, QRectF(x, y, w, h), true, true, sx, sy);
 					psx->setPen(m_pen["selection-group-inside"]);
 					psx->setBrush(m_brush["selection-group-inside"]);
 					psx->drawRect(drRect);
@@ -405,22 +367,22 @@ void CanvasMode::drawSelection(QPainter* psx, bool drawHandles)
 					x = 0;
 					y = 0;
 				}
-				psx->setBrush(Qt::NoBrush);
+//				psx->setBrush(Qt::NoBrush);
 				if (m_doc->drawAsPreview && !m_doc->editOnPreview)
 				{
 					if (!currItem->annotation().IsOpen())
 					{
-						psx->setPen(bb);
+						psx->setPen(m_pen["frame-preview"]);
 						psx->setBrush(Qt::NoBrush);
 						psx->drawRect(QRectF(x, y, w, h).adjusted(-1, -1, 1, 1));
 					}
 				}
 				else
 				{
-					psx->setPen(ba);
-					psx->drawRect(QRectF(x, y, w, h));
-					if (drawHandles && !currItem->locked() && !currItem->isLine())
-						drawSelectionHandles(psx, QRectF(x, y, w, h), true);
+//					psx->setPen(m_pen["frame-outline"]);
+//					psx->drawRect(QRectF(x, y, w, h));
+//					if (drawHandles && !currItem->locked() && !currItem->isLine())
+//						drawSelectionHandles(psx, QRectF(x, y, w, h), true);
 					psx->setPen(m_pen["selection"]);
 					psx->setBrush(m_brush["selection"]);
 					psx->drawRect(QRectF(x, y, w, h));
@@ -429,26 +391,19 @@ void CanvasMode::drawSelection(QPainter* psx, bool drawHandles)
 				{
 					if (currItem->isLine())
 					{
-						const double markWidth = 4.0 / m_canvas->scale();
-						QRectF handleRect = QRectF(0, 0, markWidth, markWidth);
 						psx->setRenderHint(QPainter::Antialiasing);
-						psx->setBrush(Qt::white);
-						psx->setPen(m_pen["handle"]);
-						handleRect.moveCenter(QPointF(x, y + h / 2.0));
-						psx->drawRect(handleRect);
-						handleRect.moveCenter(QPointF(x + w, y + h / 2.0));
-						psx->drawRect(handleRect);
+						drawSelectionHandle(psx, QPointF(x, y + h / 2.0), m_pen["selection-handle"], m_canvas->scale());
+						drawSelectionHandle(psx, QPointF(x + w, y + h / 2.0), m_pen["selection-handle"], m_canvas->scale());
 					}
 					else
 						drawSelectionHandles(psx, QRectF(x, y, w, h), false);
 				}
 				if (currItem->isWelded())
 				{
-					psx->setPen(QPen(Qt::yellow, 8.0 / m_canvas->scale(), Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
 					for (int i = 0 ; i <  currItem->weldList.count(); i++)
 					{
 						PageItem::WeldingInfo wInf =  currItem->weldList.at(i);
-						psx->drawPoint(QPointF(wInf.weldPoint.x(), wInf.weldPoint.y()));
+						drawWeldMarker(psx, QPointF(wInf.weldPoint.x(), wInf.weldPoint.y()), m_color["weld"], m_canvas->scale());
 					}
 				}
 			}
@@ -502,8 +457,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 			if (currItem->isGroup())
 			{
 				p->save();
-				p->setBrush(m_brush["outline"]);
-				p->setPen(m_pen["outline"]);
+				p->setBrush(m_brush["frame-move"]);
+				p->setPen(m_pen["frame-move"]);
 				p->setWorldTransform(itemTrans, true);
 				if (matRot != 0)
 					p->setRenderHint(QPainter::Antialiasing);
@@ -512,7 +467,7 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 				p->setClipRect(QRectF(0.0, 0.0, visualWidth, visualHeight));
 				PageItem_Group* gItem = currItem->asGroupFrame();
 				int itemCountG = gItem->groupItemList.count();
-				if (itemCountG < m_canvas->moveWithFullOutlinesThreshold)
+				if (itemCountG < Canvas::moveWithFullOutlinesThreshold)
 				{
 					if (gItem->imageFlippedH())
 					{
@@ -548,8 +503,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 			else
 			{
 				p->save();
-				p->setBrush(m_brush["outline"]);
-				p->setPen(m_pen["outline"]);
+				p->setBrush(m_brush["frame-move"]);
+				p->setPen(m_pen["frame-move"]);
 				p->setWorldTransform(itemTrans, true);
 				if (matRot != 0)
 					p->setRenderHint(QPainter::Antialiasing);
@@ -560,8 +515,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 				p->restore();
 
 				p->save();
-				p->setBrush(m_brush["outline"]);
-				p->setPen(m_pen["outline"]);
+				p->setBrush(m_brush["frame-move"]);
+				p->setPen(m_pen["frame-move"]);
 				p->setWorldTransform(itemTrans, true);
 				if (matRot != 0)
 					p->setRenderHint(QPainter::Antialiasing);
@@ -575,7 +530,7 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 		double x, y, w, h;
 		m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 		int docSelectionCount = m_doc->m_Selection->count();
-		if (docSelectionCount < m_canvas->moveWithBoxesOnlyThreshold)
+		if (docSelectionCount < Canvas::moveWithBoxesOnlyThreshold)
 		{
 			PageItem *currItem;
 			for (int i = 0; i < docSelectionCount; ++i)
@@ -593,7 +548,7 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 				double matRot = getRotationDFromMatrix(itemTrans);
 
 				p->save();
-				if (docSelectionCount < m_canvas->moveWithFullOutlinesThreshold)
+				if (docSelectionCount < Canvas::moveWithFullOutlinesThreshold)
 				{
 //					QRectF br(currItem->getVisualBoundingRect());
 #ifdef GESTURE_FRAME_PREVIEW
@@ -619,8 +574,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 #endif  // GESTURE_FRAME_PREVIEW
 					{
 						p->save();
-						p->setBrush(m_brush["outline"]);
-						p->setPen(m_pen["outline"]);
+						p->setBrush(m_brush["frame-move"]);
+						p->setPen(m_pen["frame-move"]);
 						p->setWorldTransform(itemTrans, true);
 						if (matRot != 0)
 							p->setRenderHint(QPainter::Antialiasing);
@@ -631,8 +586,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 						p->restore();
 
 						p->save();
-						p->setBrush(m_brush["outline"]);
-						p->setPen(m_pen["outline"]);
+						p->setBrush(m_brush["frame-move"]);
+						p->setPen(m_pen["frame-move"]);
 						p->setWorldTransform(itemTrans, true);
 						if (matRot != 0)
 							p->setRenderHint(QPainter::Antialiasing);
@@ -642,8 +597,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 				}
 				else
 				{
-					p->setBrush(m_brush["outline"]);
-					p->setPen(m_pen["outline"]);
+					p->setBrush(m_brush["frame-move"]);
+					p->setPen(m_pen["frame-move"]);
 					p->setWorldTransform(itemTrans, true);
 					if (matRot != 0)
 						p->setRenderHint(QPainter::Antialiasing);
@@ -657,8 +612,8 @@ void CanvasMode::drawOutline(QPainter* p, double deltax, double deltay)
 		}
 		else
 		{
-			p->setBrush(m_brush["outline"]);
-			p->setPen(m_pen["outline"]);
+			p->setBrush(m_brush["frame-move"]);
+			p->setPen(m_pen["frame-move"]);
 			p->translate(deltax, deltay);
 			p->translate(x, y);
 			p->drawRect(QRectF(0, 0, w, h));
@@ -755,15 +710,14 @@ void CanvasMode::setModeCursor()
 #ifdef GESTURE_FRAME_PREVIEW
 void CanvasMode::clearPixmapCache()
 {
-	if (m_pixmapCache.count())
+	if (m_pixmapCache.isEmpty())
+		return;
+	foreach(PageItemPreview* ip, m_pixmapCache)
 	{
-		foreach(PageItemPreview* ip, m_pixmapCache)
-		{
-			if (ip)
-				delete ip;
-		}
-		m_pixmapCache.clear();
+		if (ip)
+			delete ip;
 	}
+	m_pixmapCache.clear();
 }
 #endif // GESTURE_FRAME_PREVIEW
 
@@ -830,7 +784,7 @@ void CanvasMode::setResizeCursor(int how, double rot)
 
 bool CanvasMode::commonMouseMove(QMouseEvent *m)
 {
-	//m_mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	//m_mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	if ((m_canvas->m_viewMode.m_MouseButtonPressed && (m->buttons() & Qt::RightButton) && (m->modifiers() & Qt::ControlModifier)) || ((!(m->modifiers() & Qt::ControlModifier)) && (m->buttons() & Qt::MiddleButton)))
 	{
 		if (!m_panGesture)
@@ -846,6 +800,8 @@ bool CanvasMode::commonMouseMove(QMouseEvent *m)
 
 void CanvasMode::commonDrawControls(QPainter* p, bool drawHandles)
 {
+	setStyle(); // reload pen and brush styles
+
 	if (m_canvas->m_viewMode.operItemMoving)
 		drawOutline(p);
 	else
@@ -932,6 +888,7 @@ void CanvasMode::commonkeyPressEvent_Default(QKeyEvent *e)
 				case modeRotation:
 					m_view->deselectItems(false);
 					/* fall through */
+					[[fallthrough]];
 				case modeLinkFrames:
 				case modeUnlinkFrames:
 				case modeEditWeldPoint:
@@ -974,7 +931,7 @@ void CanvasMode::commonkeyPressEvent_Default(QKeyEvent *e)
 			ContextMenu* cmen = nullptr;
 			if (m_doc->m_Selection->isEmpty())
 			{
-				//CB We should be able to get this calculated by the canvas.... it is already in m_canvas->globalToCanvas(m->globalPos());
+				//CB We should be able to get this calculated by the canvas.... it is already in m_canvas->globalToCanvas(m->globalPosition());
 				QPoint p(QCursor::pos() - mainWindow->mapToGlobal(QPoint(0,0)));
 				FPoint fp(p.x() / m_view->scale() + m_doc->minCanvasCoordinate.x(),
 				p.y() / m_view->scale() + m_doc->minCanvasCoordinate.y());
@@ -1139,7 +1096,7 @@ void CanvasMode::commonkeyPressEvent_NormalNodeEdit(QKeyEvent *e)
 			m_view->setCursor(QCursor(Qt::ArrowCursor));
 			if (m_doc->m_Selection->isEmpty())
 			{
-				//CB We should be able to get this calculated by the canvas.... it is already in m_canvas->globalToCanvas(m->globalPos());
+				//CB We should be able to get this calculated by the canvas.... it is already in m_canvas->globalToCanvas(m->globalPosition());
 				FPoint fp = m_canvas->globalToCanvas(QCursor::pos());
 				cmen = new ContextMenu(mainWindow, m_doc, fp.x(), fp.y());
 			}
@@ -1746,13 +1703,73 @@ void CanvasMode::commonkeyReleaseEvent(QKeyEvent *e)
 						currItem->ContourLine.translate(xposOrig - currItem->xPos(),yposOrig - currItem->yPos());
 					m_doc->nodeEdit.finishTransaction(currItem);
 					currItem->update();
-					m_doc->regionsChanged()->update(currItem->getVisualBoundingRect());
+					m_doc->regionsChanged()->update(currItem->getVisualBoundingRect());					
 				}
 				for (int i = 0; i < docSelectionCount; ++i)
 					m_doc->m_Selection->itemAt(i)->checkChanges(true);
 				if (docSelectionCount > 1 && m_view->groupTransactionStarted())
 					m_view->endGroupTransaction();
+				m_doc->changedPagePreview();
 			}
 			break;
 	}
 }
+
+void CanvasMode::setStyle()
+{
+	/*
+	Paper Fill				= prefsData->displayPrefs.paperColor; // white
+	Scratch Space			= prefsData->displayPrefs.scratchColor; // light grey
+	Selected Page Border	= prefsData->displayPrefs.pageBorderColor; // red
+	Frames					= prefsData->displayPrefs.frameNormColor; // black
+	Locked Frames			= prefsData->displayPrefs.frameLockColor; // brown
+	Selected Frames			= prefsData->displayPrefs.frameColor; // red
+	Linked Frames			= prefsData->displayPrefs.frameLinkColor; // red
+	Grouped Frames			= prefsData->displayPrefs.frameGroupColor; // dark teal
+	Annotation Frames		= prefsData->displayPrefs.frameAnnotationColor; // blue
+	Text Control Characters = prefsData->displayPrefs.controlCharColor; // brown
+	*/
+
+	m_color["frame-selection"]	= PrefsManager::instance().appPrefs.displayPrefs.frameColor;
+	m_color["frame-group"]		= PrefsManager::instance().appPrefs.displayPrefs.frameGroupColor;
+	m_color["frame"]			= PrefsManager::instance().appPrefs.displayPrefs.frameNormColor;
+	m_color["frame-move"]		= Qt::gray;
+	m_color["weld"]				= QColor(214, 146, 43);
+	m_color["node"]				= QColor(0, 136, 255);
+	m_color["node-handle"]		= QColor(255, 51, 187);
+	m_color["test"]				= Qt::magenta;
+	QColor selectionAlpha		= m_color["frame-selection"];
+	selectionAlpha.setAlphaF(.05f);
+
+//CB for now 1.0 looks ok for Mac
+#ifdef Q_OS_MAC
+	double stroke = 2.0;
+#else
+	double stroke = 1.0;
+#endif
+
+	m_pen["frame-move"]				= QPen(m_color["frame-move"], 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["frame-move"].setCosmetic(true);
+	m_pen["frame-preview"]			= QPen(Qt::black, 1.0, Qt::DotLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["frame-preview"].setCosmetic(true);
+	m_pen["selection"]				= QPen(m_color["frame-selection"], stroke, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["selection"].setCosmetic(true);
+	m_pen["selection-handle"]		= QPen(m_color["frame-selection"], stroke, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["selection-handle"].setCosmetic(true);
+	m_pen["selection-group"]		= m_pen["selection"];
+	m_pen["selection-group-inside"] = QPen(m_color["frame-group"], 1.0 , Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["selection-group-inside"].setCosmetic(true);
+	m_pen["vector"]					= QPen(m_color["node"], stroke, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["vector"].setCosmetic(true);
+	m_pen["node"]					= QPen(m_color["node"], stroke, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["node"].setCosmetic(true);
+	m_pen["node-handle"]			= QPen(m_color["node-handle"], stroke, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["node-handle"].setCosmetic(true);
+	m_pen["node-dash"]				= QPen(m_color["node-handle"], stroke, Qt::DashLine, Qt::FlatCap, Qt::MiterJoin);
+	m_pen["node-dash"].setCosmetic(true);
+
+	m_brush["frame-move"]				= Qt::NoBrush;
+	m_brush["selection"]				= Qt::NoBrush;
+	m_brush["selection-group"]			= selectionAlpha;
+	m_brush["selection-group-inside"]	= Qt::NoBrush;
+}
