@@ -31,27 +31,16 @@
 
 #include "appmodes.h"
 #include "canvas.h"
-#include "canvasgesture_resize.h"
 #include "fpoint.h"
 #include "fpointarray.h"
-#include "hyphenator.h"
-#include "pageitem_textframe.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "scraction.h"
 #include "scribus.h"
-#include "scribusXml.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "ui/insertTable.h"
 #include "ui/pageselector.h"
-#include "ui/propertiespalette.h"
-#include "ui/scrapbookpalette.h"
+#include "ui/scrspinbox.h"
 #include "undomanager.h"
-#include "units.h"
-#include "util.h"
 #include "util_math.h"
 
 BezierMode::BezierMode(ScribusView* view) : CanvasMode(view) 
@@ -209,6 +198,7 @@ void BezierMode::mouseDoubleClickEvent(QMouseEvent *m)
 		else
 			m_view->requestMode(m_doc->appMode);
 		m_doc->changed();
+		m_doc->changedPagePreview();
 		m_firstPoly = true;
 		m_inItemCreation = false;
 		m_canvas->setRenderModeUseBuffer(false);
@@ -235,14 +225,12 @@ void BezierMode::mouseDoubleClickEvent(QMouseEvent *m)
 
 void BezierMode::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	
 	PageItem *currItem;
 	m->accept();
-	m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
-//	qDebug() << "legacy mode move:" << m->x() << m->y() << m_canvas->globalToCanvas(m->globalPos()).x() << m_canvas->globalToCanvas(m->globalPos()).y();
-//	emit MousePos(m->x()/m_canvas->scale(),// + m_doc->minCanvasCoordinate.x(), 
-//				  m->y()/m_canvas->scale()); // + m_doc->minCanvasCoordinate.y());
+	m_canvas->displayCorrectedXYHUD(m->globalPosition(), mousePointDoc.x(), mousePointDoc.y());
+
 	if (commonMouseMove(m))
 		return;
 	
@@ -250,8 +238,8 @@ void BezierMode::mouseMoveEvent(QMouseEvent *m)
 	{
 		if (GetItem(&currItem))
 		{
-			double newX = qRound(mousePointDoc.x()); //m_view->translateToDoc(m->x(), m->y()).x());
-			double newY = qRound(mousePointDoc.y()); //m_view->translateToDoc(m->x(), m->y()).y());
+			double newX = qRound(mousePointDoc.x());
+			double newY = qRound(mousePointDoc.y());
 			
 			if (m_doc->DragP)
 				return;
@@ -274,7 +262,8 @@ void BezierMode::mouseMoveEvent(QMouseEvent *m)
 			if ((m_mouseButtonPressed) && (m->buttons() & Qt::LeftButton))
 			{
 				QPoint startP = m_canvas->canvasToGlobal(QPointF(m_xp, m_yp));
-				m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
+				QPoint globalPos = m->globalPosition().toPoint();
+				m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(globalPos)).normalized());
 				m_view->setRedrawMarkerShown(true);
 				m_view->HaveSelRect = true;
 				return;
@@ -285,7 +274,7 @@ void BezierMode::mouseMoveEvent(QMouseEvent *m)
 
 void BezierMode::mousePressEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	
 	int z;
 	double Rxp = 0;
@@ -302,9 +291,9 @@ void BezierMode::mousePressEvent(QMouseEvent *m)
 	m_doc->leaveDrag = false;
 
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
-	m_xp = mousePointDoc.x(); //qRound(m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
-	m_yp = mousePointDoc.y(); //qRound(m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
+	m_view->registerMousePress(m->globalPosition());
+	m_xp = mousePointDoc.x();
+	m_yp = mousePointDoc.y();
 	Rxp = m_doc->ApplyGridF(FPoint(m_xp, m_yp)).x();
 	Rxpd = m_xp - Rxp;
 	m_xp = qRound(Rxp);
@@ -360,7 +349,7 @@ void BezierMode::mousePressEvent(QMouseEvent *m)
 
 void BezierMode::mouseReleaseEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 
 	PageItem *currItem;
 	m_mouseButtonPressed = false;
@@ -438,6 +427,7 @@ void BezierMode::mouseReleaseEvent(QMouseEvent *m)
 		else
 			m_view->requestMode(m_doc->appMode);
 		m_doc->changed();
+		m_doc->changedPagePreview();
 //		emit DocChanged();
 		m_firstPoly = true;
 		m_inItemCreation = false;
@@ -479,9 +469,9 @@ void BezierMode::mouseReleaseEvent(QMouseEvent *m)
 void BezierMode::selectPage(QMouseEvent *m)
 {
 	m_mouseButtonPressed = true;
-	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-	m_xp = mousePointDoc.x(); //static_cast<int>(m->x()/m_canvas->scale());
-	m_yp = mousePointDoc.y(); //static_cast<int>(m->y()/m_canvas->scale());
+	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+	m_xp = mousePointDoc.x();
+	m_yp = mousePointDoc.y();
 	m_doc->nodeEdit.deselect();
 	m_view->deselectItems(false);
 
