@@ -34,30 +34,20 @@
 #include "appmodes.h"
 #include "canvas.h"
 #include "fpoint.h"
-#include "fpointarray.h"
 #include "hyphenator.h"
 #include "iconmanager.h"
 #include "pageitem_noteframe.h"
 #include "pageitem_textframe.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
-#include "prefsmanager.h"
-#include "sccolorengine.h"
 #include "scmimedata.h"
 #include "scribus.h"
-#include "scribusXml.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "ui/aligndistribute.h"
 #include "ui/contextmenu.h"
 #include "ui/hruler.h"
-#include "ui/insertTable.h"
 #include "ui/pageselector.h"
-#include "ui/propertiespalette.h"
+#include "ui/scrspinbox.h"
 #include "undomanager.h"
-#include "units.h"
-#include "util.h"
 #include "util_math.h"
 
 
@@ -80,7 +70,7 @@ void CanvasMode_Edit::blinkTextCursor()
 	PageItem* currItem;
 	if (m_doc->appMode == modeEdit && GetItem(&currItem))
 	{
-		QRectF brect = QRectF(0, 0, currItem->width(), currItem->height());
+		QRectF brect(0, 0, currItem->width(), currItem->height());
 		QTransform m = currItem->getTransform();
 		brect = m.mapRect(brect);
 		m_canvas->update(QRectF(m_canvas->canvasToLocal(brect.topLeft()), QSizeF(brect.width(),brect.height())*m_canvas->scale()).toRect());
@@ -154,6 +144,36 @@ void CanvasMode_Edit::keyPressEvent(QKeyEvent *e)
 	m_keyRepeat = false;
 }
 
+void CanvasMode_Edit::keyReleaseEvent(QKeyEvent *e)
+{
+	PageItem* currItem;
+	if (!GetItem(&currItem))
+	{
+		return;
+	}
+
+	if (currItem->isImageFrame() && !currItem->locked())
+	{
+		switch (e->key())
+		{
+			case Qt::Key_Up:
+			case Qt::Key_Down:
+			case Qt::Key_Left:
+			case Qt::Key_Right:
+				m_doc->changedPagePreview();
+				break;
+			default:
+				break;
+		}
+	}
+
+	if (currItem->isTextFrame())
+	{
+		m_doc->changedPagePreview();
+	}
+
+}
+
 
 
 void CanvasMode_Edit::rulerPreview(double base, double xp)
@@ -166,7 +186,7 @@ void CanvasMode_Edit::rulerPreview(double base, double xp)
 		QPoint oldP = m_canvas->canvasToLocal(QPointF(mRulerGuide, itPos.y()));
 		mRulerGuide = base + xp;
 		QPoint p = m_canvas->canvasToLocal(QPointF(mRulerGuide, itPos.y() + currItem->height() * mm.m22()));
-		m_canvas->update(QRect(oldP.x()-2, oldP.y(), p.x()+2, p.y()));
+		m_canvas->update(QRect(oldP.x() - 2, oldP.y(), p.x() + 2, p.y()));
 	}
 }
 
@@ -177,7 +197,7 @@ void CanvasMode_Edit::drawControls(QPainter* p)
 	PageItem* currItem;
 	if (GetItem(&currItem))
 	{
-		QPen pp = QPen(Qt::blue, 1.0 / m_canvas->scale(), Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+		QPen pp(Qt::blue, 1.0 / m_canvas->scale(), Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
 		pp.setCosmetic(true);
 		PageItem_TextFrame* textframe = currItem->asTextFrame();
 		if (textframe)
@@ -221,7 +241,7 @@ void CanvasMode_Edit::drawControls(QPainter* p)
 			p->drawRect(0, 0, currItem->OrigW*currItem->imageXScale(), currItem->OrigH*currItem->imageYScale());
 			p->translate(currItem->OrigW*currItem->imageXScale() / 2, currItem->OrigH*currItem->imageYScale() / 2);
 			p->scale(1.0 / m_canvas->scale(), 1.0 / m_canvas->scale());
-			QPen pps = QPen(Qt::blue, 1.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
+			QPen pps(Qt::blue, 1.0, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
 			pps.setCosmetic(true);
 			p->setPen(pps);
 			p->drawLine(-10, 0, 10, 0);
@@ -236,8 +256,8 @@ void CanvasMode_Edit::drawControls(QPainter* p)
 
 void CanvasMode_Edit::drawTextCursor ( QPainter *p, PageItem_TextFrame* textframe )
 {
-	if ((!m_longCursorTime && m_blinkTime.elapsed() > qApp->cursorFlashTime() / 2 ) ||
-		(m_longCursorTime && m_blinkTime.elapsed() > qApp->cursorFlashTime() )
+	if ((!m_longCursorTime && m_blinkTime.elapsed() > QApplication::cursorFlashTime() / 2 ) ||
+		(m_longCursorTime && m_blinkTime.elapsed() > QApplication::cursorFlashTime() )
 		)
 	{
 		m_cursorVisible = !m_cursorVisible;
@@ -323,7 +343,7 @@ void CanvasMode_Edit::mouseDoubleClickEvent(QMouseEvent *m)
 		//CB if annotation, open the annotation dialog
 		if (currItem->isAnnotation())
 		{
-		//	qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		//	QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 			m_view->requestMode(submodeAnnotProps);
 		}
 		//otherwise, select between the whitespace
@@ -392,7 +412,8 @@ void CanvasMode_Edit::mouseDoubleClickEvent(QMouseEvent *m)
 
 void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const QPoint globalPos = m->globalPosition().toPoint();
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	
 	double newX, newY;
 	PageItem *currItem;
@@ -417,7 +438,7 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 					QPointF rotP = p.map(QPointF(0.0, 0.0));
 					double itemRotation = xy2Deg(mousePointDoc.x() - rotP.x(), mousePointDoc.y() - rotP.y());
 					currItem->setImageRotation(itemRotation);
-					m_canvas->displayRotHUD(m->globalPos(), itemRotation);
+					m_canvas->displayRotHUD(m->globalPosition(), itemRotation);
 				}
 				else
 				{
@@ -426,7 +447,7 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 					QTransform mm2 = mm1.inverted();
 					QPointF rota = mm2.map(QPointF(newX, newY)) - mm2.map(QPointF(Mxp, Myp));
 					currItem->moveImageInFrame(rota.x() / currItem->imageXScale(), rota.y() / currItem->imageYScale());
-					m_canvas->displayXYHUD(m->globalPos(), currItem->imageXOffset() * currItem->imageXScale(), currItem->imageYOffset() * currItem->imageYScale());
+					m_canvas->displayXYHUD(m->globalPosition(), currItem->imageXOffset() * currItem->imageXScale(), currItem->imageYOffset() * currItem->imageYScale());
 				}
 				currItem->update();
 				Mxp = newX;
@@ -438,7 +459,7 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 				int refEndSel(currItem->asTextFrame()->itemText.endOfSelection());
 				currItem->itemText.deselectAll();
 				currItem->HasSel = false;
-				m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
+				m_view->slotSetCurs(globalPos.x(), globalPos.y());
 				//Make sure we don't go here if the old cursor position was not set
 				if (oldCp!=-1 && currItem->itemText.length() > 0)
 				{
@@ -513,7 +534,7 @@ void CanvasMode_Edit::mouseMoveEvent(QMouseEvent *m)
 			SeRx = newX;
 			SeRy = newY;
 			QPoint startP = m_canvas->canvasToGlobal(QPointF(Mxp, Myp));
-			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
+			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(globalPos)).normalized());
 			m_view->setRedrawMarkerShown(true);
 			m_view->HaveSelRect = true;
 			return;
@@ -537,19 +558,18 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 				ss->set("ETEA", QString(""));
 		}
 	}
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 
-	bool inText;
-	PageItem *currItem;
+	const QPoint globalPos = m->globalPosition().toPoint();
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+	
 	m_canvas->PaintSizeRect(QRect());
-	QTransform pm;
 	m_canvas->m_viewMode.m_MouseButtonPressed = true;
 	m_canvas->m_viewMode.operItemMoving = false;
 	m_view->HaveSelRect = false;
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
+	m_view->registerMousePress(m->globalPosition());
 	Mxp = mousePointDoc.x();
 	Myp = mousePointDoc.y();
 	SeRx = Mxp;
@@ -563,13 +583,15 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 	}
 
 	frameResizeHandle = 0;
-	int oldP=0;
+	int oldP = 0;
+
+	PageItem* currItem{ nullptr };
 	if (GetItem(&currItem))
 	{
 //		m_view->slotDoCurs(false);
 		if ((!currItem->locked() || currItem->isTextFrame()) && !currItem->isLine())
 		{
-			FPoint canvasPoint = m_canvas->globalToCanvas(m->globalPos());
+			FPoint canvasPoint = m_canvas->globalToCanvas(m->globalPosition());
 			if (m_canvas->frameHitTest(QPointF(canvasPoint.x(), canvasPoint.y()), currItem) < 0)
 			{
 				m_doc->m_Selection->delaySignalsOn();
@@ -590,7 +612,7 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 					}
 					if (currItem->isTextFrame())
 					{
-						m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
+						m_view->slotSetCurs(globalPos.x(), globalPos.y());
 						oldCp = currItem->itemText.cursorPosition();
 					}
 				}
@@ -612,7 +634,7 @@ void CanvasMode_Edit::mousePressEvent(QMouseEvent *m)
 		//CB Where we set the cursor for a click in text frame
 		if (currItem->isTextFrame())
 		{
-			inText = m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
+			bool inText = m_view->slotSetCurs(globalPos.x(), globalPos.y());
 			//CB If we clicked outside a text frame to go out of edit mode and deselect the frame
 			if (!inText)
 			{
@@ -728,8 +750,8 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 #ifdef GESTURE_FRAME_PREVIEW
 	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-	PageItem *currItem;
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+	PageItem *currItem = nullptr;
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m->accept();
@@ -750,6 +772,8 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 			m_canvas->m_viewMode.operItemResizing = false;
 			if (currItem->isLine())
 				m_view->updateContents();
+			if (currItem->isImageFrame())
+				m_doc->changedPagePreview();
 		}
 		if (m_canvas->m_viewMode.operItemMoving)
 		{
@@ -836,6 +860,7 @@ void CanvasMode_Edit::mouseReleaseEvent(QMouseEvent *m)
 			//currItem->emitAllToGUI();
 			m_view->updatesOn(true);
 			m_view->updateContents();
+			m_doc->changedPagePreview();
 		}
 	}
 	//CB Drag selection performed here
@@ -941,20 +966,17 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 	const unsigned SELECT_IN_GROUP = Qt::AltModifier;
 	const unsigned SELECT_MULTIPLE = Qt::ShiftModifier;
 	const unsigned SELECT_BENEATH = Qt::ControlModifier;
-	QTransform p;
-	QRectF mpo;
-	PageItem *currItem;
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = true;
-	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-	Mxp = mousePointDoc.x(); //m->x()/m_canvas->scale());
-	Myp = mousePointDoc.y(); //m->y()/m_canvas->scale());
-	double grabRadius = m_doc->guidesPrefs().grabRadius / m_canvas->scale();
-	int MxpS = static_cast<int>(mousePointDoc.x()); //m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
-	int MypS = static_cast<int>(mousePointDoc.y()); //m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
-	mpo = QRectF(Mxp-grabRadius, Myp-grabRadius, grabRadius*2, grabRadius*2);
-//	mpo.translate(m_doc->minCanvasCoordinate.x() * m_canvas->scale(), m_doc->minCanvasCoordinate.y() * m_canvas->scale());
+
+	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+	Mxp = mousePointDoc.x();
+	Myp = mousePointDoc.y();
+	int MxpS = static_cast<int>(mousePointDoc.x());
+	int MypS = static_cast<int>(mousePointDoc.y());
+	//QRectF mpo(Mxp - grabRadius, Myp - grabRadius, grabRadius * 2, grabRadius * 2);
+
 	m_doc->nodeEdit.deselect();
-// 	int a;
 	if (!m_doc->masterPageMode())
 	{
 		int pgNum = -1;
@@ -1004,7 +1026,7 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 		m_view->setRulerPos(m_view->contentsX(), m_view->contentsY());
 	}
 	
-	currItem = nullptr;
+	PageItem* currItem = nullptr;
 	if ((m->modifiers() & SELECT_BENEATH) != 0)
 	{
 		for (int i = 0; i < m_doc->m_Selection->count(); ++i)
@@ -1021,7 +1043,7 @@ bool CanvasMode_Edit::SeleItem(QMouseEvent *m)
 	{
 		m_view->deselectItems(false);
 	}
-	currItem = m_canvas->itemUnderCursor(m->globalPos(), currItem, (m->modifiers() & SELECT_IN_GROUP));
+	currItem = m_canvas->itemUnderCursor(m->globalPosition(), currItem, (m->modifiers() & SELECT_IN_GROUP));
 	if (currItem)
 	{
 		m_doc->m_Selection->delaySignalsOn();
