@@ -14,7 +14,6 @@
 ***************************************************************************/
 
 
-#include "canvasmode_magnifier.h"
 
 #include <QApplication>
 #include <QButtonGroup>
@@ -30,26 +29,17 @@
 #include <QWidgetAction>
 #include <QDebug>
 
-#include "appmodes.h"
+
 #include "canvas.h"
+#include "canvasmode_magnifier.h"
 #include "fpoint.h"
-#include "fpointarray.h"
 #include "iconmanager.h"
-#include "pageitem_textframe.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
-#include "prefsmanager.h"
 #include "scribus.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
-#include "selection.h"
 #include "ui/contextmenu.h"
 #include "ui/pageselector.h"
-#include "ui/propertiespalette.h"
-#include "undomanager.h"
-#include "units.h"
-#include "util.h"
-#include "util_math.h"
+#include "ui/scrspinbox.h"
 
 CanvasMode_Magnifier::CanvasMode_Magnifier(ScribusView* view) : CanvasMode(view)
 {
@@ -115,7 +105,7 @@ void CanvasMode_Magnifier::mouseDoubleClickEvent(QMouseEvent *m)
 
 void CanvasMode_Magnifier::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	
 	m_lastPosWasOverGuide = false;
 	m->accept();
@@ -128,7 +118,8 @@ void CanvasMode_Magnifier::mouseMoveEvent(QMouseEvent *m)
 		m_SeRx = newX;
 		m_SeRy = newY;
 		QPoint startP = m_canvas->canvasToGlobal(QPointF(m_Mxp, m_Myp));
-		m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
+		QPoint globalPos = m->globalPosition().toPoint();
+		m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(globalPos)).normalized());
 		m_view->setRedrawMarkerShown(true);
 		m_view->HaveSelRect = true;
 	}
@@ -136,7 +127,7 @@ void CanvasMode_Magnifier::mouseMoveEvent(QMouseEvent *m)
 
 void CanvasMode_Magnifier::mousePressEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	
 	m_canvas->PaintSizeRect(QRect());
 	m_canvas->m_viewMode.m_MouseButtonPressed = true;
@@ -145,9 +136,9 @@ void CanvasMode_Magnifier::mousePressEvent(QMouseEvent *m)
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
-	m_Mxp = mousePointDoc.x(); //qRound(m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
-	m_Myp = mousePointDoc.y(); //qRound(m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
+	m_view->registerMousePress(m->globalPosition());
+	m_Mxp = mousePointDoc.x();
+	m_Myp = mousePointDoc.y();
 	double Rxp = m_doc->ApplyGridF(FPoint(m_Mxp, m_Myp)).x();
 	m_Mxp = qRound(Rxp);
 	double Ryp = m_doc->ApplyGridF(FPoint(m_Mxp, m_Myp)).y();
@@ -172,11 +163,13 @@ void CanvasMode_Magnifier::mousePressEvent(QMouseEvent *m)
 		m_view->Magnify = true;
 		m_view->setCursor(IconManager::instance().loadCursor("lupez.png"));
 	}
-	m_Mxp = mousePointDoc.x(); //m->globalPos().x();
-	m_Myp = mousePointDoc.y(); //m->globalPos().y();
+	m_Mxp = mousePointDoc.x();
+	m_Myp = mousePointDoc.y();
 	m_SeRx = m_Mxp;
 	m_SeRy = m_Myp;
-	m_view->redrawMarker->setGeometry(m->globalPos().x(), m->globalPos().y(), 1, 1);
+
+	QPoint globalPos = m->globalPosition().toPoint();
+	m_view->redrawMarker->setGeometry(globalPos.x(), globalPos.y(), 1, 1);
 }
 
 void CanvasMode_Magnifier::mouseReleaseEvent(QMouseEvent *m)
@@ -184,7 +177,7 @@ void CanvasMode_Magnifier::mouseReleaseEvent(QMouseEvent *m)
 #ifdef GESTURE_FRAME_PREVIEW
 	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m->accept();
