@@ -13,7 +13,6 @@
 *                                                                         *
 ***************************************************************************/
 
-#include "canvasmode_nodeedit.h"
 
 #include <QMenu>
 #include <QMouseEvent>
@@ -22,21 +21,17 @@
 #include "canvas.h"
 #include "canvasgesture_pan.h"
 #include "canvasgesture_rectselect.h"
+#include "canvasmode_nodeedit.h"
 #include "fpoint.h"
 #include "iconmanager.h"
 #include "nodeeditcontext.h"
 #include "pageitem.h"
-#include "scraction.h"
 #include "scribus.h"
-#include "scribusXml.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
 #include "ui/pageselector.h"
-#include "ui/propertiespalette.h"
 #include "ui/scrspinbox.h"
-#include "undomanager.h"
-#include "util_math.h"
 
 CanvasMode_NodeEdit::CanvasMode_NodeEdit(ScribusView* view) : CanvasMode(view)
 {
@@ -56,7 +51,6 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 	p->scale(m_canvas->scale(), m_canvas->scale());
 	p->translate(-m_doc->minCanvasCoordinate.x(), -m_doc->minCanvasCoordinate.y());
 	p->setTransform(currItem->getTransform(), true);
-	p->setPen(QPen(Qt::blue, 1 / m_canvas->m_viewMode.scale, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
 	p->setBrush(Qt::NoBrush);
 
 	if ((m_doc->nodeEdit.isContourLine()) && (!currItem->ContourLine.empty()))
@@ -77,17 +71,20 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 				p->scale(1, -1);
 			}
 		}
-	}
-	// draw curve
+	}	
 	const double scale = m_canvas->m_viewMode.scale;
-	const double onePerScale = 1 / scale;
+
+	// Draw Vector Path
 	if (cli.size() > 3)
 	{
+		p->save();
+		p->setRenderHint(QPainter::Antialiasing);
+
 		for (int i = 0; i < cli.size() - 3; i += 4)
 		{
 			if (cli.isMarker(i))
 				continue;
-			p->setPen(QPen(Qt::blue, onePerScale, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+
 			const FPoint& a1 = cli.point(i);
 			const FPoint& a2 = cli.point(i + 1);
 			const FPoint& a3 = cli.point(i + 3);
@@ -95,52 +92,51 @@ void CanvasMode_NodeEdit::drawControls(QPainter* p)
 			QPainterPath Bez;
 			Bez.moveTo(a1.x(), a1.y());
 			Bez.cubicTo(a2.x(), a2.y(), a3.x(), a3.y(), a4.x(), a4.y());
+			p->setPen(pens().value("vector"));
 			p->drawPath(Bez);
-			p->setPen(QPen(Qt::blue, onePerScale, Qt::DotLine, Qt::FlatCap, Qt::MiterJoin));
+			p->setPen(pens().value("node-handle"));
 			p->drawLine(QPointF(a1.x(), a1.y()), QPointF(a2.x(), a2.y()));
 			p->drawLine(QPointF(a3.x(), a3.y()), QPointF(a4.x(), a4.y()));
 		}
+		p->restore();
 	}
 	double x = 0.0;
 	double y = 0.0;
-	// draw points
+	// Draw Nodes
 	for (int i = 0; i < cli.size() - 1; i += 2)
 	{
 		if (cli.isMarker(i))
 			continue;
-		Qt::GlobalColor color1 = (m_doc->nodeEdit.clre() == (i + 1)) ? Qt::red : Qt::magenta;
-		Qt::GlobalColor color2 = (m_doc->nodeEdit.clre() == i) ? Qt::red : Qt::blue;
+
 		if (m_doc->nodeEdit.edPoints())
 		{
-			p->setPen(QPen(color1, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
 			cli.point(i + 1, &x, &y);
-			p->drawPoint(QPointF(x, y));
-			p->setPen(QPen(color2, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
+			drawNodeControl(p, QPointF(x, y), pens().value("node"), scale);
+
 			cli.point(i, &x, &y);
-			p->drawPoint(QPointF(x, y));
+			drawNodeHandle(p, QPointF(x, y), pens().value("node"), scale);
 		}
 		else
 		{
-			p->setPen(QPen(color2, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
 			cli.point(i, &x, &y);
-			p->drawPoint(QPointF(x, y));
-			p->setPen(QPen(color1, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
+			drawNodeHandle(p, QPointF(x, y), pens().value("node"), scale);
+
 			cli.point(i + 1, &x, &y);
-			p->drawPoint(QPointF(x, y));
+			drawNodeControl(p, QPointF(x, y), pens().value("node"), scale);
 		}
 	}
 	
 	if (m_doc->nodeEdit.clre() != -1)
 	{
-		p->setPen(QPen(Qt::red, 8 / scale, Qt::SolidLine, Qt::RoundCap, Qt::MiterJoin));
 		cli.point(m_doc->nodeEdit.clre(), &x, &y);
-		p->drawPoint(QPointF(x, y));
+		drawNodeControl(p, QPointF(x, y), pens().value("node"), scale, true);
+
 		const auto& selectedNodes = m_doc->nodeEdit.selNode();
 		for (int i = 0; i < selectedNodes.count(); ++i)
 		{
 			int selectedNode = selectedNodes.at(i);
 			cli.point(selectedNode, &x, &y);
-			p->drawPoint(QPointF(x, y));
+			drawNodeHandle(p, QPointF(x, y), pens().value("node"), scale, true);
 		}
 	}
 
@@ -264,11 +260,12 @@ void CanvasMode_NodeEdit::mouseDoubleClickEvent(QMouseEvent *m)
 
 void CanvasMode_NodeEdit::mouseMoveEvent(QMouseEvent *m)
 {
-	PageItem *currItem;
-	FPoint npf;
 	double sc = m_canvas->scale();
+	FPoint npf = m_canvas->globalToCanvas(m->globalPosition());
+
 	m->accept();
-	npf = m_canvas->globalToCanvas(m->globalPos());
+
+	PageItem* currItem { nullptr };
 	if (GetItem(&currItem))
 	{
 		if (m_doc->DragP)
@@ -293,14 +290,14 @@ void CanvasMode_NodeEdit::mouseMoveEvent(QMouseEvent *m)
 	}
 	else // shouldn't be in nodeedit mode now, should it??
 	{
-		npf = m_canvas->globalToCanvas(m->globalPos());
+		npf = m_canvas->globalToCanvas(m->globalPosition());
 		if ((m_canvas->m_viewMode.m_MouseButtonPressed) && (m->buttons() & Qt::LeftButton) && (m_GyM == -1) && (m_GxM == -1))
 		{
 			if (!m_rectangleSelect)
 			{
 				m_rectangleSelect = new RectSelect(this);
 			}
-			m_rectangleSelect->prepare(m->globalPos());
+			m_rectangleSelect->prepare(m->globalPosition());
 			m_view->startGesture(m_rectangleSelect);
 			return;
 		}
@@ -353,10 +350,10 @@ void CanvasMode_NodeEdit::mousePressEvent(QMouseEvent *m)
 	m_doc->leaveDrag = false;
 	m_MoveGX = m_MoveGY = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
+	m_view->registerMousePress(m->globalPosition());
 	QRect mpo;
-	m_Mxp = m->x();
-	m_Myp = m->y();
+	m_Mxp = m->position().x();
+	m_Myp = m->position().y();
 
 	if (((m->buttons() & Qt::RightButton) && (m->modifiers() & Qt::ControlModifier)) || ((!(m->modifiers() & Qt::ControlModifier)) && (m->buttons() & Qt::MiddleButton)))
 	{
@@ -406,7 +403,7 @@ void CanvasMode_NodeEdit::mouseReleaseEvent(QMouseEvent *m)
 		if (m_doc->nodeEdit.hasNodeSelected() && (m_doc->nodeEdit.selectionCount() == 1))
 		{
 			//FIXME:av
-			FPoint newP = m_canvas->globalToCanvas(m->globalPos());
+			FPoint newP = m_canvas->globalToCanvas(m->globalPosition());
 			currItem->OldB2 = currItem->width();
 			currItem->OldH2 = currItem->height();
 			FPointArray Clip;
@@ -506,7 +503,7 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 	m_doc->nodeEdit.deselect();
 
 	QTransform pm2 = currItem->getTransform();
-	npf2 = m_canvas->globalToCanvas(m->globalPos()).transformPoint(pm2, true);
+	npf2 = m_canvas->globalToCanvas(m->globalPosition()).transformPoint(pm2, true);
 	if ((currItem->isSymbol() || currItem->isGroup()) && (!m_doc->nodeEdit.isContourLine()))
 	{
 		if (currItem->imageFlippedH())
@@ -525,7 +522,7 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 		if (((m_doc->nodeEdit.edPoints()) && (i % 2 != 0)) || ((!m_doc->nodeEdit.edPoints()) && (i % 2 == 0)))
 			continue;
 		QPointF npf = pm2.map(Clip.pointQF(i));
-		if (m_canvas->hitsCanvasPoint(m->globalPos(), npf))
+		if (m_canvas->hitsCanvasPoint(m->globalPosition(), npf))
 		{
 			m_doc->nodeEdit.setClre(i);
 			if ((m_doc->nodeEdit.edPoints()) && (m_doc->nodeEdit.selNode().contains(i) == 0))
@@ -580,10 +577,10 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 			bool foundP = false;
 			int seg = 0;
 			double absDist = 9999999999.9;
-			FPoint point = FPoint(0, 0);
-			FPoint normal = FPoint(0, 0);
-			FPoint tangent = FPoint(0, 0);
-			FPoint nearPoint = FPoint(0, 0);
+			FPoint point(0, 0);
+			FPoint normal(0, 0);
+			FPoint tangent(0, 0);
+			FPoint nearPoint(0, 0);
 			double nearT = 0.0;
 			QRect mpo2(0, 0, m_doc->guidesPrefs().grabRadius*3, m_doc->guidesPrefs().grabRadius*3);
 			mpo2.moveCenter(QPoint(qRound(npf2.x()), qRound(npf2.y())));
@@ -832,10 +829,10 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 		bool foundP = false;
 		uint seg = 0;
 		double absDist = 9999999999.9;
-		FPoint point = FPoint(0, 0);
-		FPoint normal = FPoint(0, 0);
-		FPoint tangent = FPoint(0, 0);
-		FPoint nearPoint = FPoint(0, 0);
+		FPoint point(0, 0);
+		FPoint normal(0, 0);
+		FPoint tangent(0, 0);
+		FPoint nearPoint(0, 0);
 		double nearT = 0.0;
 		QRect mpo2(0, 0, m_doc->guidesPrefs().grabRadius * 3, m_doc->guidesPrefs().grabRadius * 3);
 		mpo2.moveCenter(QPoint(qRound(npf2.x()), qRound(npf2.y())));
@@ -917,16 +914,15 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 	if (edited)
 	{
 		currItem->FrameType = 3;
-		double xp, yp, w, h, xp2, yp2, w2, h2;
-		xp = currItem->xPos();
-		yp = currItem->yPos();
-		w = currItem->width();
-		h = currItem->height();
+		double xp = currItem->xPos();
+		double yp = currItem->yPos();
+		double w = currItem->width();
+		double h = currItem->height();
 		m_doc->adjustItemSize(currItem, true);
-		xp2 = currItem->xPos();
-		yp2 = currItem->yPos();
-		w2 = currItem->width();
-		h2 = currItem->height();
+		double xp2 = currItem->xPos();
+		double yp2 = currItem->yPos();
+		double w2 = currItem->width();
+		double h2 = currItem->height();
 		currItem->update();
 		if ((xp != xp2) || (yp != yp2) || (w != w2) || (h != h2))
 			m_view->DrawNew();
@@ -939,19 +935,19 @@ void CanvasMode_NodeEdit::handleNodeEditPress(QMouseEvent* m, QRect r)
 	}
 	if ((m_doc->nodeEdit.selectionCount() != 0) || ((m_doc->nodeEdit.segP1() != -1) && (m_doc->nodeEdit.segP2() != -1)) || (m_doc->nodeEdit.hasNodeSelected() && (!m_doc->nodeEdit.edPoints())))
 	{
-		m_Mxp = m->x();
-		m_Myp = m->y();
+		m_Mxp = m->position().x();
+		m_Myp = m->position().y();
 		m_canvas->setRenderModeFillBuffer();
 	}
 	else
 	{
-		m_Mxp = m->x();
-		m_Myp = m->y();
-		m_Dxp = qRound(m->x() / m_canvas->scale());  // + m_doc->minCanvasCoordinate.x());
-		m_Dyp = qRound(m->y() / m_canvas->scale());  // + m_doc->minCanvasCoordinate.y());
+		m_Mxp = m->position().x();
+		m_Myp = m->position().y();
+		m_Dxp = qRound(m->position().x() / m_canvas->scale());  // + m_doc->minCanvasCoordinate.x());
+		m_Dyp = qRound(m->position().y() / m_canvas->scale());  // + m_doc->minCanvasCoordinate.y());
 		if (!m_rectangleSelect)
 			m_rectangleSelect = new RectSelect(this);
-		m_rectangleSelect->prepare(m->globalPos());
+		m_rectangleSelect->prepare(m->globalPosition());
 		m_view->startGesture(m_rectangleSelect);
 	}
 	
@@ -992,7 +988,7 @@ bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect /*r*/, PageIt
 			if (((m_doc->nodeEdit.edPoints()) && (i % 2 != 0)) || ((!m_doc->nodeEdit.edPoints()) && (i % 2 == 0)))
 				continue;
 			QPointF point = Clip.pointQF(i);
-			if (m_canvas->hitsCanvasPoint(m->globalPos(), itemPos.map(point)))
+			if (m_canvas->hitsCanvasPoint(m->globalPosition(), itemPos.map(point)))
 			{
 				if (m_doc->nodeEdit.submode() == NodeEditContext::MOVE_POINT)
 					m_view->setCursor(QCursor(Qt::SizeAllCursor));
@@ -1025,7 +1021,7 @@ bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect /*r*/, PageIt
 				for (double d = 0.0; d <= 1.0; d += delta)
 				{
 					QPointF pl = Bez.pointAtPercent(d);
-					if (m_canvas->hitsCanvasPoint(m->globalPos(), FPoint(pl.x(), pl.y())))
+					if (m_canvas->hitsCanvasPoint(m->globalPosition(), FPoint(pl.x(), pl.y())))
 					{
 						if (m_doc->nodeEdit.submode() == NodeEditContext::MOVE_POINT)
 							m_view->setCursor(IconManager::instance().loadCursor("handc.png"));
@@ -1048,19 +1044,17 @@ bool CanvasMode_NodeEdit::handleNodeEditMove(QMouseEvent* m, QRect /*r*/, PageIt
 
 void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 {
-	FPoint npf;
 	if ((m_canvas->m_viewMode.m_MouseButtonPressed) && !m_doc->nodeEdit.hasNodeSelected() && (m_doc->nodeEdit.segP1()  == -1) && (m_doc->nodeEdit.segP2() == -1))
 	{
 		if (!m_rectangleSelect)
-		{
 			m_rectangleSelect = new RectSelect(this);
-		}
-		m_rectangleSelect->prepare(m->globalPos());
+		m_rectangleSelect->prepare(m->globalPosition());
 		m_view->startGesture(m_rectangleSelect);
 		return;
 	}
-	int newX = m->x();
-	int newY = m->y();
+	FPoint npf;
+	double newX = m->position().x();
+	double newY = m->position().y();
 	FPoint np(newX - m_Mxp, newY - m_Myp, 0, 0, currItem->rotation(), 1, 1, true);
 	np = np * (1.0 / m_canvas->scale());
 	m_canvas->m_viewMode.operItemMoving = true;
@@ -1096,7 +1090,7 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 			int storedClRe = m_doc->nodeEdit.clre();
 			if (m_doc->nodeEdit.selectionCount() == 1)
 			{
-				npf = m_canvas->globalToCanvas(m->globalPos());
+				npf = m_canvas->globalToCanvas(m->globalPosition());
 				double nx = npf.x();
 				double ny = npf.y();
 				if (!m_doc->ApplyGuides(&nx, &ny) && !m_doc->ApplyGuides(&nx, &ny,true))
@@ -1131,7 +1125,6 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 						cli = currItem->ContourLine;
 					else
 						cli = currItem->PoLine;
-					
 					int tmpNode;
 					int curr = (m_doc->nodeEdit.clre() == 0) ? cli.size() - 2 : m_doc->nodeEdit.clre();
 					int prev = (curr + cli.size() - 4) % cli.size();
@@ -1168,11 +1161,9 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 						npf.setY(currItem->ContourLine.point(m_doc->nodeEdit.clre()).y());
 					else
 						npf.setY(currItem->PoLine.point(m_doc->nodeEdit.clre()).y());
-
-
 				}
 				m_doc->nodeEdit.moveClipPoint(currItem, npf);
-				m_canvas->displayXYHUD(m->globalPos(), npf.x(), npf1.y());
+				m_canvas->displayXYHUD(m->globalPosition(), npf.x(), npf1.y());
 			}
 			else
 			{
@@ -1198,7 +1189,7 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 		}
 		else
 		{
-			npf = m_canvas->globalToCanvas(m->globalPos());
+			npf = m_canvas->globalToCanvas(m->globalPosition());
 			double nx = npf.x();
 			double ny = npf.y();
 			if (!m_doc->ApplyGuides(&nx, &ny) && !m_doc->ApplyGuides(&nx, &ny,true))
@@ -1225,7 +1216,7 @@ void CanvasMode_NodeEdit::handleNodeEditDrag(QMouseEvent* m, PageItem* currItem)
 				}
 			}
 			m_doc->nodeEdit.moveClipPoint(currItem, npf);
-			m_canvas->displayXYHUD(m->globalPos(), npf.x(), npf.y());
+			m_canvas->displayXYHUD(m->globalPosition(), npf.x(), npf.y());
 		}
 		m_Mxp = newX;
 		m_Myp = newY;
