@@ -14,8 +14,6 @@
 ***************************************************************************/
 
 
-#include "canvasmode_normal.h"
-
 #include <QApplication>
 #include <QButtonGroup>
 #include <QCheckBox>
@@ -37,16 +35,12 @@
 #include "canvasgesture_linemove.h"
 #include "canvasgesture_resize.h"
 #include "canvasgesture_rulermove.h"
+#include "canvasmode_normal.h"
 #include "fileloader.h"
 #include "fpoint.h"
-#include "fpointarray.h"
-#include "hyphenator.h"
 #include "iconmanager.h"
 #include "loadsaveplugin.h"
-#include "pageitem_arc.h"
 #include "pageitem_line.h"
-#include "pageitem_regularpolygon.h"
-#include "plugins/formatidlist.h"
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
@@ -60,16 +54,8 @@
 #include "ui/aligndistribute.h"
 #include "ui/contextmenu.h"
 #include "ui/customfdialog.h"
-#include "ui/insertTable.h"
 #include "ui/pageselector.h"
-#include "ui/polyprops.h"
-#include "ui/propertiespalette.h"
-#include "ui/propertiespalette_line.h"
-#include "ui/propertiespalette_text.h"
-#include "ui/propertiespalette_xyz.h"
 #include "undomanager.h"
-#include "util.h"
-#include "util_math.h"
 
 CanvasMode_Normal::CanvasMode_Normal(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
 {
@@ -138,8 +124,11 @@ void CanvasMode_Normal::deactivate(bool forGesture)
 
 void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 {
+	const QPoint globalPos = m->globalPosition().toPoint();
 	PageItem *currItem = nullptr;
+
 	m->accept();
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	if (m_doc->drawAsPreview)
 	{
@@ -225,7 +214,7 @@ void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 		else if (currItem->itemType() == PageItem::TextFrame)
 		{
 			// See if double click was on a frame handle
-			FPoint p = m_canvas->globalToCanvas(m->globalPos());
+			FPoint p = m_canvas->globalToCanvas(m->globalPosition());
 			Canvas::FrameHandle fh = m_canvas->frameHitTest(QPointF(p.x(),p.y()), currItem);
 			//CB if annotation, open the annotation dialog
 			if (currItem->isAnnotation())
@@ -239,7 +228,7 @@ void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 			else if (m_doc->appMode != modeEdit)
 			{
 				m_view->requestMode(modeEdit);
-				m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
+				m_view->slotSetCurs(globalPos.x(), globalPos.y());
 				//used for updating Notes Styles Editor and menu actions for marks
 				//if cursor is in mark`s place
 				m_ScMW->setTBvals(currItem);
@@ -270,7 +259,7 @@ void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 		else if (currItem->isTable())
 		{
 			m_view->requestMode(modeEditTable);
-			m_view->slotSetCurs(m->globalPos().x(), m->globalPos().y());
+			m_view->slotSetCurs(globalPos.x(), globalPos.y());
 			m_ScMW->setTBvals(currItem);
 		}
 	}
@@ -280,16 +269,15 @@ void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 {
 // 	qDebug()<<"CanvasMode_Normal::mouseMoveEvent";
-// 	const double mouseX = m->globalX();
-// 	const double mouseY = m->globalY();
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const QPoint globalPos = m->globalPosition().toPoint();
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	
 	bool wasLastPostOverGuide = m_lastPosWasOverGuide;
 	m_lastPosWasOverGuide = false;
-	PageItem* currItem = nullptr;
+	PageItem *currItem = nullptr;
 	bool erf = false;
 	m->accept();
-//	qDebug() << "legacy mode move:" << m->x() << m->y() << m_canvas->globalToCanvas(m->globalPos()).x() << m_canvas->globalToCanvas(m->globalPos()).y();
+//	qDebug() << "legacy mode move:" << m->x() << m->y() << m_canvas->globalToCanvas(m->globalPosition()).x() << m_canvas->globalToCanvas(m->globalPosition()).y();
 //	emit MousePos(m->x()/m_canvas->scale(),// + m_doc->minCanvasCoordinate.x(), 
 //				  m->y()/m_canvas->scale()); // + m_doc->minCanvasCoordinate.y());
 
@@ -316,7 +304,7 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 		}
 		else
 		{
-			PageItem* hoveredItem = m_canvas->itemUnderCursor(m->globalPos(), nullptr, m->modifiers());
+			PageItem* hoveredItem = m_canvas->itemUnderCursor(m->globalPosition(), nullptr, m->modifiers());
 			if (hoveredItem)
 				frameResizeHandle = m_canvas->frameHitTest(QPointF(mousePointDoc.x(), mousePointDoc.y()), hoveredItem);
 		}
@@ -366,14 +354,14 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 	if (!movingOrResizing && mouseIsOnPage)
 	{
 		PageItem* hoveredItem = nullptr;
-		hoveredItem = m_canvas->itemUnderCursor(m->globalPos(), hoveredItem, m->modifiers());
+		hoveredItem = m_canvas->itemUnderCursor(m->globalPosition(), hoveredItem, m->modifiers());
 		if (hoveredItem)
 		{
 			if (m_doc->drawAsPreview)
 			{
 				if (hoveredItem->isAnnotation())
 				{
-					QString toolT = "";
+					QString toolT;
 					if (!hoveredItem->annotation().ToolTip().isEmpty())
 						toolT = hoveredItem->annotation().ToolTip();
 					if (hoveredItem->annotation().Type() == Annotation::Button)
@@ -396,7 +384,7 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 					if (toolT.isEmpty())
 						toolT = hoveredItem->itemText.plainText();
 					if (!toolT.isEmpty())
-						QToolTip::showText(m->globalPos() + QPoint(5, 5), toolT, m_canvas);
+						QToolTip::showText(globalPos + QPoint(5, 5), toolT, m_canvas);
 					if (hoveredItem != m_hoveredItem)
 					{
 						if (m_hoveredItem)
@@ -429,9 +417,9 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 			{
 				if (hoveredItem->isTextFrame() && hoveredItem->frameOverflows())
 				{
-					if (m_canvas->cursorOverTextFrameControl(m->globalPos(), hoveredItem))
+					if (m_canvas->cursorOverTextFrameControl(m->globalPosition(), hoveredItem))
 					{
-						QToolTip::showText(m->globalPos() + QPoint(5, 5), tr("Overflow Characters: %1 (%2 White Spaces)\nClick to link to existing text frame or auto-create new linked text frame").arg(hoveredItem->frameOverflowCount()).arg(hoveredItem->frameOverflowBlankCount()), m_canvas);
+						QToolTip::showText(globalPos + QPoint(5, 5), tr("Overflow Characters: %1 (%2 White Spaces)\nClick to link to existing text frame or auto-create new linked text frame").arg(hoveredItem->frameOverflowCount()).arg(hoveredItem->frameOverflowBlankCount()), m_canvas);
 					}
 				}
 				else
@@ -458,8 +446,8 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 	m_mouseCurrentPoint = mousePointDoc;
 	if ((GetItem(&currItem)) && (!m_shiftSelItems))
 	{
-		double newX = qRound(mousePointDoc.x()); //m_view->translateToDoc(m->x(), m->y()).x());
-		double newY = qRound(mousePointDoc.y()); //m_view->translateToDoc(m->x(), m->y()).y());
+		double newX = qRound(mousePointDoc.x());
+		double newY = qRound(mousePointDoc.y());
 		// #0007865
 		if (/*(((m_view->dragTimerElapsed()) && (m->buttons() & Qt::LeftButton)) ||*/
 			(m_view->moveTimerElapsed())
@@ -511,8 +499,8 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 			if (!m_canvas->m_viewMode.operItemResizing)
 			{
 				//Dragging an item (plus more?)
-				newX = mousePointDoc.x(); //static_cast<int>(m->x()/sc);
-				newY = mousePointDoc.y(); //static_cast<int>(m->y()/sc);
+				newX = mousePointDoc.x();
+				newY = mousePointDoc.y();
 				m_canvas->m_viewMode.operItemMoving = true;
 				if (!(m_doc->drawAsPreview && !m_doc->editOnPreview))
 					m_view->setCursor(Qt::ClosedHandCursor);
@@ -723,7 +711,7 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 					m_view->ensureVisible(selectionCenter.x(), selectionCenter.y(), localwidth / 2 + 20, localheight / 2 + 20);
 					m_canvas->repaint();
 					m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
-					m_canvas->displayCorrectedXYHUD(m->globalPos(), gx + m_objectDeltaPos.x(), gy + m_objectDeltaPos.y());
+					m_canvas->displayCorrectedXYHUD(m->globalPosition(), gx + m_objectDeltaPos.x(), gy + m_objectDeltaPos.y());
 				}
 			}
 		}
@@ -756,7 +744,8 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 					break;
 				QTransform p;
 				m_canvas->Transform(currItem, p);
-				QRect mpo(m->x() - m_doc->guidesPrefs().grabRadius, m->y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
+				QPoint mouseMoint = m->position().toPoint();
+				QRect mpo(mouseMoint.x() - m_doc->guidesPrefs().grabRadius, mouseMoint.y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
 				if (QRegion(p.map(QPolygon(QRect(-3, -3, static_cast<int>(currItem->width() + 6), static_cast<int>(currItem->height() + 6))))).contains(mpo))
 				{
 					QRect tx = p.mapRect(QRect(0, 0, static_cast<int>(currItem->width()), static_cast<int>(currItem->height())));
@@ -805,7 +794,7 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 			double newY = qRound(mousePointDoc.y());
 			m_mouseSavedPoint.setXY(newX, newY);
 			QPoint startP = m_canvas->canvasToGlobal(m_mousePressPoint);
-			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
+			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(globalPos)).normalized());
 			m_view->setRedrawMarkerShown(true);
 			m_view->HaveSelRect = true;
 			return;
@@ -816,7 +805,8 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 void CanvasMode_Normal::mousePressEvent(QMouseEvent *m)
 {
 //	qDebug("CanvasMode_Normal::mousePressEvent");
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const QPoint globalPos = m->globalPosition().toPoint();
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	PageItem *currItem;
 
 	m_objectDeltaPos  = FPoint(0, 0);
@@ -828,7 +818,7 @@ void CanvasMode_Normal::mousePressEvent(QMouseEvent *m)
 	m_doc->DragP = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
+	m_view->registerMousePress(m->globalPosition());
 
 	if (m->button() == Qt::MiddleButton)
 	{
@@ -909,7 +899,7 @@ void CanvasMode_Normal::mousePressEvent(QMouseEvent *m)
 		if (m_doc->m_Selection->isEmpty())
 		{
 			m_mouseCurrentPoint = m_mousePressPoint = m_mouseSavedPoint = mousePointDoc;
-			m_view->redrawMarker->setGeometry(m->globalPos().x(), m->globalPos().y(), 1, 1);
+			m_view->redrawMarker->setGeometry(globalPos.x(), globalPos.y(), 1, 1);
 			m_view->setRedrawMarkerShown(true);
 		}
 		else
@@ -962,8 +952,8 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 #ifdef GESTURE_FRAME_PREVIEW
 	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-	PageItem *currItem;
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
+	PageItem *currItem { nullptr };
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m->accept();
@@ -990,12 +980,12 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 	// link text frames
 	//<<#10116: Click on overflow icon to get into link frame mode
 	PageItem* clickedItem = nullptr;
-	clickedItem = m_canvas->itemUnderCursor(m->globalPos(), clickedItem, m->modifiers());
+	clickedItem = m_canvas->itemUnderCursor(m->globalPosition(), clickedItem, m->modifiers());
 	if (clickedItem && clickedItem->isTextFrame() && (!clickedItem->isAnnotation()) && (!m_doc->drawAsPreview))
 	{
 		if (clickedItem->frameOverflows())
 		{
-			if (m_canvas->cursorOverTextFrameControl(m->globalPos(), clickedItem))
+			if (m_canvas->cursorOverTextFrameControl(m->globalPosition(), clickedItem))
 			{
 				m_view->requestMode(modeLinkFrames);
 				return;
@@ -1110,6 +1100,7 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 			m_view->updatesOn(true);
 			m_view->updateContents();
 			m_doc->changed();
+			m_doc->changedPagePreview();
 		}
 	}
 
@@ -1261,7 +1252,7 @@ void CanvasMode_Normal::mouseReleaseEvent(QMouseEvent *m)
 				{
 					if (currItem->annotation().IsOpen())
 					{
-						if (m_canvas->cursorOverFrameControl(m->globalPos(), QRectF(245, 20, 11, 11), currItem))
+						if (m_canvas->cursorOverFrameControl(m->globalPosition(), QRectF(245, 20, 11, 11), currItem))
 						{
 							currItem->annotation().setOpen(false);
 							currItem->asTextFrame()->setTextAnnotationOpen(false);
@@ -1421,7 +1412,7 @@ void CanvasMode_Normal::handleRadioButtonRelease(PageItem* currItem)
 
 void CanvasMode_Normal::handleJavaAction(PageItem* currItem, int event)
 {
-	QString scriptCode = "";
+	QString scriptCode;
 	switch (event)
 	{
 		case Annotation::Java_PressButton:
@@ -1558,12 +1549,10 @@ bool CanvasMode_Normal::SeleItem(QMouseEvent *m)
 	QTransform p;
 	PageItem *currItem;
 	m_canvas->m_viewMode.m_MouseButtonPressed = true;
-	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	m_mouseCurrentPoint  = mousePointDoc;
-//	double grabRadius = m_doc->guidesPrefs().grabRadius / m_canvas->scale();
-	int MxpS = static_cast<int>(mousePointDoc.x()); //m->x()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.x());
-	int MypS = static_cast<int>(mousePointDoc.y()); //m->y()/m_canvas->scale() + 0*m_doc->minCanvasCoordinate.y());
-//	QRectF mpo(m_mouseCurrentPoint.x()-grabRadius, m_mouseCurrentPoint.y()-grabRadius, grabRadius*2, grabRadius*2);
+	int MxpS = static_cast<int>(mousePointDoc.x());
+	int MypS = static_cast<int>(mousePointDoc.y());
 	m_doc->nodeEdit.deselect();
 
 	 // Guides are on foreground and want to be processed first
@@ -1582,7 +1571,7 @@ bool CanvasMode_Normal::SeleItem(QMouseEvent *m)
 		}
 		else
 		{
-			PageItem* hoveredItem = m_canvas->itemUnderCursor(m->globalPos(), nullptr, m->modifiers());
+			PageItem* hoveredItem = m_canvas->itemUnderCursor(m->globalPosition(), nullptr, m->modifiers());
 			if (hoveredItem)
 				frameResizeHandle = m_canvas->frameHitTest(QPointF(mousePointDoc.x(), mousePointDoc.y()), hoveredItem);
 		}
@@ -1679,7 +1668,7 @@ bool CanvasMode_Normal::SeleItem(QMouseEvent *m)
 		m_view->deselectItems(false);
 	}
 
-	currItem = m_canvas->itemUnderCursor(m->globalPos(), currItem, ((m->modifiers() & SELECT_IN_GROUP) || (m_doc->drawAsPreview && !m_doc->editOnPreview)));
+	currItem = m_canvas->itemUnderCursor(m->globalPosition(), currItem, ((m->modifiers() & SELECT_IN_GROUP) || (m_doc->drawAsPreview && !m_doc->editOnPreview)));
 	if (currItem)
 	{
 		m_doc->m_Selection->delaySignalsOn();
@@ -1751,7 +1740,7 @@ bool CanvasMode_Normal::SeleItem(QMouseEvent *m)
 		}
 		else
 		{
-			PageItem* hoveredItem = m_canvas->itemUnderCursor(m->globalPos(), nullptr, m->modifiers());
+			PageItem* hoveredItem = m_canvas->itemUnderCursor(m->globalPosition(), nullptr, m->modifiers());
 			if (hoveredItem)
 				frameResizeHandle = m_canvas->frameHitTest(QPointF(mousePointDoc.x(), mousePointDoc.y()), hoveredItem);
 		}
@@ -1810,7 +1799,7 @@ void CanvasMode_Normal::importToPage()
 			int en = fmt->filter.indexOf(")");
 			while (an != -1)
 			{
-				allFormats += fmt->filter.mid(an+1, en-an-1)+" ";
+				allFormats += fmt->filter.mid(an + 1, en - an - 1)+" ";
 				an = fmt->filter.indexOf("(", en);
 				en = fmt->filter.indexOf(")", an);
 			}
