@@ -13,7 +13,7 @@
 *                                                                         *
 ***************************************************************************/
 
-#include "canvasmode_rotate.h"
+
 
 #include <QMouseEvent>
 #include <QPainter>
@@ -21,19 +21,20 @@
 
 #include "appmodes.h"
 #include "canvas.h"
+#include "canvasmode_rotate.h"
 #include "fpoint.h"
 #include "iconmanager.h"
 #include "pageitem.h"
 #include "prefsmanager.h"
-#include "ui/propertiespalette.h"
-#include "ui/propertiespalette_xyz.h"
-#include "ui/basepointwidget.h"
 #include "scribus.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
+#include "ui/basepointwidget.h"
 #include "ui/contextmenu.h"
 #include "ui/pageselector.h"
+#include "ui/propertiespalette.h"
+#include "ui/propertiespalette_xyz.h"
 #include "ui/scrspinbox.h"
 #include "undomanager.h"
 #include "util_math.h"
@@ -67,7 +68,7 @@ void CanvasMode_Rotate::drawItemOutlines(QPainter* p)
 	/*p->scale(m_canvas->scale(), m_canvas->scale());
 	p->translate(-m_doc->minCanvasCoordinate.x(), -m_doc->minCanvasCoordinate.y());*/
 
-	QColor  drawColor = qApp->palette().color(QPalette::Active, QPalette::Highlight);
+	QColor  drawColor = QApplication::palette().color(QPalette::Active, QPalette::Highlight);
 	p->setRenderHint(QPainter::Antialiasing);
 	p->setBrush(Qt::NoBrush);
 	p->setPen(QPen(drawColor, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
@@ -87,7 +88,7 @@ void CanvasMode_Rotate::drawItemOutlines(QPainter* p)
 	p->restore();
 }
 
-void CanvasMode_Rotate::getNewItemPosition(PageItem* item, FPoint& pos, double& rotation)
+void CanvasMode_Rotate::getNewItemPosition(const PageItem* item, FPoint& pos, double& rotation)
 {
 	double newAngle = xy2Deg(m_canvasCurrCoord.x() - m_rotCenter.x(), m_canvasCurrCoord.y() - m_rotCenter.y());
 	if (m_angleConstrained)
@@ -112,7 +113,7 @@ void CanvasMode_Rotate::getNewItemPosition(PageItem* item, FPoint& pos, double&
 		pos.setXY(ma.m11() * n.x() + ma.m21() * n.y() + ma.dx(), ma.m22() * n.y() + ma.m12() * n.x() + ma.dy());
 		rotation = item->rotation() + newAngle;
 	}
-	else if (m_rotMode != 0)
+	else if (m_rotMode != AnchorPoint::TopLeft)
 	{
 		FPoint n(0,0);
 		QTransform ma;
@@ -122,21 +123,41 @@ void CanvasMode_Rotate::getNewItemPosition(PageItem* item, FPoint& pos, double&
 		double ro = newAngle - item->rotation();
 		switch (m_rotMode)
 		{
-		case 2:
-			ma.translate(item->width() / 2.0, item->height() / 2.0);
-			n = FPoint(-item->width() / 2.0, -item->height() / 2.0);
+		case AnchorPoint::None:
+		case AnchorPoint::TopLeft:
+			// No translation
 			break;
-		case 4:
-			ma.translate(item->width(), item->height());
-			n = FPoint(-item->width(), -item->height());
+		case AnchorPoint::Top:
+			ma.translate(item->width()/2.0, 0);
+			n = FPoint(-item->width()/2.0, 0);
 			break;
-		case 3:
+		case AnchorPoint::TopRight:
+			ma.translate(item->width(), 0);
+			n = FPoint(-item->width(), 0);
+			break;
+		case AnchorPoint::Left:
+			ma.translate(0, item->height()/2.0);
+			n = FPoint(0, -item->height()/2.0);
+			break;
+		case AnchorPoint::Center:
+			ma.translate(item->width()/2.0, item->height()/2.0);
+			n = FPoint(-item->width()/2.0, -item->height()/2.0);
+			break;
+		case AnchorPoint::Right:
+			ma.translate(item->width(), item->height()/2.0);
+			n = FPoint(-item->width(), -item->height()/2.0);
+			break;
+		case AnchorPoint::BottomLeft:
 			ma.translate(0, item->height());
 			n = FPoint(0, -item->height());
 			break;
-		case 1:
-			ma.translate(item->width(), 0);
-			n = FPoint(-item->width(), 0);
+		case AnchorPoint::Bottom:
+			ma.translate(item->width()/2.0, item->height());
+			n = FPoint(-item->width()/2.0, -item->height());
+			break;
+		case AnchorPoint::BottomRight:
+			ma.translate(item->width(), item->height());
+			n = FPoint(-item->width(), -item->height());
 			break;
 		}
 		ma.rotate(ro);
@@ -165,7 +186,7 @@ void CanvasMode_Rotate::activate(bool fromGesture)
 	m_view->MidButt  = false;
 	m_inItemRotation = false;
 	m_canvasPressCoord.setXY(-1.0, -1.0);
-	m_oldRotMode   = m_rotMode   = 0;
+	m_oldRotMode   = m_rotMode   = AnchorPoint::TopLeft;
 	m_oldRotCenter = m_rotCenter = FPoint(0.0, 0.0);
 	m_startAngle   = 0.0;
 	setModeCursor();
@@ -196,7 +217,7 @@ void CanvasMode_Rotate::leaveEvent(QEvent *e)
 
 void CanvasMode_Rotate::mousePressEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	m_canvasPressCoord = mousePointDoc;
 	
 	m_canvas->PaintSizeRect(QRect());
@@ -207,8 +228,8 @@ void CanvasMode_Rotate::mousePressEvent(QMouseEvent *m)
 	m_view->HaveSelRect = false;
 	m_doc->leaveDrag = false;
 	m->accept();
-	m_view->registerMousePress(m->globalPos());
-	QRect mpo(m->x()-m_doc->guidesPrefs().grabRadius, m->y()-m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius*2, m_doc->guidesPrefs().grabRadius*2);
+	m_view->registerMousePress(m->globalPosition());
+	QRect mpo(m->position().x()-m_doc->guidesPrefs().grabRadius, m->position().y()-m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius*2, m_doc->guidesPrefs().grabRadius*2);
 	double Rxp = m_doc->ApplyGridF(m_canvasPressCoord).x();
 	m_canvasPressCoord.setX( qRound(Rxp) );
 	double Ryp = m_doc->ApplyGridF(m_canvasPressCoord).y();
@@ -236,12 +257,12 @@ void CanvasMode_Rotate::mousePressEvent(QMouseEvent *m)
 			m_doc->m_Selection->getGroupRect(&gxR, &gyR, &gwR, &ghR);
 			if (QRect(static_cast<int>(gx), static_cast<int>(gy), static_cast<int>(gw), static_cast<int>(gh)).intersects(mpo))
 			{
-				m_rotMode   = 2;
+			m_rotMode   = AnchorPoint::Center;
 				m_rotCenter = FPoint(gxR + gwR / 2.0, gyR + ghR / 2.0);
 				if (QRect(static_cast<int>(gx + gw) - 6, static_cast<int>(gy + gh) - 6, 6, 6).intersects(mpo))
 				{
 					m_rotCenter = FPoint(gxR, gyR);
-					m_rotMode   = 0;
+					m_rotMode   = AnchorPoint::TopLeft;
 				}
 				m_doc->setRotationMode(m_rotMode);
 				m_view->RCenter = m_rotCenter;
@@ -253,7 +274,7 @@ void CanvasMode_Rotate::mousePressEvent(QMouseEvent *m)
 		{
 			QTransform mat;
 			m_canvas->Transform(currItem, mat);
-			m_rotMode   = 2;
+			m_rotMode   = AnchorPoint::Center;
 			m_rotCenter = FPoint(currItem->width() / 2, currItem->height() / 2, 0, 0, currItem->rotation(), 1, 1, false);
 //			if (!currItem->asLine())
 //			{
@@ -262,23 +283,43 @@ void CanvasMode_Rotate::mousePressEvent(QMouseEvent *m)
 					if (mat.mapRect(QRect(0, 0, 6, 6)).intersects(mpo))
 					{
 						m_rotCenter = FPoint(currItem->width(), currItem->height(), 0, 0, currItem->rotation(), 1, 1, false);
-						m_rotMode   = 4;
+						m_rotMode   = AnchorPoint::BottomRight;
+					}
+					else if (mat.mapRect(QRect(static_cast<int>(currItem->width() / 2) - 6, 0, 6, 6)).intersects(mpo))
+					{
+						m_rotCenter = FPoint((currItem->width() / 2), currItem->height(), 0, 0, currItem->rotation(), 1, 1, false);
+						m_rotMode   = AnchorPoint::Bottom;
 					}
 					else if (mat.mapRect(QRect(static_cast<int>(currItem->width()) - 6, 0, 6, 6)).intersects(mpo))
 					{
 						m_rotCenter = FPoint(0, currItem->height(), 0, 0, currItem->rotation(), 1, 1, false);
-						m_rotMode   = 3;
+						m_rotMode   = AnchorPoint::BottomLeft;
 					}
 					else if (mat.mapRect(QRect(static_cast<int>(currItem->width()) - 6, static_cast<int>(currItem->height()) - 6, 6, 6)).intersects(mpo))
 					{
 						m_rotCenter = FPoint(0, 0);
-						m_rotMode   = 0;
+						m_rotMode   = AnchorPoint::TopLeft;
+					}
+					else if (mat.mapRect(QRect(static_cast<int>(currItem->width() / 2) - 6, static_cast<int>(currItem->height()) - 6, 6, 6)).intersects(mpo))
+					{
+						m_rotCenter = FPoint(currItem->width() / 2, 0, 0, 0, currItem->rotation(), 1, 1, false);
+						m_rotMode   = AnchorPoint::Top;
 					}
 					else if (mat.mapRect(QRect(0, static_cast<int>(currItem->height()) - 6, 6, 6)).intersects(mpo))
 					{
 						m_rotCenter = FPoint(currItem->width(), 0, 0, 0, currItem->rotation(), 1, 1, false);
-						m_rotMode   = 1;
+						m_rotMode   = AnchorPoint::TopRight;
 					}	
+					else if (mat.mapRect(QRect(0, static_cast<int>(currItem->height() / 2) - 6, 6, 6)).intersects(mpo))
+					{
+						m_rotCenter = FPoint(0, currItem->height() / 2, 0, 0, currItem->rotation(), 1, 1, false);
+						m_rotMode   = AnchorPoint::Left;
+					}
+					else if (mat.mapRect(QRect(currItem->width(), static_cast<int>(currItem->height() / 2) - 6, 6, 6)).intersects(mpo))
+					{
+						m_rotCenter = FPoint(currItem->width(), currItem->height() / 2, 0, 0, currItem->rotation(), 1, 1, false);
+						m_rotMode   = AnchorPoint::Right;
+					}
 				}
 				m_doc->setRotationMode(m_rotMode);
 				m_view->RCenter = m_rotCenter;
@@ -294,7 +335,7 @@ void CanvasMode_Rotate::mouseReleaseEvent(QMouseEvent *m)
 #ifdef GESTURE_FRAME_PREVIEW
 	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	PageItem *currItem;
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
@@ -316,7 +357,7 @@ void CanvasMode_Rotate::mouseReleaseEvent(QMouseEvent *m)
 			m_view->startGroupTransaction(Um::Rotate, "", Um::IRotate);
 		}
 		double angle = 0;
-		double newW  = xy2Deg(mousePointDoc.x() - m_view->RCenter.x(), mousePointDoc.y() - m_view->RCenter.y()); //xy2Deg(m->x()/sc - m_view->RCenter.x(), m->y()/sc - m_view->RCenter.y());
+		double newW  = xy2Deg(mousePointDoc.x() - m_view->RCenter.x(), mousePointDoc.y() - m_view->RCenter.y());
 		if (m->modifiers() & Qt::ControlModifier)
 		{
 			newW = constrainAngle(newW, m_doc->opToolPrefs().constrain);
@@ -378,7 +419,7 @@ void CanvasMode_Rotate::mouseReleaseEvent(QMouseEvent *m)
 
 void CanvasMode_Rotate::mouseMoveEvent(QMouseEvent *m)
 {
-	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
+	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPosition());
 	m_canvasCurrCoord  = mousePointDoc;
 	m_angleConstrained = false;
 	
@@ -394,7 +435,7 @@ void CanvasMode_Rotate::mouseMoveEvent(QMouseEvent *m)
 			double itemRotation;
 			FPoint itemPos;
 			getNewItemPosition(currItem, itemPos, itemRotation);
-			m_canvas->displayRotHUD(m->globalPos(), itemRotation);
+			m_canvas->displayRotHUD(m->globalPosition(), itemRotation);
 		}
 		if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 		{
@@ -416,7 +457,7 @@ void CanvasMode_Rotate::mouseMoveEvent(QMouseEvent *m)
 					break;
 				QTransform p;
 				m_canvas->Transform(currItem, p);
-				QRect mpo(m->x() - m_doc->guidesPrefs().grabRadius, m->y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
+				QRect mpo = QRect(m->position().x() - m_doc->guidesPrefs().grabRadius, m->position().y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
 				if ((QRegion(p.map(QPolygon(QRect(-3, -3, static_cast<int>(currItem->width() + 6), static_cast<int>(currItem->height() + 6))))).contains(mpo)))
 				{
 					QRect tx = p.mapRect(QRect(0, 0, static_cast<int>(currItem->width()), static_cast<int>(currItem->height())));
@@ -431,7 +472,8 @@ void CanvasMode_Rotate::mouseMoveEvent(QMouseEvent *m)
 		if ((m_canvas->m_viewMode.m_MouseButtonPressed) && (m->buttons() & Qt::LeftButton))
 		{
 			QPoint startP = m_canvas->canvasToGlobal(m_canvasPressCoord);
-			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(m->globalPos())).normalized());
+			QPoint globalPos = m->globalPosition().toPoint();
+			m_view->redrawMarker->setGeometry(QRect(m_view->mapFromGlobal(startP), m_view->mapFromGlobal(globalPos)).normalized());
 			m_view->setRedrawMarkerShown(true);
 			m_view->HaveSelRect = true;
 		}
@@ -457,15 +499,38 @@ void CanvasMode_Rotate::keyPressEvent(QKeyEvent *e)
 		m_oldRotCenter = m_rotCenter = m_view->RCenter;
 		m_doc->m_Selection->getVisualGroupRect(&gx, &gy, &gw, &gh);
 		m_rotMode   = m_doc->rotationMode();
-		m_rotCenter = FPoint(gx + gw / 2.0, gy + gh / 2.0);
-		if (m_rotMode == 0)
+
+		switch(m_rotMode){
+		case AnchorPoint::TopLeft:
 			m_rotCenter = FPoint(gx, gy);
-		else if (m_rotMode == 1)
+			break;
+		case AnchorPoint::Top:
+			m_rotCenter = FPoint(gx + gw / 2.0, gy);
+			break;
+		case AnchorPoint::TopRight:
 			m_rotCenter = FPoint(gx + gw, gy);
-		else if (m_rotMode == 3)
+			break;
+		case AnchorPoint::Left:
+			m_rotCenter = FPoint(gx, gy + gh / 2.0);
+			break;
+		case AnchorPoint::Right:
+			m_rotCenter = FPoint(gx + gw, gy + gh / 2.0);
+			break;
+		case AnchorPoint::BottomLeft:
 			m_rotCenter = FPoint(gx, gy + gh);
-		else if (m_rotMode == 4)
+			break;
+		case AnchorPoint::Bottom:
+			m_rotCenter = FPoint(gx + gw / 2.0, gy + gh);
+			break;
+		case AnchorPoint::BottomRight:
 			m_rotCenter = FPoint(gx + gw, gy + gh);
+			break;
+		case AnchorPoint::Center:
+		default:
+			m_rotCenter = FPoint(gx + gw / 2.0, gy + gh / 2.0);
+			break;
+		}
+
 	}
 }
 
@@ -473,17 +538,17 @@ void CanvasMode_Rotate::keyReleaseEvent(QKeyEvent *e)
 {
 	if (e->key() == Qt::Key_Up)
 	{
-		auto id = m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->checkedId();
-		id = id > 0 ? id - 1 : 4;
-		m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->setCheckedId(id);
+		auto id = m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->selectedAnchor();
+		//id = id > 0 ? id - 1 : 4;
+		m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->setSelectedAnchor(id);
 		m_doc->setRotationMode(id);
 		return;
 	}
 	if (e->key() == Qt::Key_Down)
 	{
-		auto id = m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->checkedId();
-		id = (id + 1) % 5;
-		m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->setCheckedId(id);
+		auto id = m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->selectedAnchor();
+		//id = (id + 1) % 5;
+		m_view->m_ScMW->propertiesPalette->xyzPal->basePointWidget->setSelectedAnchor(id);
 		m_doc->setRotationMode(id);
 		return;
 	}
