@@ -127,6 +127,7 @@ QList<ScColorProfileInfo> ScLcms2ColorMgmtEngineImpl::getAvailableProfileInfo(co
 		profileInfo.deviceClass = translateLcmsProfileClass( cmsGetDeviceClass(hIn) );
 		profileInfos.append(profileInfo);
 		cmsCloseProfile(hIn);
+		hIn = nullptr;
 	}
 
 	return profileInfos;
@@ -534,12 +535,12 @@ eProfileClass ScLcms2ColorMgmtEngineImpl::translateLcmsProfileClass(cmsProfileCl
 
 QString ScLcms2ColorMgmtEngineImpl::translateLcmsWCharToQString(const wchar_t* wstr, int size)
 {
-	static_assert(sizeof(wchar_t) == 2 || sizeof(wchar_t) == 4, "wchar_t size is unexpected");
+	static_assert(sizeof(wchar_t) == 2 || sizeof(wchar_t) == 4);
 
-	if (sizeof(wchar_t) == 2)
+	if constexpr (sizeof(wchar_t) == 2)
 		return QString::fromWCharArray(wstr, size);
 
-	if (sizeof(wchar_t) == 4)
+	if constexpr (sizeof(wchar_t) == 4)
 	{
 		// In this case lcms2 use wchar_t type to carry UTF16 data,
 		// so we have to convert wchar_t data to ushort type before
@@ -549,18 +550,18 @@ QString ScLcms2ColorMgmtEngineImpl::translateLcmsWCharToQString(const wchar_t* w
 		if (size <= 0)
 			return QString();
 
-		std::unique_ptr<ushort[]> utf16Data(new (std::nothrow) ushort[(size_t) size + 1]);
+		std::unique_ptr<char16_t[]> utf16Data(new (std::nothrow) char16_t[(size_t) size + 1]);
 		if (utf16Data)
 		{
 			for (int i = 0; i < size; ++i)
-				utf16Data[i] = static_cast<ushort>(wstr[i]);
+				utf16Data[i] = static_cast<char16_t>(wstr[i]);
 			utf16Data[size] = 0;
 			return QString::fromUtf16(utf16Data.get(), size);
 		}
 	}
 
 	return QString();
- }
+}
 
 void ScLcms2ColorMgmtEngineImpl::cmsErrorHandler(cmsContext contextID, cmsUInt32Number /*ErrorCode*/, 
 												 const char *ErrorText)
