@@ -6,7 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 /***************************************************************************
 	copyright            : (C) 2006 by Craig Bradney
-	email                : cbradney@zip.com.au
+	email                : cbradney@scribus.info
 ***************************************************************************/
 
 #include "colorsetmanager.h"
@@ -19,7 +19,6 @@ for which a new license (GPL+exception) is in place.
 #include "prefsstructs.h"
 #include "fileloader.h"
 #include "loadsaveplugin.h"
-#include "plugins/formatidlist.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
 #include <QDomElement>
@@ -48,7 +47,7 @@ void ColorSetManager::initialiseDefaultPrefs(struct ApplicationPrefs& appPrefs)
 		appPrefs.colorPrefs.DColors.insert("Red", ScColor(0, 255, 255, 0));
 		appPrefs.colorPrefs.DColors.insert("Yellow", ScColor(0, 0, 255, 0));
 		appPrefs.colorPrefs.DColors.insert("Magenta", ScColor(0, 255, 0, 0));
-		appPrefs.colorPrefs.DColorSet = "Scribus_Small";
+		appPrefs.colorPrefs.DColorSet = "Scribus Small";
 		return;
 	}
 
@@ -284,7 +283,14 @@ bool ColorSetManager::checkPaletteFormat(const QString& paletteFileName) const
 		return false;
 	QDomDocument docu("scridoc");
 	QTextStream ts(&f);
-	ts.setCodec("UTF-8");
+	ts.setEncoding(QStringConverter::Utf8);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	if (!docu.setContent(ts.readAll()))
+	{
+		f.close();
+		return false;
+	}
+#else
 	QString errorMsg;
 	int errorLine = 0, errorColumn = 0;
 	if (!docu.setContent(ts.readAll(), &errorMsg, &errorLine, &errorColumn))
@@ -292,6 +298,7 @@ bool ColorSetManager::checkPaletteFormat(const QString& paletteFileName) const
 		f.close();
 		return false;
 	}
+#endif
 	f.close();
 	QDomElement elem = docu.documentElement();
 	return elem.tagName() == "SCRIBUSCOLORS";
@@ -316,7 +323,7 @@ bool ColorSetManager::loadPalette(const QString& paletteFileName, ScribusDoc *do
 			doc->docGradients.clear();
 			doc->docPatterns.clear();
 		}
-		const FileFormat *fmt = LoadSavePlugin::getFormatById(FORMATID_SLA150IMPORT);
+		const FileFormat *fmt = LoadSavePlugin::getFormatById(FORMATID_SLA170IMPORT);
 		if (fmt)
 		{
 			fmt->setupTargets(doc, nullptr, doc->scMW(), nullptr, &(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts));
