@@ -9,7 +9,7 @@ for which a new license (GPL+exception) is in place.
 	copyright			: (C) 2005 by Franz Schmid
 	email				: Franz.Schmid@altmuehlnet.de
 	copyright			: (C) 2005 by Craig Bradney
-	email				: cbradney@zip.com.au
+	email				: cbradney@scribus.info
 ***************************************************************************/
 
 /***************************************************************************
@@ -21,6 +21,8 @@ for which a new license (GPL+exception) is in place.
 *																		 *
 ***************************************************************************/
 
+#include <QList>
+
 #include "commonstrings.h"
 #include "documentchecker.h"
 #include "pageitem.h"
@@ -31,12 +33,8 @@ for which a new license (GPL+exception) is in place.
 #include "scribusdoc.h"
 #include "scribusstructs.h"
 #include "text/textlayoutpainter.h"
-#include "util.h"
 #include "util_formats.h"
 
-#include <QList>
-
-
 class MissingGlyphsPainter: public TextLayoutPainter
 {
 	errorCodes& m_itemError;
@@ -110,7 +108,7 @@ bool DocumentChecker::checkDocument(ScribusDoc *currDoc, const QString& checkerP
 void DocumentChecker::checkPages(ScribusDoc *currDoc, const CheckerPrefs& checkerSettings)
 {
 	errorCodes pageError;
-	for (int i=0; i < currDoc->DocPages.count(); ++i )
+	for (int i = 0; i < currDoc->DocPages.count(); ++i)
 	{
 		pageError.clear();
 		if (checkerSettings.checkAppliedMasterDifferentSide)
@@ -305,7 +303,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 					if  (((qRound(72.0 / currItem->imageXScale()) > checkerSettings.maxResolution) || (qRound(72.0 / currItem->imageYScale()) > checkerSettings.maxResolution))
 							&& (currItem->isRaster) && (checkerSettings.checkResolution))
 						itemError.insert(ImageDPITooHigh, 0);
-					QFileInfo fi = QFileInfo(currItem->Pfile);
+					QFileInfo fi(currItem->Pfile);
 					QString ext = fi.suffix().toLower();
 					if (extensionIndicatesPDF(ext) && (checkerSettings.checkRasterPDF))
 						itemError.insert(PlacedPDF, 0);
@@ -569,7 +567,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 					if  (((qRound(72.0 / currItem->imageXScale()) > checkerSettings.maxResolution) || (qRound(72.0 / currItem->imageYScale()) > checkerSettings.maxResolution))
 							&& (currItem->isRaster) && (checkerSettings.checkResolution))
 						itemError.insert(ImageDPITooHigh, 0);
-					QFileInfo fi = QFileInfo(currItem->Pfile);
+					QFileInfo fi(currItem->Pfile);
 					QString ext = fi.suffix().toLower();
 					if (extensionIndicatesPDF(ext) && (checkerSettings.checkRasterPDF))
 						itemError.insert(PlacedPDF, 0);
@@ -597,7 +595,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 								}
 								if (checkerSettings.checkNotCMYKOrSpot)
 								{
-									for (int i=0; i<usedColorSpaces.size(); ++i)
+									for (int i = 0; i < usedColorSpaces.size(); ++i)
 									{
 										if (usedColorSpaces[i] == CS_DeviceRGB || usedColorSpaces[i] == CS_ICCBased || usedColorSpaces[i] == CS_CalGray
 											|| usedColorSpaces[i] == CS_CalRGB || usedColorSpaces[i] == CS_Lab)
@@ -609,7 +607,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 								}
 								if (checkerSettings.checkDeviceColorsAndOutputIntent && currDoc->HasCMS)
 								{
-									for (int i=0; i<usedColorSpaces.size(); ++i)
+									for (int i = 0; i < usedColorSpaces.size(); ++i)
 									{
 										if (currPrintProfCS == ColorSpace_Cmyk && (usedColorSpaces[i] == CS_DeviceRGB || usedColorSpaces[i] == CS_DeviceGray))
 										{
@@ -628,7 +626,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 								itemError.insert(Transparency, 0);
 							if (checkerSettings.checkFontNotEmbedded || checkerSettings.checkFontIsOpenType)
 							{
-								for (int i=0; i<usedFonts.size(); ++i)
+								for (int i = 0; i < usedFonts.size(); ++i)
 								{
 									PDFFont currentFont = usedFonts[i];
 									if (!currentFont.isEmbedded && checkerSettings.checkFontNotEmbedded)
@@ -639,7 +637,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 							}
 							if (checkerSettings.checkResolution)
 							{
-								for (int i=0; i<imgs.size(); ++i)
+								for (int i = 0; i < imgs.size(); ++i)
 								{
 									if ((imgs[i].dpiX < checkerSettings.minResolution) || (imgs[i].dpiY < checkerSettings.minResolution))
 										itemError.insert(ImageDPITooLow, 0);
@@ -656,7 +654,7 @@ void DocumentChecker::checkItems(ScribusDoc *currDoc, const CheckerPrefs& checke
 				if ( currItem->frameOverflows() && (checkerSettings.checkOverflow) && (!((currItem->isAnnotation()) && ((currItem->annotation().Type() == Annotation::Combobox) || (currItem->annotation().Type() == Annotation::Listbox)))))
 					itemError.insert(TextOverflow, 0);
 
-				if (checkerSettings.checkEmptyTextFrames && (currItem->itemText.length()==0 || currItem->frameUnderflows()))
+				if (checkerSettings.checkEmptyTextFrames && (currItem->itemText.length() == 0 || currItem->frameUnderflows()))
 				{
 					bool isEmptyAnnotation = (currItem->isAnnotation() && 
 					                         ((currItem->annotation().Type() == Annotation::Link) ||
