@@ -5,10 +5,11 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 
-#include <cstdlib>
 #include <cmath>
+#include <cstdlib>
 #include <zlib.h>
 
+#include <QApplication>
 #include <QCheckBox>
 #include <QCursor>
 #include <QDir>
@@ -18,31 +19,20 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMessageBox>
 #include <QProgressBar>
-#include <QRegExp>
-#include <QtAlgorithms>
 #include <QTextCodec>
 #include <QTextStream>
+#include <QtAlgorithms>
 
 #include "commonstrings.h"
 #include "fileloader.h"
-#include "hyphenator.h"
 #include "loadsaveplugin.h"
-#include "pagestructs.h"
-#include "pluginmanager.h"
 #include "prefsmanager.h"
 #include "resourcecollection.h"
 #include "scclocale.h"
 #include "scconfig.h"
-#include "scpage.h"
 #include "scribuscore.h"
-#include "scribusXml.h"
-#include "units.h"
-#include "util.h"
-
-#include "plugins/formatidlist.h"
-#include "ui/guidemanager.h"
 #include "ui/fontreplacedialog.h"
-#include "ui/missing.h"
+#include "util.h"
 
 /*!
  \author Franz Schmid
@@ -57,6 +47,7 @@ FileLoader::FileLoader(const QString & fileName) :
 	formatSLA13x(LoadSavePlugin::getFormatById(FORMATID_SLA13XIMPORT)),
 	formatSLA134(LoadSavePlugin::getFormatById(FORMATID_SLA134IMPORT)),
 	formatSLA150(LoadSavePlugin::getFormatById(FORMATID_SLA150IMPORT)),
+	formatSLA170(LoadSavePlugin::getFormatById(FORMATID_SLA170IMPORT)),
 	m_prefsManager(PrefsManager::instance()),
 	m_fileName(fileName),
 	m_fileType(-1)
@@ -67,8 +58,6 @@ FileLoader::FileLoader(const QString & fileName) :
 	m_newReplacement = false;
 }
 
-// FIXME: This static method is here as a temporary transitional
-// measure during the process of converting to file loader plugins.
 const QString FileLoader::getLoadFilterString()
 {
 //	return LoadSavePlugin::fileDialogLoadFilter().join(";;");
@@ -97,6 +86,13 @@ const QString FileLoader::getLoadFilterString()
 	return fmtString.simplified();
 }
 
+const QString FileLoader::getSaveAsFilterString()
+{
+	QStringList fmts = LoadSavePlugin::fileDialogSaveFilter();
+	QString fmtString = fmts.join(";;");
+	return fmtString.simplified();
+}
+
 /*!
  \fn int FileLoader::TestFile()
  \author Franz Schmid
@@ -106,7 +102,7 @@ const QString FileLoader::getLoadFilterString()
  */
 int FileLoader::testFile()
 {
-	QFileInfo fi = QFileInfo(m_fileName);
+	QFileInfo fi(m_fileName);
 	int ret = -1;
 	if (!fi.exists())
 		ret = -1;
@@ -182,7 +178,8 @@ bool FileLoader::loadPage(ScribusDoc* currDoc, int PageToLoad, bool Mpage, const
 // 			if (ret)
 // 				it->plug->getReplacedFontData(newReplacement, ReplacedFonts, dummyScFaces);
 		}
-		if (m_fileType == FORMATID_SLA13XIMPORT || m_fileType == FORMATID_SLA134IMPORT || m_fileType == FORMATID_SLA150IMPORT)
+		if (m_fileType == FORMATID_SLA13XIMPORT || m_fileType == FORMATID_SLA134IMPORT || 
+			m_fileType == FORMATID_SLA150IMPORT || m_fileType == FORMATID_SLA170IMPORT)
 		{
 			it->plug->setupTargets(currDoc, nullptr, currDoc->scMW(), currDoc->scMW()->mainWindowProgressBar, &(m_prefsManager.appPrefs.fontPrefs.AvailFonts));
 			ret = it->plug->loadPage(m_fileName, PageToLoad, Mpage, renamedPageName);
@@ -202,7 +199,7 @@ bool FileLoader::loadPage(ScribusDoc* currDoc, int PageToLoad, bool Mpage, const
  \date
  \brief Loads the file "FileName" as a Scribus document
  \param currDoc the current document
- \retval bool true when loading is succsessful, false otherwise
+ \retval bool true when loading is successful, false otherwise
  */
 bool FileLoader::loadFile(ScribusDoc* currDoc)
 {
@@ -248,6 +245,7 @@ bool FileLoader::loadFile(ScribusDoc* currDoc)
 			case FORMATID_SLA13XIMPORT:
 			case FORMATID_SLA134IMPORT:
 			case FORMATID_SLA150IMPORT:
+			case FORMATID_SLA170IMPORT:
 				{
 					it->setupTargets(currDoc, nullptr, currDoc->scMW(), currDoc->scMW()->mainWindowProgressBar, &(m_prefsManager.appPrefs.fontPrefs.AvailFonts));
 					ret = it->loadFile(m_fileName, LoadSavePlugin::lfCreateDoc);
@@ -264,11 +262,11 @@ bool FileLoader::loadFile(ScribusDoc* currDoc)
 	return ret;
 }
 
-bool FileLoader::saveFile(const QString& fileName, ScribusDoc *doc, QString *savedFile)
+bool FileLoader::saveFile(const QString& fileName, ScribusDoc *doc, QString *savedFile, uint formatID)
 {
 	bool ret = false;
 	QList<FileFormat>::const_iterator it;
-	if (findFormat(FORMATID_SLA150EXPORT, it))
+	if (findFormat(formatID, it))
 	{
 		it->setupTargets(doc, doc->view(), doc->scMW(), doc->scMW()->mainWindowProgressBar, &(m_prefsManager.appPrefs.fontPrefs.AvailFonts));
 		ret = it->saveFile(fileName);
@@ -379,7 +377,6 @@ void FileLoader::readParagraphStyle(ParagraphStyle& vg, const QDomElement& pg, S
 			tgv >> xf2;
 			tb.tabPosition = ScCLocale::toDoubleC(xf2);
 			tb.tabType = static_cast<int>(ScCLocale::toDoubleC(xf));
-			tb.tabFillChar =  QChar();
 			tbs.append(tb);
 		}
 		vg.setTabValues(tbs);
@@ -397,10 +394,8 @@ void FileLoader::readParagraphStyle(ParagraphStyle& vg, const QDomElement& pg, S
 				ParagraphStyle::TabRecord tb;
 				tb.tabPosition = ScCLocale::toDoubleC(it.attribute("Pos"));
 				tb.tabType = it.attribute("Type").toInt();
-				QString tbCh = it.attribute("Fill", QString());
-				if (tbCh.isEmpty())
-					tb.tabFillChar = QChar();
-				else
+				QString tbCh(it.attribute("Fill", QString()));
+				if (!tbCh.isEmpty())
 					tb.tabFillChar = tbCh[0];
 				tbs.append(tb);
 			}
@@ -473,3 +468,16 @@ bool FileLoader::findFormat(uint formatId, QList<FileFormat>::const_iterator &it
 	}
 	return false;
 }
+
+uint FileLoader::findFormatIDFromDescription(const QString &fileType)
+{
+	QList<FileFormat> fileFormats(LoadSavePlugin::supportedFormats());
+	auto it = fileFormats.constBegin();
+	auto itEnd(fileFormats.constEnd());
+	for (; it != itEnd; ++it)
+	{
+		if (it->trName == fileType)
+			return it->formatId;
+	}
+	return -1;
+}
