@@ -117,8 +117,8 @@ void gtAction::writeUnstyled(const QString& text, bool isNote)
 	textStr.remove(ch13);
 	textStr.replace(ch10, ch13);
 	textStr.replace(ch5, ch13);
-	textStr.replace(QString(0x2028), SpecialChars::LINEBREAK);
-	textStr.replace(QString(0x2029), SpecialChars::PARSEP);
+	textStr.replace(QChar(0x2028), SpecialChars::LINEBREAK);
+	textStr.replace(QChar(0x2029), SpecialChars::PARSEP);
 	if (isNote)
 	{
 		if (m_note == nullptr)
@@ -812,7 +812,7 @@ QString gtAction::parseColor(const QString &s)
 			c = QColor(r.toInt(), g.toInt(), b.toInt());
 		}
 		else
-			c.setNamedColor(s.trimmed());
+			c = QColor::fromString(s.trimmed());
 		found = false;
 		for (it = m_textFrame->doc()->PageColors.begin(); it != m_textFrame->doc()->PageColors.end(); ++it)
 		{
@@ -840,6 +840,7 @@ void gtAction::finalize()
 		m_textFrame->doc()->docHyphenator->slotHyphenate(m_textFrame);
 	m_textFrame->doc()->regionsChanged()->update(QRectF());
 	m_textFrame->doc()->changed();
+	m_textFrame->doc()->changedPagePreview();
 }
 
 gtAction::~gtAction()
