@@ -13,7 +13,7 @@ for which a new license (GPL+exception) is in place.
 	copyright            : (C) 2004 by Alessandro Rimoldi
 	email                : http://ideale.ch/contact
 	copyright            : (C) 2005 by Craig Bradney
-	email                : cbradney@zip.com.au
+	email                : cbradney@scribus.info
 ***************************************************************************/
 
 /***************************************************************************
@@ -37,6 +37,7 @@ for which a new license (GPL+exception) is in place.
 #include <io.h>
 
 #include <QApplication>
+#include <QImageReader>
 #include <QMessageBox>
 #include <exception>
 
@@ -79,9 +80,9 @@ bool emergencyActivated { false };
 
 #if !defined(_CONSOLE)
 #if defined(_DEBUG)
-#pragma comment(lib, "qtmaind.lib")
+#pragma comment(lib, "Qt6EntryPointd.lib")
 #else
-#pragma comment(lib, "qtmain.lib")
+#pragma comment(lib, "Qt6EntryPoint.lib")
 #endif
 #endif
 
@@ -100,6 +101,7 @@ int main(int argc, char *argv[])
 
 	ScribusQApp::setAttribute(Qt::AA_EnableHighDpiScaling);
 	ScribusQApp::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
+	QImageReader::setAllocationLimit(1024);
 
 	ScribusQApp app(argc, argv);
 	setPythonEnvironment(ScribusQApp::applicationDirPath());
