@@ -506,7 +506,7 @@ public: // Start public functions
 	void dropLinks();
 	void unlinkWithText();
 
-	void setSampleItem(bool b) { m_sampleItem = b; }
+	void setSampleItem(bool b) {m_sampleItem = b;}
 	const QVector<double>& dashes() const { return DashValues; }
 	QVector<double>& dashes() { return DashValues; }
 	void setDashes(const QVector<double>& val) { DashValues = val; }
@@ -729,7 +729,7 @@ public: // Start public functions
 	void maskFlip(bool &flipX, bool &flipY) const;
 	//
 	bool fillEvenOdd() const { return fillRule; }
-	void setFillEvenOdd(bool val);
+	void setFillEvenOdd(bool evenOdd);
 	//
 	bool overprint() const { return doOverprint; }
 	void setOverprint(bool val);
@@ -1274,7 +1274,7 @@ public: // Start public functions
 	void setImageVisible(bool);
 
 	void updateConstants();
-	bool isWelded() const {return !weldList.isEmpty(); }  //true if to this item some other items are welded (weldList is list of these items)
+	bool isWelded() const { return !weldList.isEmpty(); }  //true if to this item some other items are welded (weldList is list of these items)
 	void weldTo(PageItem* item);
 	QList<PageItem*> itemsWeldedTo(PageItem* except = nullptr);
 	void unWeld();
@@ -1287,7 +1287,7 @@ public: // Start public functions
 	
 	bool groupClipping() const { return m_groupClips; }
 	void setGroupClipping(bool val) { m_groupClips = val; }
-
+	
 	virtual bool hasFill() const { return ((fillColor() != CommonStrings::None) || (GrType != 0)); }
 	virtual bool hasStroke() const { return ((lineColor() != CommonStrings::None) || (GrTypeStroke != 0) || (!NamedLStyle.isEmpty()) || (!patternStrokeVal.isEmpty())); }
 
