@@ -196,7 +196,6 @@ void PageItem_Line::getBoundingRect(double *x1, double *y1, double *x2, double *
 	if (m_rotation != 0)
 	{
 		FPointArray pb;
-		pb.resize(0);
 		pb.addPoint(FPoint(0,       - m_lineWidth / 2.0, m_xPos, m_yPos, m_rotation, 1.0, 1.0));
 		pb.addPoint(FPoint(m_width, - m_lineWidth / 2.0, m_xPos, m_yPos, m_rotation, 1.0, 1.0));
 		pb.addPoint(FPoint(m_width, + m_lineWidth / 2.0, m_xPos, m_yPos, m_rotation, 1.0, 1.0));
@@ -221,7 +220,7 @@ void PageItem_Line::getBoundingRect(double *x1, double *y1, double *x2, double *
 		*y2 = m_yPos + qMax(1.0, m_lineWidth) / 2.0;
 	}
 
-	QRectF totalRect(QPointF(*x1, *y1), QPointF(*x2, *y2));
+	QRectF totalRect = QRectF(QPointF(*x1, *y1), QPointF(*x2, *y2));
 	if (m_startArrowIndex != 0)
 	{
 		QRectF arrowRect = getStartArrowBoundingRect();
@@ -244,7 +243,6 @@ void PageItem_Line::getOldBoundingRect(double *x1, double *y1, double *x2, doubl
 	if (oldRot != 0)
 	{
 		FPointArray pb;
-		pb.resize(0);
 		pb.addPoint(FPoint(0,        - m_oldLineWidth / 2.0, oldXpos, oldYpos, oldRot, 1.0, 1.0));
 		pb.addPoint(FPoint(oldWidth, - m_oldLineWidth / 2.0, oldXpos, oldYpos, oldRot, 1.0, 1.0));
 		pb.addPoint(FPoint(oldWidth, + m_oldLineWidth / 2.0, oldXpos, oldYpos, oldRot, 1.0, 1.0));
@@ -269,7 +267,7 @@ void PageItem_Line::getOldBoundingRect(double *x1, double *y1, double *x2, doubl
 		*y2 = oldYpos + qMax(1.0, m_oldLineWidth) / 2.0;
 	}
 
-	QRectF totalRect(QPointF(*x1, *y1), QPointF(*x2, *y2));
+	QRectF totalRect = QRectF(QPointF(*x1, *y1), QPointF(*x2, *y2));
 	if (m_startArrowIndex != 0)
 	{
 		QRectF arrowRect = getStartArrowOldBoundingRect();
@@ -293,7 +291,6 @@ void PageItem_Line::getVisualBoundingRect(double * x1, double * y1, double * x2,
 	if (m_rotation != 0)
 	{
 		FPointArray pb;
-		pb.resize(0);
 		pb.addPoint(FPoint(0.0,           -extraSpace, xPos(), yPos(), m_rotation, 1.0, 1.0));
 		pb.addPoint(FPoint(visualWidth(), -extraSpace, xPos(), yPos(), m_rotation, 1.0, 1.0));
 		pb.addPoint(FPoint(visualWidth(), +extraSpace, xPos(), yPos(), m_rotation, 1.0, 1.0));
@@ -334,132 +331,116 @@ void PageItem_Line::getVisualBoundingRect(double * x1, double * y1, double * x2,
 
 QRectF PageItem_Line::getStartArrowBoundingRect() const
 {
-	QRectF arrowRect;
-	if (m_startArrowIndex != 0)
+	if (m_startArrowIndex == 0)
+		return QRectF();
+	QTransform arrowTrans;
+	FPointArray arrow = m_Doc->arrowStyles().at(m_startArrowIndex - 1).points.copy();
+	arrowTrans.translate(m_xPos, m_yPos);
+	arrowTrans.rotate(m_rotation);
+	arrowTrans.translate(0, 0);
+	arrowTrans.scale(m_startArrowScale / 100.0, m_startArrowScale / 100.0);
+	if (NamedLStyle.isEmpty())
 	{
-		QTransform arrowTrans;
-		FPointArray arrow = m_Doc->arrowStyles().at(m_startArrowIndex - 1).points.copy();
-		arrowTrans.translate(m_xPos, m_yPos);
-		arrowTrans.rotate(m_rotation);
-		arrowTrans.translate(0, 0);
-		arrowTrans.scale(m_startArrowScale / 100.0, m_startArrowScale / 100.0);
-		if (NamedLStyle.isEmpty())
-		{
-			if (m_lineWidth != 0.0)
-				arrowTrans.scale(m_lineWidth, m_lineWidth);
-		}
-		else
-		{
-			const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
-			const SingleLine& sl = ml.last();
-			if (sl.Width != 0.0)
-				arrowTrans.scale(sl.Width, sl.Width);
-		}
-		arrowTrans.scale(-1, 1);
-		arrow.map(arrowTrans);
-		FPoint minAr = getMinClipF(&arrow);
-		FPoint maxAr = getMaxClipF(&arrow);
-		arrowRect = QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
+		if (m_lineWidth != 0.0)
+			arrowTrans.scale(m_lineWidth, m_lineWidth);
 	}
-
-	return arrowRect;
+	else
+	{
+		const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
+		const SingleLine& sl = ml.last();
+		if (sl.Width != 0.0)
+			arrowTrans.scale(sl.Width, sl.Width);
+	}
+	arrowTrans.scale(-1, 1);
+	arrow.map(arrowTrans);
+	FPoint minAr = getMinClipF(&arrow);
+	FPoint maxAr = getMaxClipF(&arrow);
+	return QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));;
 }
 
 QRectF PageItem_Line::getStartArrowOldBoundingRect() const
 {
-	QRectF arrowRect;
-	if (m_startArrowIndex != 0)
+	if (m_startArrowIndex == 0)
+		return QRectF();
+	QTransform arrowTrans;
+	FPointArray arrow = m_Doc->arrowStyles().at(m_startArrowIndex - 1).points.copy();
+	arrowTrans.translate(oldXpos, oldYpos);
+	arrowTrans.rotate(oldRot);
+	arrowTrans.translate(0, 0);
+	arrowTrans.scale(m_startArrowScale / 100.0, m_startArrowScale / 100.0);
+	if (NamedLStyle.isEmpty())
 	{
-		QTransform arrowTrans;
-		FPointArray arrow = m_Doc->arrowStyles().at(m_startArrowIndex - 1).points.copy();
-		arrowTrans.translate(oldXpos, oldYpos);
-		arrowTrans.rotate(oldRot);
-		arrowTrans.translate(0, 0);
-		arrowTrans.scale(m_startArrowScale / 100.0, m_startArrowScale / 100.0);
-		if (NamedLStyle.isEmpty())
-		{
-			if (m_oldLineWidth != 0.0)
-				arrowTrans.scale(m_oldLineWidth, m_oldLineWidth);
-		}
-		else
-		{
-			const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
-			const SingleLine& sl = ml.last();
-			if (sl.Width != 0.0)
-				arrowTrans.scale(sl.Width, sl.Width);
-		}
-		arrowTrans.scale(-1, 1);
-		arrow.map(arrowTrans);
-		FPoint minAr = getMinClipF(&arrow);
-		FPoint maxAr = getMaxClipF(&arrow);
-		arrowRect = QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
+		if (m_oldLineWidth != 0.0)
+			arrowTrans.scale(m_oldLineWidth, m_oldLineWidth);
 	}
-
-	return arrowRect;
+	else
+	{
+		const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
+		const SingleLine& sl = ml.last();
+		if (sl.Width != 0.0)
+			arrowTrans.scale(sl.Width, sl.Width);
+	}
+	arrowTrans.scale(-1, 1);
+	arrow.map(arrowTrans);
+	FPoint minAr = getMinClipF(&arrow);
+	FPoint maxAr = getMaxClipF(&arrow);
+	return QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
 }
 
 QRectF PageItem_Line::getEndArrowBoundingRect() const
 {
-	QRectF arrowRect;
-	if (m_endArrowIndex != 0)
+	if (m_endArrowIndex == 0)
+		return QRectF();
+	QTransform arrowTrans;
+	FPointArray arrow = m_Doc->arrowStyles().at(m_endArrowIndex - 1).points.copy();
+	arrowTrans.translate(m_xPos, m_yPos);
+	arrowTrans.rotate(m_rotation);
+	arrowTrans.translate(m_width, 0);
+	arrowTrans.scale(m_endArrowScale / 100.0, m_endArrowScale / 100.0);
+	if (NamedLStyle.isEmpty())
 	{
-		QTransform arrowTrans;
-		FPointArray arrow = m_Doc->arrowStyles().at(m_endArrowIndex - 1).points.copy();
-		arrowTrans.translate(m_xPos, m_yPos);
-		arrowTrans.rotate(m_rotation);
-		arrowTrans.translate(m_width, 0);
-		arrowTrans.scale(m_endArrowScale / 100.0, m_endArrowScale / 100.0);
-		if (NamedLStyle.isEmpty())
-		{
-			if (m_lineWidth != 0.0)
-				arrowTrans.scale(m_lineWidth, m_lineWidth);
-		}
-		else
-		{
-			const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
-			const SingleLine& sl = ml.last();
-			if (sl.Width != 0.0)
-				arrowTrans.scale(sl.Width, sl.Width);
-		}
-		arrow.map(arrowTrans);
-		FPoint minAr = getMinClipF(&arrow);
-		FPoint maxAr = getMaxClipF(&arrow);
-		arrowRect = QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
+		if (m_lineWidth != 0.0)
+			arrowTrans.scale(m_lineWidth, m_lineWidth);
 	}
-
-	return arrowRect;
+	else
+	{
+		const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
+		const SingleLine& sl = ml.last();
+		if (sl.Width != 0.0)
+			arrowTrans.scale(sl.Width, sl.Width);
+	}
+	arrow.map(arrowTrans);
+	FPoint minAr = getMinClipF(&arrow);
+	FPoint maxAr = getMaxClipF(&arrow);
+	return QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
 }
 
 QRectF PageItem_Line::getEndArrowOldBoundingRect() const
 {
-	QRectF arrowRect;
-	if (m_endArrowIndex != 0)
+	if (m_endArrowIndex == 0)
+		return QRectF();
+	QTransform arrowTrans;
+	FPointArray arrow = m_Doc->arrowStyles().at(m_endArrowIndex - 1).points.copy();
+	arrowTrans.translate(oldXpos, oldYpos);
+	arrowTrans.rotate(oldRot);
+	arrowTrans.translate(oldWidth, 0);
+	arrowTrans.scale(m_endArrowScale / 100.0, m_endArrowScale / 100.0);
+	if (NamedLStyle.isEmpty())
 	{
-		QTransform arrowTrans;
-		FPointArray arrow = m_Doc->arrowStyles().at(m_endArrowIndex - 1).points.copy();
-		arrowTrans.translate(oldXpos, oldYpos);
-		arrowTrans.rotate(oldRot);
-		arrowTrans.translate(oldWidth, 0);
-		arrowTrans.scale(m_endArrowScale / 100.0, m_endArrowScale / 100.0);
-		if (NamedLStyle.isEmpty())
-		{
-			if (m_oldLineWidth != 0.0)
-				arrowTrans.scale(m_oldLineWidth, m_oldLineWidth);
-		}
-		else
-		{
-			const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
-			const SingleLine& sl = ml.last();
-			if (sl.Width != 0.0)
-				arrowTrans.scale(sl.Width, sl.Width);
-		}
-		arrow.map(arrowTrans);
-		FPoint minAr = getMinClipF(&arrow);
-		FPoint maxAr = getMaxClipF(&arrow);
-		arrowRect = QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
+		if (m_oldLineWidth != 0.0)
+			arrowTrans.scale(m_oldLineWidth, m_oldLineWidth);
 	}
-
-	return arrowRect;
+	else
+	{
+		const MultiLine ml = m_Doc->docLineStyles[NamedLStyle];
+		const SingleLine& sl = ml.last();
+		if (sl.Width != 0.0)
+			arrowTrans.scale(sl.Width, sl.Width);
+	}
+	arrow.map(arrowTrans);
+	FPoint minAr = getMinClipF(&arrow);
+	FPoint maxAr = getMaxClipF(&arrow);
+	return QRectF(QPointF(minAr.x(), minAr.y()), QPointF(maxAr.x(), maxAr.y()));
 }
 
 double PageItem_Line::visualXPos() const
