@@ -8,7 +8,7 @@ for which a new license (GPL+exception) is in place.
 #ifndef CXFDOCUMENT_H
 #define CXFDOCUMENT_H
 
-#include <QDomDocument>
+#include <QDomElement>
 #include <QList>
 #include <QMap>
 #include <QString>
@@ -33,12 +33,12 @@ public:
 	bool parse(const QString& fileName);
 	void reset();
 	
-protected:
+private:
 	QMap<QString, CxfColorSpecificationShPtr> m_colorSpecs;
 	QList<CxfObject*> m_objects;
 	
-	bool parseColorSpecificationCollection(QDomElement& elem);
-	bool parseObjectCollection(QDomElement& elem);
+	bool parseColorSpecificationCollection(const QDomElement& elem);
+	bool parseObjectCollection(const QDomElement& elem);
 };
 
 #endif
