@@ -69,17 +69,24 @@ namespace Pdf
 	 Cf. PDF32000-2008, 7.3.3
 	 */
 	QByteArray toPdf(uint v);
-	
+
 	/**
 	 Cf. PDF32000-2008, 7.3.3
 	 */
 	QByteArray toPdf(qlonglong v);
-	
+
 	/**
 	 Cf. PDF32000-2008, 7.3.3
 	 */
 	QByteArray toPdf(qulonglong v);
 	
+	/**
+	 Cf. PDF32000-2008, 7.3.3
+	 */
+#if !defined(Q_OS_WIN) && (Q_PROCESSOR_WORDSIZE != 4)
+	QByteArray toPdf(size_t v);
+#endif
+	
 	/**
 	 Cf. PDF32000-2008, 7.3.3
 	 */
@@ -133,8 +140,8 @@ namespace Pdf
 	/**
 	 converts to a PDF rectangle, cf. PDF32000-2008, 8.9.5
 	 */
-	QByteArray toRectangleArray(const QRect& r);
-	QByteArray toRectangleArray(const QRectF& r);
+	QByteArray toRectangleArray(QRect r);
+	QByteArray toRectangleArray(QRectF r);
 	
 	
 	
