@@ -5,6 +5,12 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 
+#include <QDebug>
+#include <QRegularExpression>
+#include <QStandardItemModel>
+#include <QTextStream>
+#include <QThread>
+#include <QTimer>
 
 #include "../formatidlist.h"
 #include "barcodegenerator.h"
@@ -16,16 +22,12 @@ for which a new license (GPL+exception) is in place.
 #include "ui/colorsandfills.h"
 #include "undomanager.h"
 
-#include <QDebug>
-#include <QTextStream>
-#include <QStandardItemModel>
-#include <QTimer>
-#include <QThread>
+
 
 BarcodeType::BarcodeType(const QString &cmd, const QString &exa, const QString &exaop)
-           : command(cmd),
-             exampleContents(exa),
-             exampleOptions(exaop)
+		   : command(cmd),
+			 exampleContents(exa),
+			 exampleOptions(exaop)
 {
 
 }
@@ -64,43 +66,42 @@ BarcodeGenerator::BarcodeGenerator(QWidget* parent, const char* name)
 	QString bwipp = ts.readAll();
 	f.close();
 
-	QRegExp rx(
+	QRegularExpression rx(
 				"[\\r\\n]+% --BEGIN (RESOURCE|RENDERER|ENCODER) ([\\w-]+)--[\\r\\n]+"
 				"(.*[\\r\\n]+)?"
 				"(%%BeginResource.*[\\r\\n]+)"
-				"% --END \\1 \\2--[\\r\\n]+");
-	rx.setMinimal(true);
-	int pos = 0;
-	while ( (pos = rx.indexIn(bwipp, pos)) != -1 )
+				"% --END \\1 \\2--[\\r\\n]+",
+				QRegularExpression::InvertedGreedinessOption | QRegularExpression::DotMatchesEverythingOption);
+
+	for (const QRegularExpressionMatch& match : rx.globalMatch(bwipp))
 	{
-		int len = rx.matchedLength();
-		QString restype = rx.cap(1);
-		QString resname = rx.cap(2);
-		QString reshead = rx.cap(3);
-		QString resbody = rx.cap(4);
+		QString restype = match.captured(1);
+		QString resname = match.captured(2);
+		QString reshead = match.captured(3);
+		QString resbody = match.captured(4);
 
 		resbodys[resname] = resbody;
 
-		if (restype=="ENCODER")
+		if (restype == "ENCODER")
 		{
-			QRegExp rxhead(
+			QRegularExpression rxhead(
 						"% --REQUIRES (.*)--[\\r\\n]+"
 						"% --DESC:(.*)[\\r\\n]+"
 						"% --EXAM:(.*)[\\r\\n]+"
 						"% --EXOP:(.*)[\\r\\n]+"
 						"% --RNDR:(.*)[\\r\\n]+"
 						);
-			if (rxhead.indexIn(reshead) >= 0)
+			QRegularExpressionMatch match = rxhead.match(reshead);
+			if (match.hasMatch())
 			{
-				resreqs[resname] = rxhead.cap(1).trimmed();
-				resdescs[resname] = rxhead.cap(2).trimmed();
-				resexams[resname] = rxhead.cap(3).trimmed();
-				resexops[resname] = rxhead.cap(4).trimmed();
-				resrndrs[resname] = rxhead.cap(5).trimmed();
+				resreqs[resname] = match.captured(1).trimmed();
+				resdescs[resname] = match.captured(2).trimmed();
+				resexams[resname] = match.captured(3).trimmed();
+				resexops[resname] = match.captured(4).trimmed();
+				resrndrs[resname] = match.captured(5).trimmed();
 				encoderlist.append(resname);
 			}
 		}
-		pos += len;
 	}
 
 	foreach (const QString& enc, encoderlist)
@@ -314,8 +315,8 @@ BarcodeGenerator::BarcodeGenerator(QWidget* parent, const char* name)
 	paintBarcodeTimer->setSingleShot(true);
 	connect(paintBarcodeTimer, SIGNAL(timeout()), this, SLOT(paintBarcode()));
 
-	connect(ui.bcFamilyCombo, SIGNAL(activated(QString)), this, SLOT(bcFamilyComboChanged()));
-	connect(ui.bcCombo, SIGNAL(activated(QString)), this, SLOT(bcComboChanged()));
+	connect(ui.bcFamilyCombo, SIGNAL(activated(int)), this, SLOT(bcFamilyComboChanged()));
+	connect(ui.bcCombo, SIGNAL(activated(int)), this, SLOT(bcComboChanged()));
 	connect(ui.bgColorButton, SIGNAL(clicked()), this, SLOT(bgColorButton_pressed()));
 	connect(ui.lnColorButton, SIGNAL(clicked()), this, SLOT(lnColorButton_pressed()));
 	connect(ui.txtColorButton, SIGNAL(clicked()), this, SLOT(txtColorButton_pressed()));
@@ -462,62 +463,62 @@ void BarcodeGenerator::updateOptionsTextFromUI()
 
 	if (ui.includetextCheck->isChecked())
 	{
-		if (!opts.contains(QRegExp("\\bincludetext\\b")))
+		if (!opts.contains(QRegularExpression("\\bincludetext\\b")))
 			opts.append(" includetext");
 	}
 	else
 	{
-		opts.replace(QRegExp("\\bincludetext\\b")," ");
+		opts.replace(QRegularExpression("\\bincludetext\\b")," ");
 	}
 
 	if (ui.guardwhitespaceCheck->isChecked())
 	{
-		if (!opts.contains(QRegExp("\\bguardwhitespace\\b")))
+		if (!opts.contains(QRegularExpression("\\bguardwhitespace\\b")))
 			opts.append(" guardwhitespace");
 	}
 	else
 	{
-		opts.replace(QRegExp("\\bguardwhitespace\\b")," ");
+		opts.replace(QRegularExpression("\\bguardwhitespace\\b")," ");
 	}
 
 	if (ui.includecheckCheck->isChecked())
 	{
-		if (!opts.contains(QRegExp("\\bincludecheck\\b")))
+		if (!opts.contains(QRegularExpression("\\bincludecheck\\b")))
 			opts.append(" includecheck");
 	}
 	else
 	{
-		opts.replace(QRegExp("\\bincludecheck\\b")," ");
+		opts.replace(QRegularExpression("\\bincludecheck\\b")," ");
 	}
 
 	if (ui.includecheckintextCheck->isChecked())
 	{
-		if (!opts.contains(QRegExp("\\bincludecheckintext\\b")))
+		if (!opts.contains(QRegularExpression("\\bincludecheckintext\\b")))
 			opts.append(" includecheckintext");
 	}
 	else
 	{
-		opts.replace(QRegExp("\\bincludecheckintext\\b")," ");
+		opts.replace(QRegularExpression("\\bincludecheckintext\\b")," ");
 	}
 
 	if (ui.parseCheck->isChecked())
 	{
-		if (!opts.contains(QRegExp("\\bparse\\b")))
+		if (!opts.contains(QRegularExpression("\\bparse\\b")))
 			opts.append(" parse");
 	}
 	else
 	{
-		opts.replace(QRegExp("\\bparse\\b")," ");
+		opts.replace(QRegularExpression("\\bparse\\b")," ");
 	}
 
 	if (ui.parsefncCheck->isChecked())
 	{
-		if (!opts.contains(QRegExp("\\bparsefnc\\b")))
+		if (!opts.contains(QRegularExpression("\\bparsefnc\\b")))
 			opts.append(" parsefnc");
 	}
 	else
 	{
-		opts.replace(QRegExp("\\bparsefnc\\b")," ");
+		opts.replace(QRegularExpression("\\bparsefnc\\b")," ");
 	}
 
 	QString enc = map[ui.bcCombo->currentText()].command;
@@ -526,27 +527,27 @@ void BarcodeGenerator::updateOptionsTextFromUI()
 	if (ui.formatCombo->currentIndex() != 0)
 	{
 		QString t = ui.formatCombo->currentText();
-		if (!opts.contains(QRegExp("\\b" + QRegExp::escape(vlbl) + "=.*\\b")))
+		if (!opts.contains(QRegularExpression("\\b" + QRegularExpression::escape(vlbl) + "=.*\\b")))
 			opts.append(" " + vlbl + "=" + t);
 		else
-			opts.replace(QRegExp("\\b" + QRegExp::escape(vlbl) + "=\\S*\\b"), vlbl + "=" + t);
+			opts.replace(QRegularExpression("\\b" + QRegularExpression::escape(vlbl) + "=\\S*\\b"), vlbl + "=" + t);
 	}
 	else
 	{
-		opts.replace(QRegExp("\\b" + QRegExp::escape(vlbl) + "=\\S*\\b"), " ");
+		opts.replace(QRegularExpression("\\b" + QRegularExpression::escape(vlbl) + "=\\S*\\b"), " ");
 	}
 
 	if (ui.eccCombo->currentIndex() != 0)
 	{
 		QString t = ui.eccCombo->currentText();
-		if (!opts.contains(QRegExp("\\beclevel=.*\\b")))
+		if (!opts.contains(QRegularExpression("\\beclevel=.*\\b")))
 			opts.append(" eclevel=" + t);
 		else
-			opts.replace(QRegExp("\\beclevel=\\S*\\b"), "eclevel=" + t);
+			opts.replace(QRegularExpression("\\beclevel=\\S*\\b"), "eclevel=" + t);
 	}
 	else
 	{
-		opts.replace(QRegExp("\\beclevel=\\S*\\b")," ");
+		opts.replace(QRegularExpression("\\beclevel=\\S*\\b")," ");
 	}
 
 	ui.optionsEdit->blockSignals(true);
@@ -558,37 +559,38 @@ void BarcodeGenerator::updateOptionsTextFromUI()
 void BarcodeGenerator::updateUIFromOptionsText()
 {
 	ui.includetextCheck->blockSignals(true);
-	ui.includetextCheck->setChecked(ui.optionsEdit->text().contains(QRegExp("\\bincludetext\\b")));
+	ui.includetextCheck->setChecked(ui.optionsEdit->text().contains(QRegularExpression("\\bincludetext\\b")));
 	ui.includetextCheck->blockSignals(false);
 
 	ui.guardwhitespaceCheck->blockSignals(true);
-	ui.guardwhitespaceCheck->setChecked(ui.optionsEdit->text().contains(QRegExp("\\bguardwhitespace\\b")));
+	ui.guardwhitespaceCheck->setChecked(ui.optionsEdit->text().contains(QRegularExpression("\\bguardwhitespace\\b")));
 	ui.guardwhitespaceCheck->blockSignals(false);
 
 	ui.includecheckCheck->blockSignals(true);
-	ui.includecheckCheck->setChecked(ui.optionsEdit->text().contains(QRegExp("\\bincludecheck\\b")));
+	ui.includecheckCheck->setChecked(ui.optionsEdit->text().contains(QRegularExpression("\\bincludecheck\\b")));
 	ui.includecheckCheck->blockSignals(false);
 
 	ui.includecheckintextCheck->blockSignals(true);
-	ui.includecheckintextCheck->setChecked(ui.optionsEdit->text().contains(QRegExp("\\bincludecheckintext\\b")));
+	ui.includecheckintextCheck->setChecked(ui.optionsEdit->text().contains(QRegularExpression("\\bincludecheckintext\\b")));
 	ui.includecheckintextCheck->blockSignals(false);
 
 	ui.parseCheck->blockSignals(true);
-	ui.parseCheck->setChecked(ui.optionsEdit->text().contains(QRegExp("\\bparse\\b")));
+	ui.parseCheck->setChecked(ui.optionsEdit->text().contains(QRegularExpression("\\bparse\\b")));
 	ui.parseCheck->blockSignals(false);
 
 	ui.parsefncCheck->blockSignals(true);
-	ui.parsefncCheck->setChecked(ui.optionsEdit->text().contains(QRegExp("\\bparsefnc\\b")));
+	ui.parsefncCheck->setChecked(ui.optionsEdit->text().contains(QRegularExpression("\\bparsefnc\\b")));
 	ui.parsefncCheck->blockSignals(false);
 
 	QString enc = map[ui.bcCombo->currentText()].command;
 	QString vlbl = resvlbl.contains(enc) ? resvlbl[enc].toLower() : "version";
 
-	QRegExp rxf("\\b" + QRegExp::escape(vlbl) + "=(\\S*)\\b");
+	QRegularExpression rxf("\\b" + QRegularExpression::escape(vlbl) + "=(\\S*)\\b");
 	ui.formatCombo->blockSignals(true);
 	if (ui.optionsEdit->text().contains(rxf))
 	{
-		int idx = ui.formatCombo->findText(rxf.cap(1));
+		QRegularExpressionMatch match = rxf.match(ui.optionsEdit->text());
+		int idx = ui.formatCombo->findText(match.captured(1));
 		if (idx == -1)
 			idx = 0;
 		ui.formatCombo->setCurrentIndex(idx);
@@ -599,11 +601,12 @@ void BarcodeGenerator::updateUIFromOptionsText()
 	}
 	ui.formatCombo->blockSignals(false);
 
-	QRegExp rxe("\\beclevel=(\\S*)\\b");
+	QRegularExpression rxe("\\beclevel=(\\S*)\\b");
 	ui.eccCombo->blockSignals(true);
 	if (ui.optionsEdit->text().contains(rxe))
 	{
-		int idx = ui.eccCombo->findText(rxe.cap(1));
+		QRegularExpressionMatch match = rxe.match(ui.optionsEdit->text());
+		int idx = ui.eccCombo->findText(match.captured(1));
 		if (idx == -1)
 			idx = 0;
 		ui.eccCombo->setCurrentIndex(idx);
@@ -679,17 +682,12 @@ void BarcodeGenerator::on_eccCombo_currentIndexChanged(int)
 
 void BarcodeGenerator::paintColorSample(QLabel *l, const ScColor & c)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
 	QPixmap currentPixmap = l->pixmap(Qt::ReturnByValue);
-#else
-	QPixmap currentPixmap = l->pixmap() ? *(l->pixmap()) : QPixmap();
-#endif
-	
-	double pixelRatio = l->devicePixelRatioF();
 	QSize pixmapSize(currentPixmap.width(), currentPixmap.height());
 	if (currentPixmap.isNull())
 	{
 		QRect rect = l->frameRect();
+		double pixelRatio = l->devicePixelRatioF();
 		pixmapSize = QSize(rect.width() * pixelRatio, rect.height() * pixelRatio);
 	}
 	QPixmap pm(pixmapSize.width(), pixmapSize.height());
