@@ -128,7 +128,7 @@ class PLUGIN_API Scribus150Format : public LoadSavePlugin
 		void readToolSettings(ScribusDoc* doc, const ScXmlStreamAttributes& attrs) const;
 		void readTypographicSettings(ScribusDoc* doc, const ScXmlStreamAttributes& attrs) const;
 
-		bool readArrows(ScribusDoc* doc, const ScXmlStreamAttributes& attrs) const;
+		bool readArrows(ScribusDoc* doc, ScXmlStreamAttributes& attrs) const;
 		bool readBookMark(ScribusDoc::BookMa& bookmark, int& elem, const ScXmlStreamAttributes& attrs) const;
 		bool readCheckProfile(ScribusDoc* doc, const ScXmlStreamAttributes& attrs) const;
 		void readColor(ColorList& colors, const ScXmlStreamAttributes& attrs) const;
@@ -150,7 +150,7 @@ class PLUGIN_API Scribus150Format : public LoadSavePlugin
 		bool readPageSets(ScribusDoc* doc, ScXmlStreamReader& reader) const;
 		void readParagraphStyle(ScribusDoc *doc, ScXmlStreamReader& reader, ParagraphStyle& newStyle) const;
 		void readTableStyle(ScribusDoc *doc, ScXmlStreamReader& reader, TableStyle& newStyle) const;
-		void readTableBorderLines(ScribusDoc* doc, ScXmlStreamReader& reader, TableBorder& border) const;
+		void readTableBorderLines(ScribusDoc *doc, ScXmlStreamReader& reader, TableBorder& border) const;
 		void readCellStyle(ScribusDoc *doc, ScXmlStreamReader& reader, CellStyle& newStyle) const;
 		bool readPattern(ScribusDoc* doc, ScXmlStreamReader& reader, const QString& baseDir);
 		bool readPDFOptions(ScribusDoc* doc, ScXmlStreamReader& reader);
@@ -183,48 +183,48 @@ class PLUGIN_API Scribus150Format : public LoadSavePlugin
 
 		PageItem* pasteItem(ScribusDoc *doc, const ScXmlStreamAttributes& attrs, const QString& baseDir, PageItem::ItemKind itemKind, int pageNr = -2 /* currentPage*/);
 
-		void writeCheckerProfiles(ScXmlStreamWriter& docu) const;
-		void writeLineStyles(ScXmlStreamWriter& docu) const;
-		void writeLineStyles(ScXmlStreamWriter& docu, const QStringList& styleNames) const;
-		void writeArrowStyles(ScXmlStreamWriter& docu) const;
-		void writeJavascripts(ScXmlStreamWriter& docu) const;
-		void writeBookmarks(ScXmlStreamWriter& docu) const;
-		void writeColors(ScXmlStreamWriter& docu, bool part = false) const;
-		void writeColors(ScXmlStreamWriter& docu, const QStringList& colorNames) const;
-		void writeGradients(ScXmlStreamWriter & docu, bool part = false) const;
-		void writeGradients(ScXmlStreamWriter & docu, const QStringList& gradientNames) const;
-		void writeHyphenatorLists(ScXmlStreamWriter& docu) const;
-		void writeParagraphStyles(ScXmlStreamWriter& docu) const;
-		void writeCharStyles(ScXmlStreamWriter& docu) const;
-		void writeTableStyles(ScXmlStreamWriter& docu) const;
-		void writeCellStyles(ScXmlStreamWriter& docu) const;
-		void putPStyle(ScXmlStreamWriter& docu, const ParagraphStyle & style, const QString &nodeName) const;
-		void putCStyle(ScXmlStreamWriter& docu, const CharStyle & style) const;
-		void putNamedCStyle(ScXmlStreamWriter& docu, const CharStyle & style) const;
-		void putTableStyle(ScXmlStreamWriter& docu, const TableStyle & style) const;
-		void putCellStyle(ScXmlStreamWriter& docu, const CellStyle & style) const;
-		void writeStoryText(ScribusDoc *doc, ScXmlStreamWriter&, StoryText& story, PageItem* item = nullptr) const;
-		void writeITEXTs(ScribusDoc *doc, ScXmlStreamWriter&, StoryText& story, PageItem* item = nullptr) const;
-		void writeLayers(ScXmlStreamWriter& docu) const;
-		void writePrintOptions(ScXmlStreamWriter& docu) const;
-		void writePdfOptions(ScXmlStreamWriter& docu) const;
-		void writeDocItemAttributes(ScXmlStreamWriter& docu) const;
-		void writeTOC(ScXmlStreamWriter& docu) const;
-		void writeMarks(ScXmlStreamWriter & docu) const;
-		void writeNotesStyles(ScXmlStreamWriter & docu) const;
-		void writeNotesStyles(ScXmlStreamWriter & docu, const QStringList& styleSelection) const;
-		void writeNotesFrames(ScXmlStreamWriter & docu) const;
-		void writeNotesFrames(ScXmlStreamWriter & docu, const QList<PageItem_NoteFrame*>& nfList) const;
-		void writeNotes(ScXmlStreamWriter & docu) const;
-		void writeNotes(ScXmlStreamWriter & docu, const QList<TextNote*>& noteList) const;
-		void writePageSets(ScXmlStreamWriter& docu) const;
-		void writeSections(ScXmlStreamWriter& docu) const;
-		void writePatterns(ScXmlStreamWriter& docu, const QString& baseDir, bool part = false, Selection* selection = 0) const;
+		void writeCheckerProfiles(ScXmlStreamWriter& docu);
+		void writeLineStyles(ScXmlStreamWriter& docu);
+		void writeLineStyles(ScXmlStreamWriter& docu, const QStringList& styleNames);
+		void writeArrowStyles(ScXmlStreamWriter& docu);
+		void writeJavascripts(ScXmlStreamWriter& docu);
+		void writeBookmarks(ScXmlStreamWriter& docu);
+		void writeColors(ScXmlStreamWriter& docu, bool part = false);
+		void writeColors(ScXmlStreamWriter& docu, const QStringList& colorNames);
+		void writeGradients(ScXmlStreamWriter & docu, bool part = false);
+		void writeGradients(ScXmlStreamWriter & docu, const QStringList& gradientNames);
+		void writeHyphenatorLists(ScXmlStreamWriter& docu);
+		void writeParagraphStyles(ScXmlStreamWriter& docu);
+		void writeCharStyles(ScXmlStreamWriter& docu);
+		void writeTableStyles(ScXmlStreamWriter& docu);
+		void writeCellStyles(ScXmlStreamWriter& docu);
+		void putPStyle(ScXmlStreamWriter& docu, const ParagraphStyle & style, const QString &nodeName);
+		void putCStyle(ScXmlStreamWriter& docu, const CharStyle & style);
+		void putNamedCStyle(ScXmlStreamWriter& docu, const CharStyle & style);
+		void putTableStyle(ScXmlStreamWriter& docu, const TableStyle & style);
+		void putCellStyle(ScXmlStreamWriter& docu, const CellStyle & style);
+		void writeStoryText(ScribusDoc *doc, ScXmlStreamWriter&, StoryText& story, PageItem* item = nullptr);
+		void writeITEXTs(ScribusDoc *doc, ScXmlStreamWriter&, StoryText& story, PageItem* item = nullptr);
+		void writeLayers(ScXmlStreamWriter& docu);
+		void writePrintOptions(ScXmlStreamWriter& docu);
+		void writePdfOptions(ScXmlStreamWriter& docu);
+		void writeDocItemAttributes(ScXmlStreamWriter& docu);
+		void writeTOC(ScXmlStreamWriter& docu);
+		void writeMarks(ScXmlStreamWriter & docu);
+		void writeNotesStyles(ScXmlStreamWriter & docu);
+		void writeNotesStyles(ScXmlStreamWriter & docu, const QStringList& styleSelection);
+		void writeNotesFrames(ScXmlStreamWriter & docu);
+		void writeNotesFrames(ScXmlStreamWriter & docu, const QList<PageItem_NoteFrame*>& nfList);
+		void writeNotes(ScXmlStreamWriter & docu);
+		void writeNotes(ScXmlStreamWriter & docu, const QList<TextNote*>& noteList);
+		void writePageSets(ScXmlStreamWriter& docu);
+		void writeSections(ScXmlStreamWriter& docu);
+		void writePatterns(ScXmlStreamWriter& docu, const QString& baseDir, bool part = false, Selection* selection = 0);
 		void writeContent(ScXmlStreamWriter& docu, const QString& baseDir);
 
-		void WritePages(ScribusDoc *doc, ScXmlStreamWriter& docu, QProgressBar *dia2, uint maxC, bool master) const;
-		void WriteObjects(ScribusDoc *doc, ScXmlStreamWriter& docu, const QString& baseDir, QProgressBar *dia2, uint maxC, ItemSelection master, QList<PageItem*> *items = 0) const;
-		void SetItemProps(ScXmlStreamWriter& docu, PageItem* item, const QString& baseDir) const;
+		void WritePages(ScribusDoc *doc, ScXmlStreamWriter& docu, QProgressBar *dia2, uint maxC, bool master);
+		void WriteObjects(ScribusDoc *doc, ScXmlStreamWriter& docu, const QString& baseDir, QProgressBar *dia2, uint maxC, ItemSelection master, QList<PageItem*> *items = 0);
+		void SetItemProps(ScXmlStreamWriter& docu, PageItem* item, const QString& baseDir);
 		
 		QMap<QString, QString> charStyleMap;
 		QMap<QString, QString> parStyleMap;
@@ -250,6 +250,7 @@ class PLUGIN_API Scribus150Format : public LoadSavePlugin
 		int LayerToPaste {0};
 		int itemCount {0};
 		int itemCountM {0};
+		QString saveOldVersion {"1.5.8"};
 };
 
 extern "C" PLUGIN_API int scribus150format_getPluginAPIVersion();
