@@ -7,6 +7,7 @@ for which a new license (GPL+exception) is in place.
 
 #include <QSortFilterProxyModel>
 #include <QHeaderView>
+#include <QRegularExpression>
 
 #include "fontpreview.h"
 #include "prefsfile.h"
@@ -71,7 +72,7 @@ FontPreview::FontPreview(const QString& fontName, QWidget* parent, ScribusDoc* d
 		searchName = fontName;
 	else
 	{
-		Q_ASSERT(m_Doc!=nullptr);
+		Q_ASSERT(m_Doc != nullptr);
 		if (m_Doc->m_Selection->count() != 0)
 			searchName = m_Doc->currentStyle.charStyle().font().scName();
 		else
@@ -94,7 +95,7 @@ FontPreview::FontPreview(const QString& fontName, QWidget* parent, ScribusDoc* d
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(cancelButton_clicked()));
 	connect(resetDisplayButton, SIGNAL(clicked()), this, SLOT(resetDisplayButton_clicked()));
 	connect(sizeSpin, SIGNAL(valueChanged(int)), this, SLOT(sizeSpin_valueChanged(int)));
-	connect(fontList->selectionModel(), SIGNAL(currentChanged(const QModelIndex&,const QModelIndex&)), this, SLOT(fontList_currentChanged(const QModelIndex&, const QModelIndex&)));
+	connect(fontList->selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SLOT(fontList_currentChanged(QModelIndex,QModelIndex)));
 	connect(extendedCheckBox, SIGNAL(clicked(bool)), this, SLOT(setExtendedView(bool)));
 }
 
@@ -159,15 +160,16 @@ void FontPreview::searchEdit_textChanged(const QString &/*s*/)
 	fontList->blockSignals(true);
 	QString s(searchEdit->text());
 	if (s.isEmpty())
-		m_proxyModel->setFilterRegExp(QRegExp("*",
-											Qt::CaseInsensitive,
-											QRegExp::Wildcard));
+	{
+		QString wildcardExp = QRegularExpression::wildcardToRegularExpression(QString("*"));
+		QRegularExpression regExp(wildcardExp, QRegularExpression::CaseInsensitiveOption);
+		m_proxyModel->setFilterRegularExpression(regExp);
+	}
 	else
 	{
-		QRegExp regExp(QString("*%1*").arg(s),
-					   Qt::CaseInsensitive,
-					   QRegExp::Wildcard);
-		m_proxyModel->setFilterRegExp(regExp);
+		QString wildcardExp = QRegularExpression::wildcardToRegularExpression(QString("*%1*").arg(s));
+		QRegularExpression regExp(wildcardExp, QRegularExpression::CaseInsensitiveOption);
+		m_proxyModel->setFilterRegularExpression(regExp);
 	}
 	fontList->resizeColumnsToContents();
 	fontList->blockSignals(false);
