@@ -9,21 +9,24 @@
 
 // IMPORT
 
+#define FORMATID_SLA170IMPORT 46
 #define FORMATID_SLA150IMPORT 47
 #define FORMATID_SLA134IMPORT 48
 #define FORMATID_SLA13XIMPORT 49
 #define FORMATID_SLA12XIMPORT 50
 #define FORMATID_NATIVEIMPORTEND 99
-
+#define FORMATID_CURRENTIMPORT FORMATID_SLA170IMPORT
 #define FORMATID_FIRSTUSER     100
 
 // EXPORT
 
+#define FORMATID_SLA170EXPORT 46
 #define FORMATID_SLA150EXPORT 47
 #define FORMATID_SLA134EXPORT 48
 #define FORMATID_SLA13XEXPORT 49
 #define FORMATID_SLA12XEXPORT 50
 #define FORMATID_NATIVEEXPORTEND 99
+#define FORMATID_CURRENTEXPORT FORMATID_SLA170EXPORT
 
 #define FORMATID_ODGEXPORT 100
 #define FORMATID_SXDEXPORT 101
