@@ -17,6 +17,8 @@ for which a new license (GPL+exception) is in place.
 #include "pageitem.h"
 #include "scribusstructs.h"
 
+#include <memory>
+
 #include <QDomDocument>
 #include <QDomElement>
 #include <QHash>
@@ -67,9 +69,14 @@ public:
 class ODTIm
 {
 public:
-	ODTIm(const QString& fileName, PageItem *textItem, bool textOnly, bool prefix, bool append);
+	ODTIm(PageItem *textItem, bool prefix, bool append);
 	~ODTIm() = default;
 
+	ODTIm(ODTIm&) = delete;
+	ODTIm& operator=(const ODTIm&) = delete;
+
+	bool importFile(const QString& fileName, bool textOnly);
+
 private:
 	struct DrawStyle
 	{
@@ -106,12 +113,14 @@ private:
 		AttributeValue breakAfter;
 		AttributeValue language;
 	};
+
+	bool parseContent(const QString& fileName, bool textOnly);
+
 	bool parseRawDocReference(const QString& designMap);
 	bool parseRawDocReferenceXML(const QDomDocument &designMapDom);
-	void parseRawTextSpan(const QDomElement &elem, PageItem* item, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, int &posC);
-	void parseRawTextHyperlink(const QDomElement &elem, PageItem* item, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, int &posC);
-	void parseRawTextList(const QDomNode& elem, PageItem* item, const ParagraphStyle& newStyle, int& posC);
-	void parseRawTextParagraph(const QDomNode &elem, PageItem* item, const ParagraphStyle &newStyle, int &posC);
+	void parseRawTextSpan(const QDomElement &elem, PageItem* item, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, int &posC);
+	void parseRawTextHyperlink(const QDomElement &elem, PageItem* item, ParagraphStyle &tmpStyle, CharStyle &tmpCStyle, int &posC);
+	void parseRawTextParagraph(const QDomNode &elem, PageItem* item, ParagraphStyle &newStyle, int &posC);
 	void parseRawText(const QDomElement &elem, PageItem* item);
 
 	bool parseStyleSheets(const QString& designMap);
@@ -121,19 +130,18 @@ private:
 	bool parseDocReferenceXML(const QDomDocument &designMapDom);
 	void parseTextSpan(const QDomElement &elem, PageItem* item, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, const ObjStyleODT& tmpOStyle, int &posC);
 	void parseTextHyperlink(const QDomElement &elem, PageItem* item, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, const ObjStyleODT& tmpOStyle, int &posC);
-	void parseTextList(const QDomNode &elem, PageItem* item, const ParagraphStyle &newStyle, const ObjStyleODT &tmpOStyle, int &posC);
 	void parseTextParagraph(const QDomNode &elem, PageItem* item, const ParagraphStyle &newStyle, const ObjStyleODT &tmpOStyle, int &posC);
 	void parseText(const QDomElement &elem, PageItem* item, const ObjStyleODT& tmpOStyle);
 	void insertChars(PageItem *item, QString &txt, const ParagraphStyle &tmpStyle, const CharStyle &tmpCStyle, int &posC);
 	void applyCharacterStyle(CharStyle &tmpCStyle, const ObjStyleODT &oStyle);
 	void applyParagraphStyle(ParagraphStyle &tmpStyle, const ObjStyleODT &oStyle);
 	void resolveStyle(ObjStyleODT &tmpOStyle, const QString& pAttrs);
-	double parseUnit(const QString &unit) const;
+	double parseUnit(const QString &unit);
 	QString parseColor( const QString &s );
 	QString constructFontName(const QString& fontBaseName, const QString& fontStyle);
 	void setFontstyle(CharStyle &tmpCStyle, int kind);
 
-	ScZipHandler *uz {nullptr};
+	std::unique_ptr<ScZipHandler> m_zip;
 	ScribusDoc* m_Doc {nullptr};
 	PageItem* m_item {nullptr};
 	bool m_prefixName {false};
