@@ -127,7 +127,7 @@ bool ContentReader::startElement(const QString &name, const SXWAttributesMap &at
 		bool isTextStyle = false;
 		for (auto attr = attrs.cbegin(); attr != attrs.cend(); ++attr)
 		{
-			QString attrName = attr.key();
+			const QString& attrName = attr.key();
 			if (attrName == "style:name")
 				sname = attr.value();
 			else if ((attrName == "style:family") && (attr.value() == "text"))
@@ -168,9 +168,9 @@ bool ContentReader::startElement(const QString &name, const SXWAttributesMap &at
 
 bool ContentReader::characters(const QString &ch) 
 {
-	QString tmp = ch;
-	tmp = tmp.remove("\n");
-	tmp = tmp.remove(""); // Remove all OO.o hyphenation chars
+	QString tmp(ch);
+	tmp.remove("\n");
+	tmp.remove(""); // Remove all OO.o hyphenation chars
 	// Unneeded as scribus now also use standard unicode non-breakable space
 	// tmp = tmp.replace(QChar(160), SpecialChars::NBSPACE); // replace OO.o nbsp with Scribus nbsp
 	if (append > 0)
@@ -250,7 +250,7 @@ void ContentReader::parse(const QString& fileName)
 	sreader->parse(fileName);
 #if defined(_WIN32)
 	QString fname = QDir::toNativeSeparators(fileName);
-	QByteArray fn = (QSysInfo::WindowsVersion & QSysInfo::WV_NT_based) ? fname.toUtf8() : fname.toLocal8Bit();
+	QByteArray fn = fname.toUtf8();
 #else
 	QByteArray fn(fileName.toLocal8Bit());
 #endif
