@@ -145,8 +145,7 @@ bool StyleReader::startElement(const QString &name, const SXWAttributesMap &attr
 			if (!styleLines.isEmpty())
 			{
 				bool ok = false;
-				QString sd = styleLines;
-				int dh = sd.toInt(&ok);
+				int dh = styleLines.toInt(&ok);
 				if (ok)
 				{
 					gtParagraphStyle* s = dynamic_cast<gtParagraphStyle*>(currentStyle);
@@ -164,13 +163,13 @@ bool StyleReader::startElement(const QString &name, const SXWAttributesMap &attr
 		QString style;
 		for (auto attr = attrs.cbegin(); attr != attrs.cend(); ++attr)
 		{
-			QString attrName = attr.key();
+			const QString& attrName = attr.key();
 			if (attrName == "style:name")
 				key = attr.value();
 			else if (attrName == "fo:font-family")
 			{
 				family = attr.value();
-				family = family.remove("'");
+				family.remove("'");
 			}
 			else if (attrName == "style:font-style-name")
 				style += attr.value() + " ";
@@ -212,8 +211,8 @@ void StyleReader::styleProperties(const SXWAttributesMap& attrs)
 	bool hasColorTag = false;
 	for (auto attr = attrs.begin(); attr != attrs.end(); ++attr)
 	{
-		QString attrName = attr.key();
-		QString attrValue = attr.value();
+		const QString& attrName = attr.key();
+		const QString& attrValue = attr.value();
 		if ((attrName == "style:font-name") && (!inList))
 			currentStyle->getFont()->setName(getFont(attrValue));
 		else if (attrName == "fo:font-size")
@@ -274,11 +273,11 @@ void StyleReader::styleProperties(const SXWAttributesMap& attrs)
 			currentStyle->getFont()->setHscale(static_cast<int>(getSize(attrValue, -1.0)));
 		else if ((attrName == "style:text-position") &&
 				 ((attrValue.indexOf("sub") != -1) ||
-				  ((attrValue.at(0) == "-") && (attrValue.at(0) != "0"))))
+				  ((attrValue.at(0) == '-') && (attrValue.at(0) != '0'))))
 			currentStyle->getFont()->toggleEffect(SUBSCRIPT);
 		else if ((attrName == "style:text-position") &&
 				 ((attrValue.indexOf("super") != -1) ||
-				  ((attrValue.at(0) != "-") && (attrValue.at(0) != "0"))))
+				  ((attrValue.at(0) != '-') && (attrValue.at(0) != '0'))))
 			currentStyle->getFont()->toggleEffect(SUPERSCRIPT);
 		else if ((attrName == "fo:margin-top") && (pstyle != nullptr))
 			pstyle->setSpaceAbove(getSize(attrValue));
@@ -344,8 +343,8 @@ void StyleReader::styleStyle(const SXWAttributesMap& attrs)
 
 	for (auto attr = attrs.begin(); attr != attrs.end(); ++attr)
 	{
-		QString attrName = attr.key();
-		QString attrValue = attr.value();
+		const QString& attrName = attr.key();
+		const QString& attrValue = attr.value();
 		if (attrName == "style:family")
 		{
 			if (attrValue == "paragraph")
@@ -426,10 +425,10 @@ void StyleReader::tabStop(const SXWAttributesMap& attrs)
 		return;
 	gtParagraphStyle* pstyle = dynamic_cast<gtParagraphStyle*>(currentStyle);
 	assert(pstyle != nullptr);
-	QString pos = attrs.value("style:position");
+	QString pos(attrs.value("style:position"));
 	if (pos.isEmpty())
 		return;
-	QString type = attrs.value("style:type");
+	QString type(attrs.value("style:type"));
 	if (!type.isEmpty())
 		type = "left";
 	double posd = getSize(pos);
@@ -480,7 +479,7 @@ void StyleReader::parse(const QString& fileName)
 {
 #if defined(_WIN32)
 	QString fname = QDir::toNativeSeparators(fileName);
-	QByteArray fn = (QSysInfo::WindowsVersion & QSysInfo::WV_NT_based) ? fname.toUtf8() : fname.toLocal8Bit();
+	QByteArray fn = fname.toUtf8();
 #else
 	QByteArray fn(fileName.toLocal8Bit());
 #endif
@@ -505,16 +504,13 @@ gtStyle* StyleReader::getDefaultStyle()
 
 gtStyle* StyleReader::getStyle(const QString& name)
 {
-	if (styles.contains(name))
-	{
-		gtStyle* tmp = styles[name];
-		QString tname = tmp->getName();
-		if ((tname.indexOf(docname) == -1) && usePrefix)
-			tmp->setName(docname + "_" + tname);
-
-		return tmp;
-	}
-	return getDefaultStyle();
+	if (!styles.contains(name))
+		return getDefaultStyle();
+	gtStyle* tmp = styles[name];
+	QString tname(tmp->getName());
+	if ((tname.indexOf(docname) == -1) && usePrefix)
+		tmp->setName(docname + "_" + tname);
+	return tmp;
 }
 
 void StyleReader::setStyle(const QString& name, gtStyle* style)
@@ -652,11 +648,11 @@ bool StyleReader::updateStyle(gtStyle* style, gtStyle* parent2Style, const QStri
 		style->getFont()->setHscale(static_cast<int>(getSize(value, -1.0)));
 	else if ((key == "style:text-position") &&
 			 ((value.indexOf("sub") != -1) ||
-			  ((value.at(0) == "-") && (value.at(0) != "0"))))
+			  ((value.at(0) == '-') && (value.at(0) != '0'))))
 		style->getFont()->toggleEffect(SUBSCRIPT);
 	else if ((key == "style:text-position") &&
 			 ((value.indexOf("super") != -1) ||
-			  ((value.at(0) != "-") && (value.at(0) != "0"))))
+			  ((value.at(0) != '-') && (value.at(0) != '0'))))
 		style->getFont()->toggleEffect(SUPERSCRIPT);
 	else if ((key == "fo:margin-top") && (pstyle != nullptr))
 		pstyle->setSpaceAbove(getSize(value));
@@ -704,7 +700,7 @@ bool StyleReader::updateStyle(gtStyle* style, gtStyle* parent2Style, const QStri
 double StyleReader::getSize(const QString& s, double parentSize) const
 {
 	QString dbl("0.0");
-	QString lowerValue = s.toLower();
+	QString lowerValue(s.toLower());
 	double ret = 0.0;
 	if (lowerValue.indexOf("pt") != -1)
 	{
