@@ -18,7 +18,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -28,29 +27,16 @@ for which a new license (GPL+exception) is in place.
 #include "commonstrings.h"
 #include "importcgm.h"
 #include "loadsaveplugin.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusview.h"
-#include "sctextstream.h"
 #include "selection.h"
-#include "ui/customfdialog.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_formats.h"
 #include "util_math.h"
 
 ScBitReader::ScBitReader(QByteArray &data)
@@ -78,7 +64,7 @@ quint32 ScBitReader::getUInt(uint size)
 		{
 			actBit = 7;
 			actByte++;
-			if (actByte >= buffer.count())
+			if (actByte >= buffer.size())
 				break;
 			dat = buffer[actByte];
 		}
@@ -88,7 +74,7 @@ quint32 ScBitReader::getUInt(uint size)
 
 void ScBitReader::alignToWord()
 {
-	if (actByte < buffer.count() - 1)
+	if (actByte < buffer.size() - 1)
 	{
 		actByte++;
 		actByte += actByte % 2;
@@ -261,7 +247,7 @@ bool CgmPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		{
 			PageItem* group = m_Doc->groupObjectsList(Elements);
 			if (!pictName.isEmpty())
-				group->setItemName(group->generateUniqueCopyName(pictName, false).replace( QRegExp("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%\\.]"), "_" ));
+				group->setItemName(group->generateUniqueCopyName(pictName, false).replace( QRegularExpression("[\\s\\/\\{\\[\\]\\}\\<\\>\\(\\)\\%\\.]"), "_" ));
 		}
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
@@ -949,7 +935,7 @@ void CgmPlug::decodeClass2(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF max, min;
 		max = getBinaryCoords(ts, true);
 		min = getBinaryCoords(ts, true);
-		QRectF vd(max, min);
+		QRectF vd = QRectF(max, min);
 		vcdFlippedV = (vd.height() > 0);
 		vcdFlippedH = (vd.width() < 0);
 		vd = vd.normalized();
@@ -1083,7 +1069,7 @@ void CgmPlug::decodeClass3(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF max, min;
 		max = getBinaryCoords(ts);
 		min = getBinaryCoords(ts);
-		QRectF vd(max, min);
+		QRectF vd = QRectF(max, min);
 		vd = vd.normalized();
 		double w = convertCoords(vd.width());
 		double h = convertCoords(vd.height());
@@ -1425,8 +1411,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		}
 		ts >> mode;
 		int bytesRead = ts.device()->pos() - pos;
-		QLineF pr(p, r);
-		QLineF rq(r, q);
+		QLineF pr = QLineF(p, r);
+		QLineF rq = QLineF(r, q);
 		double originX = p.x();
 		double originY = p.y();
 		bool flipX = false;
@@ -1557,23 +1543,22 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 					istr.skipRawData(1);
 			}
 		}
-		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
-		if (tempFile.open())
-		{
-			QString fileName = getLongPathName(tempFile.fileName());
-			tempFile.setAutoRemove(false);
-			tempFile.close();
-			ite->isInlineImage = true;
-			ite->isTempFile = true;
-			image.save(fileName, "PNG");
-			if ((image.width() < 20) || image.height() < 20)
-				ite->pixm.imgInfo.lowResType = 0;
-			m_Doc->loadPict(fileName, ite);
-			ite->setImageFlippedH(flipX);
-			ite->setImageFlippedV(flipY);
-			ite->setImageScalingMode(false, false);
-			ite->adjustPictScale();
-		}
+		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
+		tempFile->setAutoRemove(false);
+		tempFile->open();
+		QString fileName = getLongPathName(tempFile->fileName());
+		tempFile->close();
+		ite->isInlineImage = true;
+		ite->isTempFile = true;
+		image.save(fileName, "PNG");
+		if ((image.width() < 20) || image.height() < 20)
+			ite->pixm.imgInfo.lowResType = 0;
+		m_Doc->loadPict(fileName, ite);
+		delete tempFile;
+		ite->setImageFlippedH(flipX);
+		ite->setImageFlippedV(flipY);
+		ite->setImageScalingMode(false, false);
+		ite->adjustPictScale();
 		colorPrecision = t_colorPrecision;
 		colorIndexPrecision = t_colorIndexPrecision;
 	}
@@ -1583,9 +1568,10 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 	}
 	else if (elemID == 11)
 	{
-		QPointF max = getBinaryCoords(ts);
-		QPointF min = getBinaryCoords(ts);
-		QRectF vd(max, min);
+		QPointF max, min;
+		max = getBinaryCoords(ts);
+		min = getBinaryCoords(ts);
+		QRectF vd = QRectF(max, min);
 		vd = vd.normalized();
 		double w = convertCoords(vd.width());
 		double h = convertCoords(vd.height());
@@ -1628,17 +1614,17 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF pStart = convertCoords(getBinaryCoords(ts));
 		QPointF pInter = convertCoords(getBinaryCoords(ts));
 		QPointF pEnd = convertCoords(getBinaryCoords(ts));
-		QLineF s_e(pStart, pEnd);
+		QLineF s_e = QLineF(pStart, pEnd);
 		QLineF n_s = s_e.normalVector();
 		n_s.translate(s_e.pointAt(0.5) - s_e.p1());
-		QLineF s_i(pStart, pInter);
+		QLineF s_i = QLineF(pStart, pInter);
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
 		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
-			QLineF rad1(center, pStart);
-			QLineF rad3(center, pInter);
+			QLineF rad1 = QLineF(center, pStart);
+			QLineF rad3 = QLineF(center, pInter);
 			double radius = rad1.length();
 			Coords.resize(0);
 			Coords.svgInit();
@@ -1676,17 +1662,17 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF pEnd = convertCoords(getBinaryCoords(ts));
 		quint16 mode;
 		ts >> mode;
-		QLineF s_e(pStart, pEnd);
+		QLineF s_e = QLineF(pStart, pEnd);
 		QLineF n_s = s_e.normalVector();
 		n_s.translate(s_e.pointAt(0.5) - s_e.p1());
-		QLineF s_i(pStart, pInter);
+		QLineF s_i = QLineF(pStart, pInter);
 		QLineF n_i = s_i.normalVector();
 		n_i.translate(s_i.pointAt(0.5) - s_i.p1());
 		QPointF center;
 		if (n_s.intersects(n_i, &center) != QLineF::NoIntersection)
 		{
-			QLineF rad1(center, pStart);
-			QLineF rad3(center, pInter);
+			QLineF rad1 = QLineF(center, pStart);
+			QLineF rad3 = QLineF(center, pInter);
 			double radius = rad1.length();
 			Coords.resize(0);
 			Coords.svgInit();
@@ -1738,8 +1724,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv(cx, cy, cx + sx, cy + sy);
-		QLineF env(cx, cy, cx + ex, cy + ey);
+		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
+		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		if (qFuzzyCompare(sx, ex) && qFuzzyCompare(sy, ey))
 		{
@@ -1795,8 +1781,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv(cx, cy, cx + sx, cy + sy);
-		QLineF env(cx, cy, cx + ex, cy + ey);
+		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
+		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		if (qFuzzyCompare(sx, ex) && qFuzzyCompare(sy, ey))
 		{
@@ -1882,8 +1868,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF r2 = getBinaryCoords(ts);
 		double r2x = convertCoords(r2.x());
 		double r2y = convertCoords(r2.y());
-		QLineF dstX(cx, cy, r1x, r1y);
-		QLineF dstY(cx, cy, r2x, r2y);
+		QLineF dstX = QLineF(cx, cy, r1x, r1y);
+		QLineF dstY = QLineF(cx, cy, r2x, r2y);
 		double distX = dstX.length();
 		double distY = dstY.length();
 		double rotB = dstX.angle();
@@ -1901,8 +1887,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv(cx, cy, cx + sx, cy + sy);
-		QLineF env(cx, cy, cx + ex, cy + ey);
+		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
+		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		ell.addEllipse(QPointF(cx, cy), distX, distY);
 		ell.translate(-cx, -cy);
@@ -1986,8 +1972,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		QPointF r2 = getBinaryCoords(ts);
 		double r2x = convertCoords(r2.x());
 		double r2y = convertCoords(r2.y());
-		QLineF dstX(cx, cy, r1x, r1y);
-		QLineF dstY(cx, cy, r2x, r2y);
+		QLineF dstX = QLineF(cx, cy, r1x, r1y);
+		QLineF dstY = QLineF(cx, cy, r2x, r2y);
 		double distX = dstX.length();
 		double distY = dstY.length();
 		double rotB = dstX.angle();
@@ -2006,8 +1992,8 @@ void CgmPlug::decodeClass4(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			sx *= -1;
 			ex *= -1;
 		}
-		QLineF stv(cx, cy, cx + sx, cy + sy);
-		QLineF env(cx, cy, cx + ex, cy + ey);
+		QLineF stv = QLineF(cx, cy, cx + sx, cy + sy);
+		QLineF env = QLineF(cx, cy, cx + ex, cy + ey);
 		QPainterPath ell;
 		ell.addEllipse(QPointF(cx, cy), distX, distY);
 		ell.translate(-cx, -cy);
@@ -2387,14 +2373,14 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		m_Doc->adjustItemSize(ite);
 		ite->OldB2 = ite->width();
 		ite->OldH2 = ite->height();
-		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
-		if (tempFile.open())
+		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_cgm_XXXXXX.png");
+		tempFile->setAutoRemove(false);
+		if (tempFile->open())
 		{
-			QString fileName = getLongPathName(tempFile.fileName());
+			QString fileName = getLongPathName(tempFile->fileName());
 			if (!fileName.isEmpty())
 			{
-				tempFile.setAutoRemove(false);
-				tempFile.close();
+				tempFile->close();
 				ite->isInlineImage = true;
 				ite->isTempFile = true;
 				tmpImg.save(fileName, "PNG");
@@ -2426,6 +2412,7 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 			m_Doc->Items->removeAll(ite);
 			delete ite;
 		}
+		delete tempFile;
 		colorPrecision = t_colorPrecision;
 	//	qDebug() << "PATTERN TABLE" << "Index" << index << "NX" << nx << "NY" << ny;
 	}
@@ -2435,8 +2422,8 @@ void CgmPlug::decodeClass5(QDataStream &ts, quint16 elemID, quint16 paramLen)
 		double phy = convertCoords(getBinaryDistance(ts));
 		double pwx = convertCoords(getBinaryDistance(ts));
 		double pwy = convertCoords(getBinaryDistance(ts));
-		QLineF hp(0, 0, phx, phy);
-		QLineF wp(0, 0, pwx, pwy);
+		QLineF hp = QLineF(0, 0, phx, phy);
+		QLineF wp = QLineF(0, 0, pwx, pwy);
 		patternScaleX = wp.length();
 		patternScaleY = hp.length();
 	//	qDebug() << "PATTERN SIZE" << wp.length() << hp.length();
