@@ -37,7 +37,6 @@ for which a new license (GPL+exception) is in place.
 #include "prefstable.h"
 #include "ui/propertiespalette.h"
 #include "rawimage.h"
-#include "scclocale.h"
 #include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
@@ -53,7 +52,7 @@ for which a new license (GPL+exception) is in place.
 #include "undomanager.h"
 #include "util.h"
 #include "util_formats.h"
-#include "util_math.h"
+
 
 
 // Initialize members here, if any
@@ -77,7 +76,7 @@ bool ImportIdmlImpl::run(const QString & target, ScribusDoc* doc)
 	/* Implement Progress Dialog Later */
 	
 	/**
-	Here, first we parse the idml document, in the order designmap.xml,preferences.xml, fonts.xml, styles.xml, gradiant.xml, all the stories will be transformed into Story Objects, and finally all the master spreads and spreads.
+	Here, first we parse the idml document, in the order designmap.xml,preferences.xml, fonts.xml, styles.xml, gradient.xml, all the stories will be transformed into Story Objects, and finally all the master spreads and spreads.
 	We set the document page width, height etc from preferences.xml, styles are defined and added into the list.
 	
 	QMap are maintained with QString, Object for each item which is referred later in the document using the self attribute. This includes all styles, stories etc.
@@ -416,10 +415,11 @@ void ImportIdmlImpl::readParagraphStyle(ScribusDoc *doc, QDomNode node,  Paragra
 						tb.tabPosition = tabElements.text().toDouble();
 						if(tabElements.tagName()=="AlignmentCharacter")
 						{
-							QString tbCh   = tabElements.text();
+							QString tbCh(tabElements.text());
 							if(tbCh.contains("$ID/",Qt::CaseSensitive))
 								tbCh = tbCh.split("$ID/",QString::SkipEmptyParts,Qt::CaseSensitive).at(1);
-							tb.tabFillChar = tbCh.isEmpty() ? QChar() : tbCh[0];
+							if (!tbCh.isEmpty())
+								tb.tabFillChar = tbCh[0];
 							tbs.append(tb);
 							if (tbs.count() > 0)
 								newStyle.setTabValues(tbs);
@@ -695,7 +695,7 @@ void ImportIdmlImpl::addTextFrame(ScribusDoc* doc, QDomNode node)
 			StrokeColor = CommonStrings::None;
 		ItemLayer = elem.attribute("ItemLayer","");
 		itemTransform =  applyTransform(elem.attribute("ItemTranform",""));
-		/* Try to add gradiant feature */
+		/* Try to add gradient feature */
 	}
 	//Reading the properties
 	QList<PathPoint> pathPoints;
