@@ -22,7 +22,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QUrl>
 
@@ -118,8 +117,8 @@ QImage PagesPlug::readThumbnail(const QString& fName)
 	}
 /*	else
 	{
-		QFileInfo fi = QFileInfo(fName);
-		baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+		QFileInfo fi(fName);
+		baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 		docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
 		docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 		m_Doc = new ScribusDoc();
@@ -195,12 +194,12 @@ bool PagesPlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	pagecount = 1;
 	mpagecount = 0;
 	QFileInfo fi(fNameIn);
-	if ( !ScCore->usingGUI() )
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	if ( showProgress )
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -441,6 +440,15 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 		}
 		delete tmpFile;
 	}
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = designMapDom.setContent(f);
+	if (!parseResult)
+	{
+		qDebug() << "Error loading File" << parseResult.errorMessage << "at Line" << parseResult.errorLine << "Column" << parseResult.errorColumn;
+		return false;
+	}
+#else
 	QString errorMsg;
 	int errorLine = 0;
 	int errorColumn = 0;
@@ -449,6 +457,8 @@ bool PagesPlug::parseDocReference(const QString& designMap, bool compressed)
 		qDebug() << "Error loading File" << errorMsg << "at Line" << errorLine << "Column" << errorColumn;
 		return false;
 	}
+#endif
+
 	papersize = "Custom";
 	QDomElement docElem = designMapDom.documentElement();
 	for (QDomElement drawPag = docElem.firstChildElement(); !drawPag.isNull(); drawPag = drawPag.nextSiblingElement())
@@ -735,7 +745,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 											if (type == "sfa:calibrated-white-color-type")
 											{
 												QColor c;
-												double w = spg.attribute("sfa:w", "1").toDouble();
+												float w = spg.attribute("sfa:w", "1").toFloat();
 												c.setRgbF(w, w, w);
 												ScColor tmp;
 												tmp.fromQColor(c);
@@ -843,7 +853,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 											if (type == "sfa:calibrated-white-color-type")
 											{
 												QColor c;
-												double w = spg.attribute("sfa:w", "1").toDouble();
+												float w = spg.attribute("sfa:w", "1").toFloat();
 												c.setRgbF(w, w, w);
 												ScColor tmp;
 												tmp.fromQColor(c);
@@ -973,7 +983,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 													if (type == "sfa:calibrated-white-color-type")
 													{
 														QColor c;
-														double w = sph.attribute("sfa:w", "1").toDouble();
+														float w = sph.attribute("sfa:w", "1").toFloat();
 														c.setRgbF(w, w, w);
 														ScColor tmp;
 														tmp.fromQColor(c);
@@ -1033,7 +1043,7 @@ void PagesPlug::parseStyleSheets(QDomElement &drawPag)
 											if (type == "sfa:calibrated-white-color-type")
 											{
 												QColor c;
-												double w = spg.attribute("sfa:w", "1").toDouble();
+												float w = spg.attribute("sfa:w", "1").toFloat();
 												c.setRgbF(w, w, w);
 												ScColor tmp;
 												tmp.fromQColor(c);
