@@ -11,7 +11,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QTextCodec>
 #include <QStack>
 #include <QDebug>
@@ -23,31 +22,18 @@ for which a new license (GPL+exception) is in place.
 #include "commonstrings.h"
 #include "loadsaveplugin.h"
 #include "pageitem_imageframe.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scpattern.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
-#include "sctextstream.h"
 #include "selection.h"
-#include "ui/customfdialog.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_formats.h"
 #include "util_math.h"
 
 PctPlug::PctPlug(ScribusDoc* doc, int flags)
@@ -1005,21 +991,20 @@ void PctPlug::parsePict(QDataStream &ts)
 						image = image.convertToFormat(QImage::Format_ARGB32);
 						int z = m_Doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified, baseX, baseY, image.width() * resX, image.height() * resY, 0, m_Doc->itemToolPrefs().imageFillColor, CommonStrings::None);
 						PageItem *ite = m_Doc->Items->at(z);
-						QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
-						if (tempFile.open())
-						{
-							QString fileName = getLongPathName(tempFile.fileName());
-							tempFile.setAutoRemove(false);
-							tempFile.close();
-							ite->isInlineImage = true;
-							ite->isTempFile = true;
-							image.save(fileName, "PNG");
-							ite->moveBy(m_Doc->currentPage()->xOffset(), m_Doc->currentPage()->yOffset());
-							ite->moveBy(offsetX, offsetY);
-							finishItem(ite);
-							m_Doc->loadPict(fileName, ite);
-							ite->setImageScalingMode(false, false);
-						}
+						QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
+						tempFile->setAutoRemove(false);
+						tempFile->open();
+						QString fileName = getLongPathName(tempFile->fileName());
+						tempFile->close();
+						ite->isInlineImage = true;
+						ite->isTempFile = true;
+						image.save(fileName, "PNG");
+						ite->moveBy(m_Doc->currentPage()->xOffset(), m_Doc->currentPage()->yOffset());
+						ite->moveBy(offsetX, offsetY);
+						finishItem(ite);
+						m_Doc->loadPict(fileName, ite);
+						ite->setImageScalingMode(false, false);
+						delete tempFile;
 					}
 //					qDebug() << "End of Pict";
 					return;
@@ -1599,7 +1584,7 @@ void PctPlug::handleShortLine(QDataStream &ts)
 		currentPoint = QPoint(x * resX, y * resY);
 		return;
 	}
-	QPoint s(x * resX, y * resY);
+	QPoint s = QPoint(x * resX, y * resY);
 	if (currentPoint != s)
 	{
 		handleLineModeEnd();
@@ -1631,7 +1616,7 @@ void PctPlug::handleLine(QDataStream &ts)
 	qint16 x1, x2, y1, y2;
 	ts >> y1 >> x1;
 	ts >> y2 >> x2;
-	QPoint s(x1 * resX, y1 * resY);
+	QPoint s = QPoint(x1 * resX, y1 * resY);
 	if (currentPoint != s)
 	{
 		handleLineModeEnd();
@@ -1842,21 +1827,20 @@ void PctPlug::handlePixmap(QDataStream &ts, quint16 opCode)
 			image.invertPixels();
 		int z = m_Doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified, baseX + dstRect.left() * resX, baseY + dstRect.top() * resY, imgCols * resY, imgRows * resY, 0, m_Doc->itemToolPrefs().imageFillColor, m_Doc->itemToolPrefs().imageStrokeColor);
 		PageItem *ite = m_Doc->Items->at(z);
-		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
-		if (tempFile.open())
-		{
-			QString fileName = getLongPathName(tempFile.fileName());
-			tempFile.setAutoRemove(false);
-			tempFile.close();
-			ite->isInlineImage = true;
-			ite->isTempFile = true;
-			image.save(fileName, "PNG");
-			ite->moveBy(baseX, baseY);
-			ite->moveBy(offsetX, offsetY);
-			finishItem(ite);
-			m_Doc->loadPict(fileName, ite);
-			ite->setImageScalingMode(false, false);
-		}
+		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
+		tempFile->setAutoRemove(false);
+		tempFile->open();
+		QString fileName = getLongPathName(tempFile->fileName());
+		tempFile->close();
+		delete tempFile;
+		ite->isInlineImage = true;
+		ite->isTempFile = true;
+		image.save(fileName, "PNG");
+		ite->moveBy(baseX, baseY);
+		ite->moveBy(offsetX, offsetY);
+		finishItem(ite);
+		m_Doc->loadPict(fileName, ite);
+		ite->setImageScalingMode(false, false);
 		skipOpcode = false;
 	}
 	alignStreamToWord(ts, 0);
@@ -2183,36 +2167,34 @@ void PctPlug::setFillPattern(PageItem* ite)
 		image = image.convertToFormat(QImage::Format_ARGB32);
 		ScPattern pat(m_Doc);
 		PageItem* newItem = new PageItem_ImageFrame(m_Doc, 0, 0, 1, 1, 0, CommonStrings::None, CommonStrings::None);
-		QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
-		if (tempFile.open())
+		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
+		tempFile->setAutoRemove(false);
+		tempFile->open();
+		QString fileName = getLongPathName(tempFile->fileName());
+		tempFile->close();
+		delete tempFile;
+		newItem->isInlineImage = true;
+		newItem->isTempFile = true;
+		image.setDotsPerMeterY(2834);
+		image.setDotsPerMeterX(2834);
+		image.save(fileName, "PNG");
+		if (newItem->loadImage(fileName, false, 72, false))
 		{
-			QString fileName = getLongPathName(tempFile.fileName());
-			tempFile.setAutoRemove(false);
-			tempFile.close();
-			newItem->isInlineImage = true;
-			newItem->isTempFile = true;
-			image.setDotsPerMeterY(2834);
-			image.setDotsPerMeterX(2834);
-			image.save(fileName, "PNG");
-			if (newItem->loadImage(fileName, false, 72, false))
-			{
-				pat.width = image.width();
-				pat.height = image.height();
-				pat.scaleX = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
-				pat.scaleY = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
-				pat.pattern = newItem->pixm.qImage().copy();
-				newItem->setWidth(pat.pattern.width());
-				newItem->setHeight(pat.pattern.height());
-				newItem->SetRectFrame();
-				newItem->gXpos = 0.0;
-				newItem->gYpos = 0.0;
-				newItem->gWidth = pat.pattern.width();
-				newItem->gHeight = pat.pattern.height();
-				pat.items.append(newItem);
-			}
-
+			pat.width = image.width();
+			pat.height = image.height();
+			pat.scaleX = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
+			pat.scaleY = (72.0 / newItem->pixm.imgInfo.xres) * newItem->pixm.imgInfo.lowResScale;
+			pat.pattern = newItem->pixm.qImage().copy();
+			newItem->setWidth(pat.pattern.width());
+			newItem->setHeight(pat.pattern.height());
+			newItem->SetRectFrame();
+			newItem->gXpos = 0.0;
+			newItem->gYpos = 0.0;
+			newItem->gWidth = pat.pattern.width();
+			newItem->gHeight = pat.pattern.height();
+			pat.items.append(newItem);
 		}
-		patternName = "Pattern_" + newItem->itemName();
+		patternName = "Pattern_"+newItem->itemName();
 		patternName = patternName.trimmed().simplified().replace(" ", "_");
 		m_Doc->addPattern(patternName, pat);
 		importedPatterns.append(patternName);
