@@ -16,7 +16,6 @@ for which a new license (GPL+exception) is in place.
 #include <QInputDialog>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 
 #include <poppler/ErrorCodes.h>
@@ -36,34 +35,19 @@ for which a new license (GPL+exception) is in place.
 
 #include "commonstrings.h"
 #include "loadsaveplugin.h"
-#include "pagesize.h"
 #include "pdfimportoptions.h"
 #include "pdfoptions.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scribus.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
-#include "sctextstream.h"
 #include "selection.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_formats.h"
-#include "util_math.h"
 #include "util_os.h"
-
-#include "ui/customfdialog.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 
 PdfPlug::PdfPlug(ScribusDoc* doc, int flags)
 {
@@ -81,13 +65,8 @@ QImage PdfPlug::readThumbnail(const QString& fName)
 
 	QString pdfFile = QDir::toNativeSeparators(fName);
 	QByteArray encodedFileName = os_is_win() ? pdfFile.toUtf8() : QFile::encodeName(pdfFile);
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(22, 3, 0)
 	auto fname = std::make_unique<GooString>(encodedFileName.data());
 	PDFDoc pdfDoc{ std::move(fname) };
-#else
-	auto fname = new GooString(encodedFileName.data());
-	PDFDoc pdfDoc{fname, nullptr, nullptr, nullptr};
-#endif
 	if (!pdfDoc.isOk() || pdfDoc.getErrorCode() == errEncrypted)
 		return QImage();
 
@@ -132,7 +111,7 @@ QImage PdfPlug::readThumbnail(const QString& fName)
 	return image;
 }
 
-bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
+bool PdfPlug::import(const QString& fNameIn, const TransactionSettings& trSettings, int flags, bool showProgress)
 {
 #ifdef Q_OS_MACOS
 	showProgress = false;
@@ -163,7 +142,7 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 		m_progressDialog->setProgress("GI", 0);
 		m_progressDialog->show();
 		connect(m_progressDialog, SIGNAL(canceled()), this, SLOT(cancelRequested()));
-		QApplication::processEvents();
+		qApp->processEvents();
 	}
 	else
 		m_progressDialog = nullptr;
@@ -171,7 +150,7 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 	if (m_progressDialog)
 	{
 		m_progressDialog->setOverallProgress(1);
-		QApplication::processEvents();
+		qApp->processEvents();
 	}
 	double docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
 	double docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
@@ -191,7 +170,7 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 		}
 	}
 
-	if (ret || !m_interactive)
+	if ((ret) || (!m_interactive))
 	{
 		if (docWidth > docHeight)
 			m_Doc->setPageOrientation(1);
@@ -207,7 +186,7 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
 		m_Doc->view()->updatesOn(false);
 	m_Doc->scMW()->setScriptRunning(true);
-	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
 	if (convert(fNameIn))
@@ -228,8 +207,8 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
-		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
-		if (!m_elements.isEmpty() && !ret && m_interactive)
+		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		if ((m_elements.count() > 0) && (!ret) && (m_interactive))
 		{
 			if (flags & LoadSavePlugin::lfScripted)
 			{
@@ -290,7 +269,7 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 		m_Doc->scMW()->setScriptRunning(false);
 		if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 			m_Doc->view()->updatesOn(true);
-		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		success = false;
 	}
 	if (m_interactive)
@@ -298,10 +277,10 @@ bool PdfPlug::importFile(const QString& fNameIn, const TransactionSettings& trSe
 	//CB If we have a gui we must refresh it if we have used the progressbar
 	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 	{
-		if (showProgress && !m_interactive)
+		if ((showProgress) && (!m_interactive))
 			m_Doc->view()->DrawNew();
 	}
-	QApplication::restoreOverrideCursor();
+	qApp->restoreOverrideCursor();
 	return success;
 }
 
@@ -315,7 +294,6 @@ PdfPlug::~PdfPlug()
 bool PdfPlug::convert(const QString& fn)
 {
 	bool firstPg = true;
-	int currentLayer = m_Doc->activeLayer();
 	int baseLayer = m_Doc->activeLayer();
 	m_importedColors.clear();
 	if (m_progressDialog)
@@ -323,7 +301,7 @@ bool PdfPlug::convert(const QString& fn)
 		m_progressDialog->setOverallProgress(2);
 		m_progressDialog->setLabel("GI", tr("Generating Items"));
 		m_progressDialog->setBusyIndicator("GI");
-		QApplication::processEvents();
+		qApp->processEvents();
 	}
 
 	globalParams.reset(new GlobalParams());
@@ -331,13 +309,8 @@ bool PdfPlug::convert(const QString& fn)
 
 	QList<OptionalContentGroup*> ocgGroups;
 	QByteArray encodedFileName = os_is_win() ? fn.toUtf8() : QFile::encodeName(fn);
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(22, 3, 0)
 	auto fname = std::make_unique<GooString>(encodedFileName.data());
 	auto pdfDoc = std::make_unique<PDFDoc>(std::move(fname));
-#else
-	auto fname = new GooString(encodedFileName.data());
-	auto pdfDoc = std::unique_ptr<PDFDoc>(new PDFDoc(fname, nullptr, nullptr, nullptr));
-#endif
 	if (pdfDoc)
 	{
 		if (pdfDoc->getErrorCode() == errEncrypted)
@@ -345,22 +318,16 @@ bool PdfPlug::convert(const QString& fn)
 			pdfDoc = nullptr;
 			if (m_progressDialog)
 				m_progressDialog->hide();
-			QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+			qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
 			ScribusMainWindow* mw = m_Doc->scMW();
 			bool ok;
 			QString text = QInputDialog::getText(mw, tr("Open PDF-File"), tr("Password"), QLineEdit::Normal, "", &ok);
 			if (ok && !text.isEmpty())
 			{
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(22, 3, 0)
 				auto fname = std::make_unique<GooString>(encodedFileName.data());
 				std::optional<GooString> userPW(std::in_place, text.toLocal8Bit().data());
 				pdfDoc.reset(new PDFDoc(std::move(fname), userPW, userPW, nullptr));
-#else
-				auto fname = new GooString(encodedFileName.data());
-				auto userPW = new GooString(text.toLocal8Bit().data());
-				pdfDoc.reset(new PDFDoc(fname, userPW, userPW, nullptr));
-#endif
-				QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
+				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
 			}
 			if ((!pdfDoc) || (pdfDoc->getErrorCode() != errNone))
 			{
@@ -401,7 +368,7 @@ bool PdfPlug::convert(const QString& fn)
 			{
 				if (m_progressDialog)
 					m_progressDialog->hide();
-				QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
+				qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
 				PdfImportOptions optImp(ScCore->primaryMainWindow());
 				QFileInfo fi(fn);
 				optImp.setUpOptions(fi.fileName(), firstPage, lastPage, m_interactive, boxesAreDifferent, this);
@@ -424,7 +391,7 @@ bool PdfPlug::convert(const QString& fn)
 					useMediaBox = false;
 				if (cropped)
 					useMediaBox = true;
-				QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
+				qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
 				if (m_progressDialog)
 					m_progressDialog->show();
 			}
@@ -433,7 +400,7 @@ bool PdfPlug::convert(const QString& fn)
 			if (m_progressDialog)
 			{
 				m_progressDialog->setTotalSteps("GI", pageNs.size());
-				QApplication::processEvents();
+				qApp->processEvents();
 			}
 			if (pageNs.size() <= 0) {
 				m_pdfDoc = nullptr;
@@ -449,11 +416,11 @@ bool PdfPlug::convert(const QString& fn)
 
 			if (dev->isOk())
 			{
-				POPPLER_CONST_25_02 OCGs* ocg = pdfDoc->getOptContentConfig();
+				OCGs* ocg = pdfDoc->getOptContentConfig();
 				if (ocg && ocg->hasOCGs())
 				{
 					QStringList ocgNames;
-					POPPLER_CONST_25_02 Array *order = ocg->getOrderArray();
+					Array *order = ocg->getOrderArray();
 					if (order)
 					{
 						for (int i = 0; i < order->getLength (); ++i)
@@ -461,7 +428,7 @@ bool PdfPlug::convert(const QString& fn)
 							Object orderItem = order->get(i);
 							if (orderItem.isDict())
 							{
-								const Object& ref = order->getNF(i);
+								const Object & ref = order->getNF(i);
 								if (ref.isRef())
 								{
 									OptionalContentGroup *oc = ocg->findOcgByRef(ref.getRef());
@@ -515,6 +482,7 @@ bool PdfPlug::convert(const QString& fn)
 					if (ocg && ocg->hasOCGs())
 					{
 						QString actL(m_Doc->activeLayerName());
+						int currentLayer;
 						for (int i = 0; i < ocgGroups.count(); i++)
 						{
 							OptionalContentGroup *oc = ocgGroups[i];
@@ -542,22 +510,22 @@ bool PdfPlug::convert(const QString& fn)
 					{
 						Object obj;
 						Dict *infoDict = info.getDict();
-						obj = infoDict->lookup("Title");
+						obj = infoDict->lookup((char*) "Title");
 						if (obj.isString())
 						{
 							m_Doc->documentInfo().setTitle(UnicodeParsedString(obj.getString()));
 						}
-						obj = infoDict->lookup("Author");
+						obj = infoDict->lookup((char*) "Author");
 						if (obj.isString())
 						{
 							m_Doc->documentInfo().setAuthor(UnicodeParsedString(obj.getString()));
 						}
-						obj = infoDict->lookup("Subject");
+						obj = infoDict->lookup((char*) "Subject");
 						if (obj.isString())
 						{
 							m_Doc->documentInfo().setSubject(UnicodeParsedString(obj.getString()));
 						}
-						obj = infoDict->lookup("Keywords");
+						obj = infoDict->lookup((char*) "Keywords");
 						if (obj.isString())
 						{
 							//		s1 = obj.getString();
@@ -600,7 +568,7 @@ bool PdfPlug::convert(const QString& fn)
 						if (m_progressDialog)
 						{
 							m_progressDialog->setProgress("GI", i);
-							QApplication::processEvents();
+							qApp->processEvents();
 						}
 						int pp = pageNs[i];
 						m_Doc->setActiveLayer(baseLayer);
@@ -740,13 +708,8 @@ bool PdfPlug::convert(const QString& fn)
 							names = catDict.dictLookup("OpenAction");
 							if (names.isDict())
 							{
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(0, 86, 0)
 								std::unique_ptr<LinkAction> linkActionUPtr = LinkAction::parseAction(&names, pdfDoc->getCatalog()->getBaseURI());
 								LinkAction *linkAction = linkActionUPtr.get();
-#else
-								LinkAction *linkAction = nullptr;
-								linkAction = LinkAction::parseAction(&names, pdfDoc->getCatalog()->getBaseURI());
-#endif
 								if (linkAction && (linkAction->getKind() == actionJavaScript))
 								{
 									LinkJavaScript *jsa = (LinkJavaScript*) linkAction;
@@ -819,7 +782,7 @@ bool PdfPlug::convert(const QString& fn)
 //	qDebug() << "converting finished";
 //	qDebug() << "Imported" << m_elements.count() << "Elements";
 
-	if (m_elements.isEmpty())
+	if (m_elements.count() == 0)
 	{
 		for (int i = 0; i < m_importedColors.count(); i++)
 		{
@@ -909,46 +872,8 @@ QRectF PdfPlug::getCBox(int box, int pgNum)
 	return cRect;
 }
 
-QString PdfPlug::UnicodeParsedString(const GooString *s1) const
+QString PdfPlug::UnicodeParsedString(const GooString *s1)
 {
-#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(25, 10, 0)
-	if (!s1 || s1->empty())
-		return QString();
-	bool isUnicode;
-	int i;
-	Unicode u;
-	QString result;
-	if ((s1->getChar(0) & 0xff) == 0xfe && (s1->size() > 1 && (s1->getChar(1) & 0xff) == 0xff))
-	{
-		isUnicode = true;
-		i = 2;
-		result.reserve((s1->size() - 2) / 2);
-	}
-	else
-	{
-		isUnicode = false;
-		i = 0;
-		result.reserve(s1->size());
-	}
-	while (i < s1->size())
-	{
-		if (isUnicode)
-		{
-			u = ((s1->getChar(i) & 0xff) << 8) | (s1->getChar(i + 1) & 0xff);
-			i += 2;
-		}
-		else
-		{
-			u = s1->getChar(i) & 0xff;
-			++i;
-		}
-		// #15616: imagemagick may write unicode strings incorrectly in PDF
-		if (u == 0)
-			continue;
-		result += QChar(u);
-	}
-	return result;
-#else
 	if (!s1 || s1->getLength() == 0)
 		return QString();
 	bool isUnicode;
@@ -985,10 +910,9 @@ QString PdfPlug::UnicodeParsedString(const GooString *s1) const
 		result += QChar( u );
 	}
 	return result;
-#endif
 }
 
-QString PdfPlug::UnicodeParsedString(const std::string& s1) const
+QString PdfPlug::UnicodeParsedString(const std::string& s1)
 {
 	if (s1.length() == 0)
 		return QString();
