@@ -11,7 +11,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -22,32 +21,32 @@ for which a new license (GPL+exception) is in place.
 
 #include "commonstrings.h"
 #include "loadsaveplugin.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
+// #include "pagesize.h"
+// #include "prefscontext.h"
+// #include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
+// #include "prefstable.h"
+// #include "rawimage.h"
 #include "scclocale.h"
 #include "sccolorengine.h"
 #include "scconfig.h"
-#include "sclimits.h"
+// #include "sclimits.h"
 #include "scmimedata.h"
-#include "scpaths.h"
+// #include "scpaths.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
-#include "sctextstream.h"
+// #include "sctextstream.h"
 #include "selection.h"
-#include "ui/customfdialog.h"
+// #include "ui/customfdialog.h"
 #include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
 #include "ui/propertiespalette.h"
 #include "undomanager.h"
 #include "units.h"
 #include "util.h"
-#include "util_formats.h"
+// #include "util_formats.h"
 #include "util_math.h"
 
 ShapePlug::ShapePlug(ScribusDoc* doc, int flags)
@@ -61,8 +60,8 @@ ShapePlug::ShapePlug(ScribusDoc* doc, int flags)
 
 QImage ShapePlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+	QFileInfo fi(fName);
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 	double b = 0.0, h = 0.0;
 	parseHeader(fName, b, h);
 	if (b == 0.0)
@@ -126,17 +125,15 @@ bool ShapePlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 	importerFlags = flags;
 	cancel = false;
-//	double x, y, b, h;
-	double b, h;
 	bool ret = false;
-	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	if ( showProgress )
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -156,10 +153,8 @@ bool ShapePlug::import(const QString& fNameIn, const TransactionSettings& trSett
 	else
 		progressDialog = nullptr;
 /* Set default Page to size defined in Preferences */
-//	x = 0.0;
-//	y = 0.0;
-	b = 0.0;
-	h = 0.0;
+	double b = 0.0;
+	double h = 0.0;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
@@ -425,7 +420,6 @@ void ShapePlug::parseGroup(QDomNode &DOC)
 		LineEnd = Qt::FlatCap;
 		LineJoin = Qt::MiterJoin;
 		FPointArray PoLine;
-		PoLine.resize(0);
 		QDomElement pg = DOC.toElement();
 		QString STag = pg.tagName();
 		QString style = pg.attribute( "style", "" ).simplified();
@@ -445,7 +439,7 @@ void ShapePlug::parseGroup(QDomNode &DOC)
 						FillCol = CommonStrings::None;
 					else
 					{
-						fill.setNamedColor( params );
+						fill = QColor::fromString( params );
 						FillCol = "FromDia"+fill.name();
 						ScColor tmp;
 						tmp.fromQColor(fill);
@@ -462,7 +456,7 @@ void ShapePlug::parseGroup(QDomNode &DOC)
 			{
 				if (!((params == "foreground") || (params == "background") || (params == "fg") || (params == "bg") || (params == "none") || (params == "default")) || (params == "inverse"))
 				{
-					stroke.setNamedColor( params );
+					stroke = QColor::fromString( params );
 					StrokeCol = "FromDia"+stroke.name();
 					ScColor tmp;
 					tmp.fromQColor(stroke);
@@ -662,7 +656,6 @@ void ShapePlug::parseGroupProperties(QDomNode &DOC, double &minXCoor, double &mi
 	{
 		double x1, y1, x2, y2;
 		FPointArray PoLine;
-		PoLine.resize(0);
 		QDomElement pg = DOC.toElement();
 		QString STag = pg.tagName();
 		if (STag == "svg:line")
@@ -863,16 +856,12 @@ double ShapePlug::parseUnit(const QString &unit)
 
 const char * ShapePlug::getCoord( const char *ptr, double &number )
 {
-	int integer, exponent;
-	double decimal, frac;
-	int sign, expsign;
-
-	exponent = 0;
-	integer = 0;
-	frac = 1.0;
-	decimal = 0;
-	sign = 1;
-	expsign = 1;
+	int exponent = 0;
+	int integer = 0;
+	double frac = 1.0;
+	double decimal = 0.0;
+	int sign = 1;
+	int expsign = 1;
 
 	// read the sign
 	if (*ptr == '+')
@@ -925,8 +914,8 @@ const char * ShapePlug::getCoord( const char *ptr, double &number )
 
 bool ShapePlug::parseSVG( const QString &s, FPointArray *ite )
 {
-	QString d = s;
-	d = d.replace( QRegExp( "," ), " ");
+	QString d(s);
+	d.replace( QRegularExpression( "," ), " ");
 	bool ret = false;
 	if (!d.isEmpty())
 	{
