@@ -13,7 +13,6 @@ for which a new license (GPL+exception) is in place.
 #include <QMessageBox>
 #include <QMimeData>
 #include <QPainterPath>
-#include <QRegExp>
 #include <QStack>
 #include <QTemporaryFile>
 
@@ -266,7 +265,7 @@ QImage SVGPlug::readThumbnail(const QString& fName)
 	if (!docElem.attribute("viewBox").isEmpty())
 	{
 		QString viewbox(docElem.attribute("viewBox"));
-		QStringList points = viewbox.replace(QRegExp(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
+		QStringList points = viewbox.replace(QRegularExpression(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
 		if (points.size() > 3)
 		{
 			QTransform matrix;
@@ -349,7 +348,11 @@ bool SVGPlug::loadData(const QString& fName)
 		compressor.setStreamFormat(QtIOCompressor::GzipFormat);
 		if (!compressor.open(QIODevice::ReadOnly))
 			return false;
-		success = inpdoc.setContent(&compressor);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+		success = (bool) inpdoc.setContent(&compressor);
+#else
+		success = inpdoc.setContent(&compressor, nullptr);
+#endif
 		compressor.close();
 	}
 	else
@@ -357,7 +360,11 @@ bool SVGPlug::loadData(const QString& fName)
 		QFile file(fName);
 		if (!file.open(QIODevice::ReadOnly))
 			return false;
-		success = inpdoc.setContent(&file);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+		success = (bool) inpdoc.setContent(&file);
+#else
+		success = inpdoc.setContent(&file, nullptr);
+#endif
 		file.close();
 	}
 	return success;
@@ -448,7 +455,7 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 	if (!docElem.attribute("viewBox").isEmpty())
 	{
 		QString viewbox(docElem.attribute("viewBox"));
-		QStringList points = viewbox.replace(QRegExp(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
+		QStringList points = viewbox.replace(QRegularExpression(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
 		if (points.size() > 3)
 		{
 			QTransform matrix;
@@ -1073,7 +1080,7 @@ QRectF SVGPlug::parseViewBox(const QDomElement &e)
 	if (!e.attribute("viewBox").isEmpty())
 	{
 		QString viewbox(e.attribute("viewBox"));
-		QStringList points = viewbox.replace(QRegExp(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
+		QStringList points = viewbox.replace(QRegularExpression(","), " ").simplified().split(' ', Qt::SkipEmptyParts);
 		if (points.size() > 3)
 		{
 			double left   = ScCLocale::toDoubleC(points[0]);
@@ -1598,7 +1605,7 @@ QList<PageItem*> SVGPlug::parseImage(const QDomElement &e)
 {
 	FPointArray clipPath;
 	QList<PageItem*> IElements;
-	QString fname = e.attribute("xlink:href");
+	QString hrefData = e.attribute("xlink:href"); //contains filename or xlink:href data:image/png embedded image
 	double baseX = m_Doc->currentPage()->xOffset();
 	double baseY = m_Doc->currentPage()->yOffset();
 	double x = e.attribute("x").isEmpty() ? 0.0 : parseUnit(e.attribute("x"));
@@ -1609,17 +1616,19 @@ QList<PageItem*> SVGPlug::parseImage(const QDomElement &e)
 	parseClipPathAttr(e, clipPath);
 	int z = m_Doc->itemAdd(PageItem::ImageFrame, PageItem::Unspecified, baseX, baseY, w, h, 1, m_Doc->itemToolPrefs().imageFillColor, m_Doc->itemToolPrefs().imageStrokeColor);
 	PageItem* ite = m_Doc->Items->at(z);
-	if (!fname.isEmpty())
+	if (!hrefData.isEmpty())
 	{
-		if (!fname.startsWith("data:"))
-			m_Doc->loadPict(fname, ite);
+		//hrefData contains a filename
+		if (!hrefData.startsWith("data:"))
+			m_Doc->loadPict(hrefData, ite);
 		else
 		{
-			int startData = fname.indexOf(",");
-			QString dataType = fname.left(startData);
-			fname.remove(0, startData + 1);
+			//hrefData is embedded
+			int startData = hrefData.indexOf(",");
+			QString dataType = hrefData.left(startData);
+			hrefData.remove(0, startData + 1);
 			QByteArray ba;
-			ba.append(fname);
+			ba.append(hrefData.toLatin1());
 			if (dataType.contains("base64"))
 				ba = QByteArray::fromBase64(ba);
 			QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_svg_XXXXXX.png");
@@ -2384,7 +2393,7 @@ QString SVGPlug::parseColor(const QString &s)
 		c = QColor(r.toInt(), g.toInt(), b.toInt());
 	}
 	else
-		c.setNamedColor(s.trimmed());
+		c = QColor::fromString(s.trimmed());
 
 	ScColor tmp;
 	tmp.fromQColor(c);
