@@ -17,7 +17,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QUrl>
 #include <QDebug>
@@ -981,7 +980,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 	double ob_rotation = 0;
 	QString fillColor = CommonStrings::None;
 	QString strokeColor = CommonStrings::None;
-	QString fillGradient = "";
+	QString fillGradient;
 	int fillGradientTyp = 6;
 	int fillTint = 100;
 	int strokeTint = 100;
@@ -1001,7 +1000,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 	bool resizable = false;
 	FPointArray Path;
 	Path.resize(0);
-	QString imageFile = "";
+	QString imageFile;
 	QByteArray imageData;
 	imageData.resize(0);
 	QVector<double> DashValues;
@@ -1197,7 +1196,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 						QDomElement eo = spo.toElement();
 						if (eo.tagName() == "vo:point")
 						{
-							FPoint pp(parseUnit(eo.attribute("vo:x", "0")), parseUnit(eo.attribute("vo:y", "0")));
+							FPoint pp = FPoint(parseUnit(eo.attribute("vo:x", "0")), parseUnit(eo.attribute("vo:y", "0")));
 							if (eo.hasAttribute("vo:control"))
 							{
 								if ((eo.attribute("vo:control") == "constraint-before") || (eo.attribute("vo:control") == "before"))
@@ -1304,7 +1303,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 						else if (spo.tagName() == "uni:applyElementOpacity")
 							shadowObjTrans = (spo.text() == "true");
 					}
-					QLineF oLine(0, 0, shadowOffset, 0);
+					QLineF oLine = QLineF(0, 0, shadowOffset, 0);
 					oLine.setAngle(shadowAngle - 180.0);
 					shadowX = oLine.p2().x();
 					shadowY = oLine.p2().y();
@@ -1536,7 +1535,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 				QString gradColor1Str = colorStops[1]->name;
 				QColor gradColor1 = colorStops[1]->color;
 				item->meshGradientPatches.clear();
-				FPoint center(item->width() / 2.0, item->height() / 2.0);
+				FPoint center = FPoint(item->width() / 2.0, item->height() / 2.0);
 				MeshPoint cP;
 				cP.resetTo(center);
 				cP.transparency = 1.0;
@@ -1578,7 +1577,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 				item->GrControl4 = FPoint(0, item->height());
 				if (gradientAngle != 0)
 				{
-					QLineF gradientVector(item->width() / 2.0, item->height() / 2.0, 0, 0);
+					QLineF gradientVector = QLineF(item->width() / 2.0, item->height() / 2.0, 0, 0);
 					gradientVector.setLength(gradientVector.length() + 1);
 					gradientVector.setAngle(gradientVector.angle() + gradientAngle);
 					QPointF g1 = intersectBoundingRect(item, gradientVector);
@@ -1650,15 +1649,15 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 			{
 				if (!imageData.isEmpty())
 				{
-					QTemporaryFile tempFile(QDir::tempPath() + "/scribus_temp_viva_XXXXXX.png");
-					if (tempFile.open())
+					QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_viva_XXXXXX.png");
+					tempFile->setAutoRemove(false);
+					if (tempFile->open())
 					{
-						QString fileName = getLongPathName(tempFile.fileName());
+						QString fileName = getLongPathName(tempFile->fileName());
 						if (!fileName.isEmpty())
 						{
-							tempFile.setAutoRemove(false);
-							tempFile.write(imageData);
-							tempFile.close();
+							tempFile->write(imageData);
+							tempFile->close();
 							item->isInlineImage = true;
 							item->isTempFile = true;
 							item->AspectRatio = true;
@@ -1666,6 +1665,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 							m_Doc->loadPict(fileName, item);
 						}
 					}
+					delete tempFile;
 				}
 			}
 			item->setImageXYScale(imageScaleX / item->pixm.imgInfo.xres * 72, imageScaleX / item->pixm.imgInfo.xres * 72);
@@ -2044,7 +2044,7 @@ void VivaPlug::parseAttributeSetXML(const QDomElement& obNode, AttributeSet &att
 		}
 		else if (stxe.tagName() == "vta:tabulators")
 		{
-			QString tabs = "";
+			QString tabs;
 			for (QDomNode stc = stxe.firstChild(); !stc.isNull(); stc = stc.nextSibling())
 			{
 				QDomElement stce = stc.toElement();
@@ -2297,7 +2297,7 @@ void VivaPlug::applyCharacterAttrs(CharStyle &tmpCStyle, ParagraphStyle &newStyl
 
 QString VivaPlug::constructFontName(const QString& fontBaseName, const QString& fontStyle)
 {
-	QString fontName = "";
+	QString fontName;
 	bool found = false;
 	SCFontsIterator it(PrefsManager::instance().appPrefs.fontPrefs.AvailFonts);
 	for ( ; it.hasNext(); it.next())
