@@ -13,7 +13,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QDebug>
 
@@ -25,30 +24,18 @@ for which a new license (GPL+exception) is in place.
 #include "loadsaveplugin.h"
 #include "pageitem.h"
 #include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
-#include "scclocale.h"
-#include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
-#include "scpattern.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "sctextstream.h"
 #include "selection.h"
-#include "ui/customfdialog.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_formats.h"
 #include "util_math.h"
 
 XfigPlug::XfigPlug(ScribusDoc* doc, int flags)
@@ -62,8 +49,8 @@ XfigPlug::XfigPlug(ScribusDoc* doc, int flags)
 
 QImage XfigPlug::readThumbnail(const QString& fName)
 {
-	QFileInfo fi = QFileInfo(fName);
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+	QFileInfo fi(fName);
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 	double w=0.0, h=0.0, x=0.0, y=0.0;
 	parseHeader(fName, x, y, w, h);
 	docX = x;
@@ -257,14 +244,14 @@ bool XfigPlug::import(const QString& fNameIn, const TransactionSettings& trSetti
 	CustColors.insert("Pink2", ScColor(255, 192, 192));
 	CustColors.insert("Pink", ScColor(255, 224, 224));
 	CustColors.insert("Gold", ScColor(255, 215, 0));
-	QFileInfo fi = QFileInfo(fNameIn);
-	if ( !ScCore->usingGUI() )
+	QFileInfo fi(fNameIn);
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	if ( showProgress )
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -900,9 +887,9 @@ void XfigPlug::processPolyline(QDataStream &ts, const QString& data)
 
 void XfigPlug::processSpline(QDataStream &ts, const QString& data)
 {
-	QString tmp = data;
-	QString fArrowData = "";
-	QString bArrowData = "";
+	QString tmp(data);
+	QString fArrowData;
+	QString bArrowData;
 	int		command;
 	int		subtype;				// 0: open approximated spline
 									// 1: closed approximated spline
@@ -1018,9 +1005,9 @@ void XfigPlug::processSpline(QDataStream &ts, const QString& data)
 
 void XfigPlug::processArc(QDataStream &ts, const QString& data)
 {
-	QString tmp = data;
-	QString fArrowData = "";
-	QString bArrowData = "";
+	QString tmp(data);
+	QString fArrowData;
+	QString bArrowData;
 	int		command;
 	int		subtype;				// (1: open ended arc, 2: pie-wedge (closed))
 	int		line_style;				// (enumeration type)
@@ -1189,8 +1176,8 @@ void XfigPlug::processEllipse(const QString& data)
 		if (line_style > 0)
 			ite->setDashes(getDashValues(LineW, line_style));
 		ite->setTextFlowMode(PageItem::TextFlowDisabled);
-		int rot = m_Doc->rotationMode();
-		m_Doc->setRotationMode ( 2);
+		AnchorPoint rot = m_Doc->rotationMode();
+		m_Doc->setRotationMode ( AnchorPoint::Center);
 		m_Doc->rotateItem(-angle * 180.0 / M_PI, ite);
 		m_Doc->setRotationMode( rot);
 		depthMap.insert(999 - depth, currentItemNr);
@@ -1204,7 +1191,7 @@ QString XfigPlug::cleanText(const QString& text)
 	QString tmp;
 	bool sep = false;
 	int sepcount = 0;
-	for (int a = 1; a < text.count(); ++a)
+	for (int a = 1; a < text.size(); ++a)
 	{
 		QString ch = text.mid(a,1);
 		if (sep)
@@ -1639,7 +1626,7 @@ bool XfigPlug::convert(const QString& fn)
 		tmp = readLineFromDataStream(ts);
 		if (tmp.startsWith("#"))
 			tmp = readLineFromDataStream(ts);
-		QString resolution = tmp;
+//		QString resolution = tmp;
 		while (!ts.atEnd())
 		{
 			tmp = readLineFromDataStream(ts);
