@@ -17,7 +17,6 @@ for which a new license (GPL+exception) is in place.
 #include <QFile>
 #include <QList>
 #include <QMimeData>
-#include <QRegExp>
 #include <QStack>
 #include <QUrl>
 #include <QDebug>
@@ -29,24 +28,17 @@ for which a new license (GPL+exception) is in place.
 #include <cstdlib>
 #include <climits>
 #include <limits>
+#include <string>
 
 #include "commonstrings.h"
 
 #include "importxps.h"
 
 #include "loadsaveplugin.h"
-#include "pageitem_table.h"
-#include "pagesize.h"
-#include "prefscontext.h"
-#include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
-#include "rawimage.h"
-#include "scclocale.h"
 #include "sccolorengine.h"
 #include "scconfig.h"
 #include "scmimedata.h"
-#include "scpaths.h"
 #include "scribusXml.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
@@ -54,13 +46,9 @@ for which a new license (GPL+exception) is in place.
 #include "sctextstream.h"
 #include "selection.h"
 #include "third_party/zip/scribus_zip.h"
-#include "ui/customfdialog.h"
-#include "ui/missing.h"
 #include "ui/multiprogressdialog.h"
-#include "ui/propertiespalette.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_formats.h"
 #include "util_math.h"
 #include "xpsimportoptions.h"
 
@@ -70,8 +58,6 @@ XpsPlug::XpsPlug(ScribusDoc* doc, int flags)
 	m_Doc = doc;
 	importerFlags = flags;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
-	progressDialog = nullptr;
-	uz = nullptr;
 }
 
 QImage XpsPlug::readThumbnail(const QString& fName)
@@ -121,8 +107,8 @@ QImage XpsPlug::readThumbnail(const QString& fName)
 	}
 	if (!found)
 	{
-		QFileInfo fi = QFileInfo(fName);
-		baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
+		QFileInfo fi(fName);
+		baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
 		docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
 		docHeight = PrefsManager::instance().appPrefs.docSetupPrefs.pageHeight;
 		m_Doc = new ScribusDoc();
@@ -196,15 +182,15 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	bool ret = false;
 	firstPage = true;
 	pagecount = 1;
-	QFileInfo fi = QFileInfo(fNameIn);
+	QFileInfo fi(fNameIn);
 	m_FileName = fi.fileName();
-	if ( !ScCore->usingGUI() )
+	if (!ScCore->usingGUI())
 	{
 		interactive = false;
 		showProgress = false;
 	}
-	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath()+"/"));
-	if ( showProgress )
+	baseFile = QDir::cleanPath(QDir::toNativeSeparators(fi.absolutePath() + "/"));
+	if (showProgress)
 	{
 		ScribusMainWindow* mw = (m_Doc == nullptr) ? ScCore->primaryMainWindow() : m_Doc->scMW();
 		progressDialog = new MultiProgressDialog( tr("Importing: %1").arg(fi.fileName()), CommonStrings::tr_Cancel, mw );
@@ -219,14 +205,14 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		progressDialog->setProgress("GI", 0);
 		progressDialog->show();
 		connect(progressDialog, SIGNAL(canceled()), this, SLOT(cancelRequested()));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	else
 		progressDialog = nullptr;
 	if (progressDialog)
 	{
 		progressDialog->setOverallProgress(1);
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 	/* Set default Page to size defined in Preferences */
 	docWidth = PrefsManager::instance().appPrefs.docSetupPrefs.pageWidth;
@@ -254,12 +240,12 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 			baseY = m_Doc->currentPage()->yOffset() + m_Doc->currentPage()->height() / 2.0;
 		}
 	}
-	if ((!ret) && (interactive))
+	if (!ret && interactive)
 	{
 		baseX = m_Doc->currentPage()->xOffset();
 		baseY = m_Doc->currentPage()->yOffset() + m_Doc->currentPage()->height() / 2.0;
 	}
-	if ((ret) || (!interactive))
+	if (ret || !interactive)
 	{
 		if (docWidth > docHeight)
 			m_Doc->setPageOrientation(1);
@@ -275,7 +261,7 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	if ((!(flags & LoadSavePlugin::lfLoadAsPattern)) && (m_Doc->view() != nullptr))
 		m_Doc->view()->updatesOn(false);
 	m_Doc->scMW()->setScriptRunning(true);
-	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	QString CurDirP = QDir::currentPath();
 	QDir::setCurrent(fi.path());
 	if (convert(fNameIn))
@@ -287,7 +273,7 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->DoDrawing = true;
 		m_Doc->scMW()->setScriptRunning(false);
 		m_Doc->setLoading(false);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		if ((Elements.count() > 0) && (!ret) && (interactive))
 		{
 			if (flags & LoadSavePlugin::lfScripted)
@@ -363,7 +349,7 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 		m_Doc->scMW()->setScriptRunning(false);
 		if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 			m_Doc->view()->updatesOn(true);
-		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+		QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		success = false;
 	}
 	if (interactive)
@@ -371,10 +357,10 @@ bool XpsPlug::import(const QString& fNameIn, const TransactionSettings& trSettin
 	//CB If we have a gui we must refresh it if we have used the progressbar
 	if (!(flags & LoadSavePlugin::lfLoadAsPattern))
 	{
-		if ((showProgress) && (!interactive))
+		if (showProgress && !interactive)
 			m_Doc->view()->DrawNew();
 	}
-	qApp->restoreOverrideCursor();
+	QApplication::restoreOverrideCursor();
 	return success;
 }
 
@@ -402,7 +388,7 @@ bool XpsPlug::convert(const QString& fn)
 	{
 		progressDialog->setOverallProgress(2);
 		progressDialog->setLabel("GI", tr("Generating Items"));
-		qApp->processEvents();
+		QApplication::processEvents();
 	}
 
 	uz = new ScZipHandler();
@@ -439,7 +425,7 @@ bool XpsPlug::parseDocSequence(const QString& designMap)
 		return false;
 
 	bool parsed = false;
-	QString DocumentReference = "";
+	QString DocumentReference;
 	QDomElement docElem = designMapDom.documentElement();
 	for (QDomNode drawPag = docElem.firstChild(); !drawPag.isNull(); drawPag = drawPag.nextSibling())
 	{
@@ -471,7 +457,7 @@ bool XpsPlug::parseDocReference(const QString& designMap)
 	if (!designMapDom.setContent(f))
 		return false;
 
-	QString PageReference = "";
+	QString PageReference;
 	QDomElement docElem = designMapDom.documentElement();
 	if (importerFlags & LoadSavePlugin::lfCreateThumbnail)
 	{
@@ -506,20 +492,20 @@ bool XpsPlug::parseDocReference(const QString& designMap)
 		QString pageString = "*";
 		int pgCount = 0;
 		int maxPages = docElem.childNodes().count();
-		if (((interactive) || (importerFlags & LoadSavePlugin::lfCreateDoc)) && (maxPages > 1))
+		if ((interactive || (importerFlags & LoadSavePlugin::lfCreateDoc)) && (maxPages > 1))
 		{
 			if (progressDialog)
 				progressDialog->hide();
-			qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
+			QApplication::changeOverrideCursor(QCursor(Qt::ArrowCursor));
 			XpsImportOptions optImp(ScCore->primaryMainWindow());
 			optImp.setUpOptions(m_FileName, 1, maxPages, interactive);
 			if (optImp.exec() != QDialog::Accepted)
 				return false;
 			pageString = optImp.getPagesString();
-			qApp->changeOverrideCursor(QCursor(Qt::WaitCursor));
+			QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 			if (progressDialog)
 				progressDialog->show();
-			qApp->processEvents();
+			QApplication::processEvents();
 		}
 		parsePagesString(pageString, &pageNs, maxPages);
 		if (pageString != "*")
@@ -528,7 +514,7 @@ bool XpsPlug::parseDocReference(const QString& designMap)
 		{
 			progressDialog->setTotalSteps("GI", maxPages);
 			progressDialog->setProgress("GI", pgCount);
-			qApp->processEvents();
+			QApplication::processEvents();
 		}
 		QDomNodeList pgList = docElem.childNodes();
 		for (uint ap = 0; ap < pageNs.size(); ++ap)
@@ -670,8 +656,8 @@ void XpsPlug::parsePageReference(const QString& designMap)
 						{
 							Coords.resize(0);
 							Coords.svgInit();
-							QString pdata = "";
-							QString key = dpg.attribute("x:Key");
+							QString pdata;
+							QString key(dpg.attribute("x:Key"));
 							if (dpg.hasAttribute("Figures"))
 								pdata = dpg.attribute("Figures");
 							else if (dpg.hasChildNodes())
@@ -717,8 +703,8 @@ PageItem* XpsPlug::parseObjectXML(QDomElement &dpg, const QString& path)
 	obState.JoinStyle = Qt::MiterJoin;
 	obState.DashOffset = 0;
 	obState.DashPattern.clear();
-	QString itemName = "";
-	QString itemTarget = "";
+	QString itemName;
+	QString itemTarget;
 	if (dpg.hasAttribute("Name"))
 		itemName = dpg.attribute("Name");
 	if (dpg.hasAttribute("FixedPage.NavigateUri"))
@@ -871,11 +857,11 @@ PageItem* XpsPlug::parseObjectXML(QDomElement &dpg, const QString& path)
 				int glInd = 0;
 				if (!utfString.isEmpty())
 				{
-					QVector<uint> ucs4 = utfString.toUcs4();
+					std::u32string ucs4 = utfString.toStdU32String();
 					// FIXME HOST: this code does not do any text layout!
-					for (int sti = 0; sti < ucs4.length(); sti++)
+					for (size_t sti = 0; sti < ucs4.length(); ++sti)
 					{
-						uint chr = ucs4[sti];
+						char32_t chr = ucs4.at(sti);
 						QString utfChar = QString::fromUcs4(&chr, 1);
 						uint gl = iteFont.char2CMap(chr);
 						if (gl != 0)
@@ -909,8 +895,8 @@ PageItem* XpsPlug::parseObjectXML(QDomElement &dpg, const QString& path)
 										{
 											if (glyInd[0].startsWith("("))
 											{
-												int r = glyInd[0].indexOf(")");
-												QString comb = glyInd[0].mid(1, r-1);
+												qsizetype r = glyInd[0].indexOf(")");
+												QString comb = glyInd[0].mid(1, r - 1);
 												QStringList combInd = comb.split(":");
 												int advUtf = combInd[0].toInt() - 1;
 												sti += advUtf;
@@ -987,8 +973,8 @@ PageItem* XpsPlug::parseObjectXML(QDomElement &dpg, const QString& path)
 							{
 								if (glyInd[0].startsWith("("))
 								{
-									int r = glyInd[0].indexOf(")");
-									QString comb = glyInd[0].mid(1, r-1);
+									qsizetype r = glyInd[0].indexOf(")");
+									QString comb = glyInd[0].mid(1, r - 1);
 									QStringList combInd = comb.split(":");
 									int advUtf = combInd[0].toInt() - 1;
 									glInd += advUtf;
@@ -1168,7 +1154,7 @@ PageItem* XpsPlug::parseObjectXML(QDomElement &dpg, const QString& path)
 								{
 									Coords.resize(0);
 									Coords.svgInit();
-									QString pdata = "";
+									QString pdata;
 									QString key = dpg.attribute("x:Key");
 									if (dpg.hasAttribute("Figures"))
 										pdata = dpg.attribute("Figures");
@@ -1500,7 +1486,7 @@ void XpsPlug::parsePathDataXML(QDomElement &spe, ObjState &obState, bool forClip
 {
 	Coords.resize(0);
 	Coords.svgInit();
-	QString svgString = "";
+	QString svgString;
 	bool windFill = false;
 	for (QDomElement dpgp = spe.firstChildElement(); !dpgp.isNull(); dpgp = dpgp.nextSiblingElement())
 	{
@@ -1528,7 +1514,7 @@ void XpsPlug::parsePathDataXML(QDomElement &spe, ObjState &obState, bool forClip
 
 QString XpsPlug::parsePathGeometryXML(QDomElement &spe)
 {
-	QString svgString = "";
+	QString svgString;
 	for (QDomElement dpg = spe.firstChildElement(); !dpg.isNull(); dpg = dpg.nextSiblingElement())
 	{
 		if (dpg.tagName() != "PathFigure")
@@ -1592,8 +1578,8 @@ void XpsPlug::parseResourceFile(const QString& resFile)
 			continue;
 		Coords.resize(0);
 		Coords.svgInit();
-		QString pdata = "";
-		QString key = dpg.attribute("x:Key");
+		QString pdata;
+		QString key(dpg.attribute("x:Key"));
 		if (dpg.hasAttribute("Figures"))
 			pdata = dpg.attribute("Figures");
 		else if (dpg.hasChildNodes())
@@ -1804,7 +1790,7 @@ QString XpsPlug::handleColor(QString rgbColor, double &opacity)
 	if (rgbColor.startsWith( "sc#" ))
 	{
 		QColor c;
-		rgbColor = rgbColor.remove(0,3);
+		rgbColor.remove(0,3);
 		QStringList co = rgbColor.split(",");
 		if (co.size() == 3)
 		{
@@ -1845,11 +1831,11 @@ QString XpsPlug::handleColor(QString rgbColor, double &opacity)
 			bool ok;
 			int hex = alpha.toInt(&ok, 16);
 			opacity = 1.0 - (hex / 255.0);
-			rgbColor = rgbColor.remove(1,2);
+			rgbColor.remove(1,2);
 		}
 		else
 			opacity = 0;
-		c.setNamedColor(rgbColor);
+		c = QColor::fromString(rgbColor);
 		ScColor tmp;
 		tmp.fromQColor(c);
 		tmp.setSpotColor(false);
@@ -1927,10 +1913,10 @@ ScFace XpsPlug::loadFontByName(const QString &fileName)
 		}
 		// Obfuscation - xor bytes in font binary with bytes from guid (font's filename)
 		const static int mapping[] = {15, 14, 13, 12, 11, 10, 9, 8, 6, 7, 4, 5, 0, 1, 2, 3};
-		for (int i = 0; i < 16; i++)
+		for (int i = 0; i < 16; ++i)
 		{
 			fontData[i] = fontData[i] ^ guid[mapping[i]];
-			fontData[i+16] = fontData[i+16] ^ guid[mapping[i]];
+			fontData[i+16] = fontData[i + 16] ^ guid[mapping[i]];
 		}
 	}
 	QFile ft(fname);
