@@ -65,9 +65,9 @@ PictureBrowser::PictureBrowser(ScribusDoc* doc, QWidget *parent):
 //"goto page" button in documentbrowser
 	connect(gotoPageButton, SIGNAL(clicked()), this, SLOT(gotoPageButtonClicked()));
 
-	connect(folderView, SIGNAL(activated(const QModelIndex &)), this, SLOT(dirChosen(const QModelIndex &)));
-	connect(folderView, SIGNAL(clicked(const QModelIndex &)), this, SLOT(dirChosen(const QModelIndex &)));
-	connect(folderView, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(dirChosen(const QModelIndex &)));
+	connect(folderView, SIGNAL(activated(QModelIndex)), this, SLOT(dirChosen(QModelIndex)));
+	connect(folderView, SIGNAL(clicked(QModelIndex)), this, SLOT(dirChosen(QModelIndex)));
+	connect(folderView, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(dirChosen(QModelIndex)));
 
 //changing page
 	connect(this, SIGNAL(selectPage(int)), ScCore->primaryMainWindow(), SLOT(selectPagesFromOutlines(int)));
@@ -106,28 +106,28 @@ PictureBrowser::PictureBrowser(ScribusDoc* doc, QWidget *parent):
 	lit = new loadImagesThread(this, pModel);
 	lit->start();
 
-	connect(imageViewArea, SIGNAL(clicked(const QModelIndex &)), this, SLOT(previewIconClicked(const QModelIndex &)));
-	connect(imageViewArea, SIGNAL(doubleClicked(const QModelIndex &)), this, SLOT(previewIconDoubleClicked(const QModelIndex &)));
+	connect(imageViewArea, SIGNAL(clicked(QModelIndex)), this, SLOT(previewIconClicked(QModelIndex)));
+	connect(imageViewArea, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(previewIconDoubleClicked(QModelIndex)));
 
 	imageViewArea->SetIconSize(QSize(pbSettings.previewIconSize, pbSettings.previewIconSize));
 	imageViewArea->SetGridSize(QSize(qRound(( 1.1)*pbSettings.previewIconSize),(qRound(( 1.1)*pbSettings.previewIconSize)+ pbSettings.previewMode*10)));
 	imageViewArea->SetModel(pModel);
 
 //register item selections
-	connect(imageViewArea->SelectionModel(), SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)), this, SLOT(previewImageSelectionChanged(const QItemSelection &, const QItemSelection &)));
+	connect(imageViewArea->SelectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(previewImageSelectionChanged(QItemSelection,QItemSelection)));
 
 //documentbrowser setup
-	connect(documentWidget, SIGNAL(itemActivated(QTreeWidgetItem * , int)), this, SLOT(documentChosen(QTreeWidgetItem * , int)));
-	connect(documentWidget, SIGNAL(itemClicked(QTreeWidgetItem * , int)), this, SLOT(documentChosen(QTreeWidgetItem * , int)));
+	connect(documentWidget, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(documentChosen(QTreeWidgetItem*,int)));
+	connect(documentWidget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(documentChosen(QTreeWidgetItem*,int)));
 
 	documentWidget->setColumnCount(1);
 	documentWidget->setHeaderLabels(QStringList("Pages"));
 
 
 //collectionsbrowser setup
-	connect(collectionsWidget, SIGNAL(itemActivated(QTreeWidgetItem * , int)), this, SLOT(collectionChosen(QTreeWidgetItem * , int)));
-	connect(collectionsWidget, SIGNAL(itemClicked(QTreeWidgetItem * , int)), this, SLOT(collectionChosen(QTreeWidgetItem * , int)));
-	connect(collectionsWidget, SIGNAL(itemChanged(QTreeWidgetItem * , int)), this, SLOT(collectionsWidgetItemEdited(QTreeWidgetItem * , int)));
+	connect(collectionsWidget, SIGNAL(itemActivated(QTreeWidgetItem*,int)), this, SLOT(collectionChosen(QTreeWidgetItem*,int)));
+	connect(collectionsWidget, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(collectionChosen(QTreeWidgetItem*,int)));
+	connect(collectionsWidget, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(collectionsWidgetItemEdited(QTreeWidgetItem*,int)));
 	connect(collectionsNewCategoryButton, SIGNAL(clicked()), this, SLOT(collectionsNewCategoryButtonClicked()));
 	connect(collectionsNewButton, SIGNAL(clicked()), this, SLOT(collectionsNewButtonClicked()));
 	connect(collectionsImportButton, SIGNAL(clicked()), this, SLOT(collectionsImportButtonClicked()));
@@ -904,7 +904,7 @@ void PictureBrowser::insertImageButtonClicked()
 	iafData.frameType = PageItem::ImageFrame;
 	iafData.source = tmpImage->fileInformation.absoluteFilePath();
 
-	QString pageList = "";
+	QString pageList;
 
 	if (insertPagesCombobox->checkstate(1) == 1)
 	{
@@ -1561,26 +1561,26 @@ void PictureBrowser::loadIcons()
 {
 	IconManager& im = IconManager::instance();
 
-	iconArrowUp = QIcon(im.loadIcon("pitr_green_arrows_set_1.svg"));
-	iconArrowDown = QIcon(im.loadIcon("pitr_green_arrows_set_5.svg"));
-	iconFolderBrowser = QIcon(im.loadIcon("sarxos_Simple_Folder_Seek.svg"));
-	iconCollectionsBrowser = QIcon(im.loadIcon("sarxos_Simple_Green_Yellow_Blue_Violet_Folders.svg"));
-	iconDocumentBrowser = QIcon(im.loadIcon("sarxos_Paper_Sheets.svg"));
+	iconArrowUp = QIcon(im.loadIcon("svg/pitr_green_arrows_set_1.svg"));
+	iconArrowDown = QIcon(im.loadIcon("svg/pitr_green_arrows_set_5.svg"));
+	iconFolderBrowser = QIcon(im.loadIcon("svg/sarxos_Simple_Folder_Seek.svg"));
+	iconCollectionsBrowser = QIcon(im.loadIcon("svg/sarxos_Simple_Green_Yellow_Blue_Violet_Folders.svg"));
+	iconDocumentBrowser = QIcon(im.loadIcon("svg/sarxos_Paper_Sheets.svg"));
 	iconDocument = QIcon(im.loadIcon("doc.png"));
 	iconCollection = QIcon(im.loadIcon("cmyk.png"));
 	iconOk = QIcon(im.loadIcon("ok22.png"));
-	iconClose = QIcon(im.loadIcon("/16/close.png"));
+	iconClose = QIcon(im.loadIcon("16/close.png"));
 	iconZoomPlus = QIcon(im.loadIcon("viewmagin.png"));
 	iconZoomMinus = QIcon(im.loadIcon("viewmagout.png"));
-	iconNew = QIcon(im.loadIcon("/16/insert-table.png"));
-	iconNew2 = QIcon(im.loadIcon("/16/document-new.png"));
-	iconEdit = QIcon(im.loadIcon("/16/document-properties.png"));
-	iconRemove = QIcon(im.loadIcon("/16/edit-cut.png"));
-	iconLoad = QIcon(im.loadIcon("/16/document-open.png"));
-	iconSave = QIcon(im.loadIcon("/16/document-save.png"));
-	iconPlus = QIcon(im.loadIcon("/16/list-add.png"));
-	iconMinus = QIcon(im.loadIcon("/16/list-remove.png"));
-	iconPen = QIcon(im.loadIcon("/16/story-editor.png"));
+	iconNew = QIcon(im.loadIcon("16/insert-table.png"));
+	iconNew2 = QIcon(im.loadIcon("16/document-new.png"));
+	iconEdit = QIcon(im.loadIcon("16/document-properties.png"));
+	iconRemove = QIcon(im.loadIcon("16/edit-cut.png"));
+	iconLoad = QIcon(im.loadIcon("16/document-open.png"));
+	iconSave = QIcon(im.loadIcon("16/document-save.png"));
+	iconPlus = QIcon(im.loadIcon("16/list-add.png"));
+	iconMinus = QIcon(im.loadIcon("16/list-remove.png"));
+	iconPen = QIcon(im.loadIcon("16/story-editor.png"));
 
 	collectionsNewCategoryButton->setIcon(iconNew);
 	collectionsNewButton->setIcon(iconNew2);
@@ -1605,7 +1605,7 @@ void PictureBrowser::loadIcons()
 
 	closeButton->setIcon(iconClose);
 
-	moreButton->setIcon(iconArrowDown);
+	//moreButton->setIcon(iconArrowDown);
 
 	filterSearchDirButton->setIcon(im.loadIcon("ellipsis.png"));
 }
@@ -1681,7 +1681,7 @@ void PictureBrowser::updateDocumentBrowser()
 
 	QTreeWidgetItem *tmpItem;
 
-	for (int i = 0; i < m_Doc->Pages->count(); ++i)
+	for (int i = 0; i < (int)(m_Doc->Pages->count()); ++i)
 	{
 		tmpItem = new QTreeWidgetItem(allpages, QStringList(QString("Page %1").arg(i+1)));
 		tmpItem->setData(0, Qt::UserRole,(i+1));
@@ -1868,7 +1868,7 @@ void PictureBrowser::expandDialog(bool expand)
 
 		resize(872, 550);
 		moreButton->setText(tr("Hide"));
-		moreButton->setIcon(iconArrowUp);
+		//moreButton->setIcon(iconArrowUp);
 	}
 	else
 	{
@@ -1876,7 +1876,7 @@ void PictureBrowser::expandDialog(bool expand)
 
 		resize(872, 385);
 		moreButton->setText(tr("More"));
-		moreButton->setIcon(iconArrowDown);
+		//moreButton->setIcon(iconArrowDown);
 	}
 }
 
