@@ -20,10 +20,7 @@ PyObject *scribus_getobjecttype(PyObject* /* self */, PyObject* args)
 	QString result;
 
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 
 	if (!checkHaveDocument())
 		return nullptr;
@@ -73,10 +70,7 @@ PyObject *scribus_getfillcolor(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -89,10 +83,7 @@ PyObject *scribus_getfillshade(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -105,10 +96,7 @@ PyObject *scribus_getfilltransparency(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -121,10 +109,7 @@ PyObject *scribus_getfillblendmode(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -133,14 +118,63 @@ PyObject *scribus_getfillblendmode(PyObject* /* self */, PyObject* args)
 	return PyLong_FromLong(static_cast<long>(item->fillBlendmode()));
 }
 
+PyObject* scribus_getgradstop(PyObject* /* self */, PyObject* args)
+{
+	PyESString name;
+	int stopIndex = 0;
+	if (!PyArg_ParseTuple(args, "i|es", &stopIndex, "utf-8", name.ptr()))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	const PageItem* item = GetUniqueItem(QString::fromUtf8(name.c_str()));
+	if (item == nullptr)
+		return nullptr;
+
+	int gradStopsCount = item->fill_gradient.stops();
+
+	if (stopIndex < 0 || stopIndex >= gradStopsCount)
+	{
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Stop index out of bounds, must be 0 <= index <= stopsCount.", "python error").toLocal8Bit().constData());
+		return nullptr;
+	}
+
+	const VColorStop* stop = item->fill_gradient.colorStops()[stopIndex];
+	QByteArray stopName = stop->name.toUtf8();
+
+	return Py_BuildValue("(sdi)", stopName.constData(), stop->opacity, stop->shade);
+}
+
+PyObject* scribus_getgradstopscount(PyObject* /* self */, PyObject* args)
+{
+	PyESString name;
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	const PageItem* item = GetUniqueItem(QString::fromUtf8(name.c_str()));
+	if (item == nullptr)
+		return nullptr;
+	return PyLong_FromLong(static_cast<long>(item->fill_gradient.stops()));
+}
+
+PyObject* scribus_getgradvector(PyObject* /* self */, PyObject* args)
+{
+	PyESString name;
+	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+		return nullptr;
+	if (!checkHaveDocument())
+		return nullptr;
+	const PageItem* item = GetUniqueItem(QString::fromUtf8(name.c_str()));
+	if (item == nullptr)
+		return nullptr;
+	return Py_BuildValue("(ffff)", PointToValue(item->GrStartX), PointToValue(item->GrStartY), PointToValue(item->GrEndX), PointToValue(item->GrEndY));
+}
+
 PyObject *scribus_getcustomlinestyle(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -153,10 +187,7 @@ PyObject *scribus_getlinecolor(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -169,10 +200,7 @@ PyObject *scribus_getlinetransparency(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -185,10 +213,7 @@ PyObject *scribus_getlineblendmode(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -201,10 +226,7 @@ PyObject *scribus_getlinewidth(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -217,10 +239,7 @@ PyObject *scribus_getlineshade(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -233,10 +252,7 @@ PyObject *scribus_getlinejoin(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -249,10 +265,7 @@ PyObject *scribus_getlinecap(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -265,10 +278,7 @@ PyObject *scribus_getlinestyle(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -281,10 +291,7 @@ PyObject *scribus_getcornerradius(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -297,10 +304,7 @@ PyObject *scribus_getimageoffset(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -313,10 +317,7 @@ PyObject *scribus_getimagescale(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -329,10 +330,7 @@ PyObject *scribus_getimagefile(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -345,10 +343,7 @@ PyObject *scribus_getposition(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -362,10 +357,7 @@ PyObject *scribus_getsize(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -378,10 +370,7 @@ PyObject *scribus_getrotation(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -392,48 +381,42 @@ PyObject *scribus_getrotation(PyObject* /* self */, PyObject* args)
 
 PyObject *scribus_getboundingbox(PyObject* /* self */, PyObject* args)
 {
-	PyESString name;
-	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
-		return nullptr;
-	}
-	if (!checkHaveDocument())
-		return nullptr;
-	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
-	if (item == nullptr)
-		return nullptr;
+    PyESString name;
+    if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+        return nullptr;
+    if (!checkHaveDocument())
+        return nullptr;
+    const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
+    if (item == nullptr)
+        return nullptr;
 
-	return Py_BuildValue("(dddd)",
-	                     docUnitXToPageX(item->BoundingX),
-	                     docUnitYToPageY(item->BoundingY),
-	                     PointToValue(item->BoundingW),
-	                     PointToValue(item->BoundingH)
-	                    );
+    return Py_BuildValue("(dddd)",
+                         docUnitXToPageX(item->BoundingX),
+                         docUnitYToPageY(item->BoundingY),
+                         PointToValue(item->BoundingW),
+                         PointToValue(item->BoundingH)
+                         );
 }
 
 PyObject *scribus_getvisualboundingbox(PyObject* /* self */, PyObject* args)
 {
-	PyESString name;
-	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
-		return nullptr;
-	}
-	if (!checkHaveDocument())
-		return nullptr;
-	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
-	if (item == nullptr)
-		return nullptr;
+    PyESString name;
+    if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
+        return nullptr;
+    if (!checkHaveDocument())
+        return nullptr;
+    const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
+    if (item == nullptr)
+        return nullptr;
 
 	QRectF boundingBox = item->getVisualBoundingRect();
 
-	return Py_BuildValue("(dddd)",
-	                     docUnitXToPageX(boundingBox.x()),
-	                     docUnitYToPageY(boundingBox.y()),
-	                     PointToValue(boundingBox.width()),
-	                     PointToValue(boundingBox.height())
-	                    );
+    return Py_BuildValue("(dddd)",
+                         docUnitXToPageX(boundingBox.x()),
+                         docUnitYToPageY(boundingBox.y()),
+                         PointToValue(boundingBox.width()),
+                         PointToValue(boundingBox.height())
+                         );
 }
 
 PyObject *scribus_getallobjects(PyObject* /* self */, PyObject* args, PyObject *keywds)
@@ -451,17 +434,12 @@ PyObject *scribus_getallobjects(PyObject* /* self */, PyObject* args, PyObject *
 	PyESString esLayerName;
 
 	if (!PyArg_ParseTupleAndKeywords(args, keywds, "|iies", kwlist, &itemType, &pageNr, "utf-8", esLayerName.ptr()))
-	{
-		// Some old python versions leave bad pointers behind when an argument parsing error occurs
-		// so we can't free the memory safely in this case
-		esLayerName.resetDontFree();
 		return nullptr;
-	}
 
 	int numPages = currentDoc->Pages->count();
 	if (pageNr < 0 || pageNr >= numPages)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("page number is invalid.", "python error").toUtf8().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("page number is invalid.", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -471,7 +449,7 @@ PyObject *scribus_getallobjects(PyObject* /* self */, PyObject* args, PyObject *
 		const ScLayer *layer = currentDoc->Layers.layerByName(layerName);
 		if (!layer)
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("layer name is invalid.", "python error").toUtf8().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("layer name is invalid.", "python error").toLocal8Bit().constData());
 			return nullptr;
 		}
 		layerId = layer->ID;
@@ -508,10 +486,7 @@ PyObject *scribus_getobjectattributes(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
 	if (item == nullptr)
 		return nullptr;
@@ -549,10 +524,7 @@ PyObject *scribus_getimagecolorspace(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	const PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -561,7 +533,7 @@ PyObject *scribus_getimagecolorspace(PyObject* /* self */, PyObject* args)
 	if (item->itemType() != PageItem::ImageFrame)
 	{
 		PyErr_SetString(WrongFrameTypeError,
-			QObject::tr("Page item must be an ImageFrame", "python error").toUtf8().constData());
+			QObject::tr("Page item must be an ImageFrame", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -596,6 +568,9 @@ void cmdgetpropdocwarnings()
 	  << scribus_getfillblendmode__doc__
 	  << scribus_getfillshade__doc__ 
 	  << scribus_getfilltransparency__doc__
+	  << scribus_getgradstop__doc__ 
+	  << scribus_getgradstopscount__doc__ 
+	  << scribus_getgradvector__doc__ 
 	  << scribus_getimagecolorspace__doc__
 	  << scribus_getimagefile__doc__
 	  << scribus_getimageoffset__doc__
