@@ -10,6 +10,7 @@ for which a new license (GPL+exception) is in place.
 
 #include <QMetaObject>
 #include <QMetaProperty>
+#include <QMetaType>
 #include <QList>
 #include <QObject>
 #include <QObjectList>
@@ -275,29 +276,29 @@ PyObject* scribus_getproperty(PyObject* /*self*/, PyObject* args, PyObject* kw)
 	// Convert the property to an instance of the closest matching Python type.
 	PyObject* resultobj = nullptr;
 	// NUMERIC TYPES
-	if (prop.type() == QVariant::Int)
+	if (prop.userType() == QMetaType::Int)
 		resultobj = PyLong_FromLong(prop.toInt());
-	else if (prop.type() == QVariant::Double)
+	else if (prop.userType() == QMetaType::Double)
 		resultobj = PyFloat_FromDouble(prop.toDouble());
 	// BOOLEAN
-	else if (prop.type() == QVariant::Bool)
+	else if (prop.userType() == QMetaType::Bool)
 		resultobj = PyBool_FromLong(prop.toBool());
 	// STRING TYPES
-	else if (prop.type() == QVariant::ByteArray)
+	else if (prop.userType() == QMetaType::QByteArray)
 	{
 		QByteArray ba = prop.toByteArray();
 		resultobj = PyBytes_FromStringAndSize(ba.data(), ba.size());
 	}
-	else if (prop.type() == QVariant::String)
+	else if (prop.userType() == QMetaType::QString)
 		resultobj = PyUnicode_FromString(prop.toString().toUtf8().data());
 	// HIGHER ORDER TYPES
-	else if (prop.type() == QVariant::Point)
+	else if (prop.userType() == QMetaType::QPoint)
 	{
 		// Return a QPoint as an (x,y) tuple.
 		QPoint pt = prop.toPoint();
 		return Py_BuildValue("(ii)", pt.x(), pt.y());
 	}
-	else if (prop.type() == QVariant::Rect)
+	else if (prop.userType() == QMetaType::QRect)
 	{
 		// Return a QRect as an (x,y,width,height) tuple.
 		// FIXME: We should really construct and return an object that
@@ -306,7 +307,7 @@ PyObject* scribus_getproperty(PyObject* /*self*/, PyObject* args, PyObject* kw)
 		QRect r = prop.toRect();
 		return Py_BuildValue("(iiii)", r.x(), r.y(), r.width(), r.height());
 	}
-	else if (prop.type() == QVariant::StringList)
+	else if (prop.userType() == QMetaType::QStringList)
 	{
 		QStringList tmp = prop.toStringList();
 		return convert_QStringList_to_PyListObject(tmp);
@@ -360,14 +361,14 @@ PyObject* scribus_setproperty(PyObject* /*self*/, PyObject* args, PyObject* kw)
 
 	// Did we know how to convert the value argument to the right type?
 	bool matched = false;
-	// Did the set call succceed?
+	// Did the set call succeed?
 	bool success = false;
 
 	// Check the C++ type of the property, and try to convert the passed
 	// PyObject to something sensible looking for it.
 	// FIXME: handle enums/sets
 	// NUMERIC TYPES
-	// These are unfortuately a TOTAL PITA because of the multitude of
+	// These are unfortunately a TOTAL PITA because of the multitude of
 	// C and Python numeric types. TODO This needs to be broken out into a subroutine.
 	if (propertyType == "bool")
 	{
@@ -482,6 +483,6 @@ void cmdgetsetpropdocwarnings()
 	QStringList s;
 	s << scribus_getproperty__doc__
 	  << scribus_getpropertynames__doc__
-	  << scribus_propertyctype__doc__ 
+	  << scribus_propertyctype__doc__
 	  << scribus_setproperty__doc__;
 }
