@@ -22,11 +22,7 @@ PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	PyESString image;
 	if (!PyArg_ParseTuple(args, "es|es", "utf-8", image.ptr(), "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
-		image.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -34,7 +30,7 @@ PyObject *scribus_loadimage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Target is not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	ScCore->primaryMainWindow()->doc->loadPict(QString::fromUtf8(image.c_str()), item);
@@ -46,10 +42,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -57,7 +50,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -65,7 +58,7 @@ PyObject *scribus_scaleimage(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = !tempSelection.isEmpty();
+	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -91,10 +84,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -102,7 +92,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -110,7 +100,7 @@ PyObject *scribus_setimagescale(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = !tempSelection.isEmpty();
+	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -137,10 +127,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -148,7 +135,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -156,7 +143,7 @@ PyObject *scribus_setimageoffset(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*ScCore->primaryMainWindow()->doc->m_Selection);
-	bool hadOrigSelection = !tempSelection.isEmpty();
+	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -184,10 +171,7 @@ PyObject *scribus_setimagebrightness(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double n;
 	if (!PyArg_ParseTuple(args, "d|es", &n, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -195,7 +179,7 @@ PyObject *scribus_setimagebrightness(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -215,10 +199,7 @@ PyObject *scribus_setimagegrayscale(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -226,7 +207,7 @@ PyObject *scribus_setimagegrayscale(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -245,10 +226,7 @@ PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -259,7 +237,7 @@ PyObject *scribus_moveobjectrel(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = !tempSelection.isEmpty();
+	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -290,10 +268,7 @@ PyObject *scribus_moveobjectabs(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -304,7 +279,7 @@ PyObject *scribus_moveobjectabs(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = !tempSelection.isEmpty();
+	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	// Clear the selection
 	currentView->deselectItems();
@@ -335,10 +310,7 @@ PyObject *scribus_rotateobjectrel(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x;
 	if (!PyArg_ParseTuple(args, "d|es", &x, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -352,19 +324,14 @@ PyObject *scribus_setrotation(PyObject* /* self */, PyObject* args, PyObject* kw
 {
 	PyESString name;
 	double rotation;
-	int basepoint = 0;
+	int basepoint = (int) AnchorPoint::None;
 	char *kwargs[] = {
 					  const_cast<char *>("rotation"),
 					  const_cast<char *>("name"),
 					  const_cast<char *>("basepoint"),
 					  nullptr};
 	if (!PyArg_ParseTupleAndKeywords(args, kw, "d|esi", kwargs, &rotation, "utf-8", name.ptr(), &basepoint))
-	{
-		// Some old python versions leave bad pointers behind when an argument parsing error occurs
-		// so we can't free the memory safely in this case
-		name.resetDontFree();
 		return nullptr;
-	}
 
 	if (!checkHaveDocument())
 		return nullptr;
@@ -372,16 +339,16 @@ PyObject *scribus_setrotation(PyObject* /* self */, PyObject* args, PyObject* kw
 	if (item == nullptr)
 		return nullptr;
 
-	int oldBasePoint = 0;
-	if (basepoint != 0)
+	AnchorPoint oldBasePoint = AnchorPoint::None;
+	if (basepoint != (int) AnchorPoint::None)
 	{
 		oldBasePoint = ScCore->primaryMainWindow()->doc->rotationMode();
-		ScCore->primaryMainWindow()->doc->setRotationMode(basepoint);
+		ScCore->primaryMainWindow()->doc->setRotationMode(static_cast<AnchorPoint>(basepoint));
 	}
 
 	ScCore->primaryMainWindow()->doc->rotateItem(rotation * -1.0, item);
 
-	if (basepoint != 0)
+	if (basepoint != (int) AnchorPoint::None)
 	{
 		ScCore->primaryMainWindow()->doc->setRotationMode(oldBasePoint);
 	}
@@ -394,10 +361,7 @@ PyObject *scribus_sizeobject(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double x, y;
 	if (!PyArg_ParseTuple(args, "dd|es", &x, &y, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -416,7 +380,7 @@ PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	if (il == nullptr && ScCore->primaryMainWindow()->doc->m_Selection->count() < 2)
 	{
-		PyErr_SetString(PyExc_TypeError, QObject::tr("Need selection or argument list of items to group", "python error").toUtf8().constData());
+		PyErr_SetString(PyExc_TypeError, QObject::tr("Need selection or argument list of items to group", "python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	Selection *tempSelection = nullptr;
@@ -448,7 +412,7 @@ PyObject *scribus_groupobjects(PyObject* /* self */, PyObject* args)
 	if (finalSelection->count() < 2)
 	{
 		// We can't very well group only one item
-		PyErr_SetString(NoValidObjectError, QObject::tr("Cannot group less than two items", "python error").toUtf8().constData());
+		PyErr_SetString(NoValidObjectError, QObject::tr("Cannot group less than two items", "python error").toLocal8Bit().constData());
 		finalSelection = nullptr;
 		delete tempSelection;
 		return nullptr;
@@ -465,10 +429,7 @@ PyObject *scribus_ungroupobjects(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -488,15 +449,12 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double sc;
 	if (!PyArg_ParseTuple(args, "d|es", &sc, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	if (sc == 0.0)
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot scale by 0%.","python error").toUtf8().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot scale by 0%.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -508,10 +466,12 @@ PyObject *scribus_scalegroup(PyObject* /* self */, PyObject* args)
 
 	currentView->deselectItems();
 	currentView->selectItem(i);
+//	int h = currentView->frameResizeHandle;
+//	currentView->frameResizeHandle = 1;
 	currentView->startGroupTransaction(Um::Resize, "", Um::IResize);
 	currentDoc->scaleGroup(sc, sc);
 	currentView->endGroupTransaction();
-
+//	currentView->frameResizeHandle = h;
 	Py_RETURN_NONE;
 }
 
@@ -525,12 +485,7 @@ PyObject *scribus_getGroupItems(PyObject * /*self*/, PyObject* args, PyObject* k
 	unsigned int type = 0;
 	char* kwargs[] = {const_cast<char*>("name"), const_cast<char*>("recursive"), const_cast<char*>("type"), nullptr};
 	if (!PyArg_ParseTupleAndKeywords(args, kw, "|espi", kwargs, "utf-8", name.ptr(), &recursive, &type))
-	{
-		// Some old python versions leave bad pointers behind when an argument parsing error occurs
-		// so we can't free the memory safely in this case
-		name.resetDontFree();
 		return nullptr;
-	}
 
 	PageItem *pageItem = GetUniqueItem(QString::fromUtf8(name.c_str()));
 	if (pageItem == nullptr)
@@ -591,10 +546,7 @@ PyObject *scribus_selectobject(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *i = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -616,10 +568,7 @@ PyObject *scribus_lockobject(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -637,10 +586,7 @@ PyObject *scribus_islocked(PyObject* /* self */, PyObject* args)
 {
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -657,16 +603,13 @@ PyObject *scribus_setscaleframetoimage(PyObject* /* self */, PyObject* args)
 		return nullptr;
 	PyESString name;
 	if (!PyArg_ParseTuple(args, "|es", "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
 	if (item == nullptr)
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(WrongFrameTypeError, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	Selection *sel = new Selection(ScCore->primaryMainWindow());
@@ -685,12 +628,7 @@ PyObject *scribus_setscaleimagetoframe(PyObject* /* self */, PyObject* args, PyO
 	char* kwargs[] = {const_cast<char*>("scaletoframe"),
 		const_cast<char*>("proportional"), const_cast<char*>("name"), nullptr};
 	if (!PyArg_ParseTupleAndKeywords(args, kw, "i|ies", kwargs, &scaleToFrame, &proportional, "utf-8", name.ptr()))
-	{
-		// Some old python versions leave bad pointers behind when an argument parsing error occurs
-		// so we can't free the memory safely in this case
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -698,7 +636,7 @@ PyObject *scribus_setscaleimagetoframe(PyObject* /* self */, PyObject* args, PyO
 		return nullptr;
 	if (!item->isImageFrame())
 	{
-		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toUtf8().constData());
+		PyErr_SetString(ScribusException, QObject::tr("Specified item not an image frame.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	// Set the item to scale if appropriate. ScaleType 1 is free
@@ -719,10 +657,7 @@ PyObject *scribus_flipobject(PyObject* /* self */, PyObject* args)
 	PyESString name;
 	double h, v;
 	if (!PyArg_ParseTuple(args, "dd|es", &h, &v, "utf-8", name.ptr()))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	PageItem *item = GetUniqueItem(QString::fromUtf8(name.c_str()));
@@ -733,7 +668,7 @@ PyObject *scribus_flipobject(PyObject* /* self */, PyObject* args)
 	ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 	ScribusView* currentView = ScCore->primaryMainWindow()->view;
 	Selection tempSelection(*currentDoc->m_Selection);
-	bool hadOrigSelection = !tempSelection.isEmpty();
+	bool hadOrigSelection = (tempSelection.count() != 0);
 
 	currentDoc->m_Selection->clear();
 	// Clear the selection
@@ -770,7 +705,7 @@ PyObject *scribus_combinepolygons(PyObject * /* self */)
 		const PageItem* it = currentDoc->m_Selection->itemAt(i);
 		if (!it->isPolygon() && !it->isPolyLine())
 		{
-			PyErr_SetString(WrongFrameTypeError, QObject::tr("Selection must contain only shapes or bezier curves.", "python error").toUtf8().constData());
+			PyErr_SetString(WrongFrameTypeError, QObject::tr("Selection must contain only shapes or bezier curves.", "python error").toLocal8Bit().constData());
 			return nullptr;
 		}
 	}
@@ -789,14 +724,14 @@ PyObject *scribus_seteditmode(PyObject * /* self */)
 
 	if (currentDoc->m_Selection->count() < 1)
 	{
-		PyErr_SetString(NoValidObjectError, QString("No item selected.").toUtf8().constData());
+		PyErr_SetString(NoValidObjectError, QString("No item selected.").toLocal8Bit().constData());
 		return nullptr;
 	}
 
 	auto currItem = currentDoc->m_Selection->itemAt(0);
 	if (!currItem->isTextFrame() && !currItem->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toUtf8().constData());
+		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -814,14 +749,14 @@ PyObject *scribus_setnormalmode(PyObject * /* self */)
 
 	if (currentDoc->m_Selection->count() < 1)
 	{
-		PyErr_SetString(NoValidObjectError, QString("No item selected.").toUtf8().constData());
+		PyErr_SetString(NoValidObjectError, QString("No item selected.").toLocal8Bit().constData());
 		return nullptr;
 	}
 
 	auto currItem = currentDoc->m_Selection->itemAt(0);
 	if (!currItem->isTextFrame() && !currItem->isImageFrame())
 	{
-		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toUtf8().constData());
+		PyErr_SetString(WrongFrameTypeError, QString("Only image and text frames are supported.").toLocal8Bit().constData());
 		return nullptr;
 	}
 
