@@ -23,7 +23,6 @@ PyObject *scribus_currentpage(PyObject* /* self */)
 	return PyLong_FromLong(static_cast<long>(ScCore->primaryMainWindow()->doc->currentPageNumber() + 1));
 }
 
-
 PyObject *scribus_currentpagenumberforsection(PyObject* /* self */)
 {
 	if (!checkHaveDocument())
@@ -50,7 +49,7 @@ PyObject *scribus_getpagetype(PyObject* /* self */, PyObject* args)
 	if (!checkHaveDocument())
 		return nullptr;
 	e--;
-	if ((e < 0) || (e > ScCore->primaryMainWindow()->doc->Pages->count() - 1))
+	if ((e < 0) || (e > static_cast<int>(ScCore->primaryMainWindow()->doc->Pages->count()) - 1))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -87,7 +86,7 @@ PyObject *scribus_deletepage(PyObject* /* self */, PyObject* args)
 	if (!checkHaveDocument())
 		return nullptr;
 	e--;
-	if ((e < 0) || (e > ScCore->primaryMainWindow()->doc->Pages->count() - 1))
+	if ((e < 0) || (e > static_cast<int>(ScCore->primaryMainWindow()->doc->Pages->count()) - 1))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -105,7 +104,7 @@ PyObject *scribus_gotopage(PyObject* /* self */, PyObject* args)
 	if (!checkHaveDocument())
 		return nullptr;
 	e--;
-	if ((e < 0) || (e > ScCore->primaryMainWindow()->doc->Pages->count() - 1))
+	if ((e < 0) || (e > static_cast<int>(ScCore->primaryMainWindow()->doc->Pages->count()) - 1))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -190,6 +189,49 @@ PyObject *scribus_getpagesize(PyObject* /* self */)
 	return t;
 }
 
+PyObject *scribus_getcurrentpagesize(PyObject* /* self */)
+{
+    if (!checkHaveDocument())
+        return nullptr;
+    ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+    const ScPage* currentPage = currentDoc->currentPage();
+
+    if (currentPage == nullptr)
+        return nullptr;
+
+    PyObject *t;
+    t = Py_BuildValue(
+        "(dd)",
+        PointToValue(currentPage->width()),
+        PointToValue(currentPage->height())
+        );
+    return t;
+}
+
+PyObject *scribus_setcurrentpagesize(PyObject* /* self */, PyObject* args)
+{
+    double width, height;
+    if (!PyArg_ParseTuple(args, "dd", &width, &height))
+        return nullptr;
+    if (!checkHaveDocument())
+        return nullptr;
+
+    ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
+    ScribusView* currentView = ScCore->primaryMainWindow()->view;
+    ScPage* currentPage = currentDoc->currentPage();
+
+    if (currentPage == nullptr)
+        return nullptr;
+
+    currentPage->setWidth(ValueToPoint(width));
+    currentPage->setHeight(ValueToPoint(height));
+
+    currentView->reformPagesView();
+    currentView->DrawNew();
+
+    Py_RETURN_NONE;
+}
+
 PyObject *scribus_getpagensize(PyObject* /* self */, PyObject* args)
 {
 	int e;
@@ -200,7 +242,7 @@ PyObject *scribus_getpagensize(PyObject* /* self */, PyObject* args)
 	const ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 
 	e--;
-	if ((e < 0) || (e > currentDoc->Pages->count() - 1))
+	if ((e < 0) || (e > static_cast<int>(currentDoc->Pages->count())-1))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -224,7 +266,7 @@ PyObject *scribus_getpagenmargins(PyObject* /* self */, PyObject* args)
 	const ScribusDoc* currentDoc = ScCore->primaryMainWindow()->doc;
 
 	e--;
-	if ((e < 0) || (e > currentDoc->Pages->count() - 1))
+	if ((e < 0) || (e > static_cast<int>(currentDoc->Pages->count())-1))
 	{
 		PyErr_SetString(PyExc_IndexError, QObject::tr("Page number out of range.","python error").toLocal8Bit().constData());
 		return nullptr;
@@ -692,7 +734,6 @@ PyObject *scribus_importpage(PyObject* /* self */, PyObject* args)
 	Py_RETURN_NONE;
 }
 
-
 /*! HACK: this removes "warning: 'blah' defined but not used" compiler warnings
 with header files structure untouched (docstrings are kept near declarations)
 PV */
@@ -702,22 +743,24 @@ void cmdpagedocwarnings()
 	s << scribus_currentpage__doc__
 	  << scribus_deletepage__doc__
 	  << scribus_getColumnGuides__doc__
+	  << scribus_getcurrentpagesize__doc__
 	  << scribus_getHguides__doc__
-	  << scribus_getpageitems__doc__
-	  << scribus_getpagemargins__doc__
-	  << scribus_getpagenmargins__doc__ 
-	  << scribus_getpagensize__doc__ 
-	  << scribus_getpagesize__doc__
-	  << scribus_getpagetype__doc__
 	  << scribus_getRowGuides__doc__
 	  << scribus_getVguides__doc__
+	  << scribus_getpageitems__doc__
+	  << scribus_getpagemargins__doc__
+	  << scribus_getpagenmargins__doc__
+	  << scribus_getpagensize__doc__
+	  << scribus_getpagesize__doc__
+	  << scribus_getpagetype__doc__
 	  << scribus_gotopage__doc__
 	  << scribus_importpage__doc__
 	  << scribus_newpage__doc__
 	  << scribus_pagecount__doc__
 	  << scribus_redraw__doc__
-	  << scribus_savepageeps__doc__           
+	  << scribus_savepageeps__doc__
 	  << scribus_setColumnGuides__doc__
+	  << scribus_setcurrentpagesize__doc__
 	  << scribus_setHguides__doc__
 	  << scribus_setRowGuides__doc__
 	  << scribus_setVguides__doc__;
