@@ -54,31 +54,24 @@ PyObject *scribus_createparagraphstyle(PyObject* /* self */, PyObject* args, PyO
 		&leftMargin, &rightMargin, &gapBefore, &gapAfter, &firstIndent,
 		&hasDropCap, &dropCapLines, &peOffset, "utf-8", charStyle.ptr(),
 		"utf-8", bullet.ptr(), &tabDefinitions))
-	{
-		// Some old python versions leave bad pointers behind when an argument parsing error occurs
-		// so we can't free the memory safely in this case
-		name.resetDontFree();
-		charStyle.resetDontFree();
-		bullet.resetDontFree();
 		return nullptr;
-	}
 	if (!checkHaveDocument())
 		return nullptr;
 	if (name.isEmpty())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty paragraph style name.","python error").toUtf8().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty paragraph style name.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	
 	if ((hasDropCap != 0) && (dropCapLines <= 1) )
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap is true but dropcaplines value is invalid","python error").toUtf8().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap is true but dropcaplines value is invalid","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 	
 	if (bullet.length() > 0 && (hasDropCap  != 0))
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap and bullet are not allowed to be specified together.","python error").toUtf8().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("hasdropcap and bullet are not allowed to be specified together.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -132,7 +125,7 @@ PyObject *scribus_createparagraphstyle(PyObject* /* self */, PyObject* args, PyO
 			float tabPosition = 0.0;
 			if (!PyArg_Parse(tabPositionDefinition, "f", &tabPosition))
 			{
-				PyErr_SetString(PyExc_TypeError, QObject::tr("invalid tab-position specified.","python error").toUtf8().constData());
+				PyErr_SetString(PyExc_TypeError, QObject::tr("invalid tab-position specified.","python error").toLocal8Bit().constData());
 				return nullptr;
 			}
 
@@ -181,6 +174,7 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 		const_cast<char*>("fillshade"),
 		const_cast<char*>("strokecolor"),
 		const_cast<char*>("strokeshade"),
+		const_cast<char*>("bgcolor"),
 		const_cast<char*>("baselineoffset"),
 		const_cast<char*>("shadowxoffset"),
 		const_cast<char*>("shadowyoffset"),
@@ -209,6 +203,7 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	PyESString font;
 	PyESString features;
 	PyESString fillColor;
+	PyESString bgColor;
 	PyESString fontFeatures;
 	PyESString strokeColor;
 	PyESString language;
@@ -221,27 +216,16 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	double strikethruOffset = dbl_min, strikethruWidth = dbl_min;
 	double tracking = dbl_min;
 	
-	if (!PyArg_ParseTupleAndKeywords(args, keywords, "es|esdesesdesddddddddddddeses", keywordargs,
+	if (!PyArg_ParseTupleAndKeywords(args, keywords, "es|esdesesdesdsdddddddddddeses", keywordargs,
 									"utf-8", name.ptr(), "utf-8", font.ptr(), &fontSize, "utf-8", features.ptr(),
-									"utf-8", fillColor.ptr(), &fillShade, "utf-8", strokeColor.ptr(), &strokeShade, &baselineOffset, &shadowXOffset,
+									"utf-8", fillColor.ptr(), &fillShade, "utf-8", strokeColor.ptr(), &strokeShade, bgColor.ptr(), &baselineOffset, &shadowXOffset,
 									&shadowYOffset, &outlineWidth, &underlineOffset, &underlineWidth, &strikethruOffset, &strikethruWidth,
 									&scaleH, &scaleV, &tracking, "utf-8", language.ptr(), "utf-8", fontFeatures.ptr()))
-	{
-		// Some old python versions leave bad pointers behind when an argument parsing error occurs
-		// so we can't free the memory safely in this case
-		name.resetDontFree();
-		font.resetDontFree();
-		features.resetDontFree();
-		fillColor.resetDontFree();
-		fontFeatures.resetDontFree();
-		strokeColor.resetDontFree();
-		language.resetDontFree();
 		return nullptr;
-	}
 	
 	if (name.isEmpty())
 	{
-		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty char style name.","python error").toUtf8().constData());
+		PyErr_SetString(PyExc_ValueError, QObject::tr("Cannot have an empty char style name.","python error").toLocal8Bit().constData());
 		return nullptr;
 	}
 
@@ -250,7 +234,7 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	{
 		if (!currentDoc->AllFonts->contains(realFont))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified font is not available.", "python error").toUtf8().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified font is not available.", "python error").toLocal8Bit().constData());
 			return nullptr;
 		}
 	}
@@ -258,11 +242,12 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	const ColorList& docColors = currentDoc->PageColors;
 	QString qFillColor(fillColor.c_str());
 	QString qStrokeColor(strokeColor.defaulted("Black"));
+	QString qBgColor(bgColor.c_str());
 	if (!qFillColor.isEmpty())
 	{
 		if ((qFillColor != CommonStrings::None) && (!docColors.contains(qFillColor)))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified fill color is not available in document.", "python error").toUtf8().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified fill color is not available in document.", "python error").toLocal8Bit().constData());
 			return nullptr;
 		}
 	}
@@ -270,7 +255,15 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 	{
 		if ((qStrokeColor != CommonStrings::None) && (!docColors.contains(qStrokeColor)))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified stroke color is not available in document.", "python error").toUtf8().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified stroke color is not available in document.", "python error").toLocal8Bit().constData());
+			return nullptr;
+		}
+	}
+	if (!qBgColor.isEmpty())
+	{
+		if ((qBgColor != CommonStrings::None) && (!docColors.contains(qBgColor)))
+		{
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified background color is not available in document.", "python error").toLocal8Bit().constData());
 			return nullptr;
 		}
 	}
@@ -295,6 +288,8 @@ PyObject *scribus_createcharstyle(PyObject* /* self */, PyObject* args, PyObject
 		tmpCharStyle.setFeatures(featuresList);
 	if (!qFillColor.isEmpty())
 		tmpCharStyle.setFillColor(qFillColor);
+	if (!qBgColor.isEmpty())
+		tmpCharStyle.setBackColor(qBgColor);
 	if (fillShade >= 0)
 		tmpCharStyle.setFillShade(fillShade * 100);
 	if (!qStrokeColor.isEmpty())
@@ -344,10 +339,7 @@ PyObject *scribus_createcustomlinestyle(PyObject * /* self */, PyObject* args)
 	PyObject *obj;
 
 	if (!PyArg_ParseTuple(args, "esO", "utf-8", name.ptr(), &obj))
-	{
-		name.resetDontFree();
 		return nullptr;
-	}
 
 	if (!PyList_Check(obj)) {
 		PyErr_SetString(PyExc_TypeError, "'style' must be list.");
@@ -416,7 +408,7 @@ PyObject *scribus_createcustomlinestyle(PyObject * /* self */, PyObject* args)
 
 		if (!docColors.contains(sl.Color))
 		{
-			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified color is not available in document.", "python error").toUtf8().constData());
+			PyErr_SetString(PyExc_ValueError, QObject::tr("Specified color is not available in document.", "python error").toLocal8Bit().constData());
 			return nullptr;
 		}
 		ml.push_back(sl);
@@ -484,7 +476,7 @@ PyObject *scribus_getlinestyles(PyObject* /* self */)
 	auto itEnd = lineStyles.constEnd();
 	for (auto it = lineStyles.constBegin(); it != itEnd; ++it)
 	{
-		QString lineStyleName = it.key();
+		const QString& lineStyleName = it.key();
 		if (PyList_Append(lineStyleList, PyUnicode_FromString(lineStyleName.toUtf8())))
 		{
 			// An exception will have already been set by PyList_Append apparently.
