@@ -187,6 +187,29 @@ If \"name\" is not given the currently selected item is used.\n\
 /*! Get columns */
 PyObject *scribus_getfirstlineoffset(PyObject * /*self*/, PyObject* args);
 
+/*! docstring */
+PyDoc_STRVAR(scribus_gettracking__doc__,
+	QT_TR_NOOP("getTracking([\"name\"]) -> integer\n\
+\n\
+Gets the tracking of text inside text frame \"name\".\n\
+If \"name\" is not given the currently selected item is used. \n\
+If there is some text selected only the selected text tracking is returned.\n\
+"));
+/*! Get tracking */
+PyObject *scribus_gettracking(PyObject * /*self*/, PyObject* args);
+
+
+/*! docstring */
+PyDoc_STRVAR(scribus_getwordtracking__doc__,
+QT_TR_NOOP("getWordTracking([\"name\"]) -> integer\n\
+\n\
+Gets the word tracking of text inside text frame \"name\".\n\
+If \"name\" is not given the currently selected item is used. \n\
+If there is some text selected only the selected text tracking is returned.\n\
+"));
+/*! Get word tracking */
+PyObject *scribus_getwordtracking(PyObject * /*self*/, PyObject* args);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_getlinespacing__doc__,
 QT_TR_NOOP("getLineSpacing([\"name\"]) -> float\n\
@@ -592,6 +615,31 @@ used.\n\
 /*! Set text shde */
 PyObject *scribus_settextshade(PyObject * /*self*/, PyObject* args);
 
+/*! docstring */
+PyDoc_STRVAR(scribus_settracking__doc__,
+QT_TR_NOOP("setTracking(kern, [\"name\"])\n\
+\n\
+Sets the tracking of the text the object \"name\" to \"kern\". If\n\
+there is some text selected only the selected text is changed. \"kern\" must\n\
+be an integer. If \"name\" is not given the currently selected item is\n\
+used.\n\
+"));
+
+/*! Set text tracking */
+PyObject *scribus_settracking(PyObject * /*self*/, PyObject* args);
+
+/*! docstring */
+PyDoc_STRVAR(scribus_setwordtracking__doc__,
+QT_TR_NOOP("setWordTracking(kern, [\"name\"])\n\
+\n\
+Sets the word tracking of the text the object \"name\" to \"kern\". If\n\
+there is some text selected only the selected text is changed. \"kern\" must\n\
+be an integer. If \"name\" is not given the currently selected item is\n\
+used.\n\
+"));
+/*! Set text word tracking */
+PyObject *scribus_setwordtracking(PyObject * /*self*/, PyObject* args);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_linktextframes__doc__,
 QT_TR_NOOP("linkTextFrames(\"fromname\", \"toname\")\n\
