@@ -42,7 +42,7 @@ struct Printer
 	PyObject *file;  // string - name of file to print into (eg. output.ps)
 	PyObject *cmd; // string - if "" use standard command else use this as command (eg. "kprinter", "xpp" ...)
 	PyObject *pages; // list of integers - pages to be printed
-	int copies; // numer of printed copies
+	int copies; // number of printed copies
 	PyObject *separation; // string - No; All; Cyan; Magenta; Yellow; Black
 	int color; // bool - do we print in color=1 or greyscale=0
 	int useICC; // bool - do we use ICC Profiles 0 = No 1 = Yes
@@ -68,12 +68,10 @@ static PyObject * Printer_new(PyTypeObject *type, PyObject * /*args*/, PyObject
 {
 // do not create new object if there is no opened document
 	if (!checkHaveDocument())
-	{
 		return nullptr;
-	}
 
 	Printer *self = (Printer *)type->tp_alloc(type, 0);
-	if (self != nullptr) 
+	if (self != nullptr)
 	{
 // set allPrinters attribute
 		self->allPrinters = PyList_New(0);
@@ -513,7 +511,7 @@ static PyObject *Printer_print(Printer *self)
 	if (!printDone)
 	{
 		QString error = printEngine->errorMessage();
-		PyErr_SetString(PyExc_SystemError, error.toUtf8().constData());
+		PyErr_SetString(PyExc_SystemError, error.toLocal8Bit().constData());
 	}
 
 	Py_RETURN_NONE;
@@ -561,7 +559,7 @@ PyTypeObject Printer_Type = {
 	nullptr, //     PyBufferProcs *tp_as_buffer
 
 	/* Flags to define presence of optional/expanded features */
-	Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,    // long tp_flags;
+	Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE,    // long tp_flags
 
 	printer__doc__,      // char *tp_doc; /* Documentation string */
 
