@@ -44,7 +44,7 @@ PythonConsole::PythonConsole( QWidget* parent)
 	action_Open->setShortcut(tr("Ctrl+O"));
 	action_Save->setShortcut(tr("Ctrl+S"));
 	action_Run->setShortcut(Qt::Key_F9);
-	actionRun_As_Console->setShortcut(Qt::CTRL + Qt::Key_F9);
+	actionRun_As_Console->setShortcut(Qt::CTRL | Qt::Key_F9);
 
 	commandEdit->setTabStopDistance(qRound(commandEdit->fontPointSize() * 4));
 
@@ -290,34 +290,30 @@ SyntaxHighlighter::SyntaxHighlighter(QTextEdit *textEdit) : QSyntaxHighlighter(t
 	numberFormat.setForeground(colors.numberColor);
 	operatorFormat.setForeground(colors.signColor);
 
-	foreach (const QString& kw, keywords)
+	for (const QString& kw : keywords)
 	{
-		rule.pattern = QRegExp("\\b" + kw + "\\b", Qt::CaseInsensitive);
+		rule.pattern = QRegularExpression("\\b" + kw + "\\b", QRegularExpression::CaseInsensitiveOption);
 		rule.format = keywordFormat;
 		highlightingRules.append(rule);
 	}
 
-	rule.pattern = QRegExp("#[^\n]*");
+	rule.pattern = QRegularExpression("#[^\n]*");
 	rule.format = singleLineCommentFormat;
 	highlightingRules.append(rule);
 
-	rule.pattern = QRegExp("\'.*\'");
-	rule.pattern.setMinimal(true);
+	rule.pattern = QRegularExpression("\'.*\'", QRegularExpression::InvertedGreedinessOption);
 	rule.format = quotationFormat;
 	highlightingRules.append(rule);
 
-	rule.pattern = QRegExp("\".*\"");
-	rule.pattern.setMinimal(true);
+	rule.pattern = QRegularExpression("\".*\"", QRegularExpression::InvertedGreedinessOption);
 	rule.format = quotationFormat;
 	highlightingRules.append(rule);
 
-	rule.pattern = QRegExp("\\b\\d+\\b");
-	rule.pattern.setMinimal(true);
+	rule.pattern = QRegularExpression("\\b\\d+\\b", QRegularExpression::InvertedGreedinessOption);
 	rule.format = numberFormat;
 	highlightingRules.append(rule);
 
-	rule.pattern = QRegExp("[\\\\|\\<|\\>|\\=|\\!|\\+|\\-|\\*|\\/|\\%]+");
-	rule.pattern.setMinimal(true);
+	rule.pattern = QRegularExpression("[\\\\|\\<|\\>|\\=|\\!|\\+|\\-|\\*|\\/|\\%]+", QRegularExpression::InvertedGreedinessOption);
 	rule.format = operatorFormat;
 	highlightingRules.append(rule);
 }
@@ -327,15 +323,17 @@ void SyntaxHighlighter::highlightBlock(const QString &text)
 	// Apply default text color
 	setFormat(0, text.length(), colors.textColor);
 
-	foreach (HighlightingRule rule, highlightingRules)
+	for (const HighlightingRule& rule : highlightingRules)
 	{
-		QRegExp expression(rule.pattern);
-		int index = expression.indexIn(text);
+		QRegularExpression expression(rule.pattern);
+		QRegularExpressionMatch match = expression.match(text);
+		int n = 0;
+		int index = match.capturedStart(n);
 		while (index >= 0)
 		{
-			int length = expression.matchedLength();
+			int length = match.capturedLength(n);
 			setFormat(index, length, rule.format);
-			index = expression.indexIn(text, index + length);
+			index = match.capturedStart(++n);
 		}
 	}
 	setCurrentBlockState(0);
@@ -369,23 +367,23 @@ SyntaxColors::SyntaxColors()
 	PrefsContext* prefs = PrefsManager::instance().prefsFile->getPluginContext("scriptplugin");
 	if (prefs)
 	{
-		errorColor.setNamedColor(prefs->get("syntaxerror", "#aa0000"));
-		commentColor.setNamedColor(prefs->get("syntaxcomment", "#A0A0A0"));
-		keywordColor.setNamedColor(prefs->get("syntaxkeyword", "#00007f"));
-		signColor.setNamedColor(prefs->get("syntaxsign", "#aa00ff"));
-		numberColor.setNamedColor(prefs->get("syntaxnumber", "#ffaa00"));
-		stringColor.setNamedColor(prefs->get("syntaxstring", "#005500"));
-		textColor.setNamedColor(prefs->get("syntaxtext", "#000000"));
+		errorColor = QColor::fromString(prefs->get("syntaxerror", "#aa0000"));
+		commentColor = QColor::fromString(prefs->get("syntaxcomment", "#A0A0A0"));
+		keywordColor = QColor::fromString(prefs->get("syntaxkeyword", "#00007f"));
+		signColor = QColor::fromString(prefs->get("syntaxsign", "#aa00ff"));
+		numberColor = QColor::fromString(prefs->get("syntaxnumber", "#ffaa00"));
+		stringColor = QColor::fromString(prefs->get("syntaxstring", "#005500"));
+		textColor = QColor::fromString(prefs->get("syntaxtext", "#000000"));
 	}
 	else
 	{
-		errorColor.setNamedColor("#aa0000");
-		commentColor.setNamedColor("#A0A0A0");
-		keywordColor.setNamedColor("#00007f");
-		signColor.setNamedColor("#aa00ff");
-		numberColor.setNamedColor("#ffaa00");
-		stringColor.setNamedColor("#005500");
-		textColor.setNamedColor("#000000");
+		errorColor = QColor::fromString("#aa0000");
+		commentColor = QColor::fromString("#A0A0A0");
+		keywordColor = QColor::fromString("#00007f");
+		signColor = QColor::fromString("#aa00ff");
+		numberColor = QColor::fromString("#ffaa00");
+		stringColor = QColor::fromString("#005500");
+		textColor = QColor::fromString("#000000");
 	}
 }
 
@@ -403,7 +401,7 @@ void SyntaxColors::saveToPrefs()
 	prefs->set("syntaxtext", qcolor2named(textColor));
 }
 
-QString SyntaxColors::qcolor2named(const QColor& color)
+QString SyntaxColors::qcolor2named(const QColor& color) const
 {
 	int r;
 	int g;
