@@ -11,6 +11,7 @@ for which a new license (GPL+exception) is in place.
 #include <memory>
 #include <QColorDialog>
 #include <QFileDialog>
+#include <QListWidgetItem>
 #include <QPalette>
 
 #include "prefs_scripter.h"
@@ -36,6 +37,7 @@ Prefs_Scripter::Prefs_Scripter(QWidget* parent)
 	// The startup script box should be disabled  if ext scripts are off
 	startupScriptEdit->setEnabled(extensionScriptsChk->isChecked());
 	startupScriptEdit->setText(scripterCore->startupScript());
+	scriptPathsListWidget->addItems(scripterCore->scriptPaths.get());
 	// signals and slots connections
 	connect(extensionScriptsChk, SIGNAL(toggled(bool)), startupScriptEdit, SLOT(setEnabled(bool)));
 	// colors
@@ -48,6 +50,15 @@ Prefs_Scripter::Prefs_Scripter(QWidget* parent)
 	connect(numberButton, SIGNAL(clicked()), this, SLOT(setColor()));
 	connect(extensionScriptsChk, SIGNAL(toggled(bool)), startupScriptChangeButton, SLOT(setEnabled(bool)));
 	connect(startupScriptChangeButton, SIGNAL(clicked()), this, SLOT(changeStartupScript()));
+
+	changePathButton->setEnabled(false);
+	removePathButton->setEnabled(false);
+	connect(scriptPathsListWidget, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPath(QListWidgetItem*)));
+	connect(addPathButton, SIGNAL(clicked()), this, SLOT(addPath()));
+	connect(changePathButton, SIGNAL(clicked()), this, SLOT(changePath()));
+	connect(removePathButton, SIGNAL(clicked()), this, SLOT(removePath()));
+
+
 }
 
 Prefs_Scripter::~Prefs_Scripter() = default;
@@ -81,6 +92,17 @@ void Prefs_Scripter::apply()
 		prefs->set("syntaxstring", stringColor.name());
 		prefs->set("syntaxtext", textColor.name());
 
+		if (pathsChanged)
+		{
+			scripterCore->scriptPaths.clear();
+			for (int i = 0; i < scriptPathsListWidget->count(); i++)
+				scripterCore->scriptPaths.append(scriptPathsListWidget->item(i)->text());
+
+			scripterCore->scriptPaths.buildMenu();
+		}
+
+		scripterCore->scriptPaths.saveToPrefs();
+
 		emit prefsChanged();
 	}
 }
@@ -123,7 +145,7 @@ void Prefs_Scripter::setColor()
 
 void Prefs_Scripter::setupSyntaxColors()
 {
-	std::unique_ptr<SyntaxColors> syntax(new SyntaxColors());
+	auto syntax = std::make_unique<SyntaxColors>();
 
 	textColor = syntax->textColor;
 	commentColor = syntax->commentColor;
@@ -153,8 +175,7 @@ void Prefs_Scripter::setupSyntaxColors()
 void Prefs_Scripter::changeStartupScript()
 {
 	QString currentScript = startupScriptEdit->text();
-	QFileInfo fi(startupScriptEdit->text());
-	if (!fi.exists())
+	if (!QFileInfo::exists(startupScriptEdit->text()))
 		currentScript = QDir::homePath();
 
 	QString s = QFileDialog::getOpenFileName(this, tr("Locate Startup Script"), currentScript, "Python Scripts (*.py *.PY)");
@@ -162,3 +183,69 @@ void Prefs_Scripter::changeStartupScript()
 		startupScriptEdit->setText(s);
 }
 
+void Prefs_Scripter::selectPath(QListWidgetItem *c)
+{
+	changePathButton->setEnabled(true);
+	removePathButton->setEnabled(true);
+}
+
+void Prefs_Scripter::addPath()
+{
+	QString s = QFileDialog::getExistingDirectory(this, tr("Choose a Directory"), latestPath);
+	if (s.isEmpty())
+		return;
+
+	if (s.endsWith("/"))
+		s.chop(1);
+
+	s = QDir::toNativeSeparators(s);
+	if (scriptPathsListWidget->findItems(s, Qt::MatchExactly).count() != 0)
+		return;
+
+	scriptPathsListWidget->addItem(s);
+
+	scriptPathsListWidget->setCurrentRow(scriptPathsListWidget->count() - 1);
+	changePathButton->setEnabled(true);
+	removePathButton->setEnabled(true);
+	latestPath = s;
+	pathsChanged = true;
+}
+
+void Prefs_Scripter::changePath()
+{
+	QString s = QFileDialog::getExistingDirectory(this, tr("Choose a Directory"), latestPath);
+	if (s.isEmpty())
+		return;
+
+	if (s.endsWith("/"))
+		s.chop(1);
+
+	s = QDir::toNativeSeparators(s);
+	// if the new path is already in the list, just remove the old path
+	if (scriptPathsListWidget->findItems(s, Qt::MatchExactly).count() != 0)
+	{
+		removePath();
+		return;
+	}
+
+	scriptPathsListWidget->currentItem()->setText(s);
+
+	latestPath = s;
+	pathsChanged = true;
+}
+
+void Prefs_Scripter::removePath()
+{
+	const int i = scriptPathsListWidget->currentRow();
+	if (scriptPathsListWidget->count() == 1)
+		scriptPathsListWidget->clear();
+	else
+		delete scriptPathsListWidget->takeItem(i);
+
+	if (scriptPathsListWidget->count() == 0)
+	{
+		changePathButton->setEnabled(false);
+		removePathButton->setEnabled(false);
+	}
+	pathsChanged = true;
+}
