@@ -45,8 +45,6 @@ for which a new license (GPL+exception) is in place.
 ScripterCore::ScripterCore(QWidget* parent)
 {
 	m_pyConsole = new PythonConsole(parent);
-	m_scripterActions.clear();
-	m_recentScriptActions.clear();
 	returnString = "init";
 
 	m_scripterActions.insert("scripterExecuteScript", new ScrAction(QObject::tr("&Execute Script..."), QKeySequence(), this));
@@ -72,6 +70,8 @@ ScripterCore::ScripterCore(QWidget* parent)
 
 	QObject::connect(ScQApp, SIGNAL(appStarted()) , this, SLOT(runStartupScript()) );
 	QObject::connect(ScQApp, SIGNAL(appStarted()) , this, SLOT(slotRunPythonScript()) );
+
+	QObject::connect(&scriptPaths, &ScriptPaths::runScriptFile, this, &ScripterCore::runScriptFile);
 }
 
 ScripterCore::~ScripterCore()
@@ -84,6 +84,7 @@ void ScripterCore::addToMainWindowMenu(ScribusMainWindow *mw)
 {
 	m_menuMgr = mw->scrMenuMgr;
 	m_menuMgr->createMenu("Scripter", QObject::tr("&Script"));
+	scriptPaths.attachToMenu(m_menuMgr);
 	m_menuMgr->createMenu("ScribusScripts", QObject::tr("&Scribus Scripts"), "Scripter");
 	m_menuMgr->addMenuItemString("ScribusScripts", "Scripter");
 	m_menuMgr->addMenuItemString("scripterExecuteScript", "Scripter");
@@ -100,6 +101,7 @@ void ScripterCore::addToMainWindowMenu(ScribusMainWindow *mw)
 	m_menuMgr->addMenuItemStringsToMenuBar("Scripter", m_scripterActions);
 	m_recentScripts = m_savedRecentScripts;
 	rebuildRecentScriptsMenu();
+	scriptPaths.buildMenu();
 }
 
 void ScripterCore::enableMainWindowMenu()
@@ -145,7 +147,7 @@ void ScripterCore::rebuildRecentScriptsMenu()
 	int max = qMin(PrefsManager::instance().appPrefs.uiPrefs.recentDocCount, m_recentScripts.count());
 	for (int m = 0; m < max; ++m)
 	{
-		QString strippedName = m_recentScripts[m];
+		QString strippedName(m_recentScripts[m]);
 		strippedName.remove(QDir::separator());
 		m_recentScriptActions.insert(strippedName, new ScrAction(ScrAction::RecentScript, m_recentScripts[m], QKeySequence(), this, m_recentScripts[m]));
 		connect(m_recentScriptActions[strippedName], SIGNAL(triggeredData(QString)), this, SLOT(RecentScript(QString)));
@@ -179,13 +181,21 @@ void ScripterCore::finishScriptRun()
 	mainWin->HaveNewDoc();
 }
 
+/**
+ * setup the environment for running the script, run the script and clean up the environment
+ */
+void ScripterCore::runScriptFile(const QString& path)
+{
+	slotRunScriptFile(path);
+	finishScriptRun();
+}
+
 void ScripterCore::runScriptDialog()
 {
-	QString fileName;
 	RunScriptDialog dia( ScCore->primaryMainWindow(), m_enableExtPython );
 	if (dia.exec())
 	{
-		fileName = dia.selectedFile();
+		QString fileName(dia.selectedFile());
 		slotRunScriptFile(fileName, dia.extensionRequested());
 
 		if (m_recentScripts.indexOf(fileName) == -1)
@@ -212,16 +222,15 @@ void ScripterCore::StdScript(const QString& baseFilename)
 	finishScriptRun();
 }
 
-void ScripterCore::RecentScript(const QString& fn)
+void ScripterCore::RecentScript(const QString& fileName)
 {
-	QFileInfo fd(fn);
-	if (!fd.exists())
+	if (QFileInfo::exists(fileName))
 	{
-		m_recentScripts.removeAll(fn);
+		m_recentScripts.removeAll(fileName);
 		rebuildRecentScriptsMenu();
 		return;
 	}
-	slotRunScriptFile(fn);
+	slotRunScriptFile(fileName);
 	finishScriptRun();
 }
 
@@ -353,7 +362,7 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 				ScMessageBox::warning(ScCore->primaryMainWindow(),
 									tr("Script error"),
 									"<qt><p>"
-									+ tr("If you are running an official script report it at <a href=\"http://bugs.scribus.net\">bugs.scribus.net</a> please.")
+									+ tr("If you are running an official script report it at <a href=\"https://bugs.scribus.net\">bugs.scribus.net</a> please.")
 									+ "</p><pre>" + errorMsg.toHtmlEscaped() + "</pre><p>"
 									+ tr("This message is in your clipboard too. Use Ctrl+V to paste it into bug tracker.")
 									+ "</p></qt>");
@@ -379,11 +388,10 @@ void ScripterCore::slotRunScriptFile(const QString& fileName, QStringList argume
 // needed for running script from CLI
 void ScripterCore::slotRunPythonScript()
 {
-	if (!ScQApp->pythonScript.isNull())
-	{
-		slotRunScriptFile(ScQApp->pythonScript, ScQApp->pythonScriptArgs, true);
-		finishScriptRun();
-	}
+	if (ScQApp->pythonScript.isNull())
+		return;
+	slotRunScriptFile(ScQApp->pythonScript, ScQApp->pythonScriptArgs, true);
+	finishScriptRun();
 }
 
 void ScripterCore::slotRunScript(const QString& Script)
@@ -398,8 +406,7 @@ void ScripterCore::slotRunScript(const QString& Script)
 	ScCore->primaryMainWindow()->pagePalette->setView(nullptr);
 	ScCore->primaryMainWindow()->setScriptRunning(true);
 	inValue = Script;
-	QString cm;
-	cm = "# -*- coding: utf8 -*- \n";
+	QString cm("# -*- coding: utf8 -*- \n");
 	if (PyThreadState_Get() != nullptr)
 	{
 		//initscribus(ScCore->primaryMainWindow());
@@ -534,12 +541,13 @@ void ScripterCore::savePlugPrefs()
 
 void ScripterCore::aboutScript()
 {
-	QString fname = ScCore->primaryMainWindow()->CFileDialog(".", tr("Examine Script"), tr("Python Scripts (*.py *.PY);;All Files (*)"), "", fdNone);
-	if (fname.isNull())
+	QPair<QString, uint> fileNameVersion;
+	fileNameVersion = ScCore->primaryMainWindow()->CFileDialog(".", tr("Examine Script"), tr("Python Scripts (*.py *.PY);;All Files (*)"), "", fdNone);
+	if (fileNameVersion.first.isNull())
 		return;
 	QString html("<html><body>");
-	QFileInfo fi(fname);
-	QFile input(fname);
+	QFileInfo fi(fileNameVersion.first);
+	QFile input(fileNameVersion.first);
 	if (!input.open(QIODevice::ReadOnly))
 		return;
 	QTextStream intputstream(&input);
