@@ -21,17 +21,6 @@ for which a new license (GPL+exception) is in place.
  *                                                                         *
  ***************************************************************************/
 
-#include <cstdlib>
-#include <iostream>
-
-#include <QApplication>
-#include <QByteArray>
-#include <QMessageBox>
-#include <QPixmap>
-#include <QRegExp>
-#include <QString>
-#include <QWidget>
-
 // include cmdvar.h first, as it pulls in <Python.h>
 #include "cmdannotations.h"
 #include "cmdvar.h"
@@ -51,7 +40,6 @@ for which a new license (GPL+exception) is in place.
 #include "cmdutil.h"
 #include "cmdstyle.h"
 #include "guiapp.h"
-#include "iconmanager.h"
 #include "objimageexport.h"
 #include "objpdffile.h"
 #include "objprinter.h"
@@ -71,22 +59,34 @@ for which a new license (GPL+exception) is in place.
 
 #include "api/api_application.h"
 
+#include <QApplication>
+#include <QMessageBox>
+#include <QTextCodec>
+#include <QPixmap>
+#include <QWidget>
+#include <QString>
+//Added by qt3to4:
+#include <QByteArray>
+#include <cstdlib>
+#include <iostream>
+
+
 #ifdef HAVE_SCRIPTER2
 extern void scripter2_init();
 #endif
 
 // Exceptions; visible from cmdvar.h, set up in initscribus()
-PyObject* ScribusException = nullptr;
-PyObject* NoDocOpenError = nullptr;
-PyObject* WrongFrameTypeError = nullptr;
-PyObject* NoValidObjectError = nullptr;
-PyObject* NotFoundError = nullptr;
-PyObject* NameExistsError = nullptr;
+PyObject* ScribusException;
+PyObject* NoDocOpenError;
+PyObject* WrongFrameTypeError;
+PyObject* NoValidObjectError;
+PyObject* NotFoundError;
+PyObject* NameExistsError;
 
 // Other extern variables defined in cmdvar.h
-PyObject* wrappedMainWindow = nullptr;
-PyObject* wrappedQApp = nullptr;
-ScripterCore* scripterCore = nullptr;
+PyObject* wrappedMainWindow;
+PyObject* wrappedQApp;
+ScripterCore* scripterCore;
 
 
 int scriptplugin_getPluginAPIVersion()
@@ -369,6 +369,9 @@ PyMethodDef scribus_methods[] = {
 	{ "getFontSize", scribus_getfontsize, METH_VARARGS, tr(scribus_getfontsize__doc__)},
 	{ "getFrameText", scribus_getframetext, METH_VARARGS, tr(scribus_getframetext__doc__)},
 	{ "getFrameSelectedTextRange", scribus_getframeselectedtextrange, METH_VARARGS, tr(scribus_getframeselectedtextrange__doc__)},
+	{ "getGradientStop", scribus_getgradstop, METH_VARARGS, tr(scribus_getgradstop__doc__)},
+	{ "getGradientStopsCount", scribus_getgradstopscount, METH_VARARGS, tr(scribus_getgradstopscount__doc__)},
+	{ "getGradientVector", scribus_getgradvector, METH_VARARGS, tr(scribus_getgradvector__doc__)},
 	{ "getGroupItems", (PyCFunction) scribus_getGroupItems, METH_VARARGS|METH_KEYWORDS, tr(scribus_getGroupItems__doc__)},
 	{ "getGuiLanguage", (PyCFunction) scribus_getlanguage, METH_NOARGS, tr(scribus_getlanguage__doc__)},
 	{ "getHGuides", (PyCFunction) scribus_getHguides, METH_NOARGS, tr(scribus_getHguides__doc__)},
@@ -395,7 +398,6 @@ PyMethodDef scribus_methods[] = {
 	{ "getLineWidth", scribus_getlinewidth, METH_VARARGS, tr(scribus_getlinewidth__doc__)},
 	{ "getMargins", scribus_getmargins, METH_NOARGS, tr(scribus_getmargins__doc__) },
 	{ "getMasterPage", scribus_getmasterpage, METH_VARARGS, tr(scribus_getmasterpage__doc__)},
-	{ "getMinWordTracking", scribus_getminwordtracking, METH_VARARGS, tr(scribus_getminwordtracking__doc__) },
 	{ "getNextLinkedFrame", scribus_getnextlinkedframe, METH_VARARGS, tr(scribus_getnextlinkedframe__doc__)},
 	{ "getObjectAttributes", scribus_getobjectattributes, METH_VARARGS, tr(scribus_getobjectattributes__doc__)},
 	{ "getObjectType", scribus_getobjecttype, METH_VARARGS, tr(scribus_getobjecttype__doc__)},
@@ -430,10 +432,10 @@ PyMethodDef scribus_methods[] = {
 	{ "getTextLines", scribus_gettextlines, METH_VARARGS, tr(scribus_gettextlines__doc__)},
 	{ "getTextShade", scribus_gettextshade, METH_VARARGS, tr(scribus_gettextshade__doc__)},
 	{ "getTextVerticalAlignment", scribus_gettextverticalalignment, METH_VARARGS, tr(scribus_gettextverticalalignment__doc__)},
-	{ "getTracking", scribus_gettracking, METH_VARARGS, tr(scribus_gettracking__doc__) },
+	{ "getTracking", scribus_gettracking, METH_VARARGS, tr(scribus_gettracking__doc__)},
 	{ "getUnit", (PyCFunction) scribus_getunit, METH_NOARGS, tr(scribus_getunit__doc__)},
 	{ "getVisualBoundingBox", scribus_getvisualboundingbox, METH_VARARGS, tr(scribus_getvisualboundingbox__doc__) },
-	{ "getWordTracking", scribus_getwordtracking, METH_VARARGS, tr(scribus_getwordtracking__doc__) },
+	{ "getWordTracking", scribus_getwordtracking, METH_VARARGS, tr(scribus_getwordtracking__doc__)},
 	{ "pointsToDocUnit", scribus_pointstodocunit, METH_VARARGS, tr(scribus_pointstodocunit__doc__)},
 	{ "docUnitToPoints", scribus_docunittopoints, METH_VARARGS, tr(scribus_docunittopoints__doc__)},
 	{ "stringValueToPoints", scribus_stringvaluetopoints, METH_VARARGS, tr(scribus_stringvaluetopoints__doc__)},
@@ -548,6 +550,7 @@ PyMethodDef scribus_methods[] = {
 	{ "setFontSize", scribus_setfontsize, METH_VARARGS, tr(scribus_setfontsize__doc__)},
 	{ "setGradientFill", scribus_setgradfill, METH_VARARGS, tr(scribus_setgradfill__doc__)},
 	{ "setGradientStop", scribus_setgradstop, METH_VARARGS, tr(scribus_setgradstop__doc__)},
+	{ "setGradientVector", scribus_setgradvector, METH_VARARGS, tr(scribus_setgradvector__doc__) },
 	{ "setHGuides", scribus_setHguides, METH_VARARGS, tr(scribus_setHguides__doc__)},
 	{ "setImageBrightness", scribus_setimagebrightness, METH_VARARGS, tr(scribus_setimagebrightness__doc__)},
 	{ "setImageGrayscale", scribus_setimagegrayscale, METH_VARARGS, tr(scribus_setimagegrayscale__doc__)},
@@ -574,7 +577,6 @@ PyMethodDef scribus_methods[] = {
 	{ "setLineTransparency", scribus_setlinetrans, METH_VARARGS, tr(scribus_setlinetrans__doc__)},
 	{ "setLineWidth", scribus_setlinewidth, METH_VARARGS, tr(scribus_setlinewidth__doc__)},
 	{ "setMargins", scribus_setmargins, METH_VARARGS, tr(scribus_setmargins__doc__)},
-	{ "setMinWordTracking", scribus_setminwordtracking, METH_VARARGS, tr(scribus_setminwordtracking__doc__) },
 	{ "setMultiLine", scribus_setmultiline, METH_VARARGS, tr(scribus_setmultiline__doc__)},
 	{ "setNewName", scribus_setitemname, METH_VARARGS, tr(scribus_setitemname__doc__)}, // Deprecated, was in fact never documented
 	{ "setObjectAttributes", scribus_setobjectattributes, METH_VARARGS, tr(scribus_setobjectattributes__doc__)},
@@ -604,10 +606,10 @@ PyMethodDef scribus_methods[] = {
 	{ "setTextShade", scribus_settextshade, METH_VARARGS, tr(scribus_settextshade__doc__)},
 	{ "setTextStroke", scribus_settextstroke, METH_VARARGS, tr(scribus_settextstroke__doc__)},
 	{ "setTextVerticalAlignment", scribus_settextverticalalignment, METH_VARARGS, tr(scribus_settextverticalalignment__doc__)},
-	{ "setTracking", scribus_settracking, METH_VARARGS, tr(scribus_settracking__doc__) },
+	{ "setTracking", scribus_settracking, METH_VARARGS, tr(scribus_settracking__doc__)},
 	{ "setUnit", scribus_setunit, METH_VARARGS, tr(scribus_setunit__doc__)},
 	{ "setVGuides", scribus_setVguides, METH_VARARGS, tr(scribus_setVguides__doc__)},
-	{ "setWordTracking", scribus_setwordtracking, METH_VARARGS, tr(scribus_setwordtracking__doc__) },
+	{ "setWordTracking", scribus_setwordtracking, METH_VARARGS, tr(scribus_setwordtracking__doc__)},
 	{ "sizeObject", scribus_sizeobject, METH_VARARGS, tr(scribus_sizeobject__doc__)},
 	{ "statusMessage", scribus_statusmessage, METH_VARARGS, tr(scribus_statusmessage__doc__)},
 	{ "textFlowMode", scribus_settextflowmode, METH_VARARGS, tr(scribus_textflowmode__doc__)}, // Deprecated
@@ -935,16 +937,15 @@ PyObject* PyInit_scribus(void)
 	PyDict_SetItemString(d, "TAB_COMMA", Py_BuildValue("i", 3));
 	PyDict_SetItemString(d, "TAB_CENTER", Py_BuildValue("i", 4));
 	// Basepoint / AnchorPoint
-	PyDict_SetItemString(d, "BASEPOINT_TOPLEFT", Py_BuildValue("i", 1));
-	PyDict_SetItemString(d, "BASEPOINT_TOP", Py_BuildValue("i", 2));
-	PyDict_SetItemString(d, "BASEPOINT_TOPRIGHT", Py_BuildValue("i", 3));
-	PyDict_SetItemString(d, "BASEPOINT_LEFT", Py_BuildValue("i", 4));
-	PyDict_SetItemString(d, "BASEPOINT_CENTER", Py_BuildValue("i", 5));
-	PyDict_SetItemString(d, "BASEPOINT_RIGHT", Py_BuildValue("i", 6));
-	PyDict_SetItemString(d, "BASEPOINT_BOTTOMLEFT", Py_BuildValue("i", 7));
-	PyDict_SetItemString(d, "BASEPOINT_BOTTOM", Py_BuildValue("i", 8));
-	PyDict_SetItemString(d, "BASEPOINT_BOTTOMRIGHT", Py_BuildValue("i", 9));
-
+	PyDict_SetItemString(d, "BASEPOINT_TOPLEFT", Py_BuildValue("i", (int) AnchorPoint::TopLeft));
+	PyDict_SetItemString(d, "BASEPOINT_TOP", Py_BuildValue("i", (int) AnchorPoint::Top));
+	PyDict_SetItemString(d, "BASEPOINT_TOPRIGHT", Py_BuildValue("i", (int) AnchorPoint::TopRight));
+	PyDict_SetItemString(d, "BASEPOINT_LEFT", Py_BuildValue("i", (int) AnchorPoint::Left));
+	PyDict_SetItemString(d, "BASEPOINT_CENTER", Py_BuildValue("i", (int) AnchorPoint::Center));
+	PyDict_SetItemString(d, "BASEPOINT_RIGHT", Py_BuildValue("i", (int) AnchorPoint::Right));
+	PyDict_SetItemString(d, "BASEPOINT_BOTTOMLEFT", Py_BuildValue("i", (int) AnchorPoint::BottomLeft));
+	PyDict_SetItemString(d, "BASEPOINT_BOTTOM", Py_BuildValue("i", (int) AnchorPoint::Bottom));
+	PyDict_SetItemString(d, "BASEPOINT_BOTTOMRIGHT", Py_BuildValue("i", (int) AnchorPoint::BottomRight));
 
 	// Measurement units understood by Scribus's units.cpp functions are exported as constant conversion
 	// factors to be used from Python.
@@ -975,7 +976,6 @@ PyObject* PyInit_scribus(void)
 	}
 
 	// Export the Scribus version into the module namespace so scripts know what they're running in
-	PyDict_SetItemString(d, "scribus_version", PyUnicode_FromString(ScribusAPI::getVersion().toLatin1().constData()));
 	PyDict_SetItemString(d, "SCRIBUS_VERSION", PyUnicode_FromString(ScribusAPI::getVersion().toLatin1().constData()));
 	// Now build a version tuple like that provided by Python in sys.version_info
 	// The tuple is of the form (major, minor, patchlevel, extraversion, reserved)
@@ -986,10 +986,7 @@ PyObject* PyInit_scribus(void)
 
 	PyObject* versionTuple = Py_BuildValue("(iiisi)", majorVersion, minorVersion, patchVersion, (const char*)extraVersion.toUtf8(), 0);
 	if (versionTuple != nullptr)
-	{
-		PyDict_SetItemString(d, "scribus_version_info", versionTuple);
 		PyDict_SetItemString(d, "SCRIBUS_VERSION_INFO", versionTuple);
-	}
 	else
 		qDebug("Failed to build version tuple for version string '%s' in scripter", VERSION);
 
