@@ -21,6 +21,7 @@ for which a new license (GPL+exception) is in place.
  *                                                                         *
  ***************************************************************************/
 #include "iconmanager.h"
+#include "manager/dock_manager.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
 #include "scmimedata.h"
@@ -31,6 +32,7 @@ for which a new license (GPL+exception) is in place.
 #include "scribusXml.h"
 #include "selection.h"
 #include "shapepalette.h"
+#include "third_party/Qt-Advanced-Docking-System/src/DockAreaWidget.h"
 #include "ui/scmessagebox.h"
 #include "util.h"
 #include "util_math.h"
@@ -66,7 +68,7 @@ ShapeView::ShapeView(QWidget* parent) : QListWidget(parent)
 	setItemDelegate(delegate);
 	setIconSize(QSize(48, 48));
 
-	connect(this, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(HandleContextMenu(QPoint)));
+	connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(HandleContextMenu(QPoint)));
 }
 
 void ShapeView::HandleContextMenu(QPoint)
@@ -278,7 +280,7 @@ void ShapeView::updateShapeList()
 	}
 }
 
-ShapePalette::ShapePalette( QWidget* parent) : ScDockPalette(parent, "Shap", Qt::WindowFlags())
+ShapePalette::ShapePalette(QWidget *parent) : DockPanelBase("Shap", "panel-custom-shapes", parent)
 {
 	setMinimumSize( QSize( 220, 240 ) );
 	setObjectName(QString::fromLocal8Bit("Shap"));
@@ -361,12 +363,11 @@ void ShapePalette::writeToPrefs()
 void ShapePalette::readFromPrefs()
 {
 	QString prFile = QDir::toNativeSeparators(PrefsManager::instance().preferencesLocation()+"/scribusshapes.xml");
-	QFileInfo fi(prFile);
-	if (fi.exists())
+	if (QFileInfo::exists(prFile))
 	{
-		QByteArray docBytes("");
+		QByteArray docBytes;
 		loadRawText(prFile, docBytes);
-		QString docText("");
+		QString docText;
 		docText = QString::fromUtf8(docBytes);
 		QDomDocument docu("scridoc");
 		docu.setContent(docText);
@@ -450,12 +451,12 @@ void ShapePalette::Import()
 	ds >> version >> count;
 	while (!ds.atEnd())
 	{
-		QString  string = "";
-		quint32  length, dummy, shpLen, paDataLen;
+		QString string;
+		quint32 length, dummy, shpLen, paDataLen;
 		ds >> length;
 		for (uint i = 0; i < length; ++i)
 		{
-			quint16  ch;
+			quint16 ch;
 			ds >> ch;
 			if (ch > 0)
 				string += char(ch);
@@ -560,7 +561,7 @@ void ShapePalette::Import()
 
 void ShapePalette::setMainWindow(ScribusMainWindow *mw)
 {
-	m_scMW = mw;
+	m_scMW = mw;	
 	for (int a = 0; a < Frame3->count(); a++)
 	{
 		ShapeViewWidget = (ShapeView*)Frame3->widget(a);
@@ -593,7 +594,7 @@ void ShapePalette::changeEvent(QEvent *e)
 		languageChange();
 	}
 	else
-		ScDockPalette::changeEvent(e);
+		DockPanelBase::changeEvent(e);
 }
 
 void ShapePalette::iconSetChange()
