@@ -23,17 +23,17 @@ for which a new license (GPL+exception) is in place.
 *   Free Software Foundation, Inc.,                                        *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.              *
 ****************************************************************************/
+#include <QMessageBox>
+#include <QPainterPathStroker>
 
+#include "appmodes.h"
 #include "pathcut.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
-#include "appmodes.h"
 #include "selection.h"
 #include "ui/scmessagebox.h"
 #include "util.h"
-#include "iconmanager.h"
-#include <QPainterPathStroker>
-#include <QMessageBox>
+
 
 int pathcut_getPluginAPIVersion()
 {
@@ -149,7 +149,7 @@ bool PathCutPlugin::run(ScribusDoc* doc, const QString&)
 		QPainterPath objekt = mm.map(Item2->PoLine.toQPainterPath(true));
 		if ((objekt.contains(QPointF(start.x(), start.y()))) || (objekt.contains(QPointF(end.x(), end.y()))))
 		{
-			ScMessageBox::information(doc->scMW(), tr("Error"), tr("The cutting line must cross the polygon and\nboth end points must lie outside of the polygon"));
+			ScMessageBox::information(currDoc->scMW(), tr("Error"), tr("The cutting line must cross the polygon and\nboth end points must lie outside of the polygon"));
 			return true;
 		}
 		QPainterPath result = objekt.subtracted(cutter);
