@@ -20,6 +20,7 @@ for which a new license (GPL+exception) is in place.
 #include <QHash>
 
 #include "documentinformation.h"
+#include "opticalmarginlookup.h"
 #include "pagestructs.h"
 #include "pdfoptions.h"
 #include "scfonts.h"
@@ -58,7 +59,7 @@ struct CheckerPrefs
 	bool checkEmptyTextFrames;
 };
 
-typedef QMap<QString, CheckerPrefs> CheckerPrefsList;
+using CheckerPrefsList = QMap<QString, CheckerPrefs>;
 
 struct VerifierPrefs
 {
@@ -80,6 +81,7 @@ struct TypoPrefs
 	int valueUnderlineWidth; //! Underline width
 	int valueStrikeThruPos; //! Strike-through displacement
 	int valueStrikeThruWidth; //! Strike-through line width
+	OpticalMarginSets opticalMarginSets; //! OpticalMargin Group List
 
 	inline bool operator==(const TypoPrefs &other) const
 	{
@@ -122,6 +124,8 @@ struct UIPrefs
 	QString language; //! Language of the user interface
 	QString userPreferredLocale; //! System or interface language number formats
 	bool useSmallWidgets {false}; //! Use small widgets in the palettes
+	bool showLabels {true}; //! Hide UI additional labels (Professional Mode)
+	bool showLabelsOfInactiveTabs {true}; //! Hide text label of inactive tabs of Advanced Docking System
 	bool useTabs {false}; //! Use a tabbed MainWidget a la FireFox
 	bool showStartupDialog {true}; //! Whether to show the startup dialog or not
 	bool showSplashOnStartup {true}; //! Whether to show the splashscreen or not
@@ -130,7 +134,7 @@ struct UIPrefs
 	QString iconSet; //! Icon set name
 	WindowPrefs mainWinSettings;
 	QByteArray mainWinState;
-	QList<tabPrefs> tabbedPalettes;
+	QByteArray adsDockState;
 };
 
 //Paths
@@ -328,6 +332,11 @@ struct ItemAttrPrefs
 	ObjAttrVector defaultItemAttributes; //! The default item attributes
 };
 
+struct IndexPrefs
+{
+	IndexSetupVector defaultIndexSetup; //! Default Indexes
+};
+
 struct TOCPrefs
 {
 	ToCSetupVector defaultToCSetups; //! Default Tables of Contents
@@ -482,6 +491,7 @@ struct ApplicationPrefs
 	GuidesPrefs guidesPrefs;
 	HyphenatorPrefs hyphPrefs;
 	ImageCachePrefs imageCachePrefs;
+	IndexPrefs indexPrefs;
 	ItemAttrPrefs itemAttrPrefs;
 	ItemToolPrefs itemToolPrefs;
 	KeyboardShortcutsPrefs keyShortcutPrefs;
@@ -527,6 +537,9 @@ struct ScIconSetData
 	QString author;
 	QString activeversion;
 	QString variant;
+	bool isDefault;
+	QRect splashMessgeRect;
+	QString splashScreenPath;
 	QMap<QString, QString> nameTranslations;
 };
 
