@@ -36,12 +36,12 @@ PrintPreviewCreator_PDF::PrintPreviewCreator_PDF(ScribusDoc* doc) :
 	m_printOptions.prnLanguage = PrintLanguage::PDF;
 
 	// Generate a template name for temporary files
-	QTemporaryFile tempFile(ScPaths::tempFileDir() + "/scpdfpreview_XXXXXX.png");
-	if (tempFile.open())
+	QScopedPointer<QTemporaryFile> tempFile(new QTemporaryFile(ScPaths::tempFileDir() + "/scpdfpreview_XXXXXX.png"));
+	if (tempFile->open())
 	{
-		QString tempFileBase = tempFile.fileName();
-		tempFile.setAutoRemove(false);
-		tempFile.close();
+		QString tempFileBase = tempFile->fileName();
+		tempFile->setAutoRemove(false);
+		tempFile->close();
 		m_tempBaseName = QFileInfo(tempFileBase).completeBaseName();
 	}
 	if (m_tempBaseName.isEmpty())
@@ -533,15 +533,15 @@ int PrintPreviewCreator_PDF::renderPreviewSep(int pageIndex, int res)
 			QString tt;
 			if (sepLine.contains("%%SeparationColor:"))
 			{
-				int firstQuote = sepLine.indexOf('\"');
-				int lastQuote = sepLine.lastIndexOf('\"');
+				qsizetype firstQuote = sepLine.indexOf('\"');
+				qsizetype lastQuote = sepLine.lastIndexOf('\"');
 				if (firstQuote >= 0 && lastQuote >= 0 && firstQuote < lastQuote)
 					tt = sepLine.mid(firstQuote + 1, lastQuote - firstQuote - 1);
 			}
 			else
 			{
 				tt = sepLine.remove("%%SeparationName:").trimmed();
-				int cmykVals = tt.lastIndexOf("CMYK =");
+				qsizetype cmykVals = tt.lastIndexOf("CMYK =");
 				if (cmykVals >= 0)
 					tt = tt.left(cmykVals).trimmed();
 			}
