@@ -562,15 +562,15 @@ int PrintPreviewCreator_PS::renderPreviewSep(int pageIndex, int res)
 			QString tt;
 			if (sepLine.contains("%%SeparationColor:"))
 			{
-				int firstQuote = sepLine.indexOf('\"');
-				int lastQuote = sepLine.lastIndexOf('\"');
+				qsizetype firstQuote = sepLine.indexOf('\"');
+				qsizetype lastQuote = sepLine.lastIndexOf('\"');
 				if (firstQuote >= 0 && lastQuote >= 0 && firstQuote < lastQuote)
 					tt = sepLine.mid(firstQuote + 1, lastQuote - firstQuote - 1);
 			}
 			else
 			{
 				tt = sepLine.remove("%%SeparationName:").trimmed();
-				int cmykVals = tt.lastIndexOf("CMYK =");
+				qsizetype cmykVals = tt.lastIndexOf("CMYK =");
 				if (cmykVals >= 0)
 					tt = tt.left(cmykVals).trimmed();
 			}
