@@ -24,7 +24,6 @@ for which a new license (GPL+exception) is in place.
 #include <QGlobalStatic>
 #include <QHash>
 #include <QMap>
-#include <QRegExp>
 #include <QRawFont>
 #ifdef Q_OS_WIN32
 #include <QSet>
@@ -35,6 +34,7 @@ for which a new license (GPL+exception) is in place.
 #include <QTextCodec>
 
 #include <cstdlib>
+#include <utility>
 #include <vector>
 
 #include "scfonts.h"
@@ -88,7 +88,6 @@ SCFonts::SCFonts()
 void SCFonts::updateFontMap()
 {
 	fontMap.clear();
-
 	SCFontsIterator it( *this );
 	for ( ; it.hasNext(); it.next())
 	{
@@ -106,8 +105,8 @@ void SCFonts::updateFontMap()
 		else
 		{
 			QStringList styles;
-			styles.append(currentFace.style());
-			fontMap.insert(currentFace.family(), styles);
+			styles.append(it.current().style());
+			fontMap.insert(it.current().family(), styles);
 		}
 	}
 }
@@ -131,15 +130,16 @@ void SCFonts::addScalableFonts(const QString &path, const QString& DocName)
 	//QString()+/ is / of course.
 	if (path.isEmpty())
 		return;
-	FT_Library library = nullptr;
 	QString pathfile, fullpath;
-//	bool error;
-//	error =
-	FT_Init_FreeType( &library );
+
+	FT_Library library = nullptr;
+	FT_Init_FreeType (&library );
+
 	QString pathname(path);
-	if ( !pathname.endsWith("/") )
+	if (!pathname.endsWith("/"))
 		pathname += "/";
 	pathname = QDir::toNativeSeparators(pathname);
+
 	QDir d(pathname, "*", QDir::Name, QDir::Dirs | QDir::Files | QDir::Readable);
 	if ((d.exists()) && (d.count() != 0))
 	{
@@ -315,7 +315,7 @@ void getSubFontType(FT_Face face, ScFace::FontType & type)
 } 
 
 // sort name records so the preferred ones come first
-static bool nameComp(const FT_SfntName a, const FT_SfntName b)
+static bool nameComp(const FT_SfntName& a, const FT_SfntName& b)
 {
 	// sort preferred family first
 	if (a.name_id != b.name_id)
@@ -373,7 +373,7 @@ static bool nameComp(const FT_SfntName a, const FT_SfntName b)
 	return false;
 }
 
-static QString decodeNameRecord(FT_SfntName name)
+static QString decodeNameRecord(const FT_SfntName& name)
 {
 	if (!name.string || name.string_len == 0)
 		return QString();
@@ -452,7 +452,7 @@ static QString getFamilyName(const FT_Face face)
 	if (!names.isEmpty())
 	{
 		std::sort(names.begin(), names.end(), nameComp);
-		for (const FT_SfntName& name : qAsConst(names))
+		for (const FT_SfntName& name : std::as_const(names))
 		{
 			QString string(decodeNameRecord(name));
 			if (!string.isEmpty())
@@ -509,19 +509,21 @@ ScFace SCFonts::loadScalableFont(const QString &filename)
 	ScFace t;
 	if (filename.isEmpty())
 		return t;
+
 	FT_Library library = nullptr;
-	bool error;
-	error = FT_Init_FreeType( &library );
+	FT_Init_FreeType( &library );
+
 	QFileInfo fi(filename);
 	if (!fi.exists())
 		return t;
+
 	bool Subset = false;
 	char buf[128];
-	QString glyName = "";
+	QString glyName;
 	ScFace::FontFormat format;
 	ScFace::FontType   type;
 	FT_Face         face = nullptr;
-	error = FT_New_Face(library, QFile::encodeName(filename), 0, &face);
+	bool error = FT_New_Face(library, QFile::encodeName(filename), 0, &face);
 	if (error || (face == nullptr))
 	{
 		if (face != nullptr)
@@ -650,7 +652,7 @@ bool SCFonts::addScalableFont(const QString& filename, FT_Library &library, cons
 	static bool firstRun;
 	bool Subset = false;
 	char buf[128];
-	QString glyName = "";
+	QString glyName;
 	ScFace::FontFormat format;
 	ScFace::FontType   type;
 	FT_Face         face = nullptr;
@@ -1068,7 +1070,7 @@ void SCFonts::addRegistryFonts()
 	FT_Library library = nullptr;
 	FT_Init_FreeType( &library );
 
-	for (const auto key : keys)
+	for (const auto& key : keys)
 	{
 		const QSettings fontRegistry(key, QSettings::NativeFormat);
 		const QStringList allKeys = fontRegistry.allKeys();
@@ -1087,7 +1089,7 @@ void SCFonts::addRegistryFonts()
 			QString fontPath = fontInfo.absoluteFilePath();
 			QString pathName = fontInfo.absolutePath();
 
-			qApp->processEvents();
+			QApplication::processEvents();
 			
 			bool isSymlink = fontInfo.isSymLink();
 			if (isSymlink)
@@ -1133,7 +1135,7 @@ void SCFonts::addType1RegistryFonts()
 	FT_Library library = nullptr;
 	FT_Init_FreeType( &library );
 
-	for (const auto key : keys)
+	for (const auto& key : keys)
 	{
 		const QSettings fontRegistry(key, QSettings::NativeFormat);
 		const QStringList allKeys = fontRegistry.allKeys();
@@ -1165,7 +1167,7 @@ void SCFonts::addType1RegistryFonts()
 				QString fontPath = fontInfo.absoluteFilePath();
 				QString pathName = fontInfo.absolutePath();
 
-				qApp->processEvents();
+				QApplication::processEvents();
 			
 				bool isSymlink = fontInfo.isSymLink();
 				if (isSymlink)
@@ -1220,13 +1222,24 @@ void SCFonts::readFontCache(const QString& pf)
 		fr.remove();
 	m_checkedFonts.clear();
 	struct testCache foCache;
+
 	QDomDocument docu("fontcacherc");
-	QFile f(pf + "/checkfonts150.xml");
+	QFile f(pf + "/checkfonts170.xml");
 	if (!f.open(QIODevice::ReadOnly))
 		return;
 	ScCore->setSplashStatus( QObject::tr("Reading Font Cache") );
+
 	QTextStream ts(&f);
-	ts.setCodec("UTF-8");
+	ts.setEncoding(QStringConverter::Utf8);
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = docu.setContent(ts.readAll());
+	if (!parseResult)
+	{
+		f.close();
+		return;
+	}
+#else
 	QString errorMsg;
 	int errorLine = 0, errorColumn = 0;
 	if ( !docu.setContent(ts.readAll(), &errorMsg, &errorLine, &errorColumn) )
@@ -1234,10 +1247,13 @@ void SCFonts::readFontCache(const QString& pf)
 		f.close();
 		return;
 	}
+#endif
 	f.close();
+
 	QDomElement elem = docu.documentElement();
 	if (elem.tagName() != "CachedFonts")
 		return;
+
 	QDomNode DOC = elem.firstChild();
 	while (!DOC.isNull())
 	{
@@ -1253,13 +1269,13 @@ void SCFonts::readFontCache(const QString& pf)
 	}
 }
 
-void SCFonts::writeFontCache()
+void SCFonts::writeFontCache() const
 {
 	QString prefsLocation = PrefsManager::instance().preferencesLocation();
 	writeFontCache(prefsLocation);
 }
 
-void SCFonts::writeFontCache(const QString& pf)
+void SCFonts::writeFontCache(const QString& pf) const
 {
 	QDomDocument docu("fontcacherc");
 	QString st="<CachedFonts></CachedFonts>";
@@ -1285,11 +1301,11 @@ void SCFonts::writeFontCache(const QString& pf)
 
 	ScCore->setSplashStatus( QObject::tr("Writing updated Font Cache") );
 
-	QFile file(pf + "/checkfonts150.xml");
+	QFile file(pf + "/checkfonts170.xml");
 	if (!file.open(QIODevice::WriteOnly))
 		return;
 	QTextStream s(&file);
-	s.setCodec("UTF-8");
+	s.setEncoding(QStringConverter::Utf8);
 	s << docu.toString();
 	file.close();
 }
