@@ -22,7 +22,6 @@ for which a new license (GPL+exception) is in place.
 #include "commonstrings.h"
 #include "exif.h"
 #include "rawimage.h"
-#include "scclocale.h"
 #include "sccolorengine.h"
 #include "scimagecacheproxy.h"
 #include "scstreamfilter.h"
@@ -41,6 +40,9 @@ for which a new license (GPL+exception) is in place.
 #include "imagedataloaders/scimgdataloader_gmagick.h"
 #endif
 #include "imagedataloaders/scimgdataloader_jpeg.h"
+#ifdef HAVE_JXL
+#include "imagedataloaders/scimgdataloader_jpegxl.h"
+#endif
 #include "imagedataloaders/scimgdataloader_ora.h"
 #include "imagedataloaders/scimgdataloader_kra.h"
 #include "imagedataloaders/scimgdataloader_pict.h"
@@ -58,25 +60,16 @@ using namespace std;
 
 ScImage::ScImage(const QImage & image) : QImage(image)
 {
-	initialize();
 }
 
 
 // ScImage will use implicit sharing:
 ScImage::ScImage(const ScImage & image) : QImage(image.copy())
 {
-	initialize();
-}
-
-
-ScImage::ScImage()
-{
-	initialize();
 }
 
 ScImage::ScImage( int width, int height ) : QImage( width, height, QImage::Format_ARGB32 )
 {
-	initialize();
 }
 
 const QImage& ScImage::qImage() const
@@ -94,7 +87,6 @@ QImage ScImage::scaled(int w, int h, Qt::AspectRatioMode mode, Qt::Transformatio
 	return QImage::scaled(w, h, mode, transformMode);
 }
 
-
 void ScImage::initialize()
 {
 	imgInfo.xres = 72;
@@ -141,8 +133,8 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 			toGrayscale(cmyk);
 		if (effect.effectCode == ImageEffect::EF_COLORIZE)
 		{
-			QString tmpstr = effect.effectParameters;
-			QString col = CommonStrings::None;
+			QString tmpstr(effect.effectParameters);
+			QString col(CommonStrings::None);
 			int shading = 100;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 		//	fp >> col;
@@ -152,7 +144,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_BRIGHTNESS)
 		{
-			QString tmpstr = effect.effectParameters;
+			QString tmpstr(effect.effectParameters);
 			int brightnessValue = 0;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> brightnessValue;
@@ -160,7 +152,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_CONTRAST)
 		{
-			QString tmpstr = effect.effectParameters;
+			QString tmpstr(effect.effectParameters);
 			int contrastValue = 0;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> contrastValue;
@@ -168,7 +160,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_SHARPEN)
 		{
-			QString tmpstr = effect.effectParameters;
+			QString tmpstr(effect.effectParameters);
 			double radius, sigma;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> radius;
@@ -177,7 +169,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_BLUR)
 		{
-			QString tmpstr = effect.effectParameters;
+			QString tmpstr(effect.effectParameters);
 			double radius, sigma;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> radius;
@@ -186,7 +178,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_SOLARIZE)
 		{
-			QString tmpstr = effect.effectParameters;
+			QString tmpstr(effect.effectParameters);
 			double sigma;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			fp >> sigma;
@@ -194,10 +186,10 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_DUOTONE)
 		{
-			QString tmpstr = effect.effectParameters;
-			QString col1 = CommonStrings::None;
+			QString tmpstr(effect.effectParameters);
+			QString col1(CommonStrings::None);
+			QString col2(CommonStrings::None);
 			int shading1 = 100;
-			QString col2 = CommonStrings::None;
 			int shading2 = 100;
 			ScTextStream fp(&tmpstr, QIODevice::ReadOnly);
 			col1 = fp.readLine();
@@ -230,10 +222,10 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_TRITONE)
 		{
-			QString tmpstr = effect.effectParameters;
-			QString col1 = CommonStrings::None;
-			QString col2 = CommonStrings::None;
-			QString col3 = CommonStrings::None;
+			QString tmpstr(effect.effectParameters);
+			QString col1(CommonStrings::None);
+			QString col2(CommonStrings::None);
+			QString col3(CommonStrings::None);
 			int shading1 = 100;
 			int shading2 = 100;
 			int shading3 = 100;
@@ -280,11 +272,11 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_QUADTONE)
 		{
-			QString tmpstr = effect.effectParameters;
-			QString col1 = CommonStrings::None;
-			QString col2 = CommonStrings::None;
-			QString col3 = CommonStrings::None;
-			QString col4 = CommonStrings::None;
+			QString tmpstr(effect.effectParameters);
+			QString col1(CommonStrings::None);
+			QString col2(CommonStrings::None);
+			QString col3(CommonStrings::None);
+			QString col4(CommonStrings::None);
 			int shading1 = 100;
 			int shading2 = 100;
 			int shading3 = 100;
@@ -344,7 +336,7 @@ void ScImage::applyEffect(const ScImageEffectList& effectsList, ColorList& color
 		}
 		if (effect.effectCode == ImageEffect::EF_GRADUATE)
 		{
-			QString tmpstr = effect.effectParameters;
+			QString tmpstr(effect.effectParameters);
 			int numVals;
 			double xval, yval;
 			FPointArray curve;
@@ -1968,7 +1960,7 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 	imgInfo.clipPath.clear();
 	imgInfo.PDSpathData.clear();
 	imgInfo.layerInfo.clear();
-	QFileInfo fi = QFileInfo(fn);
+	QFileInfo fi(fn);
 	if (!fi.exists())
 		return false;
 	alpha.resize(0);
@@ -1984,6 +1976,8 @@ bool ScImage::getAlpha(const QString& fn, int page, QByteArray& alpha, bool PDF,
 	}
 	if (extensionIndicatesJPEG(ext))
 		return true;
+	if (extensionIndicatesJPEGXL(ext))
+		return true;
 	if (extensionIndicatesPDF(ext))
 	{
 		pDataLoader.reset( new ScImgDataLoader_PDF() );
@@ -2286,6 +2280,10 @@ bool ScImage::loadPicture(const QString & fn, int page, const CMSettings& cmSett
 		pDataLoader.reset( new ScImgDataLoader_PS() );
 	else if (extensionIndicatesJPEG(ext))
 		pDataLoader.reset( new ScImgDataLoader_JPEG() );
+	#ifdef HAVE_JXL
+	else if (extensionIndicatesJPEGXL(ext))
+		pDataLoader.reset( new ScImgDataLoader_JPEGXL() );
+	#endif
 	else if (extensionIndicatesPNG(ext))
 		pDataLoader.reset( new ScImgDataLoader_PNG() );
 	else if (extensionIndicatesPSD(ext))
