@@ -70,7 +70,7 @@ bool ScLayer::operator== (const ScLayer& other) const
 		blendMode == other.blendMode;
 }
 
-int ScLayers::getMaxID()
+int ScLayers::getMaxID() const
 {
 	int maxNr = -1;
 	for (int i = 0; i < this->count(); ++i)
@@ -593,7 +593,7 @@ bool ScLayers::setLayerMarker(int layerID, QColor color)
 	ScLayer* layer = byID(layerID);
 	if (!layer)
 		return false;
-	layer->markerColor = std::move(color);
+	layer->markerColor = color;
 	return true;
 }
 
@@ -614,7 +614,7 @@ bool ScLayers::setLayerSelectable(int layerID, bool isSelectable)
 	return true;
 }
 
-uint qHash(const ScLayer& layer)
+size_t qHash(const ScLayer& layer)
 { 
 	return qHash(&layer);
 }
