@@ -7,7 +7,6 @@ for which a new license (GPL+exception) is in place.
 
 #include "scpainter.h"
 #include "scpattern.h"
-#include "util_color.h"
 #include "util.h"
 #include "util_math.h"
 
@@ -25,7 +24,7 @@ for which a new license (GPL+exception) is in place.
 ScPainter::ScPainter(QImage *target, int w, int h, double transparency, int blendmode)
          : m_image(target),
 	       m_layerTransparency(transparency),
-	       m_blendMode(blendmode)
+		   m_blendMode(blendmode)
 {
 	Q_ASSERT(w >= 0);
 	Q_ASSERT(h >= 0);
@@ -152,7 +151,7 @@ cairo_t *ScPainter::context()
 	return m_cr;
 }
 
-const QTransform ScPainter::worldMatrix()
+QTransform ScPainter::worldMatrix()
 {
 	cairo_matrix_t matrix;
 	cairo_get_matrix(m_cr, &matrix);
@@ -373,6 +372,8 @@ void ScPainter::fillPath()
 
 void ScPainter::strokePath()
 {
+//	if (LineWidth == 0)
+//		return;
 	if (m_strokeMode != 0)
 		strokePathHelper();
 }
@@ -550,10 +551,10 @@ cairo_pattern_t * ScPainter::getMaskPattern()
 		{
 			qStopColor = colorStops[ offset ]->color;
 			double a = colorStops[offset]->opacity;
-			double r, g, b;
+			float r, g, b;
 			qStopColor.getRgbF(&r, &g, &b);
 			if (m_maskMode == 3)
-				a = /* 1.0 - */(0.3 * r + 0.59 * g + 0.11 * b);
+				a = 0.3 * r + 0.59 * g + 0.11 * b;
 			cairo_pattern_add_color_stop_rgba (pat, colorStops[ offset ]->rampPoint, r, g, b, a);
 		}
 		cairo_matrix_t matrix;
@@ -645,7 +646,7 @@ void ScPainter::fillPathHelper()
 		cairo_set_fill_rule (m_cr, CAIRO_FILL_RULE_WINDING);
 	if (m_fillMode == 1)
 	{
-		double r, g, b;
+		float r, g, b;
 		m_fill.getRgbF(&r, &g, &b);
 		if (m_maskMode > 0)
 		{
@@ -689,7 +690,7 @@ void ScPainter::fillPathHelper()
 			cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 			cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 			cairo_set_tolerance(cr, 0.5);
-			double r, g, b, a;
+			float r, g, b, a;
 			mpat = cairo_pattern_create_mesh();
 			cairo_mesh_pattern_begin_patch(mpat);
 			cairo_mesh_pattern_move_to(mpat, p1x, p1y);
@@ -732,7 +733,7 @@ void ScPainter::fillPathHelper()
 			cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 			cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 			cairo_set_tolerance(cr, 0.5);
-			double r, g, b, a;
+			float r, g, b, a;
 			QList<VColorStop*> colorStops = fill_gradient.colorStops();
 			QList<QColor> qStopColors;
 			QList<double> qStopRampPoints;
@@ -775,7 +776,7 @@ void ScPainter::fillPathHelper()
 			cairo_fill(cr);
 			cairo_set_operator(cr, CAIRO_OPERATOR_ADD);
 			mpat = cairo_pattern_create_mesh();
-			for (int offset = 1 ; offset < qStopRampPoints.count() ; offset++)
+			for (qsizetype offset = 1 ; offset < qStopRampPoints.count() ; offset++)
 			{
 				QLineF e1 = edge1;
 				QLineF e1s = edge1;
@@ -908,11 +909,11 @@ void ScPainter::fillPathHelper()
 			cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 			cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 			cairo_set_tolerance(cr, 0.5);
-			double r, g, b, a;
+			float r, g, b, a;
 			mpat = cairo_pattern_create_mesh();
-			for (int grow = 0; grow < meshGradientArray.count() - 1; ++grow)
+			for (qsizetype grow = 0; grow < meshGradientArray.count() - 1; ++grow)
 			{
-				for (int gcol = 0; gcol < meshGradientArray[grow].count() - 1; ++gcol)
+				for (qsizetype gcol = 0; gcol < meshGradientArray[grow].count() - 1; ++gcol)
 				{
 					MeshPoint mp1 = meshGradientArray[grow][gcol];
 					MeshPoint mp2 = meshGradientArray[grow][gcol + 1];
@@ -955,7 +956,7 @@ void ScPainter::fillPathHelper()
 			cairo_set_fill_rule(cr, CAIRO_FILL_RULE_EVEN_ODD);
 			cairo_set_operator(cr, CAIRO_OPERATOR_SOURCE);
 			cairo_set_tolerance(cr, 0.5);
-			double r, g, b, a;
+			float r, g, b, a;
 			mpat = cairo_pattern_create_mesh();
 			for (int col = 0; col < meshGradientPatches.count(); col++)
 			{
@@ -1018,7 +1019,7 @@ void ScPainter::fillPathHelper()
 					continue;
 				isFirst = false;
 				double a = colorStops[offset]->opacity;
-				double r, g, b;
+				float r, g, b;
 				colorStops[ offset ]->color.getRgbF(&r, &g, &b);
 				cairo_pattern_add_color_stop_rgba (pat, colorStops[ offset ]->rampPoint, r, g, b, a);
 				lastPoint = rampPoint;
@@ -1122,12 +1123,12 @@ void ScPainter::fillPathHelper()
 		cairo_push_group(m_cr);
 		if (m_hatchUseBackground && m_hatchBackground.isValid())
 		{
-			double r2, g2, b2;
+			float r2, g2, b2;
 			m_hatchBackground.getRgbF(&r2, &g2, &b2);
 			cairo_set_source_rgb(m_cr, r2, g2, b2);
 			cairo_fill_preserve(m_cr);
 		}
-		double r, g, b;
+		float r, g, b;
 		m_hatchForeground.getRgbF(&r, &g, &b);
 		cairo_clip_preserve (m_cr);
 		cairo_set_line_width(m_cr, 1);
@@ -1298,7 +1299,7 @@ void ScPainter::strokePathHelper()
 				continue;
 			isFirst = false;
 			double a = colorStops[offset]->opacity;
-			double r, g, b;
+			float r, g, b;
 			colorStops[ offset ]->color.getRgbF(&r, &g, &b);
 			cairo_pattern_add_color_stop_rgba (pat, rampPoint, r, g, b, a);
 			lastPoint = rampPoint;
@@ -1333,7 +1334,7 @@ void ScPainter::strokePathHelper()
 	}
 	else
 	{
-		double r, g, b;
+		float r, g, b;
 		m_stroke.getRgbF(&r, &g, &b);
 		cairo_set_source_rgba(m_cr, r, g, b, m_stroke_trans);
 		setRasterOp(m_blendModeStroke);
@@ -1410,7 +1411,7 @@ void ScPainter::setupPolygon(const FPointArray *points, bool closed)
 		if (nPath)
 		{
 			np = points->point(poi);
-			if (!first && closed && (np4 == firstP))
+			if ((!first) && (closed) && (np4 == firstP))
 				cairo_close_path(m_cr);
 			cairo_move_to(m_cr, np.x(), np.y());
 			first = nPath = false;
@@ -1452,7 +1453,7 @@ void ScPainter::setupSharpPolygon(const FPointArray *points, bool closed)
 		if (nPath)
 		{
 			np = points->point(poi);
-			if (!first && closed && (np4 == firstP))
+			if ((!first) && (closed) && (np4 == firstP))
 				cairo_close_path(m_cr);
 			sharpLineHelper(np);
 			cairo_move_to(m_cr, np.x(), np.y());
@@ -1588,7 +1589,7 @@ void ScPainter::drawText(const QRectF& area, const QString& text, bool filled, i
 	double y = area.y();
 	double ww = 0;
 	double hh = 0;
-	double r, g, b;
+	float r, g, b;
 
 	assert(!m_font.isNone());
 
@@ -1641,7 +1642,7 @@ void ScPainter::drawText(const QRectF& area, const QString& text, bool filled, i
 		CharStyle style(m_font, m_fontSize * 10);
 		StoryText story;
 		story.insertChars(textList[a]);
-		story.setCharStyle(0, textList[a].count(), style);
+		story.setCharStyle(0, textList[a].size(), style);
 
 		TextShaper textShaper(story, 0);
 		const QList<GlyphCluster> glyphRuns = textShaper.shape(0, story.length()).glyphs();
