@@ -17,8 +17,10 @@ for which a new license (GPL+exception) is in place.
 #include <QFont>
 #include <QImage>
 #include <QPointF>
+
 #include "scribusapi.h"
 #include "scconfig.h"
+#include "scpatterntransform.h"
 #include "sctextstruct.h"
 #include "fpoint.h"
 #include "fpointarray.h"
@@ -49,7 +51,7 @@ public:
 
 	// matrix manipulation
 	virtual void setWorldMatrix(const QTransform &);
-	virtual const QTransform worldMatrix();
+	virtual QTransform worldMatrix();
 	virtual void setZoomFactor(double);
 	virtual double zoomFactor() { return m_zoomFactor; }
 	virtual void translate(double, double);
@@ -73,11 +75,11 @@ public:
 	virtual void setStrokeMode(int stroke);
 	virtual int  strokeMode() const  { return m_strokeMode; }
 	virtual void setGradient(VGradient::VGradientType mode, const FPoint& orig, const FPoint& vec, const FPoint& foc, double scale, double skew);
-	virtual void setPattern(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY);
+	virtual void setPattern(ScPattern *pattern, const ScPatternTransform& patternTrans, bool mirrorX, bool mirrorY);
 
 	virtual void setMaskMode(int mask);
 	virtual void setGradientMask(VGradient::VGradientType mode, const FPoint& orig, const FPoint& vec, const FPoint& foc, double scale, double skew);
-	virtual void setPatternMask(ScPattern *pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY);
+	virtual void setPatternMask(ScPattern *pattern, const ScMaskTransform& maskTrans, bool mirrorX, bool mirrorY);
 
 	virtual void set4ColorGeometry(const FPoint& p1, const FPoint& p2, const FPoint& p3, const FPoint& p4, const FPoint& c1, const FPoint& c2, const FPoint& c3, const FPoint& c4);
 	virtual void set4ColorColors(const QColor& col1, const QColor& col2, const QColor& col3, const QColor& col4);
@@ -130,7 +132,6 @@ public:
 	virtual void restore();
 	virtual int blendModeFill();
 
-
 	virtual void setRasterOp(int blendMode);
 	virtual void setBlendModeFill(int blendMode);
 	virtual void setBlendModeStroke(int blendMode);
@@ -148,26 +149,19 @@ private:
 	cairo_t* m_cr { nullptr };
 	struct layerProp
 	{
-		cairo_surface_t *data;
-		int blendmode;
-		double tranparency;
-		int maskMode;				// 0 = none, 1 = gradient 2 = pattern
-		double mask_patternScaleX;
-		double mask_patternScaleY;
-		double mask_patternOffsetX;
-		double mask_patternOffsetY;
-		double mask_patternRotation;
-		double mask_patternSkewX;
-		double mask_patternSkewY;
-		bool mask_patternMirrorX;
-		bool mask_patternMirrorY;
-		double mask_gradientScale;
-		double mask_gradientSkew;
+		cairo_surface_t *data { nullptr };
+		int blendmode { 0 };
+		double transparency { 1.0 };
+		int maskMode { 0 };				// 0 = none, 1 = gradient 2 = pattern
+		ScMaskTransform maskPatternTrans;
+		bool mask_patternMirrorX { false };
+		bool mask_patternMirrorY { false };
+		double mask_gradientScale { 1.0 };
+		double mask_gradientSkew { 0.0 };
 		VGradient mask_gradient;
-		ScPattern *maskPattern;
+		ScPattern *maskPattern { nullptr };
 		FPointArray groupClip;
-		bool pushed;
-		bool fillRule;
+		bool fillRule { false };
 	};
 	cairo_pattern_t *getMaskPattern();
 	cairo_surface_t *m_imageMask { nullptr };
@@ -176,31 +170,19 @@ private:
 	QStack<layerProp> m_Layers;
 	QStack<double> m_zoomStack;
 	QImage *m_image { nullptr };
-	double  m_layerTransparency;
+	double  m_layerTransparency { 1.0 };
 	int  m_blendMode { 0 };
 	int  m_blendModeFill { 0 };
 	int  m_blendModeStroke { 0 };
-	unsigned int m_width;
-	unsigned int m_height;
 	QTransform m_matrix;
 	ScFace m_font;
 	double m_fontSize { 0.0 };
-//	bool mf_underline { false };
-//	bool mf_strikeout { false };
-//	bool mf_shadow { false };
-//	bool mf_outlined { false };
 	/*! \brief Filling */
 	QColor m_fill { 0, 0, 0 };
 	double m_fill_trans { 1.0 };
 	bool m_fillRule { true };
 	int m_fillMode { 1 };				// 0 = none, 1 = solid, 2 = gradient 3 = pattern 4 = hatch
-	double m_patternScaleX { 0.0 };
-	double m_patternScaleY { 0.0 };
-	double m_patternOffsetX { 0.0 };
-	double m_patternOffsetY { 0.0 };
-	double m_patternRotation { 0.0 };
-	double m_patternSkewX { 0.0 };
-	double m_patternSkewY { 0.0 };
+	ScPatternTransform m_patternTrans;
 	bool m_patternMirrorX { false };
 	bool m_patternMirrorY { false };
 	double m_gradientScale { 0.0 };
@@ -234,13 +216,7 @@ private:
 	double m_LineWidth { 1.0 };
 	int m_strokeMode { 0 };				// 0 = none, 1 = solid, 2 = gradient 3 = pattern
 	int m_maskMode { 0 };				// 0 = none, 1 = gradient 2 = pattern
-	double m_mask_patternScaleX { 0.0 };
-	double m_mask_patternScaleY { 0.0 };
-	double m_mask_patternOffsetX { 0.0 };
-	double m_mask_patternOffsetY { 0.0 };
-	double m_mask_patternRotation { 0.0 };
-	double m_mask_patternSkewX { 0.0 };
-	double m_mask_patternSkewY { 0.0 };
+	ScMaskTransform m_maskPatternTrans;
 	bool m_mask_patternMirrorX { false };
 	bool m_mask_patternMirrorY { false };
 	double m_mask_gradientScale { 0.0 };
@@ -256,8 +232,6 @@ private:
 	/*! \brief Zoom Factor of the Painter */
 	double m_zoomFactor { 1.0 };
 	bool m_imageMode { true };
-	bool m_layeredMode { true };
-	bool m_svgMode { false };
 };
 
 #endif
