@@ -46,6 +46,12 @@ using namespace std;
 ScPs2OutputParams::ScPs2OutputParams(ScribusDoc* doc)
 {
 	document = doc;
+	colorMode = ScPainterExBase::rgbMode;
+	hProfile = nullptr;
+	rgbToOutputColorTransform = nullptr;
+	rgbToOutputImageTransform = nullptr;
+	cmykToOutputColorTransform = nullptr;
+	cmykToOutputImageTransform = nullptr;
 }
 
 ScPainterEx_Ps2::ScPainterEx_Ps2(QIODevice* iodev, const QRect& rect, const ScPs2OutputParams& options )
@@ -66,6 +72,10 @@ ScPainterEx_Ps2::ScPainterEx_Ps2(QIODevice* iodev, const QRect& rect, const ScPs
 	clear();
 }
 
+ScPainterEx_Ps2::~ScPainterEx_Ps2()
+{
+}
+
 ScPainterExBase::ImageMode ScPainterEx_Ps2::imageMode() const
 {
 	ImageMode imageMode;
@@ -168,7 +178,7 @@ void ScPainterEx_Ps2::scale( double x, double y )
 	m_matrix.scale(x, y);
 }
 
-void ScPainterEx_Ps2::shear(double x, double y)
+void ScPainterEx_Ps2::shear( double x, double y )
 {
 	m_matrix.shear(x, y);
 }
@@ -445,7 +455,7 @@ void ScPainterEx_Ps2::putColor(const ScColorShade& colorShade, bool doFill)
 	{
 		unsigned long colorIn[4];
 		unsigned long colorOut[4];
-		ScColorTransform cmsTranform;
+		ScColorTransform cmsTranform = nullptr;
 		if (colorShade.color.getColorModel() == colorModelRGB)
 		{
 			RGBColorF rgb;
