@@ -56,6 +56,8 @@ class QQuickView;
 // application specific includes
 #include "scribusapi.h"
 #include "scribusdoc.h"
+#include "manager/dock_manager.h"
+#include "manager/widget_manager.h"
 #include "styleoptions.h"
 #include "ui/customfdialog.h"
 #include "ui/scmessagebox.h"
@@ -69,8 +71,7 @@ class BookPalette;
 class CharSelect;
 class CheckDocument;
 class ColorCombo;
-class DocumentLogManager;
-class DocumentLogViewer;
+class DockManager;
 class DownloadsPalette;
 class EditToolBar;
 class FileToolBar;
@@ -141,7 +142,7 @@ public:
 	QScreen* getScreen() const;
 	void getScreenPosition(int& xPos, int& yPos) const;
 	void getScreenDPI(int& dpiX, int& dpiY) const;
-	void addScToolBar(ScToolBar *tb, const QString& name);
+	void addScToolBar(ScToolBar *tb, const QString& name, Qt::ToolBarArea area = Qt::ToolBarArea::TopToolBarArea);
 	bool warningVersion(QWidget *parent);
 	void SetShortCut();
 	void startUpDialog();
@@ -153,7 +154,7 @@ public:
 
 	ScribusDoc* doFileNew(double width, double height, double topMargin, double leftMargin, double rightMargin, double bottomMargin, double columnDistance, double columnCount, bool autoTextFrames, int pageArrangement, int unitIndex, int firstPageLocation, int orientation, int firstPageNumber, const QString& defaultPageSize, bool requiresGUI, int pageCount = 1, bool showView = true, int marginPreset = 0);
 	ScribusDoc* newDoc(double width, double height, double topMargin, double leftMargin, double rightMargin, double bottomMargin, double columnDistance, double columnCount, bool autoTextFrames, int pageArrangement, int unitIndex, int firstPageLocation, int orientation, int firstPageNumber, const QString& defaultPageSize, bool requiresGUI, int pageCount = 1, bool showView = true, int marginPreset = 0);
-	bool DoFileSave(const QString& fileName, QString* savedFileName = nullptr);
+	bool DoFileSave(const QString& fileName, QString* savedFileName = nullptr, uint formatID = FORMATID_CURRENTEXPORT);
 
 	void changeEvent(QEvent *e) override;
 	void closeEvent(QCloseEvent *ce) override;
@@ -170,7 +171,7 @@ public:
 	void doPasteRecent(const QString& data);
 	bool getPDFDriver(const QString & filename, const std::vector<int> & pageNumbers, const QMap<int, QImage> & thumbs, QString& error, bool* cancelled = nullptr);
 	bool DoSaveAsEps(const QString& fn, QString& error);
-	QString CFileDialog(const QString& workingDirectory = ".", const QString& dialogCaption = "", const QString& fileFilter = "", const QString& defNa = "",
+	QPair<QString, uint> CFileDialog(const QString& workingDirectory = ".", const QString& dialogCaption = "", const QString& fileFilter = "", const QString& defNa = "",
 						int optionFlags = fdExistingFiles, bool *useCompression = 0, bool *useFonts = 0, bool *useProfiles = 0);
 	/*! \brief Recalculate the colors after changing CMS settings.
 	Call the appropriate document function and then update the GUI elements.
@@ -202,6 +203,13 @@ public:
 	void restoreDeletePage(SimpleState *state, bool isUndo);
 	void setPreviewToolbar();
 	void updateFromDrop();
+
+
+	//! \brief allow SE to get the SM for edit styles
+	StyleManager *styleMgr() const {return m_styleManager;}
+
+
+
 	struct CopyContentsBuffer contentsBuffer;
 	bool internalCopy { false };
 	QString internalCopyBuffer;
@@ -220,6 +228,7 @@ public:
 	/** \brief private doc for managing default patterns. */
 	ScribusDoc* m_doc {nullptr};
 
+	DockManager * dockManager {nullptr};
 
 	QProgressBar* mainWindowProgressBar {nullptr};
 	ScrSpinBox* zoomSpinBox {nullptr}; //zoom spinbox at bottom of view
@@ -258,13 +267,11 @@ public:
 	UndoPalette* undoPalette {nullptr};
 	AlignDistributePalette *alignDistributePalette {nullptr};
 	ResourceManager *resourceManager {nullptr};
-	DocumentLogViewer *documentLogViewer {nullptr};
 	StoryEditor* storyEditor {nullptr};
 	StoryEditor* CurrStED {nullptr};
 	QMdiArea *mdiArea {nullptr};
 	ScribusWin* ActWin {nullptr};
 	QClipboard *ClipB {nullptr};
-	QString LoadEnc;
 	AppModeHelper *appModeHelper {nullptr};
 
 	QMap<QString, QPointer<ScrAction> > scrActions;
@@ -468,6 +475,8 @@ public slots:
 	void HaveNewSel();
 	/** Dokument ist geaendert worden */
 	void slotDocCh(bool reb = true);
+	/** Page preview changed */
+	void slotPreviewCh();
 	/** Setzt die Abstufung */
 	//void setItemShade(int id);
 	/** Setz die Zeichensatzgroesse */
@@ -556,8 +565,6 @@ public slots:
 	void slotItemTransform();
 	//! \brief manages paints
 	void manageColorsAndFills();
-	//! \brief allow SE to get the SM for edit styles
-	StyleManager *styleMgr() const {return m_styleManager;};
 	//! \brief drawnew, call palettes to update for new page layout
 	void updateGUIAfterPagesChanged();
 	/**
@@ -614,8 +621,6 @@ private:
 	void initStatusBar(); // setup the statusbar
 	void initToolBars(); // setup the toolbars
 	void setStyleSheet(); //set stylesheet for app
-	//Returns false when there are no fonts
-	void initHyphenator();
 	void initDefaultValues();
 	void initKeyboardShortcuts();
 	void initPalettes();
@@ -651,18 +656,18 @@ private:
 
 	StyleManager *m_styleManager {nullptr};
 	UndoManager *m_undoManager {nullptr};
-	DocumentLogManager *m_documentLogManager {nullptr};
 	PrefsManager& m_prefsManager;
-	FormatsManager *m_formatsManager {nullptr};
+	WidgetManager &m_widgetManager;
+	FormatsManager *m_formatsManager {nullptr};	
 
 	QPointer<HelpBrowser> m_helpBrowser;
 	QString m_osgFilterString;
 
 	void insertMark(MarkType);
-	bool insertMarkDialog(PageItem_TextFrame* item, MarkType mT, ScItemsState* &is);
+	bool insertMarkDialog(PageItem_TextFrame* item, MarkType mT, ScItemsState* &is, const QString &text, int markInsertPosition);
 	int m_marksCount { 0 }; //remember marks count from last call
 	bool m_WasAutoSave { false };
-	bool m_pagePalVisible { false };
+	bool m_pagePaletteWasClosed { true };
 };
 
 #endif
