@@ -7,7 +7,7 @@ for which a new license (GPL+exception) is in place.
 /***************************************************************************
 	begin                : May 2005
 	copyright            : (C) 2005 by Craig Bradney
-	email                : cbradney@zip.com.au
+	email                : cbradney@scribus.info
 	copyright            : (C) 2001 by Franz Schmid
 	email                : Franz.Schmid@altmuehlnet.de
 ***************************************************************************/
@@ -39,7 +39,6 @@ for which a new license (GPL+exception) is in place.
 
 #include "scribusapp.h"
 
-#include "commonstrings.h"
 #include "downloadmanager/scdlmgr.h"
 #include "iconmanager.h"
 #include "langmgr.h"
@@ -102,9 +101,7 @@ bool ScribusQApp::useGUI = false;
 ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv)
 {
 	ScQApp = this;
-	ScCore = nullptr;
 	initDLMgr();
-	setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 }
 
 ScribusQApp::~ScribusQApp()
@@ -182,7 +179,7 @@ void ScribusQApp::parseCommandLine()
 			}
 			break;
 		}
-		if ((arg == ARG_LANG || arg == ARG_LANG_SHORT))
+		if (arg == ARG_LANG || arg == ARG_LANG_SHORT)
 		{
 			if  (++argi < argsc)
 				m_lang = args[argi];
@@ -282,7 +279,7 @@ void ScribusQApp::parseCommandLine()
 		}
 		else
 		{ //argument is not a known option, but either positional parameter or invalid.
-			if (arg.at(0) == "-")
+			if (arg.at(0) == '-')
 			{
 				std::cout << tr("Invalid argument: %1").arg(arg).toLocal8Bit().data() << std::endl;
 				std::exit(EXIT_FAILURE);
@@ -389,7 +386,7 @@ QStringList ScribusQApp::getLang(QString lang)
 			PrefsPfad = Pff;
 		else
 			PrefsPfad = ScPaths::preferencesDir();
-		QString prefsXMLFile = QDir::toNativeSeparators(PrefsPfad + "prefs150.xml");
+		QString prefsXMLFile = QDir::toNativeSeparators(PrefsPfad + "prefs170.xml");
 		QFileInfo infoPrefsFile(prefsXMLFile);
 		if (infoPrefsFile.exists())
 		{
@@ -455,15 +452,15 @@ QStringList ScribusQApp::getLang(QString lang)
 #endif
 
 	langs.append(QLocale::system().name());
-
-	// remove duplicate entries...
-	QStringList::Iterator it = langs.end();
-	while (it != langs.begin())
-	{
-		--it;
-		if (langs.count(*it) > 1)
-			it = langs.erase(it);
-	}
+	langs.removeDuplicates();
+//	// remove duplicate entries...
+//	QStringList::Iterator it = langs.end();
+//	while (it != langs.begin())
+//	{
+//		--it;
+//		if (langs.count(*it) > 1)
+//			it = langs.erase(it);
+//	}
 	return langs;
 }
 
@@ -502,7 +499,7 @@ void ScribusQApp::installTranslators(const QStringList & langs)
 		}
 
 		//CB: This might need adjusting for qm files distribution locations
-		if (transQt->load("qt_" + lang,	QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+		if (transQt->load("qt_" + lang,	QLibraryInfo::path(QLibraryInfo::TranslationsPath)))
 			loadedQt = true;
 		if (trans->load(QString("scribus." + lang), path))
 			loadedScribus = true;
@@ -559,7 +556,8 @@ void ScribusQApp::changeGUILanguage(const QString & newGUILang)
 void ScribusQApp::changeIconSet(const QString& newIconSet)
 {
 	IconManager& iconManager = IconManager::instance();
-	iconManager.clearCache();
+	//iconManager.clearCache();
+	iconManager.rebuildCache();
 	iconManager.setActiveFromPrefs(newIconSet);
 	emit iconSetChanged();
 }
@@ -570,6 +568,11 @@ void ScribusQApp::setLocale()
 	emit localeChanged();
 }
 
+void ScribusQApp::changeLabelVisibility(bool visibility)
+{
+	emit labelVisibilityChanged(visibility);
+}
+
 /*! \brief Format an arguments line for printing
 Helper procedure */
 static void printArgLine(QTextStream & ts, const char * smallArg, const char* fullArg, const QString& desc)
@@ -653,10 +656,10 @@ void ScribusQApp::showHeader()
 	const int descwidth = -(heading.length() - urlwidth - 1);
 	ts << heading << Qt::endl;
 	ts << separator << Qt::endl;
-	ts << QString("%1 %2").arg( tr("Homepage") + ":",      descwidth).arg("http://www.scribus.net" ) << Qt::endl;
-	ts << QString("%1 %2").arg( tr("Documentation") + ":", descwidth).arg("http://docs.scribus.net") << Qt::endl;
-	ts << QString("%1 %2").arg( tr("Wiki") + ":",          descwidth).arg("http://wiki.scribus.net") << Qt::endl;
-	ts << QString("%1 %2").arg( tr("Issues") + ":",        descwidth).arg("http://bugs.scribus.net") << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Homepage") + ":",      descwidth).arg("https://www.scribus.net" ) << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Documentation") + ":", descwidth).arg("https://docs.scribus.net") << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Wiki") + ":",          descwidth).arg("https://wiki.scribus.net") << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Issues") + ":",        descwidth).arg("https://bugs.scribus.net") << Qt::endl;
 	ts << Qt::endl;
 }
 
