@@ -48,7 +48,6 @@ for which a new license (GPL+exception) is in place.
 #include "util_debug.h"
 #include "util_ghostscript.h"
 
-
 //extern ScribusQApp* ScQApp;
 
 ScribusCore::ScribusCore() : defaultEngine(colorMgmtEngineFactory.createDefaultEngine()),
@@ -63,11 +62,13 @@ ScribusCore::ScribusCore() : defaultEngine(colorMgmtEngineFactory.createDefaultE
 
 ScribusCore::~ScribusCore()
 {
+
 	while (m_ScMWList.count() > 0)
 	{
 		ScribusMainWindow *mainWindow = m_ScMWList.takeAt(0);
 		delete mainWindow;
 	}
+
 	delete pluginManager;
 }
 
@@ -75,8 +76,8 @@ ScribusCore::~ScribusCore()
 static void abort_on_error(QtMsgType t, const QMessageLogContext&, const QString & m)
 {
 	std::cerr << m.toLocal8Bit().data() << "\n";
-	if (t == QtFatalMsg) assert(false);
-//	if (t != QtDebugMsg) assert(false);
+	if(t == QtFatalMsg) assert(false);
+//	if(t != QtDebugMsg) assert(false);
 }
 #endif
 
@@ -95,16 +96,16 @@ int ScribusCore::startGUI(bool showSplash, bool showFontInfo, bool showProfileIn
 	auto* scribus = new ScribusMainWindow();
 	Q_CHECK_PTR(scribus);
 	if (!scribus)
-		return(EXIT_FAILURE);
+		return EXIT_FAILURE;
 	m_ScMWList.append(scribus);
 	int retVal = initScribusCore(showSplash, showFontInfo, showProfileInfo, newGuiLanguage);
 	if (retVal == EXIT_FAILURE)
-		return(EXIT_FAILURE);
-	
+		return EXIT_FAILURE;
+
 	retVal = scribus->initScMW(true);
 	if (retVal == EXIT_FAILURE)
-		return(EXIT_FAILURE);
-	
+		return EXIT_FAILURE;
+
 	closeSplash();
 	m_scribusInitialized = true;
 	connect(ScQApp, SIGNAL(lastWindowClosed()), ScQApp, SLOT(quit()));
@@ -141,6 +142,7 @@ int ScribusCore::startGUI(bool showSplash, bool showFontInfo, bool showProfileIn
 	{
 		scribus->slotRaiseOnlineHelp();
 	}
+
 	return EXIT_SUCCESS;
 }
 
@@ -162,7 +164,7 @@ int ScribusCore::initScribusCore(bool showSplash, bool showFontInfo, bool showPr
 	if (!haveFonts)
 		return EXIT_FAILURE;
 	m_prefsManager.initDefaults();
-	m_prefsManager.initDefaultGUIFont(qApp->font());
+	m_prefsManager.initDefaultGUIFont(QApplication::font());
 	m_prefsManager.initArrowStyles();
 	m_undoManager = UndoManager::instance();
 	fileWatcher = new FileWatcher(this);
@@ -230,9 +232,9 @@ void ScribusCore::initSplash(bool showSplash)
 	if (!showSplash)
 		return;
 
-	QScreen* primaryScreeen = qApp->primaryScreen();
+	QScreen* primaryScreeen = QApplication::primaryScreen();
 	double pixelRatio = primaryScreeen ? primaryScreeen->devicePixelRatio() : 1.0;
-	QPixmap pix = IconManager::instance().loadPixmap("scribus_splash.png", true);
+	QPixmap pix = IconManager::instance().splashScreen();
 	if (pixelRatio != 1.0)
 	{
 		int w = qRound(pix.width() * pixelRatio);
@@ -243,7 +245,7 @@ void ScribusCore::initSplash(bool showSplash)
 		pix.setDevicePixelRatio(pixelRatio);
 	}
 
-	m_SplashScreen = new ScSplashScreen(pix, Qt::WindowStaysOnTopHint);
+	m_SplashScreen = new ScSplashScreen(pix, IconManager::instance().splashScreenRect(), Qt::WindowStaysOnTopHint);
 	if (m_SplashScreen != nullptr)
 	{
 		m_SplashScreen->show();
