@@ -22,6 +22,7 @@ for which a new license (GPL+exception) is in place.
  ***************************************************************************/
 #ifndef SCRIBUSDOC_H
 #define SCRIBUSDOC_H
+#include "plugins/formatidlist.h"
 #ifdef HAVE_CONFIG_H
 #include "scconfig.h"
 #endif
@@ -48,6 +49,7 @@ for which a new license (GPL+exception) is in place.
 #include "nodeeditcontext.h"
 #include "notesstyles.h"
 #include "observable.h"
+#include "opticalmarginlookup.h"
 #include "pageitem.h"
 #include "pageitem_group.h"
 #include "pageitem_latexframe.h"
@@ -115,7 +117,7 @@ public:
 	 * @brief Return the view associated with the document
 	 */
 	ScribusView* view() const;
-	ScribusMainWindow* scMW() const {return m_ScMW;}
+	ScribusMainWindow* scMW() const { return m_ScMW; }
 	void setGUI(bool hasgui, ScribusMainWindow* mw, ScribusView* view);
 	void createHyphenator();
 
@@ -148,7 +150,7 @@ public:
 	void setPageSetFirstPage(int layout, int fp);
 	void clearPageSets() { m_docPrefsData.pageSets.clear(); }
 	void appendToPageSets(const PageSet& ps) { m_docPrefsData.pageSets.append(ps); }
-	void setPaperColor(const QColor &c) { m_docPrefsData.displayPrefs.paperColor = c; }
+	void setPaperColor(const QColor& c) { m_docPrefsData.displayPrefs.paperColor = c; }
 	const QColor& paperColor() const { return m_docPrefsData.displayPrefs.paperColor; }
 	bool hyphAutomatic() const { return m_docPrefsData.hyphPrefs.Automatic; }
 	bool hyphAutoCheck() const { return m_docPrefsData.hyphPrefs.AutoCheck; }
@@ -177,10 +179,19 @@ public:
 	void clearItemAttributes() { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.clear(); }
 	void appendToItemAttributes(const ObjectAttribute& oa) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.append(oa); }
 
+	IndexSetupVector& indexSetups() { return m_docPrefsData.indexPrefs.defaultIndexSetup; }
+	void setIndexSetups(IndexSetupVector& isv) { m_docPrefsData.indexPrefs.defaultIndexSetup = isv; }
+	void clearIndexSetups() { m_docPrefsData.indexPrefs.defaultIndexSetup.clear(); }
+	void appendToIndexSetups(const IndexSetup& is) { m_docPrefsData.indexPrefs.defaultIndexSetup.append(is); }
+	bool hasIndexSetup() { return !m_docPrefsData.indexPrefs.defaultIndexSetup.empty(); }
+
+
 	ToCSetupVector& tocSetups() { return m_docPrefsData.tocPrefs.defaultToCSetups; }
 	void setTocSetups(ToCSetupVector& tsv) { m_docPrefsData.tocPrefs.defaultToCSetups = tsv; }
 	void clearTocSetups() { m_docPrefsData.tocPrefs.defaultToCSetups.clear(); }
 	void appendToTocSetups(const ToCSetup& ts) { m_docPrefsData.tocPrefs.defaultToCSetups.append(ts); }
+	/*! \brief Does this doc have any TOC setups and potentially a TOC to generate */
+	bool hasTOCSetup() { return !m_docPrefsData.tocPrefs.defaultToCSetups.empty(); }
 
 	void setArrowStyles(QList<ArrowDesc>& as) { m_docPrefsData.arrowStyles = as; }
 	QList<ArrowDesc>& arrowStyles() { return m_docPrefsData.arrowStyles; }
@@ -216,6 +227,9 @@ public:
 	int marginPreset() const { return m_docPrefsData.docSetupPrefs.marginPreset; }
 	void setMarginPreset(int mp) { m_docPrefsData.docSetupPrefs.marginPreset = mp; }
 
+	const OpticalMarginSets& opticalMarginSets() const { return m_docPrefsData.typoPrefs.opticalMarginSets; }
+	void setOpticalMarginSets(const OpticalMarginSets& sets) { m_docPrefsData.typoPrefs.opticalMarginSets = sets; }
+
 	TypoPrefs& typographicPrefs() { return m_docPrefsData.typoPrefs; }
 	GuidesPrefs& guidesPrefs() { return m_docPrefsData.guidesPrefs; }
 	ItemToolPrefs& itemToolPrefs() { return m_docPrefsData.itemToolPrefs; }
@@ -229,7 +243,7 @@ public:
 	void setSections(DocumentSectionMap dsm) { m_docPrefsData.docSectionMap = std::move(dsm); }
 	const QMap<QString, int> & usedFonts() const { return UsedFonts; }
 
-	const ApplicationPrefs& prefsData() { return m_docPrefsData; }
+	const ApplicationPrefs& prefsData() const { return m_docPrefsData; }
 	void setNewPrefs(const ApplicationPrefs& prefsData, const ApplicationPrefs& oldPrefsData, bool resizePages, bool resizeMasterPages, bool resizePageMargins, bool resizeMasterPageMargins);
 
 	// Add, delete and move pages
@@ -801,7 +815,7 @@ public:
 	/**
 	 * @brief Save function
 	 */
-	bool save(const QString& fileName, QString* savedFile = nullptr);
+	bool save(const QString& fileName, QString* savedFile = nullptr, uint formatID = FORMATID_CURRENTEXPORT);
 	/**
 	 * @brief Set the page margins. Current code uses current page only, also provide a (currently, TODO) option for this.
 	 */
@@ -1062,7 +1076,7 @@ public:
 	void removePageFromAnnotLinks(int pageIndex);
 
 	//! @brief Some internal align tools
-	enum AlignTo { alignFirst, alignLast, alignPage, alignMargins, alignGuide, alignSelection };
+	enum AlignTo {alignFirst, alignLast, alignPage, alignMargins, alignGuide, alignSelection } ;
 	enum AlignMethod { alignByMoving, alignByResizing };
 	void buildAlignItemList(Selection* customSelection = nullptr);
 	bool startAlign(uint minObjects = 1);
@@ -1146,13 +1160,13 @@ public:
 	void itemSelection_SetUnderline(int pos, int wid, Selection* customSelection = nullptr);
 	void itemSelection_SetStrikethru(int pos, int wid, Selection* customSelection = nullptr);
 	void itemSelection_SetEffects(int s, Selection* customSelection = nullptr);
-	void itemSelection_SetOpticalMargins(int i, Selection* customSelection = nullptr);
-	void itemSelection_resetOpticalMargins(Selection* customSelection = nullptr);
+	void itemSelection_SetOpticalMargins(int i, const QString& id, Selection* customSelection = nullptr);
 	void itemSelection_SetColorProfile(const QString& profileName, Selection* customSelection = nullptr);
 	void itemSelection_SetRenderIntent(int intentIndex, Selection* customSelection = nullptr);
 	void itemSelection_SetCompressionMethod(int cmIndex, Selection* customSelection = nullptr);
 	void itemSelection_SetCompressionQuality(int cqIndex, Selection* customSelection = nullptr);
-	void itemSelection_SetTracking(int us, Selection* customSelection = nullptr);
+	void itemSelection_SetTracking(double us, Selection* customSelection = nullptr);
+	void itemSelection_SetWordTracking(double us, Selection* customSelection = nullptr);
 	void MirrorPolyH(PageItem *currItem);
 	void MirrorPolyV(PageItem *currItem);
 	bool getItem(PageItem **currItem, int nr = -1);
@@ -1215,6 +1229,7 @@ public:
 	 * certain operations.
 	 */
 	void changed();
+	void changedPagePreview();
 	/*! \brief Get pointer to the current page
 	\retval Page* current page object */
 	ScPage* currentPage();
@@ -1228,8 +1243,7 @@ public:
 	FPoint ApplyGridF(const FPoint& in);
 	/*! \brief Apply grid to an QRectF, from ScribusView */
 	QRectF ApplyGridF(const QRectF& in);
-	/*! \brief Does this doc have any TOC setups and potentially a TOC to generate */
-	bool hasTOCSetup() { return !m_docPrefsData.tocPrefs.defaultToCSetups.empty(); }
+
 
 	enum SelectionSkipBehavior
 	{
@@ -1269,9 +1283,9 @@ public:
 	bool textCanvasPosition(PageItem* item, int textPos, QPointF& canvasPos);
 
 	//! \brief Get rotation mode
-	int rotationMode() const {return m_rotMode;}
+	AnchorPoint rotationMode() const {return m_rotMode;}
 	//! \brief Set rotation mode
-	void setRotationMode(int val);
+	void setRotationMode(AnchorPoint val);
 
 	//! \brief Functions which avoid doc updater and update manager to send too much
 	// unnecessary signals when doing updates on multiple items
@@ -1298,7 +1312,7 @@ protected:
 	int  m_undoRedoOngoing {0};
 	int m_ActiveLayer {0};
 	double m_docUnitRatio;
-	int m_rotMode {0};
+	AnchorPoint m_rotMode {AnchorPoint::TopLeft};
 	bool m_automaticTextFrames; // Flag for automatic Textframes
 	bool m_masterPageMode {false};
 	bool m_symbolEditMode {false};
@@ -1452,7 +1466,8 @@ public:
 	QWidget* WinHan {nullptr};
 	bool DoDrawing {true};
 	bool drawAsPreview {false};
-	bool viewAsPreview {false};
+	bool viewAsPreview {false};	
+	bool whiteSpaceModeEnabled {false};
 	bool editOnPreview {false};
 	int previewVisual {0};
 	struct OpenNodesList
@@ -1494,8 +1509,9 @@ signals:
 	 * @brief Let the document tell whatever is listening that it has changed
 	 */
 	void docChanged();
-	void updateContents();
-	void updateContents(const QRect &r);
+	void pagePreviewChanged();
+//	void updateContents();
+//	void updateContents(const QRect &r);
 	void firstSelectedItemType(int);
 
 	void updateEditItem();
@@ -1511,7 +1527,7 @@ public slots:
 	void itemSelection_TogglePrintEnabled();
 	void itemSelection_ToggleBookMark(Selection* customSelection = nullptr);
 	void itemSelection_ToggleAnnotation(Selection* customSelection = nullptr);
-	void itemSelection_Transform(int nrOfCopies, const QTransform& matrix, int basepoint);
+	void itemSelection_Transform(int nrOfCopies, const QTransform& matrix, AnchorPoint basepoint);
 	void itemSelection_ChangePreviewResolution(int id);
 
 	/*! \brief Change display quality of all images in document.
@@ -1612,6 +1628,7 @@ public slots:
 	void itemSelection_SetItemGradFill(int typp, Selection* customSelection = nullptr);
 	void itemSelection_SetItemPatternFill(const QString& pattern, Selection* customSelection = nullptr);
 	void itemSelection_SetItemPatternProps(double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY);
+	void itemSelection_SetItemHatchFill(int mode, double distance, double angle, bool useBackground, const QString& background, const QString& foreground, Selection* customSelection = nullptr);
 	void itemSelection_SetItemStrokePattern(const QString& pattern, Selection* customSelection = nullptr);
 	void itemSelection_SetItemStrokePatternProps(double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, double space, bool mirrorX, bool mirrorY, Selection* customSelection = nullptr);
 	void itemSelection_SetItemStrokePatternType(bool type, Selection* customSelection = nullptr);
@@ -1820,7 +1837,7 @@ public:
 	PageItem_NoteFrame* createNoteFrame(PageItem_TextFrame* inFrame, NotesStyle *nStyle, int index = -1);
 	PageItem_NoteFrame* createNoteFrame(NotesStyle *nStyle, double x, double y, double w, double h, double w2, const QString& fill, const QString& outline);
 	//delete noteframe
-	void delNoteFrame(PageItem_NoteFrame *noteFrame, bool removeMarks = true, bool forceDeletion = true);
+	void delNoteFrame(PageItem_NoteFrame* noteFrame, bool removeMarks = true, bool forceDeletion = true);
 	//renumber notes for given notes style
 	//return true if doc needs update after changing numbers of notes
 	bool updateNotesNums(NotesStyle* nStyle);
@@ -1855,12 +1872,12 @@ public:
 
 	//finds item which holds given mark, start searching from next to lastItem index in DocItems
 	PageItem* findMarkItem(const Mark* mrk, PageItem* &lastItem) const;
-	
+	PageItem* findFirstMarkItem(const Mark* mrk) const { PageItem* tmp = nullptr; return findMarkItem(mrk, tmp); }
+
 private:
 	//QMap<PageItem_NoteFrame*, QList<TextNote *> > map of notesframes and its list of notes
 	NotesInFrameMap m_docNotesInFrameMap;
 
-	PageItem* findFirstMarkItem(const Mark* mrk) const { PageItem* tmp = nullptr; return findMarkItem(mrk, tmp); }
 
 	//search for endnotesframe for given notes style and item holding master mark or section number
 	PageItem_NoteFrame* endNoteFrame(const NotesStyle* nStyle, void* item = nullptr);
