@@ -151,7 +151,7 @@ public:
 	bool Magnify { false };
 	bool storedFramesShown { false };
 	bool storedShowControls { false };
-	int editStrokeGradient { 0 };
+	GradientEdit editStrokeGradient { GradientEdit::Gradient };
 	bool m_AnnotChanged { false };
 	bool m_EditModeWasOn { false };
 	bool m_ChangedState { false };
@@ -173,8 +173,10 @@ public:
 	void showInlinePage(int id);
 	void hideInlinePage();
 
+	QMap<int, QImage> PagesToPixmap(int maxGr, int Nr = -1, PageToPixmapFlags flags = Pixmap_DrawFrame | Pixmap_DrawBackground);
 	QImage PageToPixmap(int Nr, int maxGr, PageToPixmapFlags flags = Pixmap_DrawFrame | Pixmap_DrawBackground);
 	QImage MPageToPixmap(const QString& name, int maxGr, bool drawFrame = true);
+	QImage drawPageToPixmap(int maxGr, ScPage *page, PageToPixmapFlags flags = Pixmap_DrawFrame | Pixmap_DrawBackground);
 
 	/**
 	 * Called when the ruler origin is dragged
@@ -250,6 +252,7 @@ public slots: // Public slots
 	void toggleCMS(bool cmsOn);
 	void switchPreviewVisual(int vis);
 	void togglePreviewEdit(bool edit);
+	void toggleWhiteSpaceMode(bool inReview);
 	void togglePreview(bool inPreview);
 	void unitChange();
 	void setRulersShown(bool isShown);
@@ -284,7 +287,7 @@ private:
 	int m_previousMode { -1 };
 	QMenu *pmen3 { nullptr };
 	QMenu *pmenResolution { nullptr };
-	QPoint m_pressLocation;
+	QPointF m_pressLocation;
 	QElapsedTimer m_moveTimer;
 	QTimer *m_dragTimer { nullptr };
 	bool m_dragTimerFired { false };
@@ -320,10 +323,10 @@ public:
 	void inputMethodEvent(QInputMethodEvent * event) override;
 	QVariant inputMethodQuery(Qt::InputMethodQuery query) const override;
 	
-	inline void registerMousePress(QPoint p);
+	inline void registerMousePress(QPointF p);
 	bool mousePressed() const;
 	void resetMousePressed();
-	inline QPoint mousePressLocation() const;
+	inline QPointF mousePressLocation() const;
 	inline bool moveTimerElapsed();
 	inline void resetMoveTimer();
 	
@@ -336,7 +339,7 @@ public:
 	bool handleObjectImport(QMimeData* mimeData, TransactionSettings* trSettings = nullptr);
 
 protected: // Protected methods
-	void enterEvent(QEvent *) override;
+	void enterEvent(QEnterEvent *) override;
 	void leaveEvent(QEvent *) override;
 	void resizeEvent(QResizeEvent *event) override;
 	bool eventFilter(QObject *obj, QEvent *event) override;
@@ -373,14 +376,14 @@ signals:
 };
 
 
-inline void ScribusView::registerMousePress(QPoint p)
+inline void ScribusView::registerMousePress(QPointF p)
 {
 	m_pressLocation = p;
 	m_moveTimer.start();
 	m_dragTimerFired = false;
 }
 
-inline QPoint ScribusView::mousePressLocation() const
+inline QPointF ScribusView::mousePressLocation() const
 {
 	return m_pressLocation;
 }
