@@ -15,6 +15,7 @@ for which a new license (GPL+exception) is in place.
 class SCRIBUS_API ScXmlStreamAttributes : public QXmlStreamAttributes
 {
 public:
+
 	ScXmlStreamAttributes(void);
 	ScXmlStreamAttributes(const QXmlStreamAttributes& attrs);
 
@@ -35,11 +36,11 @@ public:
 class SCRIBUS_API ScXmlStreamReader : public QXmlStreamReader
 {
 public:
-	explicit ScXmlStreamReader(const QString& string) : QXmlStreamReader(string) {};
-	explicit ScXmlStreamReader(QIODevice* device) : QXmlStreamReader(device) {};
-
+	ScXmlStreamReader(const QString& string) : QXmlStreamReader(string) {};
+	ScXmlStreamReader(QIODevice* device) : QXmlStreamReader(device) {};
 	ScXmlStreamAttributes scAttributes(void) const;
 
+	QString nameAsString() const { return name().toString(); }
 	void readToElementEnd(void);
 };
 
