@@ -17,13 +17,18 @@ class SCRIBUS_API ScXmlStreamWriter : public QXmlStreamWriter
 {
 public:
 	ScXmlStreamWriter(void) : QXmlStreamWriter() {}
-	explicit ScXmlStreamWriter(QByteArray* array) : QXmlStreamWriter(array) {}
-	explicit ScXmlStreamWriter(QIODevice* device) : QXmlStreamWriter(device) {}
-	explicit ScXmlStreamWriter(QString*   string) : QXmlStreamWriter(string) {}
+	ScXmlStreamWriter(QByteArray* array) : QXmlStreamWriter(array) {}
+	ScXmlStreamWriter(QIODevice* device) : QXmlStreamWriter(device) {}
+	ScXmlStreamWriter(QString*   string) : QXmlStreamWriter(string) {}
 
 	void writeAttribute(const QString & name, const QString & value) { QXmlStreamWriter::writeAttribute(name, value); }
 	void writeAttribute(const QString & name, int value)    { QXmlStreamWriter::writeAttribute(name, QString::number(value)); }
+	void writeAttribute(const QString & name, qint64 value)    { QXmlStreamWriter::writeAttribute(name, QString::number(value)); }
 	void writeAttribute(const QString & name, uint value)   { QXmlStreamWriter::writeAttribute(name, QString::number(value)); }
+	void writeAttribute(const QString & name, quint64 value)   { QXmlStreamWriter::writeAttribute(name, QString::number(value)); }
+#if !defined(Q_OS_WIN) && (Q_PROCESSOR_WORDSIZE != 4)
+	void writeAttribute(const QString & name, size_t value)   { QXmlStreamWriter::writeAttribute(name, QString::number(value)); }
+#endif
 	void writeAttribute(const QString & name, double value) { QXmlStreamWriter::writeAttribute(name, QString::number(value, 'g', 15)); }
 };
 
