@@ -28,15 +28,12 @@ pageitem.cpp  -  description
 #include <QList>
 #include <cassert>  //added to make Fedora-5 happy
 
-#include "fpoint.h"
 #include "notesstyles.h"
-#include "scfonts.h"
 #include "scribusdoc.h"
 #include "sctext_shared.h"
 #include "selection.h"
 #include "storytext.h"
 #include "textnote.h"
-//
 #include "util.h"
 #include "resourcecollection.h"
 #include "desaxe/saxiohelper.h"
@@ -221,9 +218,9 @@ void StoryText::setCursorPosition(int pos, bool relative)
 		if (isLowSurrogate(pos) && isHighSurrogate(pos - 1))
 		{
 			if (forward)
-				pos += 1;
+				++pos;
 			else
-				pos -= 1;
+				--pos;
 		}
 	}
 	d->cursorPosition = qMin((uint) qMax(pos, 0), d->len);
@@ -302,14 +299,14 @@ void StoryText::moveCursorWordLeft()
 		if (pos != BreakIterator::DONE)
 		{
 			while (pos < length() && text(pos).isSpace())
-				pos += 1;
+				++pos;
 		}
 	}
 	else
 	{
 		pos = cursorPosition();
 		while (pos > 0 && text(pos - 1).isSpace())
-			pos -= 1;
+			--pos;
 		pos = it->preceding(pos);
 	}
 
@@ -332,7 +329,7 @@ void StoryText::moveCursorWordRight()
 	{
 		pos = cursorPosition();
 		while (pos > 0 && text(pos - 1).isSpace())
-			pos -= 1;
+			--pos;
 		pos = it->preceding(pos);
 	}
 	else
@@ -341,7 +338,7 @@ void StoryText::moveCursorWordRight()
 		if (pos != BreakIterator::DONE)
 		{
 			while (pos < length() && text(pos).isSpace())
-				pos += 1;
+				++pos;
 		}
 	}
 
@@ -524,7 +521,7 @@ void StoryText::insert(int pos, const StoryText& other, bool onlySelection)
 			//applyStyle(pos, otherDefault);
 			applyStyle(pos, other.paragraphStyle(i));
 			cstyleStart = i+1;
-			pos += 1;
+			++pos;
 		}
 		else if (other.text(i) == SpecialChars::OBJECT)
 		{
@@ -538,7 +535,7 @@ void StoryText::insert(int pos, const StoryText& other, bool onlySelection)
 			}
 			applyCharStyle(pos, 1, other.charStyle(i));
 			cstyleStart = i+1;
-			pos += 1;
+			++pos;
 		}
 		else
 		{
@@ -649,7 +646,7 @@ void StoryText::removeChars(int pos, uint len)
 		if (i < d->selFirst)
 			--d->selFirst;
 		if (static_cast<uint>(i + 1) <= d->cursorPosition && d->cursorPosition > 0)
-			d->cursorPosition -= 1;
+			d->cursorPosition--;
 	}
 
 	if (oldMarksCount != d->marksCount)
@@ -719,7 +716,7 @@ void StoryText::insertChars(int pos, const QString& txt, bool applyNeighbourStyl
 
 	for (int i = 0; i < txt.length(); ++i)
 	{
-		ScText * item = new ScText(clone);
+		ScText* item = new ScText(clone);
 		item->ch= txt.at(i);
 		item->setContext(cStyleContext);
 		d->insert(pos + i, item);
@@ -730,7 +727,7 @@ void StoryText::insertChars(int pos, const QString& txt, bool applyNeighbourStyl
 			insertParSep(pos + i);
 		}
 		if (d->cursorPosition >= static_cast<uint>(pos + i))
-			d->cursorPosition += 1;
+			d->cursorPosition++;
 	}
 
 	d->len = d->count();
@@ -788,7 +785,7 @@ void StoryText::insertCharsWithSoftHyphens(int pos, const QString& txt, bool app
 			if (item->ch == SpecialChars::PARSEP)
 				insertParSep(index);
 			if (d->cursorPosition >= static_cast<uint>(index))
-				d->cursorPosition += 1;
+				d->cursorPosition++;
 			++inserted;
 		}
 	}
@@ -1290,7 +1287,7 @@ LayoutFlags StoryText::flags(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	return static_cast<LayoutFlags>(d->at(pos)->effects().value & ScStyle_NonUserStyles);
+	return  static_cast<LayoutFlags>(d->at(pos)->effects().value & ScStyle_NonUserStyles);
 }
 
 bool StoryText::hasFlag(int pos, LayoutFlags flags) const
@@ -1664,7 +1661,7 @@ void StoryText::replaceNamedResources(ResourceCollection& newNames)
 	invalidate(0, len);	
 }
 
-void StoryText::replaceCharStyles(QMap<QString,QString> newNameForOld)
+void StoryText::replaceCharStyles(const QMap<QString,QString>& newNameForOld)
 {
 	ResourceCollection newnames;
 	newnames.mapCharStyles(newNameForOld);
@@ -1765,6 +1762,14 @@ int StoryText::startOfParagraph(uint index) const
 	return length();
 }
 
+int StoryText::startOfNextParagraph(uint index) const
+{
+	if (d->at(index)->ch == SpecialChars::PARSEP)
+		return index + 1;
+
+	return nextParagraph(index) + 1;
+}
+
 int StoryText::endOfParagraph() const
 {
 	return endOfParagraph(nrOfParagraph());
@@ -1918,7 +1923,7 @@ int StoryText::prevSentence(int pos)
 	return pos;
 }
 
-int StoryText::nextParagraph(int pos)
+int StoryText::nextParagraph(int pos) const
 {
 	int len = length();
 	pos = qMin(len, pos + 1);
@@ -1927,7 +1932,7 @@ int StoryText::nextParagraph(int pos)
 	return pos;
 }
 
-int StoryText::prevParagraph(int pos)
+int StoryText::prevParagraph(int pos) const
 {
 	pos = qMax(0, pos - 1);
 	while (pos > 0 && text(pos) != SpecialChars::PARSEP)
@@ -2090,9 +2095,9 @@ void StoryText::extendSelection(int oldPos, int newPos)
 void StoryText::fixSurrogateSelection()
 {
 	if (isLowSurrogate(d->selFirst) && isHighSurrogate(d->selFirst - 1))
-		d->selFirst -= 1;
+		d->selFirst--;
 	if (isHighSurrogate(d->selLast) && isLowSurrogate(d->selLast + 1))
-		d->selLast += 1;
+		d->selLast++;
 }
 
 BreakIterator* StoryText::m_graphemeIterator = nullptr;
@@ -2238,7 +2243,7 @@ ScText* StoryText::item(int index)
 const ScText* StoryText::item(int index) const
 {
 	assert( index < length() );
-	return d->at(index);
+	return this->d->at(index);
 }
 
 
@@ -2788,9 +2793,9 @@ public:
 		}
 	}
 private:
-	int lastPos { 0 };
-	int numPara { 0 };
-	ParagraphStyle* lastStyle { nullptr };
+	int lastPos {0};
+	int numPara {0};
+	ParagraphStyle* lastStyle {nullptr};
 };
 
 struct Paragraph : public MakeAction<Paragraph_body>
@@ -2841,8 +2846,8 @@ public:
 		}
 	}
 private:
-	int lastPos { 0 };
-	CharStyle* lastStyle { nullptr };
+	int lastPos {0};
+	CharStyle* lastStyle {nullptr};
 };
 
 struct SpanAction : public MakeAction<SpanAction_body>
