@@ -17,22 +17,25 @@
 
 struct TextLayoutColor
 {
-	QString color { "Black" };
-	double shade { 100.0 };
+	QString color;
+	double shade;
 
-	TextLayoutColor() = default;
+	TextLayoutColor()
+		: color("Black")
+		, shade(100)
+	{ }
 
-	TextLayoutColor(QString c, double s = 100.0)
+	TextLayoutColor(QString c, double s=100)
 		: color(c)
 		, shade(s)
 	{ }
 
-	bool operator==(const TextLayoutColor &other) const
+	bool operator ==(const TextLayoutColor &other) const
 	{
 		return other.color == color && other.shade == shade;
 	}
 
-	bool operator!=(const TextLayoutColor &other) const
+	bool operator !=(const TextLayoutColor &other) const
 	{
 		return !(*this == other);
 	}
@@ -49,7 +52,7 @@ class SCRIBUS_API TextLayoutPainter
 {
 public:
 	TextLayoutPainter();
-	virtual ~TextLayoutPainter() = default;
+	virtual ~TextLayoutPainter();
 
 	/// Sets the current font that will be used for all subsequent glyph
 	/// drawings.
@@ -78,6 +81,11 @@ public:
 	/// The current width for line strokes.
 	virtual double strokeWidth() const;
 
+	/// Sets the current render mode for glyph boxes only.
+	virtual void setGlyphBoxRendering(bool r);
+	/// The current render mode for glyph boxes only.
+	virtual bool glyphBoxRendering();
+
 	/// Moves the current x and y positions by the specified amount.
 	virtual void translate(double x, double y);
 	/// The current x positions.
@@ -133,19 +141,30 @@ private:
 	struct State
 	{
 		ScFace font;
-		double fontSize { 0.0 };
+		double fontSize;
 		TextLayoutColor strokeColor;
 		TextLayoutColor fillColor;
 		QTransform matrix;
-		double strokeWidth { 0.0 };
-		double x { 0.0 };
-		double y { 0.0 };
-		double scaleH { 1.0 };
-		double scaleV { 1.0 };
-		bool selected { false };
+		double strokeWidth;
+		double x;
+		double y;
+		double scaleH;
+		double scaleV;
+		bool selected;
+
+		State()
+			: fontSize(0)
+			, strokeWidth(0)
+			, x(0)
+			, y(0)
+			, scaleH(1)
+			, scaleV(1)
+			, selected(false)
+		{}
 	};
 
 	std::stack<State> m_stack;
+	bool m_glyphBoxRendering {false};
 };
 
 #endif // TEXTLAYOUTPAINTER_H
