@@ -1,5 +1,7 @@
 #include "textshaper.h"
 
+#include <utility>
+
 #include <harfbuzz/hb.h>
 #include <harfbuzz/hb-ft.h>
 #include <harfbuzz/hb-icu.h>
@@ -73,13 +75,13 @@ QList<TextShaper::TextRun> TextShaper::itemizeBiDi(int fromPos) const
 
 QList<TextShaper::TextRun> TextShaper::itemizeScripts(const QList<TextRun> &runs) const
 {
-	QList<TextRun> newRuns;
+	QList<TextRun> newRuns, subRuns;
 	ScriptRun scriptrun((const UChar*) m_text.utf16(), m_text.length());
 
 	for (TextRun run : runs)
 	{
 		int start = run.start;
-		QList<TextRun> subRuns;
+		subRuns.clear();
 
 		while (scriptrun.next())
 		{
@@ -134,12 +136,12 @@ QList<TextShaper::FeaturesRun> TextShaper::itemizeFeatures(const TextRun &run) c
 
 QList<TextShaper::TextRun> TextShaper::itemizeStyles(const QList<TextRun> &runs) const
 {
-	QList<TextRun> newRuns;
+	QList<TextRun> newRuns, subRuns;
 
 	for (TextRun run : runs)
 	{
 		int start = run.start;
-		QList<TextRun> subRuns;
+		subRuns.clear();
 
 		while (start < run.start + run.len)
 		{
@@ -291,7 +293,7 @@ ShapedText TextShaper::shape(int fromPos, int toPos)
 
 	// Insert implicit spaces in justification between characters
 	// in scripts that do not use spaces to separate words
-	for (const TextRun& run : qAsConst(scriptRuns))
+	for (const TextRun& run : std::as_const(scriptRuns))
 	{
 		switch (run.script) {
 		// clustered scripts from https://drafts.csswg.org/css-text-3/#script-groups
@@ -328,7 +330,7 @@ ShapedText TextShaper::shape(int fromPos, int toPos)
 		}
 	}
 
-	for (const TextRun& textRun : qAsConst(textRuns))
+	for (const TextRun& textRun : std::as_const(textRuns))
 	{
 		const CharStyle &style = m_story.charStyle(m_textMap.value(textRun.start));
 
