@@ -14,49 +14,44 @@ for which a new license (GPL+exception) is in place.
 #include "iconmanager.h"
 #include "scribusapp.h"
 
-AlignSelect::AlignSelect(QWidget* parent) : QWidget(parent)
+AlignSelect::AlignSelect(QWidget* parent) : FormWidget(parent)
 {
-	IconManager& im = IconManager::instance();
 	buttonGroup = new QButtonGroup(this);
 
-	GroupAlignLayout = new QHBoxLayout( this );
-	GroupAlignLayout->setSpacing(3);
-	GroupAlignLayout->setContentsMargins(0, 0, 0, 0);
-
 	TextL = new QToolButton( this );
-	TextL->setIcon(im.loadIcon("16/format-justify-left.png"));
 	TextL->setCheckable( true );
 	TextL->setChecked( true );
-	GroupAlignLayout->addWidget( TextL );
 	buttonGroup->addButton(TextL, 0);
 
 	TextC = new QToolButton( this );
-	TextC->setIcon(im.loadIcon("16/format-justify-center.png"));
 	TextC->setCheckable( true );
-	GroupAlignLayout->addWidget( TextC );
 	buttonGroup->addButton(TextC, 1);
 
 	TextR = new QToolButton( this );
-	TextR->setIcon(im.loadIcon("16/format-justify-right.png"));
 	TextR->setCheckable( true );
-	GroupAlignLayout->addWidget( TextR );
 	buttonGroup->addButton(TextR, 2);
 
 	TextB = new QToolButton( this );
-	TextB->setIcon(im.loadIcon("16/format-justify-fill-block.png"));
 	TextB->setCheckable( true );
-	GroupAlignLayout->addWidget( TextB );
 	buttonGroup->addButton(TextB, 3);
 
 	TextF = new QToolButton( this );
-	TextF->setIcon(im.loadIcon("16/format-justify-fill.png"));
 	TextF->setCheckable( true );
-	GroupAlignLayout->addWidget( TextF );
 	buttonGroup->addButton(TextF, 4);
+
+	addWidget(TextL);
+	addWidget(TextC);
+	addWidget(TextR);
+	addWidget(TextB);
+	addWidget(TextF);
+
+	iconSetChange();
+	languageChange();
+
 	resize(minimumSizeHint());
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
-	connect(buttonGroup, SIGNAL(buttonClicked(int)), this, SLOT(setTypeStyle(int)));
+	connect(buttonGroup, SIGNAL(idClicked(int)), this, SLOT(setTypeStyle(int)));
 }
 
 void AlignSelect::setStyle(int s, int d)
@@ -123,4 +118,5 @@ void AlignSelect::languageChange()
 	TextC->setToolTip( tr("Align Text Center"));
 	TextB->setToolTip( tr("Align Text Justified"));
 	TextF->setToolTip( tr("Align Text Forced Justified"));
+	setText( tr("&Horizontal"));
 }
