@@ -9,31 +9,32 @@ for which a new license (GPL+exception) is in place.
 #include <QCheckBox>
 #include <QComboBox>
 #include <QDateTime>
+#include <QDialogButtonBox>
 #include <QFrame>
+#include <QGridLayout>
 #include <QGroupBox>
 #include <QHBoxLayout>
-#include <QGridLayout>
-#include <QVBoxLayout>
 #include <QLabel>
 #include <QLineEdit>
 #include <QList>
 #include <QPixmap>
 #include <QPushButton>
+#include <QRadioButton>
+#include <QScopedPointer>
+#include <QSpacerItem>
 #include <QSpinBox>
+#include <QStackedWidget>
+#include <QStringList>
 #include <QTabWidget>
 #include <QTextEdit>
 #include <QToolTip>
-#include <QRadioButton>
-#include <QSpacerItem>
-#include <QStackedWidget>
-#include <QStringList>
+#include <QVBoxLayout>
 #include <QWidget>
 
 #include "annotation.h"
 #include "buttonicon.h"
 #include "cmsettings.h"
 #include "colorcombo.h"
-#include "colorlistbox.h"
 #include "commonstrings.h"
 #include "editor.h"
 #include "iconmanager.h"
@@ -42,9 +43,7 @@ for which a new license (GPL+exception) is in place.
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
-#include "scfonts.h"
 #include "scimage.h"
-#include "scribusstructs.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selfield.h"
@@ -396,22 +395,20 @@ ScAnnot::ScAnnot(QWidget* parent, PageItem *it, ScribusDoc* doc, ScribusView* vi
 	else
 		SetAnnotationType(m_annotation.Type()-2);
 
-	PushButton1->setDefault( true );
-
-	connect(PushButton1, SIGNAL(clicked()), this, SLOT(SetValues()));
-	connect(PushButton2, SIGNAL(clicked()), this, SLOT(reject()));
+	connect(buttonBox, &QDialogButtonBox::accepted, this, &ScAnnot::SetValues);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &ScAnnot::reject);
 	connect(EditFormat, SIGNAL(clicked()), this, SLOT(editFormatSc()));
 	connect(EditKeystr, SIGNAL(clicked()), this, SLOT(editKeySc()));
 	connect(EditValScript, SIGNAL(clicked()), this, SLOT(editValidSc()));
 	connect(EditCalc, SIGNAL(clicked()), this, SLOT(editCalcSc()));
 	connect(EditJ, SIGNAL(clicked()), this, SLOT(editJavaSc()));
 	connect(SeField, SIGNAL(clicked()), this, SLOT(SelectFelder()));
-	connect(Format0c, SIGNAL(activated(const QString&)), this, SLOT(setDateSample(const QString&)));
+	connect(Format0c, SIGNAL(textActivated(QString)), this, SLOT(setDateSample(QString)));
 	connect(TxFormat, SIGNAL(activated(int)), this, SLOT(SetFoScript(int)));
 	connect(ComboBox1, SIGNAL(activated(int)), this, SLOT(SetAnnotationType(int)));
 	connect(ActionCombo, SIGNAL(activated(int)), this, SLOT(SetActionType(int)));
 	connect(SelAction, SIGNAL(activated(int)), this, SLOT(SetActionScript(int)));
-	connect(m_navig, SIGNAL(Coords(double, double)), this, SLOT(SetCoords(double, double)));
+	connect(m_navig, SIGNAL(Coords(double,double)), this, SLOT(SetCoords(double,double)));
 	connect(SpinBox11, SIGNAL(valueChanged(int)), this, SLOT(SetPage(int)));
 	connect(SpinBox21, SIGNAL(valueChanged(int)), this, SLOT(SetCross()));
 	connect(SpinBox31, SIGNAL(valueChanged(int)), this, SLOT(SetCross()));
@@ -740,7 +737,7 @@ void ScAnnot::setDateSample(const QString& ds)
 void ScAnnot::DecodeVali()
 {
 	QString pfor = m_annotation.V_act();
-	int ss = pfor.indexOf("(");
+	qsizetype ss = pfor.indexOf("(");
 	QString pfo = pfor.mid(ss + 1, pfor.length() - ss - 2);
 	QStringList pfol;
 	pfol = pfo.split(",", Qt::SkipEmptyParts);
@@ -753,14 +750,14 @@ void ScAnnot::DecodeCalc()
 	QString tm;
 	QString tm2;
 	QString pfor = m_annotation.C_act();
-	int ss = pfor.lastIndexOf("(");
+	qsizetype ss = pfor.lastIndexOf("(");
 	QString pfo = pfor.mid(ss + 1, pfor.length() - ss - 3);
 	QStringList pfol = pfo.split(",", Qt::SkipEmptyParts);
 	if (pfol.count() > 1)
 	{
 		tm2 = pfol[0].simplified();
-		tm += tm2.midRef(1, tm2.length() - 2);
-		for (int cfx = 1; cfx < pfol.count(); ++cfx)
+		tm += tm2.mid(1, tm2.length() - 2);
+		for (qsizetype cfx = 1; cfx < pfol.count(); ++cfx)
 		{
 			tm2 = pfol[cfx].simplified();
 			tm += ", " + tm2.mid(1, tm2.length() - 2);
@@ -783,7 +780,7 @@ void ScAnnot::DecodeCalc()
 void ScAnnot::DecodeNum()
 {
 	QString pfor = m_annotation.F_act();
-	int ss = pfor.indexOf("(");
+	qsizetype ss = pfor.indexOf("(");
 	QString pfo = pfor.mid(ss + 1, pfor.length() - ss - 2);
 	QStringList pfol = pfo.split(",", Qt::SkipEmptyParts);
 	if (m_annotation.Format() == 1)
@@ -1053,11 +1050,11 @@ void ScAnnot::SetPage(int v)
 
 void ScAnnot::SetCross()
 {
-	disconnect(m_navig, SIGNAL(Coords(double, double)), this, SLOT(SetCoords(double, double)));
+	disconnect(m_navig, SIGNAL(Coords(double,double)), this, SLOT(SetCoords(double,double)));
 	int x = static_cast<int>(static_cast<double>(SpinBox21->value()) / static_cast<double>(Width) * m_navig->pmx.width());
 	int y = static_cast<int>(static_cast<double>(SpinBox31->value()) / static_cast<double>(Height) * m_navig->pmx.height());
 	m_navig->drawMark(x, y);
-	connect(m_navig, SIGNAL(Coords(double, double)), this, SLOT(SetCoords(double, double)));
+	connect(m_navig, SIGNAL(Coords(double,double)), this, SLOT(SetCoords(double,double)));
 }
 
 void ScAnnot::SetValues()
