@@ -87,7 +87,7 @@ CheckDocument::CheckDocument( QWidget* parent, bool modal )
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 
 	connect(ignoreErrors, SIGNAL(clicked()), this, SIGNAL(ignoreAllErrors()));
-	connect(curCheckProfile, SIGNAL(activated(const QString&)), this, SLOT(newScan(const QString&)));
+	connect(curCheckProfile, SIGNAL(textActivated(QString)), this, SLOT(newScan(QString)));
 	connect(reScan, SIGNAL(clicked()), this, SLOT(doReScan()));
 }
 
@@ -113,7 +113,7 @@ void CheckDocument::languageChange()
 	setWindowTitle( tr( "Preflight Verifier" ) );
 	QStringList headerLabels;
 	headerLabels << tr("Items") << tr("Problems")
-				 << tr("Layer");
+				 << tr("Layer");// << tr("Information");
 	reportDisplay->setHeaderLabels(headerLabels);
 	reportDisplay->setColumnCount(headerLabels.count());
 
@@ -407,7 +407,7 @@ void CheckDocument::buildItem(QTreeWidgetItem * item,
 void CheckDocument::buildErrorList(ScribusDoc *doc)
 {
 	m_Doc = doc;
-	disconnect(curCheckProfile, SIGNAL(activated(const QString&)), this, SLOT(newScan(const QString&)));
+	disconnect(curCheckProfile, SIGNAL(textActivated(QString)), this, SLOT(newScan(QString)));
 	curCheckProfile->clear();
 	clearErrorList();
 
@@ -711,7 +711,7 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 							itemMap.insert(errorText, freeItemsErrorsIt.key());
 							posMap.insert(object, it3.value());
 						}
-						object->setExpanded(true);
+						object->setExpanded( true );
 					}
 					if (pageGraveError)
 						object->setIcon(COLUMN_ITEM, graveError );
@@ -739,8 +739,8 @@ void CheckDocument::buildErrorList(ScribusDoc *doc)
 	reportDisplay->resizeColumnToContents(COLUMN_ITEM);
 	reportDisplay->resizeColumnToContents(COLUMN_PROBLEM);
 	reportDisplay->resizeColumnToContents(COLUMN_LAYER);
-	connect(curCheckProfile, SIGNAL(activated(const QString&)), this, SLOT(newScan(const QString&)));
-	connect(reportDisplay, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(slotSelect(QTreeWidgetItem*)));
+	connect(curCheckProfile, SIGNAL(textActivated(QString)), this, SLOT(newScan(QString)));
+	connect(reportDisplay, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(slotSelect(QTreeWidgetItem*)));
 }
 
 void CheckDocument::setIgnoreEnabled(bool state)
