@@ -62,15 +62,15 @@ CMYKChoose::CMYKChoose(QWidget* parent, ScribusDoc* doc, const ScColor& orig, co
 
 	CurrSwatch.clear();
 	alertIcon = IconManager::instance().loadPixmap("alert.png");
-	imageA.fill( ScColorEngine::getDisplayColor(orig, m_doc) );
-	if ( ScColorEngine::isOutOfGamut(orig, m_doc) )
-		paintAlert(alertIcon,imageA, 2, 2, false);
-	imageN.fill( ScColorEngine::getDisplayColor(orig, m_doc) );
-	if ( ScColorEngine::isOutOfGamut(orig, m_doc) )
-		paintAlert(alertIcon, imageN, 2, 2, false);
+	imageA.fill( ScColorEngine::getDisplayColor(orig, m_doc));
+	if ( ScColorEngine::isOutOfGamut(orig, m_doc))
+		paintAlert(alertIcon,imageA, 2, 2);
+	imageN.fill( ScColorEngine::getDisplayColor(orig, m_doc));
+	if ( ScColorEngine::isOutOfGamut(orig, m_doc))
+		paintAlert(alertIcon, imageN, 2, 2);
 
 	resize( 498, 306 );
-	setWindowTitle( tr( "Edit Color" ) );
+	setWindowTitle( tr( "Edit Color" ));
 	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
 
 	setupUi(this);
@@ -78,11 +78,11 @@ CMYKChoose::CMYKChoose(QWidget* parent, ScribusDoc* doc, const ScColor& orig, co
 	ColorName->setText(name);
 	ColorSwatch->setPixmapType(ColorListBox::fancyPixmap);
 	
-	ComboBox1->addItem( tr( "CMYK" ) );
-	ComboBox1->addItem( tr( "RGB" ) );
-	ComboBox1->addItem( tr( "Web Safe RGB" ) );
-	ComboBox1->addItem( tr( "Lab" ) );
-	ComboBox1->addItem( tr( "HLC" ) );
+	ComboBox1->addItem( tr( "CMYK" ));
+	ComboBox1->addItem( tr( "RGB" ));
+	ComboBox1->addItem( tr( "Web Safe RGB" ));
+	ComboBox1->addItem( tr( "Lab" ));
+	ComboBox1->addItem( tr( "HLC" ));
 
 	Separations->setChecked(orig.isSpotColor());
 
@@ -93,7 +93,7 @@ CMYKChoose::CMYKChoose(QWidget* parent, ScribusDoc* doc, const ScColor& orig, co
 	buttonOK->setDefault( true );
 	buttonCancel->setText(CommonStrings::tr_Cancel);
 
-	hsvSelector = Swatches->addTopLevelItem( tr( "Color Map" ) );
+	hsvSelector = Swatches->addTopLevelItem( tr( "Color Map" ));
 	hsvSelector->setFlags(Qt::ItemIsSelectable | Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
 	csm.findPaletteLocations();
 	systemSwatches = Swatches->addTopLevelItem( tr("Scribus Swatches"));
@@ -211,26 +211,26 @@ CMYKChoose::CMYKChoose(QWidget* parent, ScribusDoc* doc, const ScColor& orig, co
 	// signals and slots connections
 //	Regist->setToolTip( "<qt>" + tr( "Choosing this will enable printing this on all plates. Registration colors are used for printer marks such as crop marks, registration marks and the like. These are not typically used in the layout itself." ) + "</qt>");
 	Separations->setToolTip( "<qt>" + tr( "Choosing this will make this color a spot color, thus creating another spot when creating plates or separations. This is used most often when a logo or other color needs exact representation or cannot be replicated with CMYK inks. Metallic and fluorescent inks are good examples which cannot be easily replicated with CMYK inks." ) + "</qt>");
-	connect( buttonCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
-	connect( buttonOK, SIGNAL( clicked() ), this, SLOT( leave() ) );
-	connect( CyanSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( MagentaSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( YellowSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( BlackSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( CyanSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( MagentaSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( YellowSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( BlackSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( CyanSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( MagentaSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( YellowSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( BlackSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( ColorMap, SIGNAL( ColorVal(int, int, bool)), this, SLOT( setColor2(int, int, bool)));
-	connect( ComboBox1, SIGNAL(activated(const QString&)), this, SLOT(selModel(const QString&)));
-	connect(Swatches, SIGNAL(activated(const QString &)), this, SLOT(selSwatch()));
-	connect(ColorSwatch, SIGNAL(itemClicked(int) ), this, SLOT( selFromSwatch(int) ) );
+	connect( buttonCancel, SIGNAL(clicked()), this, SLOT(reject()));
+	connect( buttonOK, SIGNAL(clicked()), this, SLOT(leave()));
+	connect( CyanSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( MagentaSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( YellowSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( BlackSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( CyanSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( MagentaSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( YellowSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( BlackSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( CyanSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( MagentaSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( YellowSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( BlackSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( ColorMap, SIGNAL(ColorVal(int,int,bool)), this, SLOT(setColor2(int,int,bool)));
+	connect( ComboBox1, SIGNAL(textActivated(QString)), this, SLOT(selModel(QString)));
+	connect(Swatches, SIGNAL(activated(QString)), this, SLOT(selSwatch()));
+	connect(ColorSwatch, SIGNAL(itemClicked(int)), this, SLOT(selFromSwatch(int)));
 	connect(Separations, SIGNAL(clicked()), this, SLOT(setSpot()));
-	connect(this, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(slotRightClick()));
+	connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotRightClick()));
 	layout()->activate();
 }
 
@@ -271,10 +271,10 @@ void CMYKChoose::slotRightClick()
 
 void CMYKChoose::setValueS(int val)
 {
-	disconnect( CyanSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( MagentaSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( YellowSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( BlackSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
+	disconnect( CyanSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( MagentaSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( YellowSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( BlackSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
 	if (CyanSL == sender())
 		CyanSp->setValue(val / 1000.0);
 	if (MagentaSL == sender())
@@ -284,10 +284,10 @@ void CMYKChoose::setValueS(int val)
 	if (BlackSL == sender())
 		BlackSp->setValue(val / 1000.0);
 	setColor();
-	connect( CyanSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( MagentaSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( YellowSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( BlackSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
+	connect( CyanSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( MagentaSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( YellowSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( BlackSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
 }
 
 void CMYKChoose::toggleSL()
@@ -308,14 +308,14 @@ QPalette CMYKChoose::sliderPix(int farbe)
 	QPainter p;
 	p.begin(&image0);
 	p.setPen(Qt::NoPen);
-	int r, g, b, c, m, y, k;
+	int r, g, b, treeItem, m, y, k;
 	QColor tmp;
 	for (int x = 0; x < 255; x += 5)
 	{
 		if (Farbe.getColorModel() == colorModelCMYK)
 		{
 			ScColorEngine::getCMYKValues(Farbe, m_doc, cmyk);
-			cmyk.getValues(c, m, y, k);
+			cmyk.getValues(treeItem, m, y, k);
 			if (dynamic)
 			{
 				switch (farbe)
@@ -324,10 +324,10 @@ QPalette CMYKChoose::sliderPix(int farbe)
 					tmp = ScColorEngine::getDisplayColorGC(ScColor(x, m, y, k), m_doc);
 					break;
 				case 300:
-					tmp = ScColorEngine::getDisplayColorGC(ScColor(c, x, y, k), m_doc);
+					tmp = ScColorEngine::getDisplayColorGC(ScColor(treeItem, x, y, k), m_doc);
 					break;
 				case 60:
-					tmp = ScColorEngine::getDisplayColorGC(ScColor(c, m, x, k), m_doc);
+					tmp = ScColorEngine::getDisplayColorGC(ScColor(treeItem, m, x, k), m_doc);
 					break;
 				}
 				p.setBrush(tmp);
@@ -494,16 +494,16 @@ QPalette CMYKChoose::sliderBlack()
 	QPainter p;
 	p.begin(&image0);
 	p.setPen(Qt::NoPen);
-	int c, m, y, k;
+	int treeItem, m, y, k;
 	CMYKColor cmyk;
 	ScColorEngine::getCMYKValues(Farbe, m_doc, cmyk);
-	cmyk.getValues(c, m, y, k);
+	cmyk.getValues(treeItem, m, y, k);
 	for (int x = 0; x < 255; x += 5)
 	{
 		if (dynamic)
-			p.setBrush( ScColorEngine::getDisplayColorGC(ScColor(c, m, y, x), m_doc) );
+			p.setBrush( ScColorEngine::getDisplayColorGC(ScColor(treeItem, m, y, x), m_doc));
 		else
-			p.setBrush( ScColorEngine::getDisplayColorGC(ScColor(0, 0, 0, x), m_doc) );
+			p.setBrush( ScColorEngine::getDisplayColorGC(ScColor(0, 0, 0, x), m_doc));
 		p.drawRect(x, 0, 5, 10);
 	}
 	p.end();
@@ -514,7 +514,7 @@ QPalette CMYKChoose::sliderBlack()
 
 void CMYKChoose::selSwatch()
 {
-	const QTreeWidgetItem *treeItem = Swatches->currentItem();
+	const QTreeWidgetItem * treeItem = Swatches->currentItem();
 	if (treeItem == hsvSelector)
 	{
 		TabStack->setCurrentIndex(0);
@@ -572,18 +572,18 @@ void CMYKChoose::selModel(const QString& mod)
 {
 	int h, s, v;
 
-	disconnect( CyanSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( MagentaSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( YellowSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( BlackSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	disconnect( CyanSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	disconnect( MagentaSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	disconnect( YellowSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	disconnect( BlackSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	disconnect( CyanSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	disconnect( MagentaSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	disconnect( YellowSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	disconnect( BlackSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
+	disconnect( CyanSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( MagentaSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( YellowSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( BlackSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	disconnect( CyanSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	disconnect( MagentaSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	disconnect( YellowSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	disconnect( BlackSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	disconnect( CyanSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	disconnect( MagentaSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	disconnect( YellowSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	disconnect( BlackSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
 	isHLC = false;
 	if (mod == tr("CMYK"))
 	{
@@ -815,41 +815,41 @@ void CMYKChoose::selModel(const QString& mod)
 		ColorMap->drawPalette(L * 2.55);
 		ColorMap->setMark(a, b);
 	}
-	imageN.fill( ScColorEngine::getDisplayColor(Farbe, m_doc) );
+	imageN.fill( ScColorEngine::getDisplayColor(Farbe, m_doc));
 	if (ScColorEngine::isOutOfGamut(Farbe, m_doc))
-		paintAlert(alertIcon, imageN, 2, 2, false);
+		paintAlert(alertIcon, imageN, 2, 2);
 	NewC->setPixmap( imageN );
 	NewC->setToolTip( "<qt>" + tr( "If color management is enabled, an exclamation mark indicates that the color may be outside of the color gamut of the current printer profile selected. What this means is the color may not print exactly as indicated on screen. More hints about gamut warnings are in the online help under Color Management." ) + "</qt>");
 	OldC->setToolTip( "<qt>" + tr( "If color management is enabled, an exclamation mark indicates that the color may be outside of the color gamut of the current printer profile selected. What this means is the color may not print exactly as indicated on screen. More hints about gamut warnings are in the online help under Color Management." ) + "</qt>");
 
-	connect( CyanSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( MagentaSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( YellowSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( BlackSp, SIGNAL( valueChanged(double) ), this, SLOT( setValSLiders(double) ) );
-	connect( CyanSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( MagentaSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( YellowSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( BlackSL, SIGNAL( valueChanged(int) ), this, SLOT( setValueS(int) ) );
-	connect( CyanSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( MagentaSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( YellowSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
-	connect( BlackSL, SIGNAL( valueChanged(int) ), this, SLOT( setColor() ) );
+	connect( CyanSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( MagentaSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( YellowSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( BlackSp, SIGNAL(valueChanged(double)), this, SLOT(setValSLiders(double)));
+	connect( CyanSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( MagentaSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( YellowSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( BlackSL, SIGNAL(valueChanged(int)), this, SLOT(setValueS(int)));
+	connect( CyanSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( MagentaSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( YellowSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
+	connect( BlackSL, SIGNAL(valueChanged(int)), this, SLOT(setColor()));
 }
 
 void CMYKChoose::setColor()
 {
 	int    h, s, v;
-	double c, m, y;
+	double treeItem, m, y;
 	double k = 0;
 	double L, a, b;
 	ScColor tmp;
 	if (Farbe.getColorModel() == colorModelCMYK)
 	{
-		c = CyanSp->value() / 100.0;
+		treeItem = CyanSp->value() / 100.0;
 		m = MagentaSp->value() / 100.0;
 		y = YellowSp->value() / 100.0;
 		k = BlackSp->value() / 100.0;
-		tmp.setColorF(c, m, y, k);
+		tmp.setColorF(treeItem, m, y, k);
 		Farbe = tmp;
 		if (dynamic)
 		{
@@ -883,11 +883,11 @@ void CMYKChoose::setColor()
 			YellowSL->setValue(iy * 1000);
 			blockSignals(false);
 		}
-		c = ic / 255.0;
+		treeItem = ic / 255.0;
 		m = im / 255.0;
 		y = iy / 255.0;
 		k = ik / 255.0;
-		tmp.setRgbColorF(c, m, y);
+		tmp.setRgbColorF(treeItem, m, y);
 		QColor tmp2 = ScColorEngine::getRGBColor(tmp, m_doc);
 		tmp2.getHsv(&h, &s, &v);
 		BlackComp = 255 - v;
@@ -935,9 +935,9 @@ void CMYKChoose::setColor()
 			ColorMap->drawPalette(L * 2.55);
 		ColorMap->setMark(a, b);
 	}
-	imageN.fill(ScColorEngine::getDisplayColor(tmp, m_doc) );
-	if ( ScColorEngine::isOutOfGamut(tmp, m_doc) )
-		paintAlert(alertIcon, imageN, 2, 2, false);
+	imageN.fill(ScColorEngine::getDisplayColor(tmp, m_doc));
+	if ( ScColorEngine::isOutOfGamut(tmp, m_doc))
+		paintAlert(alertIcon, imageN, 2, 2);
 	NewC->setPixmap( imageN );
 }
 
@@ -967,9 +967,9 @@ void CMYKChoose::setColor2(int h, int s, bool ende)
 			tmp.setColorF(cmyk.c, cmyk.m, cmyk.y, cmyk.k);
 		}
 	}
-	imageN.fill( ScColorEngine::getDisplayColor(tmp, m_doc) );
+	imageN.fill( ScColorEngine::getDisplayColor(tmp, m_doc));
 	if (ScColorEngine::isOutOfGamut(tmp, m_doc))
-		paintAlert(alertIcon, imageN, 2, 2, false);
+		paintAlert(alertIcon, imageN, 2, 2);
 	NewC->setPixmap( imageN );
 	Farbe = tmp;
 	if (ende)
@@ -1005,9 +1005,9 @@ void CMYKChoose::selFromSwatch(int itemIndex)
 			selModel( tr("Lab"));
 		}
 	}
-	imageN.fill( ScColorEngine::getDisplayColor(tmp, m_doc) );
-	if ( ScColorEngine::isOutOfGamut(tmp, m_doc) )
-		paintAlert(alertIcon, imageN, 2, 2, false);
+	imageN.fill( ScColorEngine::getDisplayColor(tmp, m_doc));
+	if ( ScColorEngine::isOutOfGamut(tmp, m_doc))
+		paintAlert(alertIcon, imageN, 2, 2);
 	NewC->setPixmap( imageN );
 	Farbe = tmp;
 	setValues();
