@@ -63,7 +63,7 @@ for which a new license (GPL+exception) is in place.
 #include "undomanager.h"
 #include "units.h"
 #include "util.h"
-#include "util_math.h"
+
 
 ColorPalette::ColorPalette(QWidget* parent) : QWidget(parent)
 {
@@ -164,8 +164,8 @@ void ColorPalette::connectSignals()
 	connect(gradEditStroke, SIGNAL(gradientChanged()), this, SLOT(handleStrokeGradient()));
 	connect(gradientType  , SIGNAL(activated(int)), this, SLOT(slotGradType(int)));
 	connect(gradientTypeStroke , SIGNAL(activated(int)), this, SLOT(slotGradTypeStroke(int)));
-	connect(namedGradient , SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
-	connect(namedGradientStroke, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradientStroke(const QString &)));
+	connect(namedGradient , SIGNAL(currentTextChanged(QString)), this, SLOT(setNamedGradient(QString)));
+	connect(namedGradientStroke, SIGNAL(currentTextChanged(QString)), this, SLOT(setNamedGradientStroke(QString)));
 	connect(overPrintCombo     , SIGNAL(activated(int)), this, SIGNAL(NewOverprint(int)));
 	connect(patternBox         , SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPattern(QListWidgetItem*)));
 	connect(patternBoxStroke   , SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPatternS(QListWidgetItem*)));
@@ -224,8 +224,8 @@ void ColorPalette::disconnectSignals()
 	disconnect(gradEditStroke, SIGNAL(gradientChanged()), this, SLOT(handleStrokeGradient()));
 	disconnect(gradientType  , SIGNAL(activated(int)), this, SLOT(slotGradType(int)));
 	disconnect(gradientTypeStroke , SIGNAL(activated(int)), this, SLOT(slotGradTypeStroke(int)));
-	disconnect(namedGradient , SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
-	disconnect(namedGradientStroke, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradientStroke(const QString &)));
+	disconnect(namedGradient , SIGNAL(currentTextChanged(QString)), this, SLOT(setNamedGradient(QString)));
+	disconnect(namedGradientStroke, SIGNAL(currentTextChanged(QString)), this, SLOT(setNamedGradientStroke(QString)));
 	disconnect(overPrintCombo     , SIGNAL(activated(int)), this, SIGNAL(NewOverprint(int)));
 	disconnect(patternBox         , SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPattern(QListWidgetItem*)));
 	disconnect(patternBoxStroke   , SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPatternS(QListWidgetItem*)));
@@ -836,10 +836,10 @@ void ColorPalette::updatePatternList()
 	{
 		ScPattern sp = patternList->value(patK[a]);
 		QPixmap pm;
-		if (sp.getPattern().width() >= sp.getPattern().height())
-			pm = QPixmap::fromImage(sp.getPattern().scaledToWidth(48, Qt::SmoothTransformation));
+		if (sp.getPattern()->width() >= sp.getPattern()->height())
+			pm = QPixmap::fromImage(sp.getPattern()->scaledToWidth(48, Qt::SmoothTransformation));
 		else
-			pm = QPixmap::fromImage(sp.getPattern().scaledToHeight(48, Qt::SmoothTransformation));
+			pm = QPixmap::fromImage(sp.getPattern()->scaledToHeight(48, Qt::SmoothTransformation));
 		QPixmap pm2(48, 48);
 		pm2.fill(palette().color(QPalette::Base));
 		QPainter p;
