@@ -48,7 +48,6 @@ for which a new license (GPL+exception) is in place.
 #include "gradientaddedit.h"
 #include "iconmanager.h"
 #include "loadsaveplugin.h"
-#include "plugins/formatidlist.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
 #include "query.h"
@@ -70,7 +69,7 @@ for which a new license (GPL+exception) is in place.
 #include "util_color.h"
 #include "util_formats.h"
 
-ColorsAndFillsDialog::ColorsAndFillsDialog(QWidget* parent, QHash<QString, VGradient> *gradients, const ColorList& colorlist, const QString& docColSet, QHash<QString, ScPattern> *patterns, ScribusDoc *doc, ScribusMainWindow *scMW)
+ColorsAndFillsDialog::ColorsAndFillsDialog(QWidget* parent, QHash<QString, VGradient>* gradients, const ColorList& colorlist, const QString& docColSet, QHash<QString, ScPattern>* patterns, ScribusDoc* doc, ScribusMainWindow* scMW)
 	: ScDialog(parent, "ColorsAndFillsDialog"),
 	m_doc(doc),
 	mainWin(scMW),
@@ -173,7 +172,7 @@ ColorsAndFillsDialog::ColorsAndFillsDialog(QWidget* parent, QHash<QString, VGrad
 	connect(dataTree, SIGNAL(itemClicked(QTreeWidgetItem*, int)), this, SLOT(itemSelected(QTreeWidgetItem*)));
 	connect(dataTree, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), this, SLOT(selEditColor(QTreeWidgetItem*)));
 	connect(dataTree, SIGNAL(itemSelectionChanged()), this, SLOT(itemSelectionChanged()));
-	connect(dataTree, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(slotRightClick(QPoint)));
+	connect(dataTree, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotRightClick(QPoint)));
 	connect(newButton, SIGNAL(clicked()), this, SLOT(createNew()));
 	connect(editButton, SIGNAL(clicked()), this, SLOT(editColorItem()));
 	connect(duplicateButton, SIGNAL(clicked()), this, SLOT(duplicateColorItem()));
@@ -199,10 +198,10 @@ QTreeWidgetItem* ColorsAndFillsDialog::updatePatternList(const QString& addedNam
 	{
 		ScPattern sp = dialogPatterns.value(patK[i]);
 		QPixmap pm;
-		if (sp.getPattern()->width() >= sp.getPattern()->height())
-			pm = QPixmap::fromImage(sp.getPattern()->scaledToWidth(48, Qt::SmoothTransformation));
+		if (sp.getPattern().width() >= sp.getPattern().height())
+			pm = QPixmap::fromImage(sp.getPattern().scaledToWidth(48, Qt::SmoothTransformation));
 		else
-			pm = QPixmap::fromImage(sp.getPattern()->scaledToHeight(48, Qt::SmoothTransformation));
+			pm = QPixmap::fromImage(sp.getPattern().scaledToHeight(48, Qt::SmoothTransformation));
 		QPixmap pm2(48, 48);
 		pm2.fill(palette().color(QPalette::Base));
 		QPainter p;
@@ -1745,7 +1744,16 @@ void ColorsAndFillsDialog::loadScribusFormat(const QString& fileName)
 
 	QDomDocument docu("scridoc");
 	QTextStream ts(&f);
-	ts.setCodec("UTF-8");
+	ts.setEncoding(QStringConverter::Utf8);
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = docu.setContent(ts.readAll());
+	if (!parseResult)
+	{
+		f.close();
+		return;
+	}
+#else
 	QString errorMsg;
 	int errorLine = 0;
 	int errorColumn = 0;
@@ -1754,6 +1762,7 @@ void ColorsAndFillsDialog::loadScribusFormat(const QString& fileName)
 		f.close();
 		return;
 	}
+#endif
 	f.close();
 
 	QDomElement elem = docu.documentElement();
@@ -1938,7 +1947,7 @@ void ColorsAndFillsDialog::doSaveDefaults(const QString& name, bool changed)
 	filename.replace(" ", "_");
 	filename  = QDir::toNativeSeparators(ScPaths::userPaletteFilesDir(true)) + filename;
 	filename += ".xml";
-	const FileFormat *fmt = LoadSavePlugin::getFormatById(FORMATID_SLA150EXPORT);
+	const FileFormat *fmt = LoadSavePlugin::getFormatById(FORMATID_SLA170EXPORT);
 	if (fmt)
 	{
 		std::unique_ptr<ScribusDoc> s_doc(new ScribusDoc());
