@@ -26,7 +26,6 @@
 #include "appmodes.h"
 #include "canvas.h"
 #include "canvasmode.h"
-#include "pageitem_textframe.h"
 #include "scmimedata.h"
 #include "scraction.h"
 #include "scribus.h"
@@ -227,7 +226,7 @@ void ContextMenu::createMenuItems_Selection()
 				if (!currItem->isNoteFrame())
 				{
 					menuMark->addAction(m_ScMW->scrActions["insertMarkNote"]);
-				//	menuMark->addAction(m_AP->scrActions["insertMarkIndex"]);
+					menuMark->addAction(m_ScMW->scrActions["insertMarkIndex"]);
 				}
 				menuMark->addAction(m_ScMW->scrActions["insertMarkItem"]);
 				menuMark->addAction(m_ScMW->scrActions["insertMark2Mark"]);
@@ -494,7 +493,8 @@ void ContextMenu::createMenuItems_Selection()
 		menuEdit->addAction(m_ScMW->scrActions["editCut"]);
 	if (!(currItem->isSingleSel))
 		menuEdit->addAction(m_ScMW->scrActions["editCopy"]);
-	if (((m_doc->appMode == modeEdit && currItem->itemType() == PageItem::TextFrame) || (m_doc->appMode == modeEditTable && currItem->itemType() == PageItem::Table)) && (ScMimeData::clipboardHasScribusText()||ScMimeData::clipboardHasPlainText()) )
+	if (((m_doc->appMode == modeEdit && currItem->itemType() == PageItem::TextFrame) || (m_doc->appMode == modeEditTable && currItem->itemType() == PageItem::Table)) &&
+		(ScMimeData::clipboardHasScribusText() || ScMimeData::clipboardHasScribusElem() || ScMimeData::clipboardHasPlainText()))
 		menuEdit->addAction(m_ScMW->scrActions["editPaste"]);
 	if (!currItem->locked() && (m_doc->appMode != modeEdit)  && (m_doc->appMode != modeEditTable) && (!(currItem->isSingleSel)))
 		menuEdit->addAction(m_ScMW->scrActions["itemDelete"]);
