@@ -25,7 +25,6 @@ for which a new license (GPL+exception) is in place.
 #include <QApplication>
 #include <QCheckBox>
 #include <QComboBox>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QFileInfo>
 #include <QFrame>
@@ -37,6 +36,7 @@ for which a new license (GPL+exception) is in place.
 #include <QPixmap>
 #include <QPushButton>
 #include <QScreen>
+#include <QScreen>
 #include <QTextCodec>
 #include <QVBoxLayout>
 
@@ -54,7 +54,6 @@ for which a new license (GPL+exception) is in place.
 #include "scfilewidget.h"
 #include "scimage.h"
 #include "scpreview.h"
-#include "scribusstructs.h"
 #include "scslainforeader.h"
 #include "units.h"
 #include "util.h"
@@ -128,16 +127,16 @@ void FDialogPreview::updatePix()
 
 void FDialogPreview::genPreview(const QString& name)
 {
-	QPixmap pm;
-	QString Buffer;
-	updatePix();
 	if (name.isEmpty())
 		return;
 	QFileInfo fi(name);
 	if (fi.isDir())
 		return;
-	int w = pixmap()->width();
-	int h = pixmap()->height();
+	QPixmap pm;
+	QString Buffer;
+	updatePix();
+	int w = pixmap().width();
+	int h = pixmap().height();
 	bool mode = false;
 	QString ext = fi.suffix().toLower();
 	QString formatD(FormatsManager::instance()->extensionListForFormat(FormatsManager::IMAGESIMGFRAME, 1));
@@ -175,7 +174,7 @@ void FDialogPreview::genPreview(const QString& name)
 		QPainter p;
 		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
 		// Qt4 FIXME imho should be better
-		pm = *pixmap();
+		pm = pixmap();
 		p.begin(&pm);
 		p.fillRect(0, 0, w, h - 44, b);
 		p.fillRect(0, h - 44, w, 44, QColor(255, 255, 255));
@@ -191,7 +190,7 @@ void FDialogPreview::genPreview(const QString& name)
 		p.drawText(2, h - 5, tr("Colorspace:") + " " + cSpace);
 		p.end();
 		setPixmap(pm);
-		repaint();
+		update();
 	}
 	else if (allFormatsV.contains(ext.toUtf8()))
 	{
@@ -213,7 +212,7 @@ void FDialogPreview::genPreview(const QString& name)
 		im = im.scaled(w - 5, h - 21, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
 		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
-		pm = *pixmap();
+		pm = pixmap();
 		p.begin(&pm);
 		p.fillRect(0, 0, w, h - 21, b);
 		p.fillRect(0, h - 21, w, 21, QColor(255, 255, 255));
@@ -221,7 +220,7 @@ void FDialogPreview::genPreview(const QString& name)
 		p.drawText(2, h - 5, desc);
 		p.end();
 		setPixmap(pm);
-		repaint();
+		update();
 	}
 	else if (ext.toUtf8() == "sce")
 	{
@@ -237,7 +236,7 @@ void FDialogPreview::genPreview(const QString& name)
 		im = im.scaled(w - 5, h - 21, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
 		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
-		pm = *pixmap();
+		pm = pixmap();
 		p.begin(&pm);
 		p.fillRect(0, 0, w, h - 21, b);
 		p.fillRect(0, h - 21, w, 21, QColor(255, 255, 255));
@@ -246,7 +245,7 @@ void FDialogPreview::genPreview(const QString& name)
 		p.drawText(2, h - 5, desc);
 		p.end();
 		setPixmap(pm);
-		repaint();
+		update();
 	}
 	else
 	{
@@ -278,10 +277,10 @@ void FDialogPreview::genPreview(const QString& name)
 	}
 }
 
-CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString& caption, const QString& filter, int flags)
-			: QDialog(parent),
-	          m_optionFlags(flags),
-	          m_previewIsShown(true)
+CustomFDialog::CustomFDialog(QWidget *parent, const QString &wDir, const QString &caption, const QString &filter, int flags, fwContextFlags contextFlags)
+	: QDialog(parent),
+	m_optionFlags(flags),
+	m_previewIsShown(true)
 {
 	m_fileDialogPrefs = PrefsManager::instance().prefsFile->getContext("customfdialog", false);
 
@@ -294,7 +293,7 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	hboxLayout = new QHBoxLayout;
 	hboxLayout->setSpacing(6);
 	hboxLayout->setContentsMargins(0, 0, 0, 0);
-	fileDialog = new ScFileWidget(this);
+	fileDialog = new ScFileWidget(this, contextFlags);
 	fileDialog->setIconProvider(new ImIconProvider());
 	fileDialog->setNameFilter(filter);
 	fileDialog->selectNameFilter(filter);
@@ -352,7 +351,8 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 		QSpacerItem* spacer2 = new QSpacerItem( 2, 2, QSizePolicy::Expanding, QSizePolicy::Minimum );
 		Layout1C->addItem( spacer2 );
 		vboxLayout->addWidget(LayoutC);
-		fileDialog->setFileMode(QFileDialog::DirectoryOnly);
+		fileDialog->setFileMode(QFileDialog::Directory);
+		fileDialog->setOption(QFileDialog::ShowDirsOnly, true);
 		fileDialog->forceDoubleClickActivation(false);
 		filePreview->hide();
 		showPreview->setVisible(false);
@@ -382,7 +382,7 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 			if (flags & fdCompressFile)
 				vboxLayout->addWidget(Layout);
 		}
-		
+		fileDialog->setOption(QFileDialog::ShowDirsOnly, false);
 		if (saveZip != nullptr)
 			saveZip->setToolTip( "<qt>" + tr( "Compress the Scribus document on save" ) + "</qt>");
 		if (withFonts != nullptr)
@@ -481,8 +481,8 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	connect(okButton, SIGNAL(clicked()), this, SLOT(okClicked()));
 	connect(cancelButton, SIGNAL(clicked()), this, SLOT(reject()));
 	connect(showPreview, SIGNAL(clicked()), this, SLOT(togglePreview()));
-	connect(fileDialog, SIGNAL(currentChanged(const QString &)), this, SLOT(fileClicked(const QString &)));
-	connect(fileDialog, SIGNAL(filesSelected(const QStringList &)), this, SLOT(accept()));
+	connect(fileDialog, SIGNAL(currentChanged(QString)), this, SLOT(fileClicked(QString)));
+	connect(fileDialog, SIGNAL(filesSelected(QStringList)), this, SLOT(accept()));
 	connect(fileDialog, SIGNAL(accepted()), this, SLOT(accept()));
 	connect(fileDialog, SIGNAL(rejected()), this, SLOT(reject()));
 }
@@ -543,7 +543,7 @@ void CustomFDialog::okClicked()
 	if (selFile.isEmpty())
 		return;
 	QFileInfo fi(selFile);
-	if (fi.isDir() && (fileDialog->fileMode() != QFileDialog::DirectoryOnly))
+	if (fi.isDir() && (fileDialog->fileMode() != QFileDialog::Directory))
 		fileDialog->gotoSelectedDirectory();
 	else
 		accept();
@@ -565,9 +565,9 @@ void CustomFDialog::togglePreview()
 	filePreview->setVisible(!m_previewIsShown);
 	QCoreApplication::processEvents();
 	filePreview->setVisible(m_previewIsShown);
-	fileDialog->repaint();
+	fileDialog->update();
 	QCoreApplication::processEvents();
-	repaint();
+	update();
 }
 
 void CustomFDialog::setSelection(const QString& fileName)
@@ -595,25 +595,30 @@ void CustomFDialog::addWidgets(QWidget *widgets)
 	vboxLayout->addWidget(widgets);
 }
 
+QString CustomFDialog::selectedNameFilter()
+{
+	return fileDialog->selectedNameFilter();
+}
+
 void CustomFDialog::handleCompress()
 {
-	QString   fileName;
+	QString fileName;
 	QFileInfo tmp(selectedFile());
-	QString   fn(tmp.fileName());
+	QString fn(tmp.fileName());
 	QStringList fc = fn.split(".", Qt::KeepEmptyParts);
-	if (fc.count() > 0)
+	if (!fc.isEmpty())
 		fileName = fc.at(0);
-	for (int a = 1; a < fc.count(); a++)
+	for (int i = 1; i < fc.count(); i++)
 	{
-		if (fc.at(a).compare("sla", Qt::CaseInsensitive) == 0)
+		if (fc.at(i).compare("sla", Qt::CaseInsensitive) == 0)
 			continue;
-		if (fc.at(a).compare("gz", Qt::CaseInsensitive) == 0)
+		if (fc.at(i).compare("gz", Qt::CaseInsensitive) == 0)
 			continue;
-		if (fc.at(a).compare(m_ext, Qt::CaseInsensitive) == 0)
+		if (fc.at(i).compare(m_ext, Qt::CaseInsensitive) == 0)
 			continue;
-		if (fc.at(a).compare(m_extZip, Qt::CaseInsensitive) == 0)
+		if (fc.at(i).compare(m_extZip, Qt::CaseInsensitive) == 0)
 			continue;
-		fileName += "." + fc[a];
+		fileName += "." + fc[i];
 	}
 	if (saveZip->isChecked())
 		tmp.setFile(fileName + "." + m_extZip);
