@@ -6,7 +6,7 @@ for which a new license (GPL+exception) is in place.
 */
 /***************************************************************************
 *   Copyright (C) 2004 by Craig Bradney                                   *
-*   cbradney@zip.com.au                                                   *
+*   cbradney@scribus.info                                                   *
 *   Copyright (C) 2005 by Petr Vanek                                      *
 *   petr@yarpen.cz                                                        *
 *                                                                         *
@@ -50,6 +50,7 @@ for which a new license (GPL+exception) is in place.
 #include <QProcess>
 #include <QPushButton>
 #include <QString>
+#include <QStringView>
 #include <QStandardItem>
 #include <QTextEdit>
 #include <QTreeView>
@@ -58,10 +59,7 @@ for which a new license (GPL+exception) is in place.
 
 #include "prefsmanager.h"
 #include "scribuscore.h"
-#include "util_debug.h"
-#include "util_keyboard.h"
 #include "iconmanager.h"
-#include "util.h"
 
 /*! \brief XML parsed for documentation history.
 This is small helper class which reads saved bookmarks configuration
@@ -82,7 +80,7 @@ class HistoryParser2
 
 			QXmlStreamReader sReader(&qFile);
 			QXmlStreamReader::TokenType tagType;
-			QStringRef tagName;
+			QStringView tagName;
 
 			while (!sReader.atEnd() && !sReader.hasError())
 			{
@@ -91,7 +89,7 @@ class HistoryParser2
 					continue;
 
 				tagName = sReader.name();
-				if (tagName != "item")
+				if (tagName != QLatin1String("item"))
 					continue;
 
 				struct histd2 his;
@@ -127,7 +125,7 @@ class BookmarkParser2
 
 			QXmlStreamReader sReader(&qFile);
 			QXmlStreamReader::TokenType tagType;
-			QStringRef tagName;
+			QStringView tagName;
 
 			while (!sReader.atEnd() && !sReader.hasError())
 			{
@@ -136,7 +134,7 @@ class BookmarkParser2
 					continue;
 
 				tagName = sReader.name();
-				if (tagName != "item")
+				if (tagName != QLatin1String("item"))
 					continue;
 
 				QXmlStreamAttributes attrs = sReader.attributes();
@@ -211,7 +209,7 @@ void HelpBrowser::closeEvent(QCloseEvent * event)
 	if (bookFile.open(QIODevice::WriteOnly))
 	{
 		QTextStream stream(&bookFile);
-		stream.setCodec("UTF-8");
+		stream.setEncoding(QStringConverter::Utf8);
 		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 		stream << "<bookmarks>\n";
 		QTreeWidgetItemIterator it(helpNav->bookmarksView);
@@ -233,7 +231,7 @@ void HelpBrowser::closeEvent(QCloseEvent * event)
 	if (histFile.open(QIODevice::WriteOnly))
 	{
 		QTextStream stream(&histFile);
-		stream.setCodec("UTF-8");
+		stream.setEncoding(QStringConverter::Utf8);
 		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 		stream << "<history>\n";
 		for (auto it = m_history.cbegin() ; it != m_history.cend(); ++it)
@@ -260,28 +258,44 @@ void HelpBrowser::setupLocalUI()
 	histMenu = new QMenu(this);
 
 	//Add Menu items
-	filePrint = fileMenu->addAction(iconManager.loadIcon("16/document-print.png"), "", this, SLOT(print()), Qt::CTRL+Qt::Key_P);
+#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+	filePrint = fileMenu->addAction(iconManager.loadIcon("16/document-print.png"), "", Qt::CTRL|Qt::Key_P, this, &HelpBrowser::print);
 	fileMenu->addSeparator();
-	fileExit = fileMenu->addAction(iconManager.loadIcon("exit.png"), "", this, SLOT(close()), Qt::CTRL+Qt::Key_W);
-	editFind = editMenu->addAction(iconManager.loadIcon("find.png"), "", this, SLOT(find()), Qt::CTRL+Qt::Key_F);
-	editFindNext = editMenu->addAction( "", this, SLOT(findNext()), Qt::Key_F3);
-	editFindPrev = editMenu->addAction( "", this, SLOT(findPrevious()), Qt::SHIFT+Qt::Key_F3);
-	bookAdd = bookMenu->addAction( "", this, SLOT(bookmarkButton_clicked()), Qt::CTRL+Qt::Key_D);
-	bookDel = bookMenu->addAction( "", this, SLOT(deleteBookmarkButton_clicked()));
-	bookDelAll = bookMenu->addAction( "", this, SLOT(deleteAllBookmarkButton_clicked()));
+	fileExit = fileMenu->addAction(iconManager.loadIcon("exit.png"), "", Qt::CTRL|Qt::Key_W, this, &HelpBrowser::close);
+	editFind = editMenu->addAction(iconManager.loadIcon("find.png"), "", Qt::CTRL|Qt::Key_F, this, &HelpBrowser::find);
+	editFindNext = editMenu->addAction( "", Qt::Key_F3, this, &HelpBrowser::findNext);
+	editFindPrev = editMenu->addAction( "", Qt::SHIFT|Qt::Key_F3, this, &HelpBrowser::findPrevious);
+	bookAdd = bookMenu->addAction( "", Qt::CTRL|Qt::Key_D, this, &HelpBrowser::bookmarkButton_clicked);
+	bookDel = bookMenu->addAction( "", this, &HelpBrowser::deleteBookmarkButton_clicked);
+	bookDelAll = bookMenu->addAction( "", this, &HelpBrowser::deleteAllBookmarkButton_clicked);
+#else
+	filePrint = fileMenu->addAction(iconManager.loadIcon("16/document-print.png"), "", this, SLOT(print()), Qt::CTRL | Qt::Key_P);
+	fileMenu->addSeparator();
+	fileExit = fileMenu->addAction(iconManager.loadIcon("exit.png"), "", this, SLOT(close()), Qt::CTRL | Qt::Key_W);
+	editFind = editMenu->addAction(iconManager.loadIcon("find.png"), "", this, SLOT(find()), Qt::CTRL | Qt::Key_F);
+	editFindNext = editMenu->addAction("", this, SLOT(findNext()), Qt::Key_F3);
+	editFindPrev = editMenu->addAction("", this, SLOT(findPrevious()), Qt::SHIFT | Qt::Key_F3);
+	bookAdd = bookMenu->addAction("", this, SLOT(bookmarkButton_clicked()), Qt::CTRL | Qt::Key_D);
+	bookDel = bookMenu->addAction("", this, SLOT(deleteBookmarkButton_clicked()));
+	bookDelAll = bookMenu->addAction("", this, SLOT(deleteAllBookmarkButton_clicked()));
+#endif
 
 	//Add Toolbar items
+#if QT_VERSION >= QT_VERSION_CHECK(6, 3, 0)
+	goHome = toolBar->addAction(iconManager.loadIcon("16/go-home.png"), "", textBrowser, &ScTextBrowser::home);
+	goBack = toolBar->addAction(iconManager.loadIcon("16/go-previous.png"), "", textBrowser, &ScTextBrowser::backward);
+	goFwd = toolBar->addAction(iconManager.loadIcon("16/go-next.png"), "", textBrowser, &ScTextBrowser::forward);
+#else
 	goHome = toolBar->addAction(iconManager.loadIcon("16/go-home.png"), "", textBrowser, SLOT(home()));
 	goBack = toolBar->addAction(iconManager.loadIcon("16/go-previous.png"), "", textBrowser, SLOT(backward()));
 	goFwd = toolBar->addAction(iconManager.loadIcon("16/go-next.png"), "", textBrowser, SLOT(forward()));
+#endif
 	goBack->setMenu(histMenu);
 	
 	helpNav->listView->header()->hide();
 	helpNav->searchingView->header()->hide();
 	helpNav->bookmarksView->header()->hide();
 
-//	splitter->setStretchFactor(splitter->indexOf(tabWidget), 0);
-//	splitter->setStretchFactor(splitter->indexOf(textBrowser), 1);
 	// reset previous size
 	m_prefs = PrefsManager::instance().prefsFile->getPluginContext("helpbrowser");
 	int xsize = m_prefs->getUInt("xsize", 640);
@@ -291,28 +305,18 @@ void HelpBrowser::setupLocalUI()
 	//basic ui
 	connect(histMenu, SIGNAL(triggered(QAction*)), this, SLOT(histChosen(QAction*)));
 	// searching
-	connect(helpNav->searchingEdit, SIGNAL(returnPressed()), this, SLOT(searchingButton_clicked()));
-	connect(helpNav->searchingButton, SIGNAL(clicked()), this, SLOT(searchingButton_clicked()));
-	connect(helpNav->searchingView, SIGNAL(itemClicked( QTreeWidgetItem *, int)), this, SLOT(itemSearchSelected(QTreeWidgetItem *, int)));
+	connect(helpNav->searchingEdit, &QLineEdit::returnPressed, this, &HelpBrowser::searchingButton_clicked);
+	connect(helpNav->searchingButton, &QPushButton::clicked, this, &HelpBrowser::searchingButton_clicked);
+	connect(helpNav->searchingView, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(itemSearchSelected(QTreeWidgetItem*,int)));
 	// bookmarks
-	connect(helpNav->bookmarkButton, SIGNAL(clicked()), this, SLOT(bookmarkButton_clicked()));
-	connect(helpNav->deleteBookmarkButton, SIGNAL(clicked()), this, SLOT(deleteBookmarkButton_clicked()));
-	connect(helpNav->deleteAllBookmarkButton, SIGNAL(clicked()), this, SLOT(deleteAllBookmarkButton_clicked()));
-	connect(helpNav->bookmarksView, SIGNAL(itemClicked( QTreeWidgetItem *, int)), this, SLOT(itemBookmarkSelected(QTreeWidgetItem *, int)));
-	// links hoover
-//	connect(textBrowser, SIGNAL(overLink(const QString &)), this, SLOT(showLinkContents(const QString &)));
-
-	// status bar
-//	connect(textBrowser,SIGNAL(statusBarMessage(QString)), this->statusBar(), SLOT(showMessage(QString)));
+	connect(helpNav->bookmarkButton, &QPushButton::clicked, this, &HelpBrowser::bookmarkButton_clicked);
+	connect(helpNav->deleteBookmarkButton, &QPushButton::clicked, this, &HelpBrowser::deleteBookmarkButton_clicked);
+	connect(helpNav->deleteAllBookmarkButton, &QPushButton::clicked, this, &HelpBrowser::deleteAllBookmarkButton_clicked);
+	connect(helpNav->bookmarksView, SIGNAL(itemClicked(QTreeWidgetItem*,int)), this, SLOT(itemBookmarkSelected(QTreeWidgetItem*,int)));
 	
 	languageChange();
 }
 
-//void HelpBrowser::showLinkContents(const QString &link)
-//{
-//	statusBar()->showMessage(link);
-//}
-
 void HelpBrowser::addHistoryItem(const histd2& histItem)
 {
 	m_history[histMenu->addAction(histItem.title)] = histItem;
@@ -620,7 +624,7 @@ void HelpBrowser::loadMenu()
 	QString toLoad;
 	for (int i = 0; i < helpMenuFiles.count(); ++i)
 	{
-		auto helpPair = helpMenuFiles.at(i);
+		const auto& helpPair = helpMenuFiles.at(i);
 		QString helpFile = QDir::toNativeSeparators(helpPair.first + helpPair.second + "/menu.xml");
 		QFileInfo helpInfo(helpFile);
 		if (helpInfo.exists())
@@ -656,7 +660,7 @@ void HelpBrowser::loadMenu()
 		helpNav->listView->setSelectionMode(QAbstractItemView::SingleSelection);
 		QItemSelectionModel *selectionModel = new QItemSelectionModel(m_menuModel);
 		helpNav->listView->setSelectionModel(selectionModel);
-		connect(helpNav->listView->selectionModel(), SIGNAL(selectionChanged( const QItemSelection &, const QItemSelection &)), this, SLOT(itemSelected( const QItemSelection &, const QItemSelection &)));
+		connect(helpNav->listView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(itemSelected(QItemSelection,QItemSelection)));
 	
 		helpNav->listView->setColumnHidden(1,true);
 	}
@@ -763,7 +767,7 @@ QString HelpBrowser::historyFile() const
 
 void HelpBrowser::displayNoHelp()
 {
-	QString noHelpMsg = tr("<h2><p>Sorry, no manual is installed!</p><p>Please see:</p><ul><li>https://docs.scribus.net for updated documentation</li><li>http://www.scribus.net for downloads</li></ul></h2>",
+	QString noHelpMsg = tr("<h2><p>Sorry, no manual is installed!</p><p>Please see:</p><ul><li>https://docs.scribus.net for updated documentation</li><li>https://www.scribus.net for downloads</li></ul></h2>",
 						   "HTML message for no documentation available to show");
 
 	textBrowser->setHtml(noHelpMsg);
