@@ -157,7 +157,7 @@ void LatexEditor::extEditorClicked()
 	externalEditorPushButton->setEnabled(false);
 	externalEditorPushButton->setText(tr("Editor running!"));
 	
-	extEditor->start(full_command);
+	extEditor->startCommand(full_command);
 }
 
 void LatexEditor::writeExternalEditorFile()
@@ -168,16 +168,17 @@ void LatexEditor::writeExternalEditorFile()
 	//First create a temp file name
 	if (extEditorFile.isEmpty())
 	{
-		QTemporaryFile editorTempFile(QDir::tempPath() + "/scribus_temp_editor_XXXXXX");
-		if (!editorTempFile.open())
+		QTemporaryFile *editortempfile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_editor_XXXXXX");
+		if (!editortempfile->open())
 		{
 			ScMessageBox::critical(nullptr, tr("Error"), "<qt>" +
 				tr("Could not create a temporary file to run the external editor!")
 				+ "</qt>");
 		}
-		extEditorFile = getLongPathName(editorTempFile.fileName());
-		editorTempFile.setAutoRemove(false);
-		editorTempFile.close();
+		extEditorFile = getLongPathName(editortempfile->fileName());
+		editortempfile->setAutoRemove(false);
+		editortempfile->close();
+		delete editortempfile;
 		fileWatcher->addFile(extEditorFile);
 	}
 	QFile f(extEditorFile);
@@ -558,13 +559,13 @@ void LatexEditor::createNewItemsTab(I18nXmlStreamReader *xml)
 	iconList->setWrapping(true);
 	iconList->setResizeMode(QListView::Adjust);
 	
-	connect(iconList, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this, SLOT(newItemSelected(QListWidgetItem *, QListWidgetItem *)));
-	connect(iconList, SIGNAL(itemDoubleClicked (QListWidgetItem *)), this, SLOT(itemDoubleClicked(QListWidgetItem *)));
+	connect(iconList, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), this, SLOT(newItemSelected(QListWidgetItem*,QListWidgetItem*)));
+	connect(iconList, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(itemDoubleClicked(QListWidgetItem*)));
 	
 	QHBoxLayout *hLayout = new QHBoxLayout();
 	QLabel *statusLabel = new QLabel(tr("No item selected!"));
 	DataPushButton *insertPushButton = new DataPushButton( tr("Insert Symbol") , iconList);
-	connect(insertPushButton, SIGNAL(clickedWithData(QObject *)), this, SLOT(insertButtonClicked(QObject *)));
+	connect(insertPushButton, SIGNAL(clickedWithData(QObject*)), this, SLOT(insertButtonClicked(QObject*)));
 	hLayout->addWidget(statusLabel, 100);
 	hLayout->addWidget(insertPushButton, 0);
 	
@@ -846,7 +847,7 @@ XmlWidget* XmlWidget::fromXml(I18nXmlStreamReader *xml)
 		return new XmlFontComboBox(xml);
 	if (tagname == QStringView(u"spinbox"))
 	{
-		if (xml->attributes().value("type") == "double")
+		if (xml->attributes().value("type") == QStringView(u"double"))
 			return new XmlDoubleSpinBox(xml);
 		return new XmlSpinBox(xml);
 	}
@@ -854,7 +855,7 @@ XmlWidget* XmlWidget::fromXml(I18nXmlStreamReader *xml)
 		return new XmlColorPicker(xml);
 	if (tagname == QStringView(u"text"))
 	{
-		if (xml->attributes().value("type") == "long")
+		if (xml->attributes().value("type") == QStringView(u"long"))
 			return new XmlTextEdit(xml);
 		return new XmlLineEdit(xml);
 	}
