@@ -39,9 +39,10 @@ for which a new license (GPL+exception) is in place.
 #include "scribusdoc.h"
 #include "selection.h"
 #include "ui/scrspinbox.h"
+#include "docks/dock_panelbase.h"
 #include "undomanager.h"
 
-LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette(parent, "Layers", Qt::WindowFlags()), m_Doc(nullptr)
+LayerPalette::LayerPalette(QWidget* parent) : DockPanelBase("Layers", "panel-layers", parent)
 {
 	setObjectName(QString::fromLocal8Bit("Layers"));
 	setMinimumSize( QSize(220, 240) );
@@ -56,7 +57,7 @@ LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette(parent, "Layers", Qt
 	layout1->setSpacing(3);
 	textLabel1 = new QLabel( this);
 	layout1->addWidget( textLabel1 );
-	blendMode = new QComboBox( this);
+	blendMode = new ComboBlendMode( this);
 	layout1->addWidget( blendMode );
 	textLabel2 = new QLabel( this);
 	textLabel2->setText( tr( "Opacity:" ) );
@@ -172,7 +173,7 @@ LayerPalette::LayerPalette(QWidget* parent) : ScDockPalette(parent, "Layers", Qt
 
 void LayerPalette::installEventFilter(QObject *obj)
 {
-	ScDockPalette::installEventFilter(obj);
+	DockPanelBase::installEventFilter(obj);
 	Table->installEventFilter(obj);
 }
 
@@ -235,7 +236,7 @@ void LayerPalette::rebuildList()
 		int layerID = it->ID;
 		//TODO once "layers" is not set anymore, need to get layer number differently
 		int layerLevel = m_Doc->layerLevelFromID(layerID);
-		tmp = tmp.setNum(layerLevel);
+		tmp.setNum(layerLevel);
 		int row = layerCount-layerLevel - 1;
 		QToolButton *pb = new QToolButton(this);
 		pb->setObjectName(tmp);
@@ -394,6 +395,7 @@ void LayerPalette::upLayer()
 	m_Doc->scMW()->changeLayer(m_Doc->activeLayer());
 	emit LayerChanged();
 	m_Doc->changed();
+	m_Doc->changedPagePreview();
 }
 
 void LayerPalette::downLayer()
@@ -410,6 +412,7 @@ void LayerPalette::downLayer()
 	emit LayerChanged();
 	markActiveLayer();
 	m_Doc->changed();
+	m_Doc->changedPagePreview();
 }
 
 void LayerPalette::changeName(int row, int col)
@@ -582,6 +585,7 @@ void LayerPalette::markLayer()
 	int layerID = m_Doc->layerIDFromLevel(level);
 	if (layerID == -1)
 		return;
+
 	const QObject* senderBox = sender();
 	if (strcmp(senderBox->metaObject()->className(), "QToolButton") == 0)
 	{
@@ -685,7 +689,7 @@ void LayerPalette::changeEvent(QEvent *e)
 	if (e->type() == QEvent::LanguageChange)
 		languageChange();
 	else
-		ScDockPalette::changeEvent(e);
+		DockPanelBase::changeEvent(e);
 }
 
 void LayerPalette::iconSetChange()
@@ -710,29 +714,7 @@ void LayerPalette::languageChange()
 {
 	setWindowTitle( tr( "Layers" ) );
 	textLabel1->setText( tr( "Blend Mode:" ) );
-
-	int  oldBlendMode = blendMode->currentIndex();
-	QSignalBlocker signalBlocker(blendMode);
-	blendMode->clear();
-	blendMode->addItem( tr("Normal"));
-	blendMode->addItem( tr("Darken"));
-	blendMode->addItem( tr("Lighten"));
-	blendMode->addItem( tr("Multiply"));
-	blendMode->addItem( tr("Screen"));
-	blendMode->addItem( tr("Overlay"));
-	blendMode->addItem( tr("Hard Light"));
-	blendMode->addItem( tr("Soft Light"));
-	blendMode->addItem( tr("Difference"));
-	blendMode->addItem( tr("Exclusion"));
-	blendMode->addItem( tr("Color Dodge"));
-	blendMode->addItem( tr("Color Burn"));
-	blendMode->addItem( tr("Hue"));
-	blendMode->addItem( tr("Saturation"));
-	blendMode->addItem( tr("Color"));
-	blendMode->addItem( tr("Luminosity"));
-
-	blendMode->setCurrentIndex(oldBlendMode);
-
+	blendMode->languageChange();
 	textLabel2->setText( tr( "Opacity:" ) );
 	opacitySpinBox->setSuffix( tr(" %"));
 	Table->horizontalHeaderItem(7)->setText( tr("Name"));
