@@ -27,11 +27,11 @@ for which a new license (GPL+exception) is in place.
 #include "linkbutton.h"
 #include "iconmanager.h"
 #include "scribusapp.h"
-#include "scribuscore.h"
 
 LinkButton::LinkButton(QWidget *pa) : QToolButton(pa)
 {
 	setBackgroundRole(QPalette::Window);
+	setCheckable(true);
 	iconSetChange();
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
@@ -41,21 +41,8 @@ void LinkButton::iconSetChange()
 {
 	QIcon a = QIcon();
 	IconManager& iconManager = IconManager::instance();
-	bool rtlLoad = QLocale(ScCore->getGuiLanguage()).textDirection() == Qt::RightToLeft;
 
-	QPixmap closedPixmap(iconManager.loadPixmap("chain-closed.png", false, rtlLoad));
-	a.addPixmap(closedPixmap, QIcon::Normal, QIcon::On);
-	a.addPixmap(iconManager.loadPixmap("chain-open.png", false, rtlLoad), QIcon::Normal, QIcon::Off);
+	a.addPixmap(iconManager.loadPixmap("chain-closed.png"), QIcon::Normal, QIcon::On);
+	a.addPixmap(iconManager.loadPixmap("chain-open.png"), QIcon::Normal, QIcon::Off);
 	setIcon(a);
-	setIconSize(closedPixmap.size());
-}
-
-QSize LinkButton::sizeHint() const
-{
-	return iconSize();
-}
-
-QSize LinkButton::minimumSizeHint() const
-{
-	return iconSize();
 }
