@@ -204,7 +204,7 @@ LoremManager::LoremManager(ScribusDoc* doc, QWidget* parent) : QDialog( parent )
 		fi = it.next();
 		if (langmgr->getLangFromAbbrev(fi.baseName(), false).isEmpty())
 			continue;
-		std::unique_ptr<LoremParser> parser(new LoremParser(fi.fileName()));
+		auto parser = std::make_unique<LoremParser>(fi.fileName());
 		if (!parser->correct)
 			continue;
 		availableLorems[parser->name] = fi.fileName();
@@ -306,7 +306,7 @@ void LoremManager::insertLoremIpsum(const QString& name, int paraCount, bool ran
 		}
 		
 		// K.I.S.S.:
-		std::unique_ptr<LoremParser> lp(new LoremParser(name));
+		auto lp = std::make_unique<LoremParser>(name);
 		QString sampleText = lp->createLorem(paraCount, random);
 		if (UndoManager::undoEnabled())
 		{
@@ -328,6 +328,7 @@ void LoremManager::insertLoremIpsum(const QString& name, int paraCount, bool ran
 	}
 	m_Doc->regionsChanged()->update(QRectF());
 	m_Doc->changed();
+	m_Doc->changedPagePreview();
 }
 
 QString LoremManager::loremIpsum() const
