@@ -12,7 +12,6 @@ for which a new license (GPL+exception) is in place.
 #include "prefsfile.h"
 #include "prefsmanager.h"
 #include "scconfig.h"
-#include "scpaths.h"
 #include "ui/customfdialog.h"
 
 #include <QApplication>
@@ -40,11 +39,11 @@ MergeDoc::MergeDoc(QWidget* parent, bool importMasterPages, int targetDocPageCou
 	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
 
 	dialogLayout = new QVBoxLayout(this);
-	dialogLayout->setMargin(10);
-	dialogLayout->setSpacing(5);
+	dialogLayout->setContentsMargins(9, 9, 9, 9);
+	dialogLayout->setSpacing(6);
 	fromInfoLayout = new QGridLayout;
-	fromInfoLayout->setMargin(0);
-	fromInfoLayout->setSpacing(5);
+	fromInfoLayout->setContentsMargins(0, 0, 0, 0);
+	fromInfoLayout->setSpacing(6);
 	fromDocData = new QLineEdit( this );
 	fromDocData->setMinimumWidth(QWidget::fontMetrics().horizontalAdvance('a') * 50);
 	fromDocLabel = new QLabel( tr( "&From Document:"), this );
@@ -97,18 +96,14 @@ MergeDoc::MergeDoc(QWidget* parent, bool importMasterPages, int targetDocPageCou
 	}
 
 	dialogLayout->addLayout( fromInfoLayout );
-	importCancelLayout = new QHBoxLayout;
-	importCancelLayout->setMargin(0);
-	importCancelLayout->setSpacing(5);
-	QSpacerItem* spacer = new QSpacerItem( 1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum );
-	importCancelLayout->addItem( spacer );
+	buttonBox = new QDialogButtonBox();
 	importButton = new QPushButton( tr( "&Import" ), this );
 	importButton->setEnabled(false);
-	importCancelLayout->addWidget( importButton );
+	buttonBox->addButton(importButton, QDialogButtonBox::AcceptRole);
 	cancelButton = new QPushButton( CommonStrings::tr_Cancel, this );
-	cancelButton->setDefault( true );
-	importCancelLayout->addWidget( cancelButton );
-	dialogLayout->addLayout( importCancelLayout );
+	cancelButton->setDefault(true);
+	buttonBox->addButton(cancelButton, QDialogButtonBox::RejectRole);
+	dialogLayout->addWidget(buttonBox);
 	resize(minimumSizeHint());
 
 	connect( importButton, SIGNAL( clicked() ), this, SLOT( accept() ) );
@@ -160,6 +155,7 @@ void MergeDoc::changeFile()
 			{
 				fromDocData->setText( QDir::toNativeSeparators(fn) );
 				importButton->setEnabled(true);
+				importButton->setDefault(true);
 				if (masterPages)
 				{
 					masterPageNameData->clear();
@@ -182,6 +178,7 @@ void MergeDoc::changeFile()
 		fromDocData->setText("");
 		count = 0;
 		importButton->setEnabled(false);
+		cancelButton->setDefault(true);
 		if (masterPages)
 		{
 			masterPageNameData->clear();
