@@ -16,6 +16,7 @@ for which a new license (GPL+exception) is in place.
 #include <QList>
 #include <QMenu>
 #include <QMessageBox>
+#include <QRegularExpression>
 #include <QResizeEvent>
 #include <QSignalBlocker>
 #include <QSignalMapper>
@@ -24,7 +25,6 @@ for which a new license (GPL+exception) is in place.
 #include <QVariant>
 #include <QWidgetAction>
 
-#include "actionmanager.h"
 #include "appmodes.h"
 #include "canvasmode.h"
 #include "commonstrings.h"
@@ -40,11 +40,7 @@ for which a new license (GPL+exception) is in place.
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "undomanager.h"
 #include "units.h"
-#include "util.h"
-#include "util_color.h"
-#include "util_formats.h"
 
 OutlineTreeItem::OutlineTreeItem(OutlineTreeItem* parent, OutlineTreeItem* after) : QTreeWidgetItem(parent, after)
 {
@@ -435,7 +431,7 @@ bool OutlineWidget::viewportEvent(QEvent *event)
 	return true;
 }
 
-OutlinePalette::OutlinePalette( QWidget* parent) : ScDockPalette(parent, "Tree", Qt::WindowFlags())
+OutlinePalette::OutlinePalette( QWidget* parent) : DockPanelBase("Tree", "panel-outline", parent)
 {
 //	resize( 220, 240 );
 	setMinimumSize( QSize( 220, 240 ) );
@@ -479,28 +475,31 @@ OutlinePalette::OutlinePalette( QWidget* parent) : ScDockPalette(parent, "Tree",
 	// signals and slots connections
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 
-	connect(reportDisplay, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(slotRightClick(QPoint)));
+	connect(reportDisplay, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotRightClick(QPoint)));
 	connect(reportDisplay, SIGNAL(itemSelectionChanged()), this, SLOT(slotMultiSelect()));
-	connect(reportDisplay, SIGNAL(itemChanged(QTreeWidgetItem*, int)), this, SLOT(slotDoRename(QTreeWidgetItem*, int)));
-	connect(filterEdit, SIGNAL(textChanged(const QString&)), this, SLOT(filterTree(const QString&)));
+	connect(reportDisplay, SIGNAL(itemChanged(QTreeWidgetItem*,int)), this, SLOT(slotDoRename(QTreeWidgetItem*,int)));
+	connect(filterEdit, SIGNAL(textChanged(QString)), this, SLOT(filterTree(QString)));
 //	connect(filterShortcut, SIGNAL(activated()), filterEdit, SLOT(setFocus()));
-	connect(reportDisplay, SIGNAL(itemDoubleClicked(QTreeWidgetItem*, int)), this, SLOT(slotDoubleClick(QTreeWidgetItem*, int)));
+	connect(reportDisplay, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)), this, SLOT(slotDoubleClick(QTreeWidgetItem*,int)));
+	connect(this, SIGNAL(visibilityChanged(bool)), this, SLOT(rebuildTree()));
+
+
 }
 
 void OutlinePalette::setMainWindow(ScribusMainWindow *mw)
 {
-	m_MainWindow=mw;
-	if (m_MainWindow==nullptr)
+	m_MainWindow = mw;
+	if (m_MainWindow == nullptr)
 		clearPalette();
 }
 
 void OutlinePalette::setDoc(ScribusDoc *newDoc)
 {
-	if (m_MainWindow==nullptr)
-		currDoc=nullptr;
+	if (m_MainWindow == nullptr)
+		currDoc = nullptr;
 	else
-		currDoc=newDoc;
-	if (currDoc==nullptr)
+		currDoc = newDoc;
+	if (currDoc == nullptr)
 		clearPalette();
 }
 
@@ -510,10 +509,16 @@ void OutlinePalette::unsetDoc()
 	clearPalette();
 }
 
-void OutlinePalette::setPaletteShown(bool visible)
+void OutlinePalette::toggleView(bool visible)
 {
-	ScDockPalette::setPaletteShown(visible);
-	if (visible && (currDoc != nullptr))
+	DockPanelBase::toggleView(visible);
+	rebuildTree();
+}
+
+
+void OutlinePalette::rebuildTree()
+{
+	if (this->isVisible() && (currDoc != nullptr))
 		BuildTree();
 }
 
@@ -559,7 +564,7 @@ void OutlinePalette::slotRightClick(QPoint point)
 			actActive->setChecked(false);
 			signalMapper->setMapping(actActive, item->LayerID);
 			connect(actActive, SIGNAL(triggered()), signalMapper, SLOT(map()));
-			connect(signalMapper, SIGNAL(mapped(int)), this, SLOT(setActiveLayer(int)));
+			connect(signalMapper, SIGNAL(mappedInt(int)), this, SLOT(setActiveLayer(int)));
 		}
 		QSignalMapper *signalMapper2 = new QSignalMapper(this);
 		actVis = pmenu->addAction( tr("Visible"));
@@ -567,7 +572,7 @@ void OutlinePalette::slotRightClick(QPoint point)
 		actVis->setChecked(item->DocObject->layerVisible(item->LayerID));
 		signalMapper2->setMapping(actVis, item->LayerID);
 		connect(actVis, SIGNAL(triggered()), signalMapper2, SLOT(map()));
-		connect(signalMapper2, SIGNAL(mapped(int)), this, SLOT(setLayerVisible(int)));
+		connect(signalMapper2, SIGNAL(mappedInt(int)), this, SLOT(setLayerVisible(int)));
 
 		QSignalMapper *signalMapper3 = new QSignalMapper(this);
 		actPrint = pmenu->addAction( tr("Printing"));
@@ -575,7 +580,7 @@ void OutlinePalette::slotRightClick(QPoint point)
 		actPrint->setChecked(item->DocObject->layerPrintable(item->LayerID));
 		signalMapper3->setMapping(actPrint, item->LayerID);
 		connect(actPrint, SIGNAL(triggered()), signalMapper3, SLOT(map()));
-		connect(signalMapper3, SIGNAL(mapped(int)), this, SLOT(setLayerPrintable(int)));
+		connect(signalMapper3, SIGNAL(mappedInt(int)), this, SLOT(setLayerPrintable(int)));
 
 		QSignalMapper *signalMapper4 = new QSignalMapper(this);
 		actLock = pmenu->addAction( tr("Locked"));
@@ -583,7 +588,7 @@ void OutlinePalette::slotRightClick(QPoint point)
 		actLock->setChecked(item->DocObject->layerLocked(item->LayerID));
 		signalMapper4->setMapping(actLock, item->LayerID);
 		connect(actLock, SIGNAL(triggered()), signalMapper4, SLOT(map()));
-		connect(signalMapper4, SIGNAL(mapped(int)), this, SLOT(setLayerLocked(int)));
+		connect(signalMapper4, SIGNAL(mappedInt(int)), this, SLOT(setLayerLocked(int)));
 //		qApp->changeOverrideCursor(QCursor(Qt::ArrowCursor));
 		pmenu->exec(QCursor::pos());
 		delete pmenu;
@@ -1070,7 +1075,7 @@ void OutlinePalette::BuildTree(bool storeVals)
 {
 	if (!m_MainWindow || m_MainWindow->scriptIsRunning())
 		return;
-	if (currDoc==nullptr)
+	if (currDoc == nullptr)
 		return;
 	if (selectionTriggered)
 		return;
@@ -1379,6 +1384,7 @@ void OutlinePalette::BuildTree(bool storeVals)
 void OutlinePalette::filterTree(const QString& keyword)
 {
 	OutlineTreeItem *item = nullptr;
+	QRegularExpression regExp(keyword, QRegularExpression::CaseInsensitiveOption);
 	QTreeWidgetItemIterator it( reportDisplay );
 	while (*it)
 	{
@@ -1387,7 +1393,7 @@ void OutlinePalette::filterTree(const QString& keyword)
 		{
 			if ((item->type == 1) || (item->type == 3) || (item->type == 4))
 			{
-				if (item->PageItemObject->itemName().contains(QRegExp(keyword, Qt::CaseInsensitive)))
+				if (item->PageItemObject->itemName().contains(regExp))
 					item->setHidden(false);
 				else
 					item->setHidden(true);
@@ -1448,7 +1454,7 @@ void OutlinePalette::changeEvent(QEvent *e)
 	if (e->type() == QEvent::LanguageChange)
 		languageChange();
 	else
-		ScDockPalette::changeEvent(e);
+		DockPanelBase::changeEvent(e);
 }
 
 void OutlinePalette::iconSetChange()
