@@ -6,8 +6,8 @@ for which a new license (GPL+exception) is in place.
 */
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QMap>
+#include <QScreen>
 #include <QTemporaryFile>
 
 #include "outputpreview_pdf.h"
@@ -130,7 +130,7 @@ OutputPreview_PDF::OutputPreview_PDF(QWidget* parent, ScribusDoc* doc) :
 		connect(header, SIGNAL(sectionClicked(int)), this, SLOT(toggleAllFromHeader()));
 		connect(m_optionsUi->enableCMYK, SIGNAL(clicked()), this, SLOT(toggleCMYK()));
 		connect(m_optionsUi->displayInkCoverage, SIGNAL(clicked()), this, SLOT(toggleCMYK_Colour()));
-		connect(m_optionsUi->inkTable, SIGNAL(cellDoubleClicked(int, int)), this, SLOT(onInkTableCellDoubleClicked(int)));
+		connect(m_optionsUi->inkTable, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(onInkTableCellDoubleClicked(int)));
 	}
 	else
 	{
@@ -190,7 +190,7 @@ OutputPreview_PDF::OutputPreview_PDF(QWidget* parent, ScribusDoc* doc) :
 	m_uiBase->pageSelector->setGUIForPage(m_doc->currentPage()->pageNr());
 
 	int w = m_previewLabel->width() + inkTableWidth + 50;
-	resize(qMin(QApplication::desktop()->width() - 30, w), 500);
+	resize(qMin(ScCore->primaryMainWindow()->screen()->size().width() - 30, w), 500);
 
 	//signals and slots
 	connect(m_uiBase->pageSelector, SIGNAL(pageChanged(int)), this, SLOT(jumpToPage(int)));
@@ -748,15 +748,15 @@ int OutputPreview_PDF::renderPreviewSep(int pageIndex, int res)
 			QString tt;
 			if (sepLine.contains("%%SeparationColor:"))
 			{
-				int firstQuote = sepLine.indexOf('\"');
-				int lastQuote = sepLine.lastIndexOf('\"');
+				qsizetype firstQuote = sepLine.indexOf('\"');
+				qsizetype lastQuote = sepLine.lastIndexOf('\"');
 				if (firstQuote >= 0 && lastQuote >= 0 && firstQuote < lastQuote)
 					tt = sepLine.mid(firstQuote + 1, lastQuote - firstQuote - 1);
 			}
 			else
 			{
 				tt = sepLine.remove("%%SeparationName:").trimmed();
-				int cmykVals = tt.lastIndexOf("CMYK =");
+				qsizetype cmykVals = tt.lastIndexOf("CMYK =");
 				if (cmykVals >= 0)
 					tt = tt.left(cmykVals).trimmed();
 			}
@@ -889,7 +889,7 @@ void OutputPreview_PDF::setupFontEmbedding(PDFOptions& options)
 
 		for (auto itAnn = annotationFonts.begin(); itAnn != annotationFonts.end(); ++itAnn)
 		{
-			QString annotFont = itAnn.key();
+			const QString& annotFont = itAnn.key();
 			if (!m_pdfOptions.EmbedList.contains(annotFont))
 				m_pdfOptions.EmbedList.append(annotFont);
 			int subsetIndex = m_pdfOptions.SubsetList.indexOf(annotFont);
@@ -1117,7 +1117,7 @@ void OutputPreview_PDF::onInkTableCellDoubleClicked(int row)
 
 	if (m_optionsUi->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void OutputPreview_PDF::toggleAllFromHeader()
@@ -1130,7 +1130,7 @@ void OutputPreview_PDF::toggleAllFromHeader()
 
 	if (m_optionsUi->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void OutputPreview_PDF::toggleCMYK()
@@ -1158,7 +1158,7 @@ void OutputPreview_PDF::toggleCMYK_Colour()
 	}
 	if (m_optionsUi->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void OutputPreview_PDF::imageLoadError(QPixmap &pixmap)
