@@ -8,10 +8,10 @@ for which a new license (GPL+exception) is in place.
 #include <algorithm>
 
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QMap>
-#include <QTransform>
+#include <QScreen>
 #include <QTemporaryFile>
+#include <QTransform>
 
 #include "outputpreview_ps.h"
 #include "commonstrings.h"
@@ -138,7 +138,7 @@ OutputPreview_PS::OutputPreview_PS(QWidget* parent, ScribusDoc* doc) :
 		connect(header, SIGNAL(sectionClicked(int)), this, SLOT(toggleAllFromHeader()));
 		connect(m_optionsUi->enableCMYK, SIGNAL(clicked()), this, SLOT(toggleCMYK()));
 		connect(m_optionsUi->displayInkCoverage, SIGNAL(clicked()), this, SLOT(toggleCMYK_Colour()));
-		connect(m_optionsUi->inkTable, SIGNAL(cellDoubleClicked(int, int)), this, SLOT(onInkTableCellDoubleClicked(int)));
+		connect(m_optionsUi->inkTable, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(onInkTableCellDoubleClicked(int)));
 	}
 	else
 	{
@@ -176,16 +176,17 @@ OutputPreview_PS::OutputPreview_PS(QWidget* parent, ScribusDoc* doc) :
 	m_optionsUi->coverThresholdValue->setValue(m_prefsManager.appPrefs.psOutputPreviewPrefs.inkCoverageThreshold);
 
 	// Generate a template name for temporary files
-	QTemporaryFile tempFile(ScPaths::tempFileDir() + "/scpreview_XXXXXX.ps");
-	if (tempFile.open())
+	QTemporaryFile *tempFile = new QTemporaryFile(ScPaths::tempFileDir() + "/scpreview_XXXXXX.ps");
+	if (tempFile->open())
 	{
-		QString tempFileBase = tempFile.fileName();
-		tempFile.setAutoRemove(false);
-		tempFile.close();
+		QString tempFileBase = tempFile->fileName();
+		tempFile->setAutoRemove(false);
+		tempFile->close();
 		m_tempBaseName = QFileInfo(tempFileBase).completeBaseName();
 	}
 	if (m_tempBaseName.isEmpty())
 		m_tempBaseName = "scpreview";
+	delete tempFile;
 
 	if (m_printOptions.firstUse)
 		PrinterUtil::getDefaultPrintOptions(m_printOptions, m_doc->bleedsVal());
@@ -211,7 +212,7 @@ OutputPreview_PS::OutputPreview_PS(QWidget* parent, ScribusDoc* doc) :
 	m_uiBase->pageSelector->setGUIForPage(m_doc->currentPage()->pageNr());
 
 	int w = m_previewLabel->width() + inkTableWidth + 50;
-	resize(qMin(QApplication::desktop()->width() - 30, w), 500);
+	resize(qMin(ScCore->primaryMainWindow()->screen()->size().width() - 30, w), 500);
 
 	//signals and slots
 	connect(m_uiBase->pageSelector, SIGNAL(pageChanged(int)), this, SLOT(jumpToPage(int)));
@@ -786,15 +787,15 @@ int OutputPreview_PS::renderPreviewSep(int pageIndex, int res)
 			QString tt;
 			if (sepLine.contains("%%SeparationColor:"))
 			{
-				int firstQuote = sepLine.indexOf('\"');
-				int lastQuote = sepLine.lastIndexOf('\"');
+				qsizetype firstQuote = sepLine.indexOf('\"');
+				qsizetype lastQuote = sepLine.lastIndexOf('\"');
 				if (firstQuote >= 0 && lastQuote >= 0 && firstQuote < lastQuote)
 					tt = sepLine.mid(firstQuote + 1, lastQuote - firstQuote - 1);
 			}
 			else
 			{
 				tt = sepLine.remove("%%SeparationName:").trimmed();
-				int cmykVals = tt.lastIndexOf("CMYK =");
+				qsizetype cmykVals = tt.lastIndexOf("CMYK =");
 				if (cmykVals >= 0)
 					tt = tt.left(cmykVals).trimmed();
 			}
@@ -976,7 +977,7 @@ void OutputPreview_PS::onInkTableCellDoubleClicked(int row)
 
 	if (m_optionsUi->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void OutputPreview_PS::toggleAllFromHeader()
@@ -989,7 +990,7 @@ void OutputPreview_PS::toggleAllFromHeader()
 
 	if (m_optionsUi->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void OutputPreview_PS::toggleCMYK()
@@ -1017,7 +1018,7 @@ void OutputPreview_PS::toggleCMYK_Colour()
 	}
 	if (m_optionsUi->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void OutputPreview_PS::imageLoadError(QPixmap &pixmap)
