@@ -105,10 +105,8 @@ void PagePalette_MasterPages::connectSignals()
 	connect(deleteButton   , SIGNAL(clicked()), this, SLOT(deleteMasterPage()));
 	connect(newButton      , SIGNAL(clicked()), this, SLOT(newMasterPage()));
 	connect(importButton   , SIGNAL(clicked()), this, SLOT(importPage()));
-	connect(masterPageListBox, SIGNAL(itemClicked(QListWidgetItem*)),
-			 this, SLOT(selectMasterPage(QListWidgetItem*)));
-	connect(masterPageListBox, SIGNAL(itemChanged(QListWidgetItem*)),
-			 this, SLOT(renameMasterPage( QListWidgetItem*)));
+	connect(masterPageListBox, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectMasterPage(QListWidgetItem*)));
+	connect(masterPageListBox, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(renameMasterPage(QListWidgetItem*)));
 	connect(finishButton   , SIGNAL(released()), this, SIGNAL(finished()));
 }
 
@@ -165,7 +163,7 @@ void PagePalette_MasterPages::deleteMasterPage()
 		if (isReservedName(m_currentPage))
 			continue;
 
-		QString extraWarn = "";
+		QString extraWarn;
 
 		if (!forceDelete)
 		{
@@ -318,7 +316,7 @@ void PagePalette_MasterPages::newMasterPage()
 {
 	int nr = m_doc->Pages->count();
 
-	QScopedPointer<NewTm> dia(new NewTm(this, tr("Name:"), tr("New MasterPage"), m_doc, tr("New Master Page %1").arg(nr)));
+	QScopedPointer<NewTm> dia(new NewTm(this, tr("Name:"), tr("New Master Page"), m_doc, tr("New Master Page %1").arg(nr)));
 	if (!dia->exec())
 		return;
 
