@@ -15,7 +15,6 @@ for which a new license (GPL+exception) is in place.
 #include <QLineEdit>
 #include <QPixmap>
 #include <QPushButton>
-#include <QRegExp>
 #include <QSignalBlocker>
 #include <QToolTip>
 #include <QValidator>
@@ -209,7 +208,7 @@ void PageSelector::iconSetChange()
 	QByteArray stylesheet;
 	if (loadRawText(ScPaths::instance().libDir() + "scribus.css", stylesheet))
 	{
-		QString downArrow(IconManager::instance().pathForIcon("16/go-down.png"));
+		QString downArrow(IconManager::instance().pathForIcon("stylesheet/go-down.png"));
 		QByteArray da;
 		da.append(downArrow.toUtf8());
 		stylesheet.replace("___downArrow___", da);
