@@ -37,10 +37,8 @@ for which a new license (GPL+exception) is in place.
 #include <QScopedPointer>
 #include <QToolButton>
 
-#include "commonstrings.h"
 #include "effectsdialog.h"
 #include "extimageprops.h"
-#include "filesearch.h"
 #include "iconmanager.h"
 #include "pageitem.h"
 #include "picsearch.h"
@@ -80,7 +78,7 @@ PicStatus::PicStatus(QWidget* parent, ScribusDoc *docu) : QDialog( parent )
 	connect(effectsButton, SIGNAL(clicked()), this, SLOT(doImageEffects()));
 	connect(buttonLayers, SIGNAL(clicked()), this, SLOT(doImageExtProp()));
 	connect(buttonEdit, SIGNAL(clicked()), this, SLOT(doEditImage()));
-	connect(imageViewArea, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(slotRightClick()));
+	connect(imageViewArea, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(slotRightClick()));
 }
 
 QPixmap PicStatus::createImgIcon(PageItem* item)
@@ -230,7 +228,7 @@ void PicStatus::sortByName()
 
 void PicStatus::sortByPage()
 {
-	QMap<int, PicItem*> sorted;
+	QMultiMap<int, PicItem*> sorted;
 
 	int num = imageViewArea->count();
 	if (num == 0)
@@ -241,7 +239,7 @@ void PicStatus::sortByPage()
 	{
 		QListWidgetItem *ite = imageViewArea->takeItem(a);
 		PicItem *item = (PicItem*)ite;
-		sorted.insertMulti(item->PageItemObject->OwnPage, item);
+		sorted.insert(item->PageItemObject->OwnPage, item);
 	}
 	int counter = 0;
 	foreach (int i, sorted.uniqueKeys())
@@ -322,7 +320,7 @@ void PicStatus::imageSelected(QListWidgetItem *ite)
 			searchButton->setEnabled(true);
 			fileManagerButton->setEnabled(true);
 		}
-		QString format = "";
+		QString format;
 		switch (currItem->pixm.imgInfo.type)
 		{
 			case 0:
@@ -528,7 +526,7 @@ void PicStatus::doImageExtProp()
 	if (currItem == nullptr)
 		return;
 
-	ExtImageProps dia(this, &currItem->pixm.imgInfo, currItem, m_Doc->view());
+	ExtImageProps dia(this, currItem, m_Doc->view());
 	if (dia.exec())
 	{
 		loadPict(currItem, currItem->Pfile);
