@@ -8,7 +8,7 @@ for which a new license (GPL+exception) is in place.
 #include <QApplication>
 #include <QColor>
 #include <QColorDialog>
-#include <QDesktopWidget>
+#include <QScreen>
 #include <QPainter>
 
 #include "iconmanager.h"
@@ -180,7 +180,7 @@ void Prefs_Display::restoreDefaults(struct ApplicationPrefs *prefsData)
 	textControlCharsButton->setText( QString() );
 	textControlCharsButton->setIcon(pm);
 
-	displayScale=prefsData->displayPrefs.displayScale;
+	displayScale = prefsData->displayPrefs.displayScale;
 
 	adjustDisplaySlider->setValue(qRound(100 * displayScale) - 150);
 	displayDPI->setText(QString::number(qRound(displayScale * 72.0))+ tr(" dpi"));
@@ -249,7 +249,7 @@ void Prefs_Display::drawRuler()
 				val = xl / iter;
 				break;
 			default:
-				val=xl / iter * 10;
+				val = xl / iter * 10;
 				break;
 		}
 		p.drawText(static_cast<int>((xl+qRound(2/displayScale)) * displayScale), 12, QString::number(val));
@@ -262,7 +262,7 @@ void Prefs_Display::drawRuler()
 void Prefs_Display::restoreDisScale()
 {
 	disconnect(adjustDisplaySlider, SIGNAL(valueChanged(int)), this, SLOT(setDisScale()));
-	int dpi = QApplication::desktop()->logicalDpiX();
+	int dpi = ScCore->primaryMainWindow()->screen()->logicalDotsPerInchX();
 	if ((dpi < 60) || (dpi > 500))
 		dpi = 72;
 	displayScale = dpi / 72.0;
@@ -401,25 +401,25 @@ void Prefs_Display::changeControlCharsColor()
 
 void Prefs_Display::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 {
-	prefsData->guidesPrefs.showPic=showImagesCheckBox->isChecked();
-	prefsData->guidesPrefs.showControls=showControlCharsCheckBox->isChecked();
-	prefsData->guidesPrefs.rulersShown=showRulersCheckBox->isChecked();
-	prefsData->guidesPrefs.rulerMode=showRulersRelativeToPageCheckBox->isChecked();
-	prefsData->guidesPrefs.linkShown=showTextChainsCheckBox->isChecked();
-	prefsData->guidesPrefs.framesShown=showFramesCheckBox->isChecked();
-	prefsData->guidesPrefs.layerMarkersShown=showLayerIndicatorsCheckBox->isChecked();
-	prefsData->displayPrefs.marginColored=showUnprintableAreaInMarginColorCheckBox->isChecked();
-	prefsData->guidesPrefs.showBleed=showBleedAreaCheckBox->isChecked();
-	prefsData->displayPrefs.showPageShadow=showPageShadowCheckBox->isChecked();
-	prefsData->displayPrefs.showVerifierWarningsOnCanvas=showVerifierWarningsOnCanvasCheckBox->isChecked();
+	prefsData->guidesPrefs.showPic = showImagesCheckBox->isChecked();
+	prefsData->guidesPrefs.showControls = showControlCharsCheckBox->isChecked();
+	prefsData->guidesPrefs.rulersShown = showRulersCheckBox->isChecked();
+	prefsData->guidesPrefs.rulerMode = showRulersRelativeToPageCheckBox->isChecked();
+	prefsData->guidesPrefs.linkShown = showTextChainsCheckBox->isChecked();
+	prefsData->guidesPrefs.framesShown = showFramesCheckBox->isChecked();
+	prefsData->guidesPrefs.layerMarkersShown = showLayerIndicatorsCheckBox->isChecked();
+	prefsData->displayPrefs.marginColored = showUnprintableAreaInMarginColorCheckBox->isChecked();
+	prefsData->guidesPrefs.showBleed = showBleedAreaCheckBox->isChecked();
+	prefsData->displayPrefs.showPageShadow = showPageShadowCheckBox->isChecked();
+	prefsData->displayPrefs.showVerifierWarningsOnCanvas = showVerifierWarningsOnCanvasCheckBox->isChecked();
 
 	double unitRatio = unitGetRatioFromIndex(prefsData->docSetupPrefs.docUnitIndex);
 	prefsData->displayPrefs.scratch.setLeft(scratchSpaceLeftSpinBox->value() / unitRatio);
 	prefsData->displayPrefs.scratch.setRight(scratchSpaceRightSpinBox->value() / unitRatio);
 	prefsData->displayPrefs.scratch.setTop(scratchSpaceTopSpinBox->value() / unitRatio);
 	prefsData->displayPrefs.scratch.setBottom(scratchSpaceBottomSpinBox->value() / unitRatio);
-	prefsData->displayPrefs.pageGapHorizontal=pageGapHorizontalSpinBox->value() / unitRatio;
-	prefsData->displayPrefs.pageGapVertical=pageGapVerticalSpinBox->value() / unitRatio;
+	prefsData->displayPrefs.pageGapHorizontal = pageGapHorizontalSpinBox->value() / unitRatio;
+	prefsData->displayPrefs.pageGapVertical = pageGapVerticalSpinBox->value() / unitRatio;
 
 	prefsData->displayPrefs.paperColor = colorPaper;
 	prefsData->displayPrefs.scratchColor = colorScratch;
