@@ -25,7 +25,7 @@ Prefs_DocumentSections::Prefs_DocumentSections(QWidget* parent, ScribusDoc* doc)
 	languageChange();
 
 	m_caption = tr("Sections");
-	m_icon = "tabtocindex_16.png";
+	m_icon = "section";
 
 	connect(sectionsTable, SIGNAL(cellChanged(int,int)), this, SLOT(tableItemChanged(int,int)));
 	connect(addButton, SIGNAL(clicked()), this, SLOT(addEntry()));
@@ -40,10 +40,6 @@ void Prefs_DocumentSections::restoreDefaults(struct ApplicationPrefs *prefsData)
 {
 	m_localSections = prefsData->docSectionMap;
 	m_maxPageIndex = m_doc->DocPages.count() - 1;
-	m_styles.clear();
-	m_styles = getFormatList();
-	m_styles << CommonStrings::tr_None;
-//	styles << tr("1, 2, 3, ...") << tr("i, ii, iii, ...") << tr("I, II, III, ...") << tr("a, b, c, ...") << tr("A, B, C, ...") << tr("*") << tr("CJK") << CommonStrings::tr_None;
 
 	updateTable();
 }
@@ -81,7 +77,6 @@ void Prefs_DocumentSections::updateTable()
 		sectionsTable->setItem(row, i++, item4);
 		//Style
 		NumFormatCombo *item5 = new NumFormatCombo(nullptr, true);
-		item5->addItems(m_styles);
 		sectionsTable->setCellWidget(row, i++, item5);
 		item5->setCurrentFormat(it->type);
 		//Start Page Number
@@ -198,7 +193,7 @@ void Prefs_DocumentSections::addEntry()
 		struct DocumentSection blank;
 		uint count = m_localSections.count();
 		blank.number = count;
-		blank.name = QString::number(count);
+		blank.name = CommonStrings::trSectionName.arg(count + 1);
 		blank.fromindex = m_maxPageIndex + 1;
 		blank.toindex = m_maxPageIndex + 1;
 		blank.type = Type_1_2_3;
@@ -224,7 +219,7 @@ void Prefs_DocumentSections::addEntry()
 			{
 				struct DocumentSection blank;
 				blank.number = ++i;
-				blank.name = QString::number(i);
+				blank.name = CommonStrings::trSectionName.arg(i + 1);
 				blank.fromindex = it->toindex + 1;
 				blank.toindex = it->toindex + 2;
 				blank.type = Type_1_2_3;
@@ -245,7 +240,7 @@ void Prefs_DocumentSections::deleteEntry()
 	int currRow = sectionsTable->currentRow();
 	if (currRow == 0 && m_localSections.count() == 1)
 		return;
-	bool found=false;
+	bool found = false;
 	DocumentSectionMap::Iterator it = m_localSections.begin();
 	int count = 0;
 	for (; it!= m_localSections.end(); ++it)
@@ -279,7 +274,7 @@ void Prefs_DocumentSections::deleteEntry()
 			m_localSections.insert(i++, it.value());
 		}
 		int newCount = m_localSections.count();
-		//int preIndex=qMax(currentIndex-1, 0);
+		//int preIndex = qMax(currentIndex - 1, 0);
 		m_localSections[0].fromindex = 0;
 		m_localSections[newCount - 1].toindex = m_maxPageIndex;
 		updateTable();
