@@ -31,8 +31,6 @@ for which a new license (GPL+exception) is in place.
 #include "prefsmanager.h"
 #include "scconfig.h"
 #include "util.h"
-#include "util_color.h"
-#include "scpaths.h"
 #include "fontlistmodel.h"
 #include "fontlistview.h"
 
@@ -167,12 +165,12 @@ void Prefs_Fonts::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 		face.subset(fontListTableView->isFontSubsetted(i));
 	}
 
-	if (m_doc == nullptr && !ScCore->primaryMainWindow()->HaveDoc)
+	if (m_doc == nullptr)
 		writePaths();
 
 	prefsData->fontPrefs.GFontSub.clear();
 	uint a = 0;
-	for (auto itfsu = RList.begin(); itfsu != RList.end(); ++itfsu)
+	for (QMap<QString,QString>::ConstIterator itfsu = RList.begin(); itfsu != RList.end(); ++itfsu)
 		prefsData->fontPrefs.GFontSub[itfsu.key()] = FlagsRepl.at(a++)->currentText();
 }
 
