@@ -5,16 +5,16 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 
-#include "ui/prefs_itemtools.h"
-#include "ui/arrowchooser.h"
-#include "ui/linkbutton.h"
-#include "prefsstructs.h"
-#include "scrspinbox.h"
-#include "scribusdoc.h"
-#include "units.h"
 #include "commonstrings.h"
 #include "prefsmanager.h"
+#include "prefsstructs.h"
 #include "sampleitem.h"
+#include "scribusdoc.h"
+#include "scrspinbox.h"
+#include "ui/arrowchooser.h"
+#include "ui/linkbutton.h"
+#include "ui/prefs_itemtools.h"
+#include "units.h"
 
 
 Prefs_ItemTools::Prefs_ItemTools(QWidget* parent, ScribusDoc* /*doc*/)
@@ -83,7 +83,7 @@ void Prefs_ItemTools::restoreDefaults(struct ApplicationPrefs *prefsData)
 	double unitRatio = unitGetRatioFromIndex(docUnitIndex);
 	unitChange(docUnitIndex);
 
-	PrefsManager& prefsManager=PrefsManager::instance();
+	PrefsManager& prefsManager = PrefsManager::instance();
 	ColorList* colorList = (m_doc != nullptr) ? (&m_doc->PageColors) : prefsManager.colorSetPtr();
 
 	//Text Tool
@@ -142,11 +142,12 @@ void Prefs_ItemTools::restoreDefaults(struct ApplicationPrefs *prefsData)
 	firstLineOffsetComboBox->setCurrentIndex((int) prefsData->itemToolPrefs.firstLineOffset);
 
 	//Image Tool
-	imageFreeScalingRadioButton->setChecked( prefsData->itemToolPrefs.imageScaleType );
-	imageFrameScalingRadioButton->setChecked( !prefsData->itemToolPrefs.imageScaleType );
+	checkBoxAutoFit->setChecked(!prefsData->itemToolPrefs.imageScaleType);
+	// imageFreeScalingRadioButton->setChecked( prefsData->itemToolPrefs.imageScaleType );
+	// imageFrameScalingRadioButton->setChecked( !prefsData->itemToolPrefs.imageScaleType );
 	imageHorizontalScalingSpinBox->setValue(qRound(prefsData->itemToolPrefs.imageScaleX * 100));
 	imageVerticalScalingSpinBox->setValue(qRound(prefsData->itemToolPrefs.imageScaleY * 100));
-	imageKeepAspectRatioCheckBox->setChecked(prefsData->itemToolPrefs.imageAspectRatio);
+//	imageKeepAspectRatioCheckBox->setChecked(prefsData->itemToolPrefs.imageAspectRatio);
 	scalingLockToolButton->setChecked(prefsData->itemToolPrefs.imageAspectRatio);
 	imageFrameFillColorComboBox->initColorList(colorList, m_doc, prefsData->itemToolPrefs.imageFillColor);
 	imageFrameFillShadingSpinBox->setValue(prefsData->itemToolPrefs.imageFillColorShade );
@@ -275,8 +276,10 @@ void Prefs_ItemTools::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 	prefsData->itemToolPrefs.imageStrokeColorShade = imageFrameFillShadingSpinBox->value();
 	prefsData->itemToolPrefs.imageScaleX = static_cast<double>(imageHorizontalScalingSpinBox->value()) / 100.0;
 	prefsData->itemToolPrefs.imageScaleY = static_cast<double>(imageVerticalScalingSpinBox->value()) / 100.0;
-	prefsData->itemToolPrefs.imageScaleType = imageFreeScalingRadioButton->isChecked();
-	prefsData->itemToolPrefs.imageAspectRatio = imageKeepAspectRatioCheckBox->isChecked();
+	// prefsData->itemToolPrefs.imageScaleType = imageFreeScalingRadioButton->isChecked();
+	prefsData->itemToolPrefs.imageScaleType = !checkBoxAutoFit->isChecked();
+	//prefsData->itemToolPrefs.imageAspectRatio = imageKeepAspectRatioCheckBox->isChecked();
+	prefsData->itemToolPrefs.imageAspectRatio = scalingLockToolButton->isChecked();
 	prefsData->itemToolPrefs.imageUseEmbeddedPath = imageUseEmbeddedClippingPathCheckBox->isChecked();
 	int haRes = 0;
 	if (onscreenResolutionFullRadioButton->isChecked())
@@ -346,10 +349,11 @@ void Prefs_ItemTools::enableSignals(bool on)
 		connect(textColorShadingSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateFontPreview()));
 		connect(scalingLockToolButton, SIGNAL(clicked()), this, SLOT(toggleImagesScalingChain()));
 		connect(imageHorizontalScalingSpinBox, SIGNAL(valueChanged(int)), this, SLOT(imageHorizontalScalingChange()));
-		connect(imageKeepAspectRatioCheckBox, SIGNAL(toggled(bool)), scalingLockToolButton, SLOT(setChecked(bool)));
+		//connect(imageKeepAspectRatioCheckBox, SIGNAL(toggled(bool)), scalingLockToolButton, SLOT(setChecked(bool)));
 		connect(imageVerticalScalingSpinBox, SIGNAL(valueChanged(int)), this, SLOT(imageVerticalScalingChange()));
-		connect(imageFreeScalingRadioButton, SIGNAL(clicked(bool)), this, SLOT(imageScalingTypeChange()));
-		connect(imageFrameScalingRadioButton, SIGNAL(clicked(bool)), this, SLOT(imageScalingTypeChange()));
+		connect(checkBoxAutoFit, SIGNAL(toggled(bool)), this, SLOT(imageScalingTypeChange()));
+		// connect(imageFreeScalingRadioButton, SIGNAL(clicked(bool)), this, SLOT(imageScalingTypeChange()));
+		// connect(imageFrameScalingRadioButton, SIGNAL(clicked(bool)), this, SLOT(imageScalingTypeChange()));
 	}
 	else
 	{
@@ -420,7 +424,7 @@ void Prefs_ItemTools::updateFontPreview()
 void Prefs_ItemTools::toggleImagesScalingChain()
 {
 	imageHorizontalScalingChange();
-	imageKeepAspectRatioCheckBox->setChecked(scalingLockToolButton->isChecked());
+	//imageKeepAspectRatioCheckBox->setChecked(scalingLockToolButton->isChecked());
 }
 
 void Prefs_ItemTools::imageHorizontalScalingChange()
@@ -437,11 +441,11 @@ void Prefs_ItemTools::imageVerticalScalingChange()
 
 void Prefs_ItemTools::imageScalingTypeChange()
 {
-	bool b=imageFreeScalingRadioButton->isChecked();
-	imageKeepAspectRatioCheckBox->setEnabled(!b);
+	bool b = !checkBoxAutoFit->isChecked();
+//	imageKeepAspectRatioCheckBox->setEnabled(!b);
 	imageHorizontalScalingSpinBox->setEnabled(b);
 	imageVerticalScalingSpinBox->setEnabled(b);
-	scalingLockToolButton->setEnabled(b);
+//	scalingLockToolButton->setEnabled(b);
 }
 
 
