@@ -72,7 +72,7 @@ Prefs_KeyboardShortcuts::Prefs_KeyboardShortcuts(QWidget* parent, ScribusDoc* /*
 
 	clearSearchButton->setIcon(IconManager::instance().loadIcon("clear_right.png"));
 	// signals and slots connections
-	connect( keyTable, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(dispKey(QTreeWidgetItem*, QTreeWidgetItem*)));
+	connect( keyTable, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), this, SLOT(dispKey(QTreeWidgetItem*,QTreeWidgetItem*)));
 	connect( noKey, SIGNAL(clicked()), this, SLOT(setNoKey()));
 	connect( setKeyButton, SIGNAL(clicked()), this, SLOT(setKeyText()));
 	connect( loadSetButton, SIGNAL(clicked()), this, SLOT(loadKeySetFile()));
@@ -80,7 +80,7 @@ Prefs_KeyboardShortcuts::Prefs_KeyboardShortcuts(QWidget* parent, ScribusDoc* /*
 	connect( exportSetButton, SIGNAL(clicked()), this, SLOT(exportKeySetFile()));
 	connect( resetSetButton, SIGNAL(clicked()), this, SLOT(resetKeySet()));
 	connect( clearSearchButton, SIGNAL(clicked()), this, SLOT(clearSearchString()));
-	connect( searchTextLineEdit, SIGNAL(textChanged(const QString&)), this, SLOT(applySearch(const QString&)));
+	connect( searchTextLineEdit, SIGNAL(textChanged(QString)), this, SLOT(applySearch(QString)));
 
 }
 
@@ -155,8 +155,19 @@ void Prefs_KeyboardShortcuts::importKeySet(const QString& filename)
 	QFile file1( filename );
 	if ( !file1.open( QIODevice::ReadOnly ) )
 		return;
+
 	QTextStream ts(&file1);
-	ts.setCodec("UTF-8");
+	ts.setEncoding(QStringConverter::Utf8);
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(ts.readAll());
+	if (!parseResult)
+	{
+		qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(filename, parseResult.errorMessage).arg(parseResult.errorLine).arg(parseResult.errorColumn).toLatin1().constData());
+		file1.close();
+		return;
+	}
+#else
 	QString errorMsg;
 	int eline;
 	int ecol;
@@ -166,6 +177,7 @@ void Prefs_KeyboardShortcuts::importKeySet(const QString& filename)
 		file1.close();
 		return;
 	}
+#endif
 	file1.close();
 
 	//load the file now
@@ -248,36 +260,45 @@ void Prefs_KeyboardShortcuts::resetKeySet()
 QStringList Prefs_KeyboardShortcuts::scanForSets()
 {
 	keySetList.clear();
-	QString location(ScPaths::instance().shareDir());
-	QDir keySetsDir(QDir::toNativeSeparators(location+"keysets/"), "*.xml", QDir::Name, QDir::Files | QDir::NoSymLinks);
+	QString location(ScPaths::instance().shareDir()+"keysets/");
+	QDir keySetsDir(QDir::toNativeSeparators(location), "*.xml", QDir::Name, QDir::Files | QDir::NoSymLinks);
 	if ((!keySetsDir.exists()) || (keySetsDir.count() <= 0))
 		return QStringList();
 
 	QStringList appNames;
 	for (uint fileCounter = 0; fileCounter < keySetsDir.count(); ++fileCounter)
 	{
-		QString filename(QDir::toNativeSeparators(location+"keysets/"+keySetsDir[fileCounter]));
-
-		QDomDocument doc( "keymapentries" );
-		QFile file( filename );
+		QString filename(QDir::toNativeSeparators(location+keySetsDir[fileCounter]));
+		QDomDocument doc("keymapentries");
+		QFile file(filename);
 		if (!file.open( QIODevice::ReadOnly))
 			continue;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+		QDomDocument::ParseResult parseResult = doc.setContent(&file);
+		if (!parseResult)
+		{
+			qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(keySetsDir[fileCounter], parseResult.errorMessage).arg(parseResult.errorLine).arg(parseResult.errorColumn).toLatin1().constData());
+			file.close();
+			continue;
+		}
+#else
 		QString errorMsg;
 		int eline;
 		int ecol;
-
 		if (!doc.setContent( &file, &errorMsg, &eline, &ecol ))
 		{
 			qDebug("%s", QString("Could not open key set file: %1\nError:%2 at line: %3, row: %4").arg(keySetsDir[fileCounter], errorMsg).arg(eline).arg(ecol).toLatin1().constData());
 			file.close();
 			continue;
 		}
+#endif
 		file.close();
 
 		QDomElement docElem = doc.documentElement();
 		if (docElem.tagName() == "shortcutset" && docElem.hasAttribute("name"))
 		{
-			QDomAttr nameAttr = docElem.attributeNode( "name" );
+			QDomAttr nameAttr = docElem.attributeNode("name");
 			if(nameAttr.value().contains(ScribusAPI::getVersionScribus().remove(".svn")))
 				appNames.prepend(nameAttr.value());
 			else
