@@ -32,7 +32,7 @@ void Prefs_Printer::languageChange()
 {
 	clipToPrinterMarginsCheckBox->setToolTip( "<qt>" + tr( "Do not show objects outside the margins on the printed page" ) + "</qt>" );
 	altPrinterCmdLineEdit->setToolTip("<qt>" + tr( "Use an alternative print manager, such as kprinter or gtklp, to utilize additional printing options") + "</qt>" );
-	printLanguageComboBox->setToolTip("<qt>" +  tr( "Sets the printing language to use.\n Setting to Postscript Level 1 or 2 can create huge files." ) + "</qt>" );
+	printLanguageComboBox->setToolTip("<qt>" +  tr( "Sets the printing language to use.\n Setting to PostScript Level 1 or 2 can create huge files." ) + "</qt>" );
 	applyUnderColorRemovalCheckBox->setToolTip( "<qt>" + tr( "A way of switching off some of the gray shades which are composed of cyan, yellow and magenta and using black instead. UCR most affects parts of images which are neutral and/or dark tones which are close to the gray. Use of this may improve printing some images and some experimentation and testing is need on a case by case basis. UCR reduces the possibility of over saturation with CMY inks." ) + "</qt>");
 	convertSpotsToProcessCheckBox->setToolTip("<qt>" + tr( "Enables Spot Colors to be converted to composite colors. Unless you are planning to print spot colors at a commercial printer, this is probably best left enabled." ) + "</qt>");
 	setMediaSizeCheckBox->setToolTip( "<qt>" + tr( "This enables you to explicitly set the media size of the PostScript file. Not recommended unless requested by your printer." ) + "</qt>");
@@ -118,9 +118,9 @@ void Prefs_Printer::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 	prefs->set("PrintRange", false);
 	prefs->set("PageNr", "");
 	prefs->set("Copies", 1);
-	prefs->set("Separations", static_cast<int>(outputComboBox->currentIndex()==1));
+	prefs->set("Separations", static_cast<int>(outputComboBox->currentIndex() == 1));
 	//FIXME: This comparison looks wrong.
-	prefs->set("PrintColor", static_cast<int>(!(colorOutputModeComboBox->currentIndex()==0)));
+	prefs->set("PrintColor", static_cast<int>(!(colorOutputModeComboBox->currentIndex() == 0)));
 	prefs->set("SepArt", 0);
 	prefs->set("MirrorH", pageMirrorHorizontallyCheckBox->isChecked());
 	prefs->set("MirrorV", pageMirrorVerticallyCheckBox->isChecked());
@@ -147,7 +147,7 @@ void Prefs_Printer::saveGuiToPrefs(struct ApplicationPrefs *prefsData) const
 
 void Prefs_Printer::selOtherComm()
 {
-	bool setter=useAltPrinterCmdCheckBox->isChecked();
+	bool setter = useAltPrinterCmdCheckBox->isChecked();
 	destinationComboBox->setEnabled(!setter);
 	altPrinterCmdLineEdit->setEnabled(setter);
 }
