@@ -23,9 +23,6 @@ for which a new license (GPL+exception) is in place.
 #include "scpaths.h"
 #include "scribusapp.h"
 #include "scribusdoc.h"
-#include "third_party/zip/scribus_zip.h"
-#include "util.h"
-#include "util_file.h"
 
 Prefs_Spelling::Prefs_Spelling(QWidget* parent, ScribusDoc* /*doc*/)
 	: Prefs_Pane(parent)
@@ -78,36 +75,36 @@ void Prefs_Spelling::downloadSpellDicts()
 	downloadProgressBar->setValue(0);
 	downloadProgressBar->setVisible(true);
 	dlLabel->setVisible(true);
-	int i=0;
+	int i = 0;
 	QString userDictDir(ScPaths::userDictDir(ScPaths::Spell, true));
-	foreach(DownloadItem d, dictList)
+	for (const DownloadItem& d : dictList)
 	{
 		if (dlLangs.contains(d.lang))
 		{
-			if (d.filetype=="zip")
+			if (d.filetype == "zip")
 			{
 				ScQApp->dlManager()->addURL(d.url, true, downloadLocation, userDictDir);
 				++i;
 			}
-			if (d.filetype=="plain")
+			if (d.filetype == "plain")
 			{
 				//qDebug()<<d.url<<d.files;
 				const QStringList plainURLs(d.files.split(";", Qt::SkipEmptyParts));
 				for (const QString& s : plainURLs)
 				{
-					ScQApp->dlManager()->addURL(d.url+"/"+s, true, downloadLocation, userDictDir);
+					ScQApp->dlManager()->addURL(d.url + "/" + s, true, downloadLocation, userDictDir);
 					++i;
 				}
 				downloadList.append(d);
 			}
 		}
 	}
-	if (i>0)
+	if (i > 0)
 	{
 		downloadProgressBar->setRange(0, i);
 		connect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadSpellDictsFinished()));
-		connect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
-		connect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
+		connect(ScQApp->dlManager(), SIGNAL(fileReceived(QString)), this, SLOT(updateProgressBar()));
+		connect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(updateProgressBar()));
 		ScQApp->dlManager()->startDownloads();
 	}
 }
@@ -186,15 +183,29 @@ void Prefs_Spelling::setAvailDictsXMLFile(const QString& availDictsXMLDataFile)
 		return;
 	if (!dataFile.open(QIODevice::ReadOnly))
 		return;
+
 	QTextStream ts(&dataFile);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
-	QString errorMsg;
-	int eline;
-	int ecol;
+	ts.setEncoding(QStringConverter::Utf8);
+
 	QDomDocument doc( "scribus_spell_dicts" );
 	QString data(ts.readAll());
 	dataFile.close();
-	if ( !doc.setContent( data, &errorMsg, &eline, &ecol ))
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
+	{
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			qDebug() << "File not found on server";
+		else
+			qDebug() << "Could not open file" << availDictsXMLDataFile;
+		return;
+	}
+#else
+	QString errorMsg;
+	int eline;
+	int ecol;
+	if (!doc.setContent(data, &errorMsg, &eline, &ecol))
 	{
 		if (data.contains("404 not found", Qt::CaseInsensitive))
 			qDebug()<<"File not found on server";
@@ -202,6 +213,8 @@ void Prefs_Spelling::setAvailDictsXMLFile(const QString& availDictsXMLDataFile)
 			qDebug()<<"Could not open file"<<availDictsXMLDataFile;
 		return;
 	}
+#endif
+
 	dictList.clear();
 	QDomElement docElem = doc.documentElement();
 	for (QDomNode n = docElem.firstChild(); !n.isNull(); n = n.nextSibling())
@@ -219,7 +232,6 @@ void Prefs_Spelling::setAvailDictsXMLFile(const QString& availDictsXMLDataFile)
 			{
 				struct DownloadItem d;
 				d.desc = e.attribute("description");
-				d.download = false;
 				d.files = e.attribute("files");
 				d.url = e.attribute("URL");
 				d.version = e.attribute("version");
@@ -243,9 +255,9 @@ void Prefs_Spelling::setAvailDictsXMLFile(const QString& availDictsXMLDataFile)
 	availDictTableWidget->setRowCount(dictList.count());
 	availDictTableWidget->setColumnCount(4);
 	int row = 0;
-	foreach(DownloadItem d, dictList)
+	for (const DownloadItem& d : dictList)
 	{
-		int column=0;
+		int column = 0;
 		//qDebug()<<d.version<<d.files<<d.url<<d.desc<<d.license;
 		QTableWidgetItem *newItem1 = new QTableWidgetItem(d.desc);
 		newItem1->setFlags(newItem1->flags() & ~Qt::ItemIsEditable);
