@@ -51,7 +51,7 @@ Prefs_UserInterface::Prefs_UserInterface(QWidget* parent, ScribusDoc* /*doc*/)
 	numberFormatComboBox->addItem(tr("Use System Format"),"System");
 	numberFormatComboBox->addItem(tr("Use Interface Language Format"),"Language");
 
-	connect(languageComboBox, SIGNAL(activated(const QString &)), this, SLOT(setSelectedGUILang(const QString &)));
+	connect(languageComboBox, SIGNAL(currentTextChanged(QString)), this, SLOT(setSelectedGUILang(QString)));
 	connect(storyEditorFontPushButton, SIGNAL(clicked()), this, SLOT(changeStoryEditorFont()));
 }
 
@@ -72,6 +72,8 @@ void Prefs_UserInterface::languageChange()
 	//showSplashCheckBox->setToolTip( "<qt>" + tr( "" ) + "</qt>");
 	//showStartupDialogCheckBox->setToolTip( "<qt>" + tr( "" ) + "</qt>");
 	storyEditorUseSmartSelectionCheckBox->setToolTip( "<qt>" + tr( "The default behavior when double-clicking on a word is to select the word and the first following space. Smart selection will select only the word, without the following space." ) + "</qt>");
+	showLabels->setToolTip("<qt>" + tr( "Shows informational labels on palettes." ) + "</qt>");
+	showLabelsOfInactiveTabs->setToolTip("<qt>" + tr( "Shows labels of inactive palette tabs." ) + "</qt>");
 }
 
 void Prefs_UserInterface::restoreDefaults(struct ApplicationPrefs *prefsData)
@@ -103,6 +105,8 @@ void Prefs_UserInterface::restoreDefaults(struct ApplicationPrefs *prefsData)
 	useTabsForDocumentsCheckBox->setChecked(prefsData->uiPrefs.useTabs);
 	showSplashCheckBox->setChecked(prefsData->uiPrefs.showSplashOnStartup);
 	useSmallWidgetsCheckBox->setChecked(prefsData->uiPrefs.useSmallWidgets);
+	showLabels->setChecked(prefsData->uiPrefs.showLabels);
+	showLabelsOfInactiveTabs->setChecked(prefsData->uiPrefs.showLabelsOfInactiveTabs);
 
 	storyEditorUseSmartSelectionCheckBox->setChecked(prefsData->storyEditorPrefs.smartTextSelection);
 	seFont.fromString(prefsData->storyEditorPrefs.guiFont);
@@ -124,6 +128,8 @@ void Prefs_UserInterface::saveGuiToPrefs(struct ApplicationPrefs *prefsData) con
 	prefsData->uiPrefs.useTabs = useTabsForDocumentsCheckBox->isChecked();
 	prefsData->uiPrefs.showSplashOnStartup = showSplashCheckBox->isChecked();
 	prefsData->uiPrefs.useSmallWidgets = useSmallWidgetsCheckBox->isChecked();
+	prefsData->uiPrefs.showLabels = showLabels->isChecked();
+	prefsData->uiPrefs.showLabelsOfInactiveTabs = showLabelsOfInactiveTabs->isChecked();
 
 	prefsData->storyEditorPrefs.guiFont = seFont.toString();
 	prefsData->storyEditorPrefs.smartTextSelection = storyEditorUseSmartSelectionCheckBox->isChecked();
