@@ -26,7 +26,6 @@ for which a new license (GPL+exception) is in place.
 #include <QColor>
 #include <QComboBox>
 #include <QCursor>
-#include <QDesktopWidget>
 #include <QFile>
 #include <QGroupBox>
 #include <QHBoxLayout>
@@ -37,6 +36,7 @@ for which a new license (GPL+exception) is in place.
 #include <QPainter>
 #include <QPixmap>
 #include <QPushButton>
+#include <QScreen>
 #include <QScrollArea>
 #include <QSpacerItem>
 #include <QSpinBox>
@@ -48,28 +48,22 @@ for which a new license (GPL+exception) is in place.
 #include <cstdlib>
 #include <algorithm>
 
-#include "checkDocument.h"
-#include "cmsettings.h"
 #include "iconmanager.h"
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
-#include "prefstable.h"
 #include "printpreviewcreator.h"
 #include "printpreviewcreatorfactory.h"
-#include "pslib.h"
 #include "sccolor.h"
-#include "sccolorengine.h"
 #include "scpaths.h"
 #include "scribuscore.h"
 #include "scribusdoc.h"
 #include "ui/pageselector.h"
-#include "util.h"
 #include "util_ghostscript.h"
-#include "util_printer.h"
 
 #if defined(_WIN32)
 #include "scprintengine_gdi.h"
+#include "util_printer.h"
 #endif
 
 #include "ui_printpreviewbase.h"
@@ -97,6 +91,7 @@ PrintPreview::PrintPreview(QWidget* parent, ScribusDoc *docu, const QString& pri
 	m_ui->printLanguageCombo->setCurrentLanguage(engine);
 
 	m_previewCreator = PrintPreviewCreatorFactory::create(docu, m_ui->printLanguageCombo->currentLanguage());
+	m_previewCreator->setDevicePixelRatio(devicePixelRatioF());
 
 	m_useGhostscript = m_previewCreator->isGhostscriptBased();
 	m_haveTiffSep  = ScCore->haveTIFFSep() && (m_ui->printLanguageCombo->hasPDF() || m_ui->printLanguageCombo->hasPostscript());
@@ -190,7 +185,7 @@ PrintPreview::PrintPreview(QWidget* parent, ScribusDoc *docu, const QString& pri
 		connect(header, SIGNAL(sectionClicked(int)), this, SLOT(toggleAllFromHeader()));
 		connect(m_ui->enableCMYK, SIGNAL(clicked()), this, SLOT(toggleCMYK()));
 		connect(m_ui->displayInkCoverage, SIGNAL(clicked()), this, SLOT(toggleCMYK_Colour()));
-		connect(m_ui->inkTable, SIGNAL(cellDoubleClicked(int, int)), this, SLOT(onInkTableCellDoubleClicked(int)));
+		connect(m_ui->inkTable, SIGNAL(cellDoubleClicked(int,int)), this, SLOT(onInkTableCellDoubleClicked(int)));
 	}
 	else
 	{
@@ -245,7 +240,7 @@ PrintPreview::PrintPreview(QWidget* parent, ScribusDoc *docu, const QString& pri
 	m_ui->pageSelector->setGUIForPage(m_doc->currentPage()->pageNr());
 
 	int w = m_previewLabel->width() + inkTableWidth + 50;
-	resize(qMin(QApplication::desktop()->width() - 30, w), 500);
+	resize(qMin(ScCore->primaryMainWindow()->screen()->size().width() - 30, w), 500);
 
 	// tooltips
 	m_ui->antiAliasing->setToolTip( "<qt>" + tr( "Provides a more pleasant view of Type 1 fonts, TrueType Fonts, OpenType Fonts, EPS, PDF and vector graphics in the preview, at the expense of a slight slowdown in previewing" ) + "</qt>" );
@@ -402,7 +397,7 @@ void PrintPreview::toggleCMYK_Colour()
 	}
 	if (m_ui->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void PrintPreview::onInkTableCellDoubleClicked(int row)
@@ -416,7 +411,7 @@ void PrintPreview::onInkTableCellDoubleClicked(int row)
 
 	if (m_ui->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void PrintPreview::onPrintLanguageChange(int /*langIndex*/)
@@ -431,6 +426,8 @@ void PrintPreview::onPrintLanguageChange(int /*langIndex*/)
 	m_previewCreator = PrintPreviewCreatorFactory::create(m_doc, newPrnLanguage);
 	m_useGhostscript = m_previewCreator->isGhostscriptBased();
 
+	m_previewCreator->setDevicePixelRatio(devicePixelRatioF());
+
 	m_ui->antiAliasing->setEnabled(m_useGhostscript);
 	m_ui->showTransparency->setEnabled(m_useGhostscript);
 
@@ -467,7 +464,7 @@ void PrintPreview::toggleAllFromHeader()
 
 	if (m_ui->enableCMYK->isChecked())
 		m_previewLabel->setPixmap(createPreview(m_currentPage, qRound(72 * m_scaleFactor)));
-	m_previewLabel->resize(m_previewLabel->pixmap()->size());
+	m_previewLabel->resize(m_previewLabel->pixmap().size());
 }
 
 void PrintPreview::scaleBox_valueChanged(int value)
@@ -534,6 +531,7 @@ QPixmap PrintPreview::createPreview(int pageIndex, int res)
 		m_previewCreator->setPrintOptions(options);
 	}
 
+	m_previewCreator->setDevicePixelRatio(devicePixelRatioF());
 	m_previewCreator->setPreviewResolution(res);
 	m_previewCreator->setAntialisingEnabled(m_ui->antiAliasing->isChecked());
 	m_previewCreator->setShowTransparency(m_ui->showTransparency->isChecked());
