@@ -15,20 +15,18 @@ for which a new license (GPL+exception) is in place.
 #include <QLocale>
 #include <QSignalBlocker>
 
-#include "commonstrings.h"
+#include "extimageprops.h"
+#include "iconmanager.h"
 #include "localemgr.h"
 #include "pageitem.h"
 #include "propertiespalette_utils.h"
-#include "sccolorengine.h"
+#include "propertiespalette.h"
 #include "scribuscore.h"
-#include "scraction.h"
 #include "scribusapp.h"
 #include "scribusview.h"
 #include "selection.h"
 #include "units.h"
 #include "undomanager.h"
-#include "util.h"
-#include "util_math.h"
 
 PropertiesPalette_Image::PropertiesPalette_Image( QWidget* parent) : QWidget(parent)
 {
@@ -37,54 +35,50 @@ PropertiesPalette_Image::PropertiesPalette_Image( QWidget* parent) : QWidget(par
 	connect(userActionSniffer, SIGNAL(actionEnd()), this, SLOT(spinboxFinishUserAction()));
 
 	setupUi(this);
-	setSizePolicy( QSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum));
 
 	imagePageNumber->setMinimum(0);
 	imagePageNumber->setSpecialValueText( tr( "Auto" ));
 	imagePageNumber->setDecimals(0);
 	imagePageNumber->setSuffix("");
-	imagePageNumberLabel->setBuddy(imagePageNumber);
 	installSniffer(imagePageNumber);
 	
-//	freeScale = new QRadioButton( "&Free Scaling", this );
-//	freeScale->setChecked( true );
-//	pageLayout_4->addWidget( freeScale );
-
-	xposImgLabel->setBuddy(imageXOffsetSpinBox);
-	yposImgLabel->setBuddy(imageYOffsetSpinBox);
-	
 	imageRotation->setWrapping( true );
 	imageRotation->setNewUnit(6);
 	installSniffer(imageRotation);
-	imageRotationLabel->setBuddy(imageRotation);
 
-	freeScale->setChecked( true );
-	
 	installSniffer(imageXScaleSpinBox);
-	xscaleLabel->setBuddy(imageXScaleSpinBox);
 	installSniffer(imageYScaleSpinBox);
-	yscaleLabel->setBuddy(imageYScaleSpinBox);
+	installSniffer(imgDpiX);
+	installSniffer(imgDpiY);
 
 	keepImageWHRatioButton->setCheckable( true );
 	keepImageWHRatioButton->setAutoRaise( true );
 
-	imgDpiX->setSuffix("");
-	installSniffer(imgDpiX);
-	imgDPIXLabel->setBuddy(imgDpiX);
+	sectionImageDimensions->expand();
+	sectionImageDimensions->setCanSaveState(true);
+	sectionImageDimensions->restorePreferences();
 
-	imgDpiY->setSuffix("");
-	installSniffer(imgDpiY);
-	imgDPIYLabel->setBuddy(imgDpiY);
+	sectionImageEffects->collapse();
+	sectionImageEffects->setCanSaveState(true);
+	sectionImageEffects->restorePreferences();
 
-	keepImageDPIRatioButton->setCheckable( true );
-	keepImageDPIRatioButton->setAutoRaise( true );
+	sectionImageColorManagement->collapse();
+	sectionImageColorManagement->setCanSaveState(true);
+	sectionImageColorManagement->restorePreferences();
 
-	frameScale->setText( tr("&To Frame Size"));
+	sectionImagePDF->collapse();
+	sectionImagePDF->setCanSaveState(true);
+	sectionImagePDF->restorePreferences();
 
-	cbProportional->setEnabled( false );
-	cbProportional->setText( "P&roportional" );
-	cbProportional->setChecked( true );
+	sectionImageLayers->collapse();
+	sectionImageLayers->setCanSaveState(true);
+	sectionImageLayers->restorePreferences();
 
+	sectionImageClippingPaths->collapse();
+	sectionImageClippingPaths->setCanSaveState(true);
+	sectionImageClippingPaths->restorePreferences();
+
+	iconSetChange();
 	languageChange();
 
 	connect(imagePageNumber    , SIGNAL(valueChanged(double)), this, SLOT(handleImagePageNumber()));
@@ -95,18 +89,17 @@ PropertiesPalette_Image::PropertiesPalette_Image( QWidget* parent) : QWidget(par
 	connect(imageRotation      , SIGNAL(valueChanged(double)), this, SLOT(handleLocalRotation()));
 	connect(imgDpiX            , SIGNAL(valueChanged(double)), this, SLOT(handleDpiX()));
 	connect(imgDpiY            , SIGNAL(valueChanged(double)), this, SLOT(handleDpiY()));
-	connect(keepImageWHRatioButton , SIGNAL(clicked())       , this, SLOT(handleImageWHRatio()));
-	connect(keepImageDPIRatioButton, SIGNAL(clicked())       , this, SLOT(handleImageDPIRatio()));
-	connect(freeScale          , SIGNAL(clicked())           , this, SLOT(handleScaling()));
-	connect(frameScale         , SIGNAL(clicked())           , this, SLOT(handleScaling()));
-	connect(cbProportional     , SIGNAL(stateChanged(int))   , this, SLOT(handleScaling()));
+	connect(keepImageWHRatioButton , SIGNAL(clicked())       , this, SLOT(handleImageAspectRatio()));
+	connect(checkBoxAutoFit    , SIGNAL(toggled(bool))		 , this, SLOT(handleScaling()));
+	connect(keepImageWHRatioButton, SIGNAL(toggled(bool))	 , this, SLOT(handleScaling()));
 	connect(imgEffectsButton   , SIGNAL(clicked())           , this, SLOT(handleImageEffects()));
-	connect(imgExtProperties   , SIGNAL(clicked())           , this, SLOT(handleExtImgProperties()));
-	connect(inputProfiles      , SIGNAL(activated(const QString&)), this, SLOT(handleProfile(const QString&)));
+	connect(inputProfiles      , SIGNAL(textActivated(QString)), this, SLOT(handleProfile(QString)));
 	connect(renderIntent       , SIGNAL(activated(int))      , this, SLOT(handleIntent()));
 	connect(compressionMethod  , SIGNAL(activated(int))      , this, SLOT(handleCompressionMethod()));
 	connect(compressionQuality , SIGNAL(activated(int))      , this, SLOT(handleCompressionQuality()));
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 	connect(ScQApp, SIGNAL(localeChanged()), this, SLOT(localeChange()));
+	connect(ScQApp, SIGNAL(labelVisibilityChanged(bool)), this, SLOT(toggleLabelVisibility(bool)));
 
 }
 
@@ -114,7 +107,7 @@ void PropertiesPalette_Image::updateSpinBoxConstants()
 {
 	if (!m_haveDoc)
 		return;
-	if(m_doc->m_Selection->count()==0)
+	if (m_doc->m_Selection->count() == 0)
 		return;
 	imageXOffsetSpinBox->setConstants(&m_doc->constants());
 	imageYOffsetSpinBox->setConstants(&m_doc->constants());
@@ -139,7 +132,7 @@ void PropertiesPalette_Image::setMainWindow(ScribusMainWindow* mw)
 
 void PropertiesPalette_Image::setDoc(ScribusDoc *d)
 {
-	if((d == (ScribusDoc*) m_doc) || (m_ScMW && m_ScMW->scriptIsRunning()))
+	if ((d == (ScribusDoc*) m_doc) || (m_ScMW && m_ScMW->scriptIsRunning()))
 		return;
 
 	if (m_doc)
@@ -252,10 +245,10 @@ void PropertiesPalette_Image::updateProfileList()
 	if (m_haveDoc)
 	{
 		if (ScCore->haveCMS() && m_doc->cmsSettings().CMSinUse)
-			colorMgmtGroup->show();
+			sectionImageColorManagement->show();
 		else
 		{
-			colorMgmtGroup->hide();
+			sectionImageColorManagement->hide();
 			return;
 		}
 
@@ -320,7 +313,7 @@ void PropertiesPalette_Image::showCMSOptions()
 	if (m_haveItem)
 		updateProfileList();
 	else if (m_doc)
-		colorMgmtGroup->setVisible(ScCore->haveCMS() && m_doc->cmsSettings().CMSinUse);
+		sectionImageColorManagement->setVisible(ScCore->haveCMS() && m_doc->cmsSettings().CMSinUse);
 }
 
 void PropertiesPalette_Image::showImageRotation(double rot)
@@ -337,13 +330,7 @@ void PropertiesPalette_Image::showScaleAndOffset(double scx, double scy, double
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	bool whRatioBlocked = keepImageWHRatioButton->blockSignals(true);
-	bool dpiRatioBlocked = keepImageDPIRatioButton->blockSignals(true);
-	if (fabs(scx - scy) > 0.0002)
-	{
-		keepImageWHRatioButton->setChecked(false);
-		keepImageDPIRatioButton->setChecked(false);
-	}
+
 	if (m_haveItem)
 	{
 		imageXOffsetSpinBox->showValue(x * m_unitRatio * m_item->imageXScale());
@@ -362,8 +349,7 @@ void PropertiesPalette_Image::showScaleAndOffset(double scx, double scy, double
 		imgDpiX->showValue(72);
 		imgDpiY->showValue(72);
 	}
-	keepImageWHRatioButton->blockSignals(whRatioBlocked);
-	keepImageDPIRatioButton->blockSignals(dpiRatioBlocked);
+
 }
 
 void PropertiesPalette_Image::handleSelectionChanged()
@@ -420,7 +406,6 @@ void PropertiesPalette_Image::handleSelectionChanged()
 		setCurrentItem(currItem);
 	}
 	updateGeometry();
-	//repaint();
 }
 
 void PropertiesPalette_Image::handleUpdateRequest(int updateFlags)
@@ -446,38 +431,52 @@ void PropertiesPalette_Image::setCurrentItem(PageItem *item)
 	m_haveItem = false;
 	m_item = item;
 
+	imageLayers->setCurrentItem(m_item, m_ScMW->view);
+	clippingPaths->setCurrentItem(m_item, m_ScMW->view);
+
 	if (m_item->isImageFrame())
 	{
+		ImageInfoRecord *info = &m_item->pixm.imgInfo;
+
 		imagePageNumber->blockSignals(true);
-		if(m_item->imageIsAvailable)
-		{
-			imagePageNumber->setMaximum(m_item->pixm.imgInfo.numberOfPages);
-			imagePageNumber->setEnabled(true);
-		}
-		else
-			imagePageNumber->setEnabled(false);
-		imagePageNumber->setValue(m_item->pixm.imgInfo.actualPageNumber);
+		if (m_item->imageIsAvailable)
+			imagePageNumber->setMaximum(info->numberOfPages);
+		imagePageNumber->setValue(info->actualPageNumber);
+		imagePageNumberLabel->setVisible(info->numberOfPages > 1);
+		imagePageNumber->blockSignals(false);
 
 		compressionMethod->setCurrentIndex(m_item->OverrideCompressionMethod ? m_item->CompressionMethodIndex + 1 : 0);
 		compressionQuality->setCurrentIndex(m_item->OverrideCompressionQuality ? m_item->CompressionQualityIndex + 1 : 0);
-		imagePageNumber->blockSignals(false);
 
 		imageXScaleSpinBox->blockSignals(true);
 		imageYScaleSpinBox->blockSignals(true);
 		imageXOffsetSpinBox->blockSignals(true);
 		imageYOffsetSpinBox->blockSignals(true);
+		imgDpiX->blockSignals(true);
+		imgDpiY->blockSignals(true);
+		keepImageWHRatioButton->blockSignals(true);
+		checkBoxAutoFit->blockSignals(true);
 		imageRotation->blockSignals(true);
 
-		imgEffectsButton->setVisible(m_item->imageIsAvailable && m_item->isRaster);
-		imgExtProperties->setVisible(m_item->imageIsAvailable && m_item->pixm.imgInfo.valid);
+		sectionImageEffects->setVisible(m_item->imageIsAvailable && m_item->isRaster);
+
+		if (m_item->imageIsAvailable && info->valid)
+		{
+			sectionImageLayers->setVisible(info->layerInfo.count() != 0);
+			sectionImageClippingPaths->setVisible(info->PDSpathData.count() != 0);
+		}
+		else
+		{
+			sectionImageLayers->setVisible(false);
+			sectionImageClippingPaths->setVisible(false);
+		}
+
 		bool setter = m_item->ScaleType;
-		freeScale->setChecked(setter);
-		frameScale->setChecked(!setter);
+		checkBoxAutoFit->setChecked(!setter);
+
 		if ((m_item->isLatexFrame()) || (m_item->isOSGFrame()))
 		{
-			freeScale->setEnabled(false);
-			frameScale->setEnabled(false);
-			cbProportional->setEnabled(false);
+			checkBoxAutoFit->setEnabled(false);
 			imageXScaleSpinBox->setEnabled(false);
 			imageYScaleSpinBox->setEnabled(false);
 			imgDpiX->setEnabled(false);
@@ -489,35 +488,24 @@ void PropertiesPalette_Image::setCurrentItem(PageItem *item)
 			imageYScaleSpinBox->setEnabled(setter);
 			imgDpiX->setEnabled(setter);
 			imgDpiY->setEnabled(setter);
-			cbProportional->setEnabled(!setter);
-			cbProportional->setChecked(m_item->AspectRatio);
-			freeScale->setEnabled(true);
-			frameScale->setEnabled(true);
-			//Necessary for undo action
-			keepImageWHRatioButton->setEnabled(setter);
-			keepImageDPIRatioButton->setEnabled(setter);
+			checkBoxAutoFit->setEnabled(true);
 			keepImageWHRatioButton->setChecked(m_item->AspectRatio);
-			keepImageDPIRatioButton->setChecked(m_item->AspectRatio);
 		}
-//CB Why do we need this? Setting it too much here
-// 		if (setter == true)
-// 		{
-// 			keepImageWHRatioButton->setChecked(setter);
-// 			keepImageDPIRatioButton->setChecked(setter);
-// 		}
-		//imageXOffsetSpinBox->setEnabled(setter);
-		//imageYOffsetSpinBox->setEnabled(setter);
-		//imageRotation->setEnabled(setter);
 
 		imageXScaleSpinBox->blockSignals(false);
 		imageYScaleSpinBox->blockSignals(false);
 		imageXOffsetSpinBox->blockSignals(false);
 		imageYOffsetSpinBox->blockSignals(false);
+		imgDpiX->blockSignals(false);
+		imgDpiY->blockSignals(false);
+		keepImageWHRatioButton->blockSignals(false);
+		checkBoxAutoFit->blockSignals(false);
 		imageRotation->blockSignals(false);
 	}
 	m_haveItem = true;
 
 	showScaleAndOffset(m_item->imageXScale(), m_item->imageYScale(), m_item->imageXOffset(), m_item->imageYOffset());
+
 	double rrR = m_item->imageRotation();
 	if (m_item->imageRotation() > 0)
 		rrR = 360 - rrR;
@@ -527,11 +515,7 @@ void PropertiesPalette_Image::setCurrentItem(PageItem *item)
 	{
 		updateProfileList();
 	}
-	if (m_item->isOSGFrame())
-	{
-		setEnabled(false);
-	}
-	if (m_item->isSymbol())
+	if (m_item->isOSGFrame() || m_item->isSymbol())
 	{
 		setEnabled(false);
 	}
@@ -566,7 +550,6 @@ void PropertiesPalette_Image::handleLocalDpi()
 	{
 		//CB Don't pass in the scale to the offset change as its taken from the new scale
 		m_doc->itemSelection_SetImageScaleAndOffset(72.0 / imgDpiX->value(), 72.0 / imgDpiY->value(), imageXOffsetSpinBox->value() / m_unitRatio, imageYOffsetSpinBox->value() / m_unitRatio);
-		
 		imageXScaleSpinBox->showValue(m_item->imageXScale() * 100 / 72.0 * m_item->pixm.imgInfo.xres);
 		imageYScaleSpinBox->showValue(m_item->imageYScale() * 100 / 72.0 * m_item->pixm.imgInfo.yres);
 	}
@@ -579,7 +562,7 @@ void PropertiesPalette_Image::handleLocalRotation()
 	if (m_haveDoc && m_haveItem)
 	{
 		m_doc->itemSelection_SetImageRotation(360 - imageRotation->value());
-		if (frameScale->isChecked())
+		if (checkBoxAutoFit->isChecked())
 		{
 			m_item->adjustPictScale();
 			m_item->update();
@@ -592,41 +575,19 @@ void PropertiesPalette_Image::handleScaling()
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
 
-	if (freeScale == sender())
+	if (checkBoxAutoFit == sender())
 	{
-		frameScale->setChecked(false);
-		freeScale->setChecked(true);
-		cbProportional->setEnabled(false);
-//		imageXOffsetSpinBox->setEnabled(true);
-//		imageYOffsetSpinBox->setEnabled(true);
-		imageXScaleSpinBox->setEnabled(true);
-		imageYScaleSpinBox->setEnabled(true);
-		imgDpiX->setEnabled(true);
-		imgDpiY->setEnabled(true);
-//		imageRotation->setEnabled(true);
-		keepImageWHRatioButton->setEnabled(true);
-		keepImageDPIRatioButton->setEnabled(true);
-	}
-	if (frameScale == sender())
-	{
-		frameScale->setChecked(true);
-		freeScale->setChecked(false);
-		cbProportional->setEnabled(true);
-//		imageXOffsetSpinBox->setEnabled(false);
-//		imageYOffsetSpinBox->setEnabled(false);
-		imageXScaleSpinBox->setEnabled(false);
-		imageYScaleSpinBox->setEnabled(false);
-		imgDpiX->setEnabled(false);
-		imgDpiY->setEnabled(false);
-//		imageRotation->setEnabled(false);
-		keepImageWHRatioButton->setEnabled(false);
-		keepImageDPIRatioButton->setEnabled(false);
+		imageXScaleSpinBox->setEnabled(!checkBoxAutoFit->isChecked());
+		imageYScaleSpinBox->setEnabled(!checkBoxAutoFit->isChecked());
+		imgDpiX->setEnabled(!checkBoxAutoFit->isChecked());
+		imgDpiY->setEnabled(!checkBoxAutoFit->isChecked());
 	}
 
 	if (m_haveDoc && m_haveItem)
 	{
-		m_item->setImageScalingMode(freeScale->isChecked(), cbProportional->isChecked());
+		m_item->setImageScalingMode(!checkBoxAutoFit->isChecked(), keepImageWHRatioButton->isChecked());
 		m_doc->changed();
+		m_doc->changedPagePreview();
 		emit UpdtGui(PageItem::ImageFrame);
 	}
 }
@@ -657,7 +618,7 @@ void PropertiesPalette_Image::handleDpiX()
 {
 	bool dpiXBlocked = imgDpiX->blockSignals(true);
 	bool dpiYBlocked = imgDpiY->blockSignals(true);
-	if (keepImageDPIRatioButton->isChecked())
+	if (keepImageWHRatioButton->isChecked())
 		imgDpiY->setValue(imgDpiX->value());
 	handleLocalDpi();
 	imgDpiX->blockSignals(dpiXBlocked);
@@ -668,59 +629,38 @@ void PropertiesPalette_Image::handleDpiY()
 {
 	bool dpiXBlocked = imgDpiX->blockSignals(true);
 	bool dpiYBlocked = imgDpiY->blockSignals(true);
-	if (keepImageDPIRatioButton->isChecked())
+	if (keepImageWHRatioButton->isChecked())
 		imgDpiX->setValue(imgDpiY->value());
 	handleLocalDpi();
 	imgDpiX->blockSignals(dpiXBlocked);
 	imgDpiY->blockSignals(dpiYBlocked);
 }
 
-void PropertiesPalette_Image::handleImageDPIRatio()
+void PropertiesPalette_Image::handleImageAspectRatio()
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
 		return;
-	bool dpiXBlocked = imgDpiX->blockSignals(true);
-	bool dpiYBlocked = imgDpiY->blockSignals(true);
-	if (keepImageDPIRatioButton->isChecked())
-	{
-		double minXY = qMin(imgDpiX->value(), imgDpiY->value());
-		imgDpiX->setValue(minXY);
-		imgDpiY->setValue(minXY);
-		handleLocalDpi();
-		keepImageWHRatioButton->setChecked(true);
-		cbProportional->setChecked(true);
-	}
-	else
-	{
-		keepImageWHRatioButton->setChecked(false);
-		cbProportional->setChecked(false);
-	}
-	imgDpiX->blockSignals(dpiXBlocked);
-	imgDpiY->blockSignals(dpiYBlocked);
-}
 
-void PropertiesPalette_Image::handleImageWHRatio()
-{
-	if (!m_ScMW || m_ScMW->scriptIsRunning())
-		return;
 	bool xscaleBlocked = imageXScaleSpinBox->blockSignals(true);
 	bool yscaleBlocked = imageYScaleSpinBox->blockSignals(true);
+	bool dpiXBlocked = imgDpiX->blockSignals(true);
+	bool dpiYBlocked = imgDpiY->blockSignals(true);
 	if (keepImageWHRatioButton->isChecked())
 	{
 		double maxXY = qMax(imageXScaleSpinBox->value(), imageYScaleSpinBox->value());
 		imageXScaleSpinBox->setValue(maxXY);
 		imageYScaleSpinBox->setValue(maxXY);
 		handleLocalScale();
-		keepImageDPIRatioButton->setChecked(true);
-		cbProportional->setChecked(true);
-	}
-	else
-	{
-		keepImageDPIRatioButton->setChecked(false);
-		cbProportional->setChecked(false);
+
+		double minXY = qMin(imgDpiX->value(), imgDpiY->value());
+		imgDpiX->setValue(minXY);
+		imgDpiY->setValue(minXY);
+		handleLocalDpi();
 	}
 	imageXScaleSpinBox->blockSignals(xscaleBlocked);
 	imageYScaleSpinBox->blockSignals(yscaleBlocked);
+	imgDpiX->blockSignals(dpiXBlocked);
+	imgDpiY->blockSignals(dpiYBlocked);
 }
 
 void PropertiesPalette_Image::handleImageEffects()
@@ -730,20 +670,12 @@ void PropertiesPalette_Image::handleImageEffects()
 	m_ScMW->ImageEffects();
 }
 
-void PropertiesPalette_Image::handleExtImgProperties()
-{
-	if (!m_haveDoc || !m_haveItem || !m_ScMW || m_ScMW->scriptIsRunning())
-		return;
-	m_ScMW->view->editExtendedImageProperties();
-	m_doc->changed();
-}
-
 void PropertiesPalette_Image::handleImagePageNumber()
 {
 	if (!m_haveDoc || !m_haveItem || !m_ScMW || m_ScMW->scriptIsRunning())
 		return;
 	bool reallynew = (m_item->pixm.imgInfo.actualPageNumber != imagePageNumber->value());
-	if(UndoManager::undoEnabled())
+	if (UndoManager::undoEnabled())
 	{
 		SimpleState *ss = new SimpleState(Um::PageNmbr.arg(static_cast<int>(imagePageNumber->value())),"",Um::IImageFrame);
 		ss->set("IMAGE_NBR");
@@ -785,6 +717,16 @@ void PropertiesPalette_Image::handleCompressionQuality()
 	m_doc->itemSelection_SetCompressionQuality(compressionQuality->currentIndex() - 1);
 }
 
+
+void PropertiesPalette_Image::iconSetChange()
+{
+	IconManager& im = IconManager::instance();
+
+	xscaleLabel->setPixmap(im.loadPixmap("scale-width"));
+	yscaleLabel->setPixmap(im.loadPixmap("scale-height"));
+	imageRotationLabel->setPixmap(im.loadPixmap("object-rotation"));
+}
+
 void PropertiesPalette_Image::languageChange()
 {
 	retranslateUi(this);
@@ -827,9 +769,12 @@ void PropertiesPalette_Image::languageChange()
 
 	QString ptSuffix = tr(" pt");
 	QString suffix   = (m_haveDoc) ? unitGetSuffixFromIndex(m_doc->unitIndex()) : ptSuffix;
-
 	imageXOffsetSpinBox->setSuffix(suffix);
 	imageYOffsetSpinBox->setSuffix(suffix);
+
+	QString dpiSuffix = tr(" dpi");
+	imgDpiX->setSuffix(dpiSuffix);
+	imgDpiY->setSuffix(dpiSuffix);
 }
 
 void PropertiesPalette_Image::unitChange()
@@ -860,6 +805,13 @@ void PropertiesPalette_Image::localeChange()
 	imgDpiY->setLocale(l);
 }
 
+void PropertiesPalette_Image::toggleLabelVisibility(bool v)
+{
+	imagePageNumberLabel->setLabelVisibility(v);
+	imageRotationLabel->setLabelVisibility(v);
+	imageScaleLabel->setLabelVisibility(v);
+}
+
 bool PropertiesPalette_Image::userActionOn()
 {
 	return m_userActionOn;
