@@ -14,27 +14,17 @@ for which a new license (GPL+exception) is in place.
 
 #include "appmodes.h"
 #include "autoform.h"
-#include "commonstrings.h"
 #include "iconmanager.h"
 #include "localemgr.h"
+#include "ui/nodeeditpalette.h"
 #include "pageitem_arc.h"
 #include "pageitem_regularpolygon.h"
-#include "pageitem_textframe.h"
-#include "polyprops.h"
-#include "sccolorengine.h"
-#include "scraction.h"
+#include "scribus.h"
 #include "scribusapp.h"
-#include "scribuscore.h"
 #include "scribusdoc.h"
 #include "scribusview.h"
 #include "selection.h"
-#include "ui/nodeeditpalette.h"
-#include "ui/propertiespalette_utils.h"
-#include "ui/propertiespalette_xyz.h"
-#include "undomanager.h"
 #include "units.h"
-#include "util.h"
-#include "util_math.h"
 
 PropertiesPalette_Shape::PropertiesPalette_Shape( QWidget* parent)
 	: QWidget(parent)
@@ -50,13 +40,12 @@ PropertiesPalette_Shape::PropertiesPalette_Shape( QWidget* parent)
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 	connect(ScQApp, SIGNAL(localeChanged()), this, SLOT(localeChange()));
+	connect(ScQApp, SIGNAL(labelVisibilityChanged(bool)), this, SLOT(toggleLabelVisibility(bool)));
 
-	connect(textFlowBtnGroup, SIGNAL(buttonClicked(int)), this, SLOT(handleTextFlow()));
-	connect(editShape  , SIGNAL(clicked())                 , this, SLOT(handleShapeEdit()));
-	connect(roundRect  , SIGNAL(valueChanged(double))      , this, SLOT(handleCornerRadius()));
-	connect(evenOdd    , SIGNAL(clicked())                 , this, SLOT(handleFillRule()) );
-	connect(nonZero    , SIGNAL(clicked())                 , this, SLOT(handleFillRule()) );
-	connect(customShape, SIGNAL(FormSel(int, int, qreal *)), this, SLOT(handleNewShape(int, int, qreal *)));
+	connect(textFlowBtnGroup, SIGNAL(idClicked(int)), this, SLOT(handleTextFlow()));
+	connect(editShape, SIGNAL(clicked()) , this, SLOT(handleShapeEdit()));
+	connect(roundRect, SIGNAL(valueChanged(double)) , this, SLOT(handleCornerRadius()));
+	connect(customShape, SIGNAL(FormSel(int,int,qreal*)), this, SLOT(handleNewShape(int,int,qreal*)));
 
 	roundRect->showValue(0);
 }
@@ -81,7 +70,7 @@ void PropertiesPalette_Shape::setMainWindow(ScribusMainWindow* mw)
 
 void PropertiesPalette_Shape::setDoc(ScribusDoc *d)
 {
-	if((d == (ScribusDoc*) m_doc) || (m_ScMW && m_ScMW->scriptIsRunning()))
+	if ((d == (ScribusDoc*) m_doc) || (m_ScMW && m_ScMW->scriptIsRunning()))
 		return;
 
 	if (m_doc)
@@ -339,20 +328,6 @@ void PropertiesPalette_Shape::setCurrentItem(PageItem *item)
 
 	roundRect->setValue(m_item->cornerRadius()*m_unitRatio);
 	showTextFlowMode(m_item->textFlowMode());
-
-	if (m_item->isPathText() || m_item->isTextFrame() || m_item->isImageFrame())
-	{
-		nonZero->setChecked(false);
-		nonZero->setEnabled(false);
-		evenOdd->setChecked(false);
-		evenOdd->setEnabled(false);
-	}
-	else
-	{
-		nonZero->setEnabled(true);
-		evenOdd->setEnabled(true);
-		showFillRule(m_item->fillRule);
-	}
 	setLocked(m_item->locked());
 	setSizeLocked(m_item->sizeLocked());
 
@@ -405,6 +380,7 @@ void PropertiesPalette_Shape::handleTextFlow()
 			mode = PageItem::TextFlowUsesImageClipping;
 		m_item->setTextFlowMode(mode);
 		m_doc->changed();
+		m_doc->changedPagePreview();
 		m_doc->invalidateAll();
 		m_doc->regionsChanged()->update(QRect());
 	}
@@ -439,6 +415,7 @@ void PropertiesPalette_Shape::handleShapeEdit()
 			connect(m_ScMW->nodePalette, SIGNAL(paletteClosed()), this, SLOT(handleShapeEditEnded()));
 		}
 		m_doc->changed();
+		m_doc->changedPagePreview();
 	}
 }
 
@@ -463,19 +440,12 @@ void PropertiesPalette_Shape::handleCornerRadius()
 	m_item->setCornerRadius(roundRect->value() / m_unitRatio);
 	m_doc->setFrameRounded();
 	m_doc->changed();
+	m_doc->changedPagePreview();
 	//called from setFrameRounded already!
 	m_doc->regionsChanged()->update(QRect());
 	m_item->update();
 }
 
-void PropertiesPalette_Shape::handleFillRule()
-{
-	if (!m_haveDoc || !m_haveItem || !m_ScMW || m_ScMW->scriptIsRunning())
-		return;
-	m_item->setFillEvenOdd(evenOdd->isChecked());
-	m_item->update();
-}
-
 void PropertiesPalette_Shape::handleNewShape(int f, int c, qreal *vals)
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning())
@@ -498,14 +468,6 @@ void PropertiesPalette_Shape::handleNewShape(int f, int c, qreal *vals)
 	}
 }
 
-void PropertiesPalette_Shape::showFillRule(bool fillRule)
-{
-	if (fillRule)
-		evenOdd->setChecked(fillRule);
-	else
-		nonZero->setChecked(!fillRule);
-}
-
 void PropertiesPalette_Shape::showTextFlowMode(PageItem::TextFlowMode mode)
 {
 	if (!m_ScMW || m_ScMW->scriptIsRunning() || !m_haveItem)
@@ -537,9 +499,6 @@ void PropertiesPalette_Shape::iconSetChange()
 	textFlowUsesBoundingBox->setIcon(iconManager.loadIcon("flow-bounding.png"));
 	textFlowUsesContourLine->setIcon(iconManager.loadIcon("flow-contour.png"));
 	textFlowUsesImageClipping->setIcon(iconManager.loadIcon("flow-contour.png"));
-
-	evenOdd->setIcon(iconManager.loadIcon("fill-rule-even-odd.png"));
-	nonZero->setIcon(iconManager.loadIcon("fill-rule-nonzero.png"));
 }
 
 void PropertiesPalette_Shape::languageChange()
@@ -569,3 +528,8 @@ void PropertiesPalette_Shape::localeChange()
 	const QLocale& l(LocaleManager::instance().userPreferredLocale());
 	roundRect->setLocale(l);
 }
+
+void PropertiesPalette_Shape::toggleLabelVisibility(bool v)
+{
+	labelTextFlow->setLabelVisibility(v);
+}
