@@ -43,8 +43,8 @@ PropertiesPalette_Table::PropertiesPalette_Table(QWidget* parent) : QWidget(pare
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 
-	connect(tableStyleCombo, SIGNAL(newStyle(const QString&)), this, SLOT(setTableStyle(const QString&)));
-	connect(cellStyleCombo, SIGNAL(newStyle(const QString&)), this, SLOT(setCellStyle(const QString&)));
+	connect(tableStyleCombo, SIGNAL(newStyle(QString)), this, SLOT(setTableStyle(QString)));
+	connect(cellStyleCombo, SIGNAL(newStyle(QString)), this, SLOT(setCellStyle(QString)));
 }
 
 void PropertiesPalette_Table::iconSetChange()
@@ -497,7 +497,7 @@ void PropertiesPalette_Table::on_borderLineShade_valueChanged(double shade)
 	updateBorderLineListItem();
 }
 
-void PropertiesPalette_Table::on_borderLineColor_activated(const QString& colorName)
+void PropertiesPalette_Table::on_borderLineColor_textActivated(const QString& colorName)
 {
 	int index = borderLineList->currentRow();
 	TableBorderLine borderLine = m_currentBorder.borderLines().at(index);
@@ -522,7 +522,7 @@ void PropertiesPalette_Table::on_borderLineStyle_activated(int style)
 	updateBorderLineListItem();
 }
 
-void PropertiesPalette_Table::on_fillColor_activated(const QString& colorName)
+void PropertiesPalette_Table::on_fillColor_textActivated(const QString& colorName)
 {
 	if (!m_item || !m_item->isTable())
 		return;
