@@ -19,6 +19,8 @@ for which a new license (GPL+exception) is in place.
 *                                                                         *
 ***************************************************************************/
 
+#include <utility>
+
 #include <QByteArray>
 #include <QComboBox>
 #include <QCryptographicHash>
@@ -43,7 +45,6 @@ for which a new license (GPL+exception) is in place.
 #include "scpaths.h"
 #include "scribusapp.h"
 #include "third_party/zip/scribus_zip.h"
-#include "util.h"
 #include "util_file.h"
 
 ResourceManager::ResourceManager(QWidget* parent)
@@ -117,22 +118,37 @@ void ResourceManager::readAvailableFonts()
 		return;
 
 	QTextStream ts(&dataFile);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
-	QString errorMsg;
-	int eline;
-	int ecol;
+	ts.setEncoding(QStringConverter::Utf8);
+
 	QDomDocument doc( m_dataFiles[RM_FONTS] );
 	QString data(ts.readAll());
 	dataFile.close();
-	if ( !doc.setContent( data, &errorMsg, &eline, &ecol ))
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
+	{
+//		qDebug() << parseResult.errorMessage << parseResult.errorLine << parseResult.errorColumn;
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			qDebug() << "File not found on server";
+		else
+			qDebug() << "Could not open file" << dataFile.fileName();
+		return;
+	}
+#else
+	QString errorMsg;
+	int eline;
+	int ecol;
+	if (!doc.setContent( data, &errorMsg, &eline, &ecol))
 	{
 //		qDebug()<<errorMsg<<eline<<ecol;
 		if (data.contains("404 not found", Qt::CaseInsensitive))
-			qDebug()<<"File not found on server";
+			qDebug() << "File not found on server";
 		else
-			qDebug()<<"Could not open file"<<dataFile.fileName();
+			qDebug() << "Could not open file" << dataFile.fileName();
 		return;
 	}
+#endif
 	m_availableList.clear();
 
 	QDomElement docElem = doc.documentElement();
@@ -148,7 +164,6 @@ void ResourceManager::readAvailableFonts()
 
 		struct DownloadItem d;
 		d.desc = e.attribute("description");
-		d.download = false;
 		d.files = e.attribute("files");
 		d.extractfiles = e.attribute("extractfiles");
 		d.url = e.attribute("URL");
@@ -162,7 +177,7 @@ void ResourceManager::readAvailableFonts()
 		if (url.isValid() && !url.isEmpty() && !url.host().isEmpty())
 			m_availableList.append(d);
 //		else
-//			qDebug()<<"rm : availFonts : invalid URL"<<d.url;
+//			qDebug() << "rm : availFonts : invalid URL" << d.url;
 	}
 }
 
@@ -175,21 +190,35 @@ void ResourceManager::readAvailableHelp()
 		return;
 
 	QTextStream ts(&dataFile);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
-	QString errorMsg;
-	int eline;
-	int ecol;
+	ts.setEncoding(QStringConverter::Utf8);
+
 	QDomDocument doc( QString(m_dataFiles[RM_HELP]).remove(".xml") );
 	QString data(ts.readAll());
 	dataFile.close();
-	if ( !doc.setContent( data, &errorMsg, &eline, &ecol ))
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
 	{
 		if (data.contains("404 not found", Qt::CaseInsensitive))
-			qDebug()<<"File not found on server";
+			qDebug() << "File not found on server";
 		else
-			qDebug()<<"Could not open file"<<dataFile.fileName();
+			qDebug() << "Could not open file" << dataFile.fileName();
 		return;
 	}
+#else
+	QString errorMsg;
+	int eline;
+	int ecol;
+	if (!doc.setContent( data, &errorMsg, &eline, &ecol))
+	{
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			qDebug() << "File not found on server";
+		else
+			qDebug() << "Could not open file" << dataFile.fileName();
+		return;
+	}
+#endif
 	m_availableList.clear();
 
 	QDomElement docElem = doc.documentElement();
@@ -207,9 +236,7 @@ void ResourceManager::readAvailableHelp()
 
 		struct DownloadItem d;
 		d.desc = e.attribute("description");
-		d.download = false;
 		d.files = e.attribute("files");
-		d.extractfiles = "";
 		d.url = e.attribute("URL");
 		d.version = e.attribute("version");
 		d.lang = e.attribute("language");
@@ -231,21 +258,35 @@ void ResourceManager::readAvailablePalettes()
 		return;
 
 	QTextStream ts(&dataFile);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
-	QString errorMsg;
-	int eline;
-	int ecol;
+	ts.setEncoding(QStringConverter::Utf8);
+
 	QDomDocument doc( QString(m_dataFiles[RM_PALETTES]).remove(".xml") );
 	QString data(ts.readAll());
 	dataFile.close();
-	if ( !doc.setContent( data, &errorMsg, &eline, &ecol ))
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
 	{
 		if (data.contains("404 not found", Qt::CaseInsensitive))
-			qDebug()<<"File not found on server";
+			qDebug() << "File not found on server";
 		else
-			qDebug()<<"Could not open file"<<dataFile.fileName();
+			qDebug() << "Could not open file" << dataFile.fileName();
 		return;
 	}
+#else
+	QString errorMsg;
+	int eline;
+	int ecol;
+	if (!doc.setContent(data, &errorMsg, &eline, &ecol))
+	{
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			qDebug() << "File not found on server";
+		else
+			qDebug() << "Could not open file" << dataFile.fileName();
+		return;
+	}
+#endif
 	m_availableList.clear();
 
 	QDomElement docElem = doc.documentElement();
@@ -261,9 +302,7 @@ void ResourceManager::readAvailablePalettes()
 
 		struct DownloadItem d;
 		d.desc = e.attribute("description");
-		d.download = false;
 		d.files = e.attribute("files");
-		d.extractfiles = "";
 		d.url = e.attribute("URL");
 		d.version = e.attribute("version");
 		d.lang = e.attribute("language");
@@ -293,7 +332,7 @@ void ResourceManager::updateInstalledFonts()
 {
 	m_dictionaryMap.clear();
 	QString fontDir(findDestinationFolder());
-	for (const DownloadItem& d : qAsConst(m_availableList))
+	for (const DownloadItem& d : std::as_const(m_availableList))
 	{
 		if (d.filetype!="zip")
 		{
@@ -376,7 +415,7 @@ void ResourceManager::updateInstalledHyph()
 	}
 
 	QStringList headers;
-	headers << tr("Language") << tr("Code") << tr("Location") << tr("Licence");
+	headers << tr("Language") << tr("Code") << tr("Location") << tr("License");
 	installedTableWidget->setHorizontalHeaderLabels(headers);
 	installedTableWidget->resizeColumnsToContents();
 	installedTableWidget->setSortingEnabled(true);
@@ -435,7 +474,7 @@ void ResourceManager::updateInstalledHelp()
 {
 	m_dictionaryMap.clear();
 	QString helpDir(findDestinationFolder());
-	for (const DownloadItem &d : qAsConst(m_availableList))
+	for (const DownloadItem &d : std::as_const(m_availableList))
 	{
 		if (QFileInfo::exists(helpDir+d.lang))
 			m_dictionaryMap.insert(d.desc, helpDir+d.lang);
@@ -473,7 +512,7 @@ void ResourceManager::updateInstalledPalettes()
 {
 	m_dictionaryMap.clear();
 	QString palDir(findDestinationFolder());
-	for (const DownloadItem& d : qAsConst(m_availableList))
+	for (const DownloadItem& d : std::as_const(m_availableList))
 	{
 		if (QFileInfo::exists(palDir+d.files))
 			m_dictionaryMap.insert(d.desc, palDir+d.files);
@@ -527,7 +566,7 @@ void ResourceManager::updateAvailableFonts()
 	availableTableWidget->setSortingEnabled(false);
 
 	int row = 0;
-	for (const DownloadItem& d :  qAsConst(m_availableList))
+	for (const DownloadItem& d : std::as_const(m_availableList))
 	{
 		int column = 0;
 //		qDebug()<<d.version<<d.files<<d.url<<d.desc<<d.license;
@@ -566,21 +605,35 @@ void ResourceManager::updateAvailableHyph()
 		return;
 
 	QTextStream ts(&dataFile);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
-	QString errorMsg;
-	int eline;
-	int ecol;
+	ts.setEncoding(QStringConverter::Utf8);
+
 	QDomDocument doc( QString(m_dataFiles[RM_HYPH]).remove(".xml") );
 	QString data(ts.readAll());
 	dataFile.close();
-	if ( !doc.setContent( data, &errorMsg, &eline, &ecol ))
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
 	{
 		if (data.contains("404 not found", Qt::CaseInsensitive))
-			qDebug()<<"File not found on server";
+			qDebug() << "File not found on server";
 		else
-			qDebug()<<"Could not open file"<<dataFile.fileName();
+			qDebug() << "Could not open file" << dataFile.fileName();
 		return;
 	}
+#else
+	QString errorMsg;
+	int eline;
+	int ecol;
+	if (!doc.setContent(data, &errorMsg, &eline, &ecol))
+	{
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			qDebug() << "File not found on server";
+		else
+			qDebug() << "Could not open file" << dataFile.fileName();
+		return;
+	}
+#endif
 	m_availableList.clear();
 
 	QDomElement docElem = doc.documentElement();
@@ -598,7 +651,6 @@ void ResourceManager::updateAvailableHyph()
 
 		struct DownloadItem d;
 		d.desc = e.attribute("description");
-		d.download = false;
 		d.files = e.attribute("files");
 		d.extractfiles = e.attribute("extractfiles");
 		d.url = e.attribute("URL");
@@ -611,7 +663,7 @@ void ResourceManager::updateAvailableHyph()
 		if (url.isValid() && !url.isEmpty() && !url.host().isEmpty())
 			m_availableList.append(d);
 		//else
-		//	qDebug()<<"hysettings : availDicts : invalid URL"<<d.url;
+		//	qDebug() << "hysettings : availDicts : invalid URL" << d.url;
 	}
 	availableTableWidget->clear();
 	if (m_availableList.isEmpty())
@@ -624,7 +676,7 @@ void ResourceManager::updateAvailableHyph()
 	availableTableWidget->setSortingEnabled(false);
 
 	int row = 0;
-	for (const DownloadItem& d : qAsConst(m_availableList))
+	for (const DownloadItem& d : std::as_const(m_availableList))
 	{
 		int column = 0;
 		//qDebug()<<d.version<<d.files<<d.url<<d.desc<<d.license;
@@ -666,21 +718,35 @@ void ResourceManager::updateAvailableSpell()
 		return;
 
 	QTextStream ts(&dataFile);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
-	QString errorMsg;
-	int eline;
-	int ecol;
+	ts.setEncoding(QStringConverter::Utf8);
+
 	QDomDocument doc( QString(m_dataFiles[RM_SPELL]).remove(".xml") );
 	QString data(ts.readAll());
 	dataFile.close();
-	if ( !doc.setContent( data, &errorMsg, &eline, &ecol ))
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
 	{
 		if (data.contains("404 not found", Qt::CaseInsensitive))
-			qDebug()<<"File not found on server";
+			qDebug() << "File not found on server";
 		else
-			qDebug()<<"Could not open file"<<dataFile.fileName();
+			qDebug() << "Could not open file" << dataFile.fileName();
 		return;
 	}
+#else
+	QString errorMsg;
+	int eline;
+	int ecol;
+	if (!doc.setContent(data, &errorMsg, &eline, &ecol))
+	{
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			qDebug() << "File not found on server";
+		else
+			qDebug() << "Could not open file" << dataFile.fileName();
+		return;
+	}
+#endif
 	m_availableList.clear();
 
 	QDomElement docElem = doc.documentElement();
@@ -698,7 +764,6 @@ void ResourceManager::updateAvailableSpell()
 
 		struct DownloadItem d;
 		d.desc = e.attribute("description");
-		d.download = false;
 		d.files = e.attribute("files");
 		d.extractfiles = e.attribute("extractfiles");
 		d.url = e.attribute("URL");
@@ -711,7 +776,7 @@ void ResourceManager::updateAvailableSpell()
 		if (url.isValid() && !url.isEmpty() && !url.host().isEmpty())
 			m_availableList.append(d);
 		//else
-		//	qDebug()<<"hysettings : availDicts : invalid URL"<<d.url;
+		//	qDebug() << "hysettings : availDicts : invalid URL" << d.url;
 	}
 	availableTableWidget->clear();
 	if (m_availableList.isEmpty())
@@ -724,7 +789,7 @@ void ResourceManager::updateAvailableSpell()
 	availableTableWidget->setSortingEnabled(false);
 
 	int row = 0;
-	for (const DownloadItem& d : qAsConst(m_availableList))
+	for (const DownloadItem& d : std::as_const(m_availableList))
 	{
 		int column = 0;
 		//qDebug()<<d.version<<d.files<<d.url<<d.desc<<d.license;
@@ -775,7 +840,7 @@ void ResourceManager::updateAvailableHelp()
 	availableTableWidget->setSortingEnabled(false);
 
 	int row = 0;
-	for (const DownloadItem& d :  qAsConst(m_availableList))
+	for (const DownloadItem& d : std::as_const(m_availableList))
 	{
 		int column = 0;
 		QTableWidgetItem *newItem1 = new QTableWidgetItem(d.desc);
@@ -820,7 +885,7 @@ void ResourceManager::updateAvailablePalettes()
 	availableTableWidget->setSortingEnabled(false);
 
 	int row = 0;
-	for (const DownloadItem &d : qAsConst(m_availableList))
+	for (const DownloadItem &d : std::as_const(m_availableList))
 	{
 		int column = 0;
 		QTableWidgetItem *newItem1 = new QTableWidgetItem(d.desc);
@@ -937,24 +1002,24 @@ void ResourceManager::updateDownloadLists()
 	downloadProgressBar->setVisible(true);
 	dataReceivedLabel->setVisible(true);
 	downloadProgressBar->setRange(0, m_dataFiles.count());
-	for (const QString& f : qAsConst(m_dataFiles))
+	for (const QString& f : std::as_const(m_dataFiles))
 		ScQApp->dlManager()->addURL("https://services.scribus.net/" + f, true, ScPaths::downloadDir(), ScPaths::downloadDir());
-	for (const QString& f : qAsConst(m_dataFiles))
+	for (const QString& f : std::as_const(m_dataFiles))
 		ScQApp->dlManager()->addURL("https://services.scribus.net/" + f + ".sha256", true, ScPaths::downloadDir(), ScPaths::downloadDir());
 	connect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadListFinished()));
-	connect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
-	connect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
-	connect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
-	connect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64, qint64)), this, SLOT(updateProgressData(qint64, qint64)));
+	connect(ScQApp->dlManager(), SIGNAL(fileReceived(QString)), this, SLOT(updateProgressBar()));
+	connect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(updateProgressBar()));
+	connect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(updateProgressBar()));
+	connect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64,qint64)), this, SLOT(updateProgressData(qint64,qint64)));
 	ScQApp->dlManager()->startDownloads();
 }
 
 void ResourceManager::downloadListFinished()
 {
 	disconnect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadListFinished()));
-	disconnect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
-	disconnect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
-	disconnect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64, qint64)), this, SLOT(updateProgressData(qint64, qint64)));
+	disconnect(ScQApp->dlManager(), SIGNAL(fileReceived(QString)), this, SLOT(updateProgressBar()));
+	disconnect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(updateProgressBar()));
+	disconnect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64,qint64)), this, SLOT(updateProgressData(qint64,qint64)));
 
 	int category = categoryComboBox->currentData().toInt();
 	bool fileOk = checkFileHash(ScPaths::downloadDir(), m_dataFiles[category], m_dataFiles[category] + ".sha256", QCryptographicHash::Sha256);
@@ -980,19 +1045,19 @@ void ResourceManager::downloadListFinished()
 			if (fileOk)
 				updateAvailableHelp();
 			else
-				qDebug()<<"Help Failure :(";
+				qDebug() << "Help Failure :(";
 			break;
 		case RM_PALETTES:
 			if (fileOk)
 				updateAvailablePalettes();
 			else
-				qDebug()<<"Palette Failure :(";
+				qDebug() << "Palette Failure :(";
 			break;
 		case RM_TEST:
 			if (fileOk)
-				qDebug()<<"Success!!!";
+				qDebug() << "Success!!!";
 			else
-				qDebug()<<"Failure :(";
+				qDebug() << "Failure :(";
 			break;
 	}
 	updateAvailableButton->setEnabled(true);
@@ -1005,8 +1070,8 @@ void ResourceManager::downloadListFinished()
 void ResourceManager::downloadFilesFinished()
 {
 	disconnect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadFilesFinished()));
-	disconnect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
-	disconnect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
+	disconnect(ScQApp->dlManager(), SIGNAL(fileReceived(QString)), this, SLOT(updateProgressBar()));
+	disconnect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(updateProgressBar()));
 	disconnect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64, qint64)), this, SLOT(updateProgressData(qint64, qint64)));
 
 	downloadProgressBar->setValue(0);
@@ -1018,25 +1083,24 @@ void ResourceManager::downloadFilesFinished()
 	switch (category)
 	{
 		case RM_FONTS:
-			for (const DownloadItem& d : qAsConst(m_downloadList))
+			for (const DownloadItem& d : std::as_const(m_downloadList))
 			{
-				if (d.filetype=="zip")
+				if (d.filetype == "zip")
 				{
-					QString fn(ScPaths::userFontDir(true)+d.files);
+					QString fn(ScPaths::userFontDir(true) + d.files);
 					QFile dledFile(fn);
 					QFileInfo fi(dledFile);
 					if (!dledFile.exists())
-						qDebug()<<"File doesn\'t exist"<<fn;
+						qDebug() << "File doesn\'t exist" << fn;
 					else
 					{
 						ScZipHandler* fun = new ScZipHandler();
 						if (!fun->open(fn))
-							qDebug()<<"Zip file doesn\'t open"<<fn;
+							qDebug() << "Zip file doesn\'t open" << fn;
 						else
 						{
 							const QStringList zipFileContents(fun->files());
-							QStringList extractFiles(d.extractfiles.split(";", Qt::SkipEmptyParts));
-							QString toDir(ScPaths::userFontDir(false)+fi.baseName()+"/");
+							QString toDir(ScPaths::userFontDir(false) + fi.baseName() + "/");
 							QDir dir(ScPaths::userFontDir(false));
 							if (!dir.exists(fi.baseName()))
 								dir.mkdir(fi.baseName());
@@ -1048,7 +1112,7 @@ void ResourceManager::downloadFilesFinished()
 						delete fun;
 					}
 				}
-				if (d.filetype=="plain")
+				if (d.filetype == "plain")
 				{
 					//do nothing as the file is already in place from dl mgr
 				}
@@ -1058,18 +1122,18 @@ void ResourceManager::downloadFilesFinished()
 		case RM_SPELL:
 			{
 				int fileType = category == RM_HYPH ? ScPaths::Hyph : ScPaths::Spell;
-				for (const DownloadItem& d : qAsConst(m_downloadList))
+				for (const DownloadItem& d : std::as_const(m_downloadList))
 				{
-					if (d.filetype=="zip")
+					if (d.filetype == "zip")
 					{
 						QString fn(ScPaths::userDictDir(static_cast<ScPaths::DictType>(fileType), true)+d.files);
 						if (!QFileInfo::exists(fn))
-							qDebug()<<"File doesn\'t exist"<<fn;
+							qDebug() << "File doesn\'t exist" << fn;
 						else
 						{
 							ScZipHandler* fun = new ScZipHandler();
 							if (!fun->open(fn))
-								qDebug()<<"Zip file doesn\'t open"<<fn;
+								qDebug() << "Zip file doesn\'t open" << fn;
 							else
 							{
 								const QStringList zipContents(fun->files());
@@ -1088,7 +1152,7 @@ void ResourceManager::downloadFilesFinished()
 							delete fun;
 						}
 					}
-					if (d.filetype=="plain")
+					if (d.filetype == "plain")
 					{
 						//do nothing as the file is already in place from dl mgr
 					}
@@ -1096,7 +1160,7 @@ void ResourceManager::downloadFilesFinished()
 			}
 			break;
 		case RM_HELP:
-			for (const DownloadItem& d : qAsConst(m_downloadList))
+			for (const DownloadItem& d : std::as_const(m_downloadList))
 			{
 				//qDebug() << d.desc << d.download << d.files << d.type;
 				if (d.filetype == "zip")
@@ -1105,7 +1169,7 @@ void ResourceManager::downloadFilesFinished()
 					//qDebug() << fn;
 					QFile dledFile(fn);
 					QFileInfo fi(dledFile);
-					QFile dledFileSHA256(fn+".sha256");
+					QFile dledFileSHA256(fn + ".sha256");
 					QFileInfo fiSHA256(dledFileSHA256);
 					if (!dledFile.exists() || !dledFileSHA256.exists())
 						qDebug() << "File doesn\'t exist" << fn << fn + ".sha256";
@@ -1119,7 +1183,7 @@ void ResourceManager::downloadFilesFinished()
 							else
 							{
 								const QStringList zipFileContents(fun->files());
-								QStringList extractFiles(d.extractfiles.split(";", Qt::SkipEmptyParts));
+//								QStringList extractFiles(d.extractfiles.split(";", Qt::SkipEmptyParts));
 								QString toDir(ScPaths::userHelpFilesDir(false) + d.lang + "/");
 								QDir dir(ScPaths::userHelpFilesDir(false));
 								if (!dir.exists(d.lang))
@@ -1153,10 +1217,10 @@ void ResourceManager::downloadLicenseFinished()
 	disconnect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadLicenseFinished()));
 }
 
-void ResourceManager::downloadLicenseFileFinished(const QString &licenceFileName)
+void ResourceManager::downloadLicenseFileFinished(const QString &licenseFileName)
 {
-	disconnect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(downloadLicenseFileFinished(const QString&)));
-	QFile dataFile(licenceFileName);
+	disconnect(ScQApp->dlManager(), SIGNAL(fileReceived(QString)), this, SLOT(downloadLicenseFileFinished(QString)));
+	QFile dataFile(licenseFileName);
 	QTextStream ts(&dataFile);
 	QString data;
 	if (dataFile.exists())
@@ -1176,7 +1240,7 @@ void ResourceManager::downloadLicenseFileFinished(const QString &licenceFileName
 
 void ResourceManager::downloadLicenseFileFailed(const QString&)
 {
-	disconnect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(downloadLicenseFileFailed(const QString&)));
+	disconnect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(downloadLicenseFileFailed(QString)));
 	QMessageBox msgBox;
 	msgBox.setText("The license file failed to download");
 	msgBox.setStandardButtons(QMessageBox::Ok);
@@ -1341,9 +1405,9 @@ void ResourceManager::startDownload()
 	{
 		downloadProgressBar->setRange(0, dlCount);
 		connect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadFilesFinished()));
-		connect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
-		connect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
-		connect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64, qint64)), this, SLOT(updateProgressData(qint64, qint64)));
+		connect(ScQApp->dlManager(), SIGNAL(fileReceived(QString)), this, SLOT(updateProgressBar()));
+		connect(ScQApp->dlManager(), SIGNAL(fileFailed(QString)), this, SLOT(updateProgressBar()));
+		connect(ScQApp->dlManager(), SIGNAL(fileDownloadProgress(qint64,qint64)), this, SLOT(updateProgressData(qint64,qint64)));
 		ScQApp->dlManager()->startDownloads();
 	}
 }
@@ -1445,7 +1509,7 @@ void ResourceManager::showLicense()
 				case RM_SPELL:
 				case RM_PALETTES:
 */
-			for (const DownloadItem& d : qAsConst(m_availableList))
+			for (const DownloadItem& d : std::as_const(m_availableList))
 			{
 				if (!filesToDownload.contains(d.desc))
 					continue;
