@@ -27,9 +27,11 @@ for which a new license (GPL+exception) is in place.
 #include <QPainter>
 #include <QPixmap>
 #include <QProgressDialog>
+#include <QRegularExpression>
 #include <QSet>
 #include <QSignalMapper>
 #include <QSpacerItem>
+#include <QStringView>
 #include <QToolBox>
 #include <QToolButton>
 #include <QToolTip>
@@ -52,7 +54,6 @@ for which a new license (GPL+exception) is in place.
 #include "scribusapp.h"
 #include "scribuscore.h"
 #include "util.h"
-#include "util_color.h"
 #include "util_file.h"
 #include "util_formats.h"
 
@@ -138,7 +139,8 @@ void BibView::dropEvent(QDropEvent *e)
 		if (e->source() == this)
 			return;
 		QString text = e->mimeData()->text();
-		int startElemPos = text.leftRef(512).indexOf("<SCRIBUSELEM");
+		int maxTextSize = qMin(text.length(), 512);
+		int startElemPos = QStringView(text).first(maxTextSize).indexOf(QStringView(u"<SCRIBUSELEM"));
 		if (startElemPos >= 0)
 			emit objDropped(text);
 	}
@@ -720,7 +722,7 @@ void BibView::readContents(const QString& name)
 }
 
 /* This is the main Dialog-Class for the Scrapbook */
-Biblio::Biblio(QWidget* parent) : ScDockPalette(parent, "Sclib", Qt::WindowFlags())
+Biblio::Biblio(QWidget* parent) : DockPanelBase("Sclib", "panel-scrapbook", parent)
 {
 	setObjectName(QString::fromLocal8Bit("Sclib"));
 	setMinimumSize( QSize(220, 240) );
@@ -803,8 +805,8 @@ Biblio::Biblio(QWidget* parent) : ScDockPalette(parent, "Sclib", Qt::WindowFlags
 	connect(upButton, SIGNAL(clicked()), this, SLOT(goOneDirUp()));
 	connect(importButton, SIGNAL(clicked()), this, SLOT(Import()));
 	connect(closeButton, SIGNAL(clicked()), this, SLOT(closeLib()));
-	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
-	connect(configMenue, SIGNAL(triggered(QAction *)), this, SLOT(updateView()));
+	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
+	connect(configMenue, SIGNAL(triggered(QAction*)), this, SLOT(updateView()));
 }
 
 void Biblio::setOpenScrapbooks(const QStringList &fileNames)
@@ -813,7 +815,7 @@ void Biblio::setOpenScrapbooks(const QStringList &fileNames)
 	disconnect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	disconnect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	disconnect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
-	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 	for (int rd = 0; rd < fileNames.count(); ++rd)
 	{
 		QString fileName = fileNames[rd];
@@ -838,11 +840,11 @@ void Biblio::setOpenScrapbooks(const QStringList &fileNames)
 	Frame3->setCurrentIndex(0);
 	upButton->setEnabled(false);
 	updateView();
-	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 	connect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
-	connect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
-	connect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
-	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
+	connect(activeBView, SIGNAL(fileDropped(QString,int)), this, SLOT(objFromFile(QString,int)));
+	connect(activeBView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(handleMouse(QPoint)));
+	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(handleDoubleClick(QListWidgetItem*)));
 }
 
 QStringList Biblio::getOpenScrapbooks() const
@@ -954,7 +956,7 @@ void Biblio::newLib()
 	disconnect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	disconnect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	disconnect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
-	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 
 	QDir d(fileName);
 	activeBView = new BibView(this);
@@ -976,10 +978,10 @@ void Biblio::newLib()
 	upButton->setEnabled(!((Frame3->currentIndex() == 0) || (Frame3->currentIndex() == 1)));
 	updateView();
 
-	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 	connect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
-	connect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
-	connect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
+	connect(activeBView, SIGNAL(fileDropped(QString,int)), this, SLOT(objFromFile(QString, int)));
+	connect(activeBView, SIGNAL(customContextMenuRequested(const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(handleDoubleClick(QListWidgetItem*)));
 
 	emit scrapbookListChanged();
@@ -1019,7 +1021,7 @@ void Biblio::closeLib()
 	disconnect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
 	disconnect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
 	disconnect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
-	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+	disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 
 	QFileInfo fi(activeBView->ScFilename);
 	ScCore->fileWatcher->removeDir(fi.absolutePath());
@@ -1029,11 +1031,11 @@ void Biblio::closeLib()
 	Frame3->setCurrentIndex(0);
 	upButton->setEnabled(!((Frame3->currentIndex() == 0) || (Frame3->currentIndex() == 1)));
 
-	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+	connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 	connect(activeBView, SIGNAL(objDropped(QString)), this, SLOT(objFromMenu(QString)));
-	connect(activeBView, SIGNAL(fileDropped(QString, int)), this, SLOT(objFromFile(QString, int)));
-	connect(activeBView, SIGNAL(customContextMenuRequested (const QPoint &)), this, SLOT(handleMouse(QPoint)));
-	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem *)), this, SLOT(handleDoubleClick(QListWidgetItem *)));
+	connect(activeBView, SIGNAL(fileDropped(QString,int)), this, SLOT(objFromFile(QString,int)));
+	connect(activeBView, SIGNAL(customContextMenuRequested(const QPoint&)), this, SLOT(handleMouse(QPoint)));
+	connect(activeBView, SIGNAL(itemDoubleClicked(QListWidgetItem*)), this, SLOT(handleDoubleClick(QListWidgetItem*)));
 
 	emit scrapbookListChanged();
 }
@@ -1076,12 +1078,12 @@ void Biblio::closeOnDel(const QString& libName)
 		closeLib();
 	else
 	{
-		disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+		disconnect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 		QFileInfo fi(bv->ScFilename);
 		ScCore->fileWatcher->removeDir(fi.absolutePath());
 		Frame3->removeItem(Frame3->indexOf(bv));
 		delete bv;
-		connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int )));
+		connect(Frame3, SIGNAL(currentChanged(int)), this, SLOT(libChanged(int)));
 	}
 }
 
@@ -1196,11 +1198,11 @@ void Biblio::handleMouse(QPoint p)
 			connect(delAct, SIGNAL(triggered()), this, SLOT(deleteObj()));
 		}
 		QSignalMapper *signalMapper = new QSignalMapper(this);
-		connect(signalMapper, SIGNAL(mapped(int)), this, SLOT(copyObj(int)));
+		connect(signalMapper, SIGNAL(mappedInt(int)), this, SLOT(copyObj(int)));
 		QMenu *pmenu2 = new QMenu( tr("Copy To:"));
 		QMenu *pmenu3 = new QMenu( tr("Move To:"));
 		QSignalMapper *signalMapper2 = new QSignalMapper(this);
-		connect(signalMapper2, SIGNAL(mapped(int)), this, SLOT(moveObj(int)));
+		connect(signalMapper2, SIGNAL(mappedInt(int)), this, SLOT(moveObj(int)));
 		for (int i = 0; i < Frame3->count(); i++)
 		{
 			const BibView* bv = (BibView*) Frame3->widget(i);
@@ -1255,7 +1257,7 @@ bool Biblio::copyObj(int id)
 	if (bv->objectMap.contains(nam))
 	{
 		Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
-		dia.setValidator(QRegExp("[\\w()]+"));
+		dia.setValidator(QRegularExpression("[\\w()]+"));
 		dia.setEditText(nam, true);
 		dia.setTestList(activeBView->objectMap.keys());
 		if (dia.exec())
@@ -1289,6 +1291,7 @@ bool Biblio::copyObj(int id)
 
 	bv->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(bv->ScFilename + "/" + nam + "." + fi.completeSuffix().toLower())), pm);
 	pm.save(QDir::cleanPath(QDir::toNativeSeparators(bv->ScFilename + "/.ScribusThumbs/" + nam + ".png")), "PNG");
+
 	QFileInfo fiD(QDir::toNativeSeparators(activeBView->ScFilename + "/" + fi.baseName()));
 	if ((fiD.exists()) && (fiD.isDir()))
 	{
@@ -1458,12 +1461,12 @@ void Biblio::renameObj()
 	QString oldName = ite->text();
 
 	Query dia(this, "tt", true, tr("&Name:"), tr("New Name"));
-	dia.setValidator(QRegExp("[\\w()]+"));
+	dia.setValidator(QRegularExpression("[\\w()]+"));
 	dia.setEditText(ite->text(), true);
 	dia.setTestList(activeBView->objectMap.keys());
 	if (!dia.exec())
 		return;
-	QString nam = dia.getEditText();
+	QString	nam = dia.getEditText();
 
 	ite->setText(nam);
 	ite->setToolTip(nam);
@@ -1475,7 +1478,7 @@ void Biblio::renameObj()
 	QFileInfo fi(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + oldName + ".png"));
 	if (fi.exists())
 		d.rename(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + oldName + ".png"), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + ite->text() + ".png")));
-	
+
 	QFileInfo fiD(QDir::toNativeSeparators(activeBView->ScFilename + "/" + oldName));
 	if ((fiD.exists()) && (fiD.isDir()))
 	{
@@ -1657,7 +1660,7 @@ void Biblio::objFromFile(const QString& path, int testResult)
 	}
 
 	Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
-	dia.setValidator(QRegExp("[\\w()]+"));
+	dia.setValidator(QRegularExpression("[\\w()]+"));
 	dia.setEditText(nam, true);
 	dia.setTestList(activeBView->objectMap.keys());
 	if (!dia.exec())
@@ -1769,7 +1772,7 @@ void Biblio::objFromFile(const QString& path, int testResult)
 	reloadLib(activeBView->ScFilename);
 }
 
-void Biblio::objFromMenu(QString text)
+void Biblio::objFromMenu(const QString& text)
 {
 	QString tmp;
 	if (!activeBView->canWrite)
@@ -1793,17 +1796,16 @@ void Biblio::objFromMenu(QString text)
 	}
 
 	Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
-	dia.setValidator(QRegExp("[\\w()]+"));
+	dia.setValidator(QRegularExpression("[\\w()]+"));
 	dia.setEditText(nam, true);
 	dia.setTestList(activeBView->objectMap.keys());
 	if (!dia.exec())
 		return;
 	nam = dia.getEditText();
 
-	QString ff = text;
-	activeBView->checkAndChange(ff, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename)));
+	activeBView->checkAndChange(text, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename)));
 	
-	QPixmap pm = QPixmap::fromImage(ScPreview::create(ff));
+	QPixmap pm = QPixmap::fromImage(ScPreview::create(text));
 	activeBView->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/" + nam + ".sce")), pm);
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
@@ -1815,7 +1817,6 @@ void Biblio::objFromMenu(QString text)
 		}
 		pm.save(QDir::cleanPath(QDir::toNativeSeparators(activeBView->ScFilename + "/.ScribusThumbs/" + nam + ".png")), "PNG");
 	}
-
 	pm = pm.scaled(60, 60, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 	QPixmap pm2(60, 60);
 	pm2.fill(palette().color(QPalette::Base));
@@ -1887,7 +1888,6 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 	if (tempBView->objectMap.contains(nam))
 		nam += "("+ tmp.setNum(m_tempCount) + ")";
 	m_tempCount++;
-
 	tempBView->checkAndChange(text, QDir::cleanPath(nativeTempScrapPath + nam + ".sce"), QDir::cleanPath(QDir::toNativeSeparators(tempBView->ScFilename)));
 	
 	QPixmap pm = QPixmap::fromImage(ScPreview::create(text));
@@ -1952,13 +1952,13 @@ void Biblio::objFromCopyAction(const QString& text, const QString& name)
 	reloadLib(tempBView->ScFilename);
 }
 
-void Biblio::objFromMainMenu(QString text, int scrapID)
+void Biblio::objFromMainMenu(const QString& text, int scrapID)
 {
 	QString tmp;
 	int scID = scrapID;
 	if (scID > 0)
 		scID++;
-	BibView* actBView = (BibView*)Frame3->widget(scID);
+	BibView* actBView = (BibView*) Frame3->widget(scID);
 	if (!actBView->canWrite)
 		return;
 
@@ -1969,17 +1969,16 @@ void Biblio::objFromMainMenu(QString text, int scrapID)
 		nam += "("+ tmp.setNum(m_tempCount) + ")";
 
 	Query dia(this, "tt", true, tr("&Name:"), tr("New Entry"));
-	dia.setValidator(QRegExp("[\\w()]+"));
+	dia.setValidator(QRegularExpression("[\\w()]+"));
 	dia.setEditText(nam, true);
 	dia.setTestList(activeBView->objectMap.keys());
 	if (!dia.exec())
 		return;
 	nam = dia.getEditText();
 
-	QString ff = text;
-	actBView->checkAndChange(ff, QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename)));
-
-	QPixmap pm = QPixmap::fromImage(ScPreview::create(ff));
+	actBView->checkAndChange(text, QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/" + nam + ".sce")), QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename)));
+	
+	QPixmap pm = QPixmap::fromImage(ScPreview::create(text));
 	actBView->addObject(nam, QDir::cleanPath(QDir::toNativeSeparators(actBView->ScFilename + "/" + nam + ".sce")), pm);
 	if (PrefsManager::instance().appPrefs.scrapbookPrefs.writePreviews)
 	{
@@ -2051,7 +2050,7 @@ void Biblio::changeEvent(QEvent *e)
 	if (e->type() == QEvent::LanguageChange)
 		languageChange();
 	else
-		ScDockPalette::changeEvent(e);
+		DockPanelBase::changeEvent(e);
 }
 
 void Biblio::iconSetChange()
