@@ -5,7 +5,7 @@ a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
 /***************************************************************************
- *   Craig Bradney, cbradney@zip.com.au                                    *
+ *   Craig Bradney, cbradney@scribus.info                                    *
  ***************************************************************************/
 
 #include <algorithm>
@@ -25,14 +25,14 @@ for which a new license (GPL+exception) is in place.
 
 static const QString FinishTag("\xA0");
 
-ScrSpinBox::ScrSpinBox(QWidget *parent, int unitIndex) : QDoubleSpinBox(parent), m_constants(nullptr)
+ScrSpinBox::ScrSpinBox(QWidget *parent, int unitIndex) : QDoubleSpinBox(parent)
 {
 	init(unitIndex);
+	setFocusPolicy(Qt::StrongFocus);
 }
 
-ScrSpinBox::ScrSpinBox(double minValue, double maxValue, QWidget *pa, int unitIndex) : QDoubleSpinBox(pa), m_constants(nullptr)
+ScrSpinBox::ScrSpinBox(double minValue, double maxValue, QWidget *pa, int unitIndex) : ScrSpinBox(pa, unitIndex)
 {
-	init(unitIndex);
 	setMinimum(minValue);
 	setMaximum(maxValue);
 }
@@ -45,8 +45,9 @@ void ScrSpinBox::init(int unitIndex)
 	setLocale(LocaleManager::instance().userPreferredLocale());
 	setSingleStep((m_unitIndex == SC_INCHES) ? 0.125 : 1.0);
 	lineEdit()->setValidator(nullptr);
-	disconnect(this, SIGNAL(valueChanged(const QString &)), this, SLOT(textChanged()));
-	connect(this, SIGNAL(valueChanged(const QString &)), this, SLOT(textChanged()));
+// just for testing
+//	disconnect(this, SIGNAL(textChanged(QString)), this, SLOT(textChanged()));
+//	connect(this, SIGNAL(textChanged(QString)), this, SLOT(textChanged()));
 	installEventFilter(this);
 }
 
@@ -94,11 +95,13 @@ void ScrSpinBox::stepBy(int steps)
 				angle -= 360.0;
 		}
 		else
-			angle = std::max(minimum(), std::min(angle, maximum()));
+			angle = std::clamp(angle, minimum(), maximum());
 		setValue(angle);
+//		lineEdit()->deselect();
 		return;
 	}
 	QDoubleSpinBox::stepBy(steps);
+//	lineEdit()->deselect();
 }
 
 void ScrSpinBox::setParameters( int s )
@@ -341,9 +344,9 @@ bool ScrSpinBox::eventFilter(QObject* watched, QEvent* event)
 
 	if (event->type() == QEvent::Wheel)
 	{
-		//If read only don't spin
-		if (isReadOnly())
-			return false;
+		// If read only don't spin OR avoid value changes if widget has no focus
+		if (isReadOnly() || !hasFocus())
+			return true;
 		auto* wheelEvent = dynamic_cast<QWheelEvent*>(event);
 		int oldStep = singleStep(); // remember old single steps
 		bool shiftB = wheelEvent->modifiers() & Qt::ShiftModifier;
