@@ -6,6 +6,8 @@ for which a new license (GPL+exception) is in place.
 */
 #include "search.h"
 
+#include <array>
+
 #include <QCheckBox>
 #include <QComboBox>
 #include <QGroupBox>
@@ -21,16 +23,12 @@ for which a new license (GPL+exception) is in place.
 #include <QScopedValueRollback>
 
 #include "appmodes.h"
-#include "canvas.h"
 #include "colorcombo.h"
-#include "colorlistbox.h"
-#include "commonstrings.h"
 #include "fontcombo.h"
 #include "iconmanager.h"
 #include "prefscontext.h"
 #include "prefsfile.h"
 #include "prefsmanager.h"
-#include "scpage.h"
 #include "scribus.h"
 #include "scribusview.h"
 #include "scrspinbox.h"
@@ -112,10 +110,9 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* item,
 	SearchLayout->addWidget( searchStyleValue, 1, 1 );
 	searchAlignValue = new QComboBox( searchGroupBox );
 	searchAlignValue->setEditable(false);
-	QString tmp_sty[] = { tr("Left"), tr("Center"), tr("Right"), tr("Block"), tr("Forced")};
-	size_t ar_sty = sizeof(tmp_sty) / sizeof(*tmp_sty);
-	for (uint a = 0; a < ar_sty; ++a)
-		searchAlignValue->addItem( tmp_sty[a] );
+	std::array<QString, 5> tmp_sty = { tr("Left"), tr("Center"), tr("Right"), tr("Block"), tr("Forced") };
+	for (size_t i = 0; i < tmp_sty.size(); ++i)
+		searchAlignValue->addItem( tmp_sty[i] );
 	tmpView = qobject_cast<QListView*>(searchAlignValue->view()); Q_ASSERT(tmpView);
 	tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
@@ -210,8 +207,8 @@ SearchReplace::SearchReplace( QWidget* parent, ScribusDoc *doc, PageItem* item,
 	ReplaceLayout->addWidget( replaceStyleValue, 1, 1 );
 	replaceAlignValue = new QComboBox( replaceGroupBox );
 	replaceAlignValue->setEditable(false);
-	for (uint a = 0; a < ar_sty; ++a)
-		replaceAlignValue->addItem(tmp_sty[a]);
+	for (uint i = 0; i < tmp_sty.size(); ++i)
+		replaceAlignValue->addItem(tmp_sty[i]);
 	tmpView = qobject_cast<QListView*>(replaceAlignValue->view()); Q_ASSERT(tmpView);
 	tmpWidth = tmpView->sizeHintForColumn(0);
 	if (tmpWidth > 0)
@@ -837,7 +834,7 @@ void SearchReplace::doReplace()
 	doSearch();
 }
 
-int SearchReplace::firstMatchCursorPosition()
+int SearchReplace::firstMatchCursorPosition() const
 {
 	return m_firstMatchPosition;
 }
