@@ -212,6 +212,7 @@ void SMCellStyle::apply()
 	//m_doc->scMW()->requestUpdate(reqTextStylesUpdate);
 
 	m_doc->changed();
+	m_doc->changedPagePreview();
 }
 
 void SMCellStyle::editMode(bool isOn)
@@ -421,18 +422,18 @@ void SMCellStyle::setupConnections()
 {
 	if (!m_page)
 		return;
-	connect(m_page->fillColor, SIGNAL(activated(const QString&)), this, SLOT(slotFillColor()));
+	connect(m_page->fillColor, SIGNAL(currentTextChanged(QString)), this, SLOT(slotFillColor()));
 	connect(m_page->fillShade, SIGNAL(clicked()), this, SLOT(slotFillShade()));
-	connect(m_page->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotParentChanged(const QString&)));
+	connect(m_page->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotParentChanged(QString)));
 }
 
 void SMCellStyle::removeConnections()
 {
 	if (!m_page)
 		return;
-	disconnect(m_page->fillColor, SIGNAL(activated(const QString&)), this, SLOT(slotFillColor()));
+	disconnect(m_page->fillColor, SIGNAL(currentTextChanged(QString)), this, SLOT(slotFillColor()));
 	disconnect(m_page->fillShade, SIGNAL(clicked()), this, SLOT(slotFillShade()));
-	disconnect(m_page->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotParentChanged(const QString&)));
+	disconnect(m_page->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotParentChanged(QString)));
 }
 
 void SMCellStyle::slotFillColor()
