@@ -168,10 +168,9 @@ void SMCellStyleWidget::showColors(const QList<CellStyle*> &cellStyles)
 		fillColor->setCurrentText(s);
 }
 
-void SMCellStyleWidget::fillFillColorCombo(ColorList &colors)
+void SMCellStyleWidget::fillFillColorCombo(const ColorList &colors)
 {
 	fillColor->clear();
 
 	fillColor->setColors(colors, true);
-	fillColor->view()->setMinimumWidth(fillColor->view()->maximumViewportSize().width()+24);
 }
