@@ -36,14 +36,14 @@ SMPStyleWidget::SMPStyleWidget(ScribusDoc* doc, StyleSet<CharStyle> *cstyles) :
 // 	optMarginCheckLeftProtruding->setVisible(false);
 
 	iconSetChange();
-	
-	backColor_->setPixmapType(ColorCombo::fancyPixmaps);
-	backColor_->clear();
-	backColor_->addItem(CommonStrings::tr_NoneColor);
 
-	lineSpacingMode->addItem( tr("Fixed Linespacing"));
-	lineSpacingMode->addItem( tr("Automatic Linespacing"));
-	lineSpacingMode->addItem( tr("Align to Baseline Grid"));
+	backgroundColor->colorButton->setContext(Context::TextBackground);
+	backgroundColor->setColor(CommonStrings::tr_NoneColor);
+	backgroundColor->setText(tr("Background"));
+
+	lineSpacingMode->addItem( tr("Fixed"));
+	lineSpacingMode->addItem( tr("Automatic"));
+	lineSpacingMode->addItem( tr("Baseline"));
 	connect(lineSpacingMode, SIGNAL(highlighted(int)), this, SLOT(slotLineSpacingModeChanged(int)));
 
 	lineSpacing->setSuffix(unitGetSuffixFromIndex(0));
@@ -65,17 +65,24 @@ SMPStyleWidget::SMPStyleWidget(ScribusDoc* doc, StyleSet<CharStyle> *cstyles) :
 	numStartSpin->setMaximum(9999);
 	numLevelSpin->setMinimum(1);
 	numLevelSpin->setMaximum(1);
+	numPrefix->setMaxLength(5);
+	numPrefix->setMaximumWidth(QFontMetrics(numPrefix->font()).averageCharWidth() * 7);
+	numSuffix->setMaxLength(5);
+	numSuffix->setMaximumWidth(QFontMetrics(numSuffix->font()).averageCharWidth() * 7);
 	fillNumRestartCombo();
 	dropCapLines->setMinimum(2);
 	dropCapLines->setMaximum(99);
 
+	fillPECombo();
+	connect(peCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(handleParEffectUse(int)));
+	connect(parentParEffectsButton, SIGNAL(clicked()), this, SLOT(slotParentParEffects()));
+
 	minSpaceSpin->setSuffix(unitGetSuffixFromIndex(SC_PERCENT));
 	minGlyphExtSpin->setSuffix(unitGetSuffixFromIndex(SC_PERCENT));
 	maxGlyphExtSpin->setSuffix(unitGetSuffixFromIndex(SC_PERCENT));
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 
-	connect(optMarginDefaultButton, SIGNAL(clicked()), this, SLOT(slotDefaultOpticalMargins()));
 	if (m_Doc)
 		connect(m_Doc->scMW(), SIGNAL(UpdateRequest(int)), this , SLOT(handleUpdateRequest(int)));
 	m_enhanced = nullptr;
@@ -100,15 +107,21 @@ void SMPStyleWidget::iconSetChange()
 {
 	IconManager& iconManager = IconManager::instance();
 
-	lineSpacingLabel->setPixmap(iconManager.loadPixmap("linespacing2.png"));
-	spaceAboveLabel->setPixmap(iconManager.loadPixmap("above.png") );
-	spaceBelowLabel->setPixmap(iconManager.loadPixmap("below.png") );
-	keepLabelStart->setPixmap(iconManager.loadPixmap("22/orphan.png") );
-	keepLabelEnd->setPixmap(iconManager.loadPixmap("22/widow.png") );
-	backIcon->setPixmap(iconManager.loadPixmap("16/color-fill.png"));
-	backShadeLabel->setPixmap(iconManager.loadPixmap("shade.png"));
+	lineSpacingLabel->setPixmap(iconManager.loadPixmap("paragraph-line-height"));
+	spaceAboveLabel->setPixmap(iconManager.loadPixmap("paragraph-space-above") );
+	spaceBelowLabel->setPixmap(iconManager.loadPixmap("paragraph-space-below") );
+	keepLabelStart->setPixmap(iconManager.loadPixmap("paragraph-orphan") );
+	keepLabelEnd->setPixmap(iconManager.loadPixmap("paragraph-widow") );
+	minSpaceLabel->setPixmap(iconManager.loadPixmap("character-space-width-min"));
+	minGlyphExtLabel->setPixmap(iconManager.loadPixmap("character-scale-width-min"));
+	maxGlyphExtLabel->setPixmap(iconManager.loadPixmap("character-scale-width-max"));
+	consecutiveHyphenLabel->setPixmap(iconManager.loadPixmap("hyphen-consecutive"));
 
-	bulletCharTableButton->setIcon(IconManager::instance().loadPixmap("22/insert-table.png"));
+	bulletCharTableButton->setIcon(iconManager.loadIcon("22/insert-table.png"));
+	distFromTextLabel->setPixmap(iconManager.loadPixmap("paragraph-list-offset"));
+	parEffectCharStyleComboLabel->setPixmap(iconManager.loadPixmap("character-style"));
+	peLabel->setPixmap(iconManager.loadPixmap("paragraph-effects-style"));
+	parentParEffectsButton->setIcon(iconManager.loadIcon("reset-style-changes"));
 }
 
 void SMPStyleWidget::languageChange()
@@ -122,9 +135,9 @@ void SMPStyleWidget::languageChange()
 	int  oldLineSpacingModeIndex = lineSpacingMode->currentIndex();
 	bool lineSpacingModeBlocked = lineSpacingMode->blockSignals(true);
 	lineSpacingMode->clear();
-	lineSpacingMode->addItem( tr("Fixed Linespacing"));
-	lineSpacingMode->addItem( tr("Automatic Linespacing"));
-	lineSpacingMode->addItem( tr("Align to Baseline Grid"));
+	lineSpacingMode->addItem( tr("Fixed"));
+	lineSpacingMode->addItem( tr("Automatic"));
+	lineSpacingMode->addItem( tr("Baseline"));
 	lineSpacingMode->setCurrentIndex(oldLineSpacingModeIndex);
 	lineSpacingMode->blockSignals(lineSpacingModeBlocked);
 
@@ -141,6 +154,8 @@ void SMPStyleWidget::languageChange()
 	numRestartCombo->setCurrentIndex(oldNumRestartIndex);
 	numRestartCombo->blockSignals(numRestartComboBlocked);
 
+	fillPECombo();
+
 /* #13455 stop making the font 2ce as big
 	QFont font1;
 	if (font1.pointSize())
@@ -151,12 +166,8 @@ void SMPStyleWidget::languageChange()
 	(bulletStrEdit->lineEdit())->setFont(font1);
 */
 
-	if (backColor_->count() > 0)
-	{
-		bool sigBlocked = backColor_->blockSignals(true);
-		backColor_->setItemText(0, CommonStrings::tr_NoneColor);
-		backColor_->blockSignals(sigBlocked);
-	}
+	backgroundColor->colorButton->setPersistentToolTip( tr("Background color of selected text"));
+	backgroundColor->setText(tr("Background"));
 }
 
 void SMPStyleWidget::unitChange(double oldRatio, double newRatio, int unitIndex)
@@ -174,62 +185,11 @@ void SMPStyleWidget::setDoc(ScribusDoc *doc)
 	if (m_Doc)
 	{
 		connect(m_Doc->scMW(), SIGNAL(UpdateRequest(int)), this , SLOT(handleUpdateRequest(int)));
-		fillColorCombo(m_Doc->PageColors);
 		fillNumerationsCombo();
 	}
 
 	cpage->setDoc(m_Doc);
-}
-
-void SMPStyleWidget::fillColorCombo(ColorList &colors)
-{
-	backColor_->clear();
-	backColor_->setColors(colors, true);
-}
-
-void SMPStyleWidget::fillBulletStrEditCombo()
-{
-	bulletStrEdit->clear();
-	bulletStrEdit->addItem(QChar(0x2022));
-	bulletStrEdit->addItem("*");
-	bulletStrEdit->addItem(QChar(0x2013));
-	bulletStrEdit->setMinimumWidth(50);
-	if (bulletStrEdit->currentText().isEmpty())
-		bulletStrEdit->setEditText(QChar(0x2022));
-}
-
-void SMPStyleWidget::fillNumerationsCombo()
-{
-	QStringList numNames;
-	const auto numerationKeys = m_Doc->numerations.keys();
-	for (const QString& numName : numerationKeys)
-	{
-		if (numName.isEmpty())
-			continue;
-		numNames.append(numName);
-	}
-	numNames.sort();
-	numComboBox->clear();
-	numComboBox->insertItems(0, numNames);
-	numComboBox->setCurrentItem(0);
-}
-
-void SMPStyleWidget::fillNumRestartCombo()
-{
-	numRestartCombo->clear();
-	numRestartCombo->addItem(tr("Document"), static_cast<int>(NSRdocument));
-	numRestartCombo->addItem(tr("Story") , static_cast<int>(NSRstory));
-}
-
-void SMPStyleWidget::checkParEffectState()
-{
-	bool enable = false;
-	if (dropCapsBox->isChecked() || bulletBox->isChecked() || numBox->isChecked())
-		enable = true;
-
-	parEffectCharStyleCombo->setEnabled(enable);
-	parEffectOffset->setEnabled(enable);
-	parEffectIndentBox->setEnabled(enable);
+	backgroundColor->colorButton->setDoc(m_Doc);
 }
 
 void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles, QList<CharStyle> &cstyles, int unitIndex, const QString &defLang)
@@ -241,9 +201,9 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 	m_hasParent = pstyle->hasParent() && parent != nullptr && parent->hasName() && pstyle->parent() != "";
 
 	lineSpacingMode->clear();
-	lineSpacingMode->addItem( tr("Fixed Linespacing"));
-	lineSpacingMode->addItem( tr("Automatic Linespacing"));
-	lineSpacingMode->addItem( tr("Align to Baseline Grid"));
+	lineSpacingMode->addItem( tr("Fixed"));
+	lineSpacingMode->addItem( tr("Automatic"));
+	lineSpacingMode->addItem( tr("Baseline"));
 	
 //	optMarginCombo->clear();
 //	optMarginCombo->addItem(tr("None"), ParagraphStyle::OM_None);
@@ -264,6 +224,8 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 	//fillNumerationsCombo();
 	//fillNumRestartCombo();
 
+	optMarginWidget->setOpticalMarginSets(m_Doc->opticalMarginSets());
+
 	if (m_hasParent)
 	{
 		lineSpacingMode->setCurrentItem(pstyle->lineSpacingMode(), pstyle->isInhLineSpacingMode());
@@ -271,8 +233,8 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		
 //		optMarginCombo->setCurrentItemByData( pstyle->opticalMargins(),  pstyle->isInhOpticalMargins() );
 //		optMarginCombo->setParentItem(optMarginCombo->getItemIndexForData( parent->opticalMargins()));
-		setOpticalMargins(pstyle->opticalMargins(), pstyle->isInhOpticalMargins(), parent);
-		connect(optMarginParentButton, SIGNAL(clicked()), this, SLOT(slotParentOpticalMargins()));
+		optMarginWidget->setOpticalMargins(pstyle->opticalMargins(), parent->opticalMargins(), pstyle->isInhOpticalMargins());		
+		optMarginWidget->setOpticalMarginSetId(pstyle->opticalMarginSetId(), parent->opticalMarginSetId(), pstyle->isInhOpticalMarginSetId());
 		
 		minSpaceSpin->setValue(pstyle->minWordTracking() * 100.0,  pstyle->isInhMinWordTracking());
 		minSpaceSpin->setParentValue(parent->minWordTracking());
@@ -340,28 +302,18 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		else
 		{
 			parentParEffectsButton->show();
-			QFont f(font());
-			f.setBold(true);
-			parentParEffectsButton->setFont(f);
 		}
 		connect(parentParEffectsButton, SIGNAL(clicked()), this, SLOT(slotParentParEffects()));
 
-		dropCapsBox->setChecked(pstyle->hasDropCap());
-		setWidgetBoldFont(dropCapsBox, !pstyle->isInhHasDropCap());
-		dropCapLines->setValue(pstyle->dropCapLines(), pstyle->isInhDropCapLines());
-		dropCapLines->setParentValue(parent->dropCapLines());
-
 		parEffectOffset->setValue(pstyle->parEffectOffset() * unitRatio, pstyle->isInhParEffectOffset());
 		parEffectOffset->setParentValue(parent->parEffectOffset() * unitRatio);
 		parEffectIndentBox->setChecked(pstyle->parEffectIndent(),pstyle->isInhParEffectIndent());
 		parEffectIndentBox->setParentValue(parent->parEffectIndent());
-
-		bulletBox->setChecked(pstyle->hasBullet());
-		setWidgetBoldFont(bulletBox, !pstyle->isInhHasBullet());
+		dropCapLines->setValue(pstyle->dropCapLines(), pstyle->isInhDropCapLines());
+		dropCapLines->setParentValue(parent->dropCapLines());
 		bulletStrEdit->setEditText(pstyle->bulletStr());
 		setWidgetBoldFont(bulletCharLabel, !pstyle->isInhBulletStr());
-		numBox->setChecked(pstyle->hasNum());
-		setWidgetBoldFont(numBox, !pstyle->isInhHasNum());
+
 		QString numName = pstyle->numName();
 		if (numName.isEmpty())
 			numName = "default";
@@ -392,11 +344,7 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		numRestartOtherBox->setParentValue(parent->numOther());
 		numRestartHigherBox->setChecked(pstyle->numHigher(), pstyle->isInhNumHigher());
 		numRestartHigherBox->setParentValue(parent->numHigher());
-
-		backColor_->setCurrentText(pstyle->backgroundColor(), pstyle->isInhBackgroundColor());
-		backColor_->setParentText(parent->backgroundColor());
-		backShade_->setValue(qRound(pstyle->backgroundShade()), pstyle->isInhBackgroundShade());
-		backShade_->setParentValue(qRound(parent->backgroundShade()));
+		backgroundColor->setColor(pstyle->backgroundColor(), qRound(pstyle->backgroundShade()), parent->backgroundColor(), qRound(pstyle->backgroundShade()), pstyle->isInhBackgroundColor());
 	}
 	else
 	{
@@ -405,8 +353,8 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		spaceAbove->setValue(pstyle->gapBefore());
 		spaceBelow->setValue(pstyle->gapAfter());
 //		optMarginCombo->setCurrentItemByData( pstyle->opticalMargins() );
-		setOpticalMargins(pstyle->opticalMargins());
-		optMarginParentButton->hide();
+		optMarginWidget->setOpticalMargins(pstyle->opticalMargins());
+		optMarginWidget->setOpticalMarginSetId(pstyle->opticalMarginSetId());
 		minSpaceSpin->setValue(pstyle->minWordTracking() * 100.0);
 		minGlyphExtSpin->setValue(pstyle->minGlyphExtension() * 100.0);
 		maxGlyphExtSpin->setValue(pstyle->maxGlyphExtension() * 100.0);
@@ -415,15 +363,10 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		parEffectIndentBox->setChecked(pstyle->parEffectIndent());
 		parentParEffectsButton->hide();
 		disconnect(parentParEffectsButton, SIGNAL(clicked()), this, SLOT(slotParentParEffects()));
-		dropCapsBox->setChecked(pstyle->hasDropCap());
-		setWidgetBoldFont(dropCapsBox, false);
+
 		dropCapLines->setValue(pstyle->dropCapLines());
-		bulletBox->setChecked(pstyle->hasBullet());
-		setWidgetBoldFont(bulletBox, false);
 		bulletStrEdit->setEditText(pstyle->bulletStr());
 		setWidgetBoldFont(bulletCharLabel, false);
-		numBox->setChecked(pstyle->hasNum());
-		setWidgetBoldFont(numBox, false);
 		QString numName = pstyle->numName();
 		if (numName.isEmpty())
 			numName = "default";
@@ -458,14 +401,21 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		keepLinesEnd->setValue (pstyle->keepLinesEnd());
 		keepTogether->setChecked (pstyle->keepTogether());
 		keepWithNext->setChecked (pstyle->keepWithNext());
-		backColor_->setCurrentText(pstyle->backgroundColor());
-		backShade_->setValue(qRound(pstyle->backgroundShade()));
+		backgroundColor->setColor(pstyle->backgroundColor(), qRound(pstyle->backgroundShade()));
+
 	}
 
 	lineSpacing->setEnabled(pstyle->lineSpacingMode() == ParagraphStyle::FixedLineSpacing);
-	dropCapLines->setEnabled(pstyle->hasDropCap());
 
-	checkParEffectState();
+	if (pstyle->hasDropCap())
+		setParagraphEffect(1);
+	else if (pstyle->hasBullet())
+		setParagraphEffect(2);
+	else if (pstyle->hasNum())
+		setParagraphEffect(3);
+	else
+		setParagraphEffect(0);
+
 	parEffectCharStyleCombo->clear();
 	parEffectCharStyleCombo->addItem(tr("No Style"));
 	for (int i =0; i < cstyles.count(); i++)
@@ -499,9 +449,6 @@ void SMPStyleWidget::show(ParagraphStyle *pstyle, QList<ParagraphStyle> &pstyles
 		parentCombo->setCurrentIndex(index);
 	}
 
-	connect(dropCapsBox, SIGNAL(toggled(bool)), this, SLOT(slotDropCap(bool)));
-	connect(bulletBox, SIGNAL(toggled(bool)), this, SLOT(slotBullets(bool)));
-	connect(numBox, SIGNAL(toggled(bool)), this, SLOT(slotNumbering(bool)));
 }
 
 void SMPStyleWidget::show(QList<ParagraphStyle*> &pstyles, QList<ParagraphStyle> &pstylesAll, QList<CharStyle> &cstyles, int unitIndex, const QString &defLang)
@@ -526,7 +473,8 @@ void SMPStyleWidget::show(QList<ParagraphStyle*> &pstyles, QList<ParagraphStyle>
 		showTabs(pstyles, unitIndex);
 		showCStyle(pstyles, cstyles, defLang, unitIndex);
 		showParent(pstyles);
-		checkParEffectState();
+		//checkParEffectState();
+		setParagraphEffect(0);
 		showColors(pstyles);
 	}
 }
@@ -543,13 +491,6 @@ void SMPStyleWidget::showColors(const QList<ParagraphStyle*> &cstyles)
 		}
 		d = cstyles[i]->backgroundShade();
 	}
-	if (d == -30000)
-	{
-		backShade_->setValue(21);
-		backShade_->setText( tr("Shade"));
-	}
-	else
-		backShade_->setValue(qRound(d));
 
 	QString s;
 	for (int i = 0; i < cstyles.count(); ++i)
@@ -561,22 +502,16 @@ void SMPStyleWidget::showColors(const QList<ParagraphStyle*> &cstyles)
 		}
 		s = cstyles[i]->backgroundColor();
 	}
-	if (s.isEmpty())
-	{
-		if (backColor_->itemText(backColor_->count() - 1) != "")
-			backColor_->addItem("");
-		backColor_->setCurrentIndex(backColor_->count() - 1);
-	}
-	else
-		backColor_->setCurrentText(s);
+
+	backgroundColor->setColor(s, qRound(d));
 }
 
 void SMPStyleWidget::showLineSpacing(const QList<ParagraphStyle*> &pstyles)
 {
 	lineSpacingMode->clear();
-	lineSpacingMode->addItem( tr("Fixed Linespacing"));
-	lineSpacingMode->addItem( tr("Automatic Linespacing"));
-	lineSpacingMode->addItem( tr("Align to Baseline Grid"));
+	lineSpacingMode->addItem( tr("Fixed"));
+	lineSpacingMode->addItem( tr("Automatic"));
+	lineSpacingMode->addItem( tr("Baseline"));
 
 	int tmpLP = -1;
 	for (int i = 0; i < pstyles.count(); ++i)
@@ -650,103 +585,7 @@ void SMPStyleWidget::showSpaceAB(const QList<ParagraphStyle*> &pstyles, int unit
 		spaceBelow->setValue(tmpA);
 }
 
-void SMPStyleWidget::showDropCap(const QList<ParagraphStyle*> &pstyles, const QList<CharStyle> &cstyles, int unitIndex)
-{
-	disconnectPESignals();
-	bool dc = pstyles[0]->hasDropCap();
-	for (int i = 0; i < pstyles.count(); ++i)
-	{
-		if (dc != pstyles[i]->hasDropCap())
-		{
-			dc = false;
-			break;
-		}
-	}
-	dropCapsBox->setChecked(dc);
 
-	int lines = -1;
-	for (int i = 0; i < pstyles.count(); ++i)
-	{
-		if (lines > -1 && pstyles[i]->dropCapLines() != lines)
-		{
-			lines = -1;
-			break;
-		}
-		lines = pstyles[i]->dropCapLines();
-	}
-	if (lines == -1)
-		dropCapLines->clear();
-	else
-		dropCapLines->setValue(lines);
-
-	dropCapsBox->setEnabled(true);
-	dropCapLines->setEnabled(true);
-	connectPESignals();
-}
-
-void SMPStyleWidget::showBullet(const QList<ParagraphStyle *> &pstyles, const QList<CharStyle> &cstyles, int unitIndex)
-{
-//	double unitRatio = unitGetRatioFromIndex(unitIndex);
-
-	disconnectPESignals();
-	bool hb = pstyles[0]->hasBullet();
-	for (int i = 0; i < pstyles.count(); ++i)
-	{
-		if (hb != pstyles[i]->hasBullet())
-		{
-			hb = false;
-			break;
-		}
-	}
-	bulletBox->setChecked(hb);
-
-	QString chStr = pstyles[0]->bulletStr();
-	for (int i = 0; i < pstyles.count(); ++i)
-	{
-		if (chStr != pstyles[i]->bulletStr())
-		{
-			chStr.clear();
-			break;
-		}
-		chStr = pstyles[i]->bulletStr();
-	}
-	bulletStrEdit->setEditText(chStr);
-
-	connectPESignals();
-	bulletCharTableButton->setEnabled(true);
-}
-
-void SMPStyleWidget::showNumeration(const QList<ParagraphStyle *> &pstyles, const QList<CharStyle> &cstyles, int unitIndex)
-{
-	disconnectPESignals();
-	QString prefix = pstyles[0]->numPrefix();
-	for (int i = 0; i < pstyles.count(); ++i)
-	{
-		if (prefix != pstyles[i]->numPrefix())
-		{
-			prefix.clear();
-			break;
-		}
-		prefix = pstyles[i]->numPrefix();
-	}
-	numPrefix->setText(prefix);
-	
-	QString suffix = pstyles[0]->numSuffix();
-	for (int i = 0; i < pstyles.count(); ++i)
-	{
-		if (suffix != pstyles[i]->numSuffix())
-		{
-			suffix.clear();
-			break;
-		}
-		suffix = pstyles[i]->numSuffix();
-	}
-	numSuffix->setText(suffix);
-
-	numFormatCombo->setEnabled(true);
-	numLevelSpin->setEnabled(true);
-	connectPESignals();
-}
 
 void SMPStyleWidget::showAlignment(const QList<ParagraphStyle*> &pstyles)
 {
@@ -823,7 +662,9 @@ void SMPStyleWidget::showOpticalMargin(const QList< ParagraphStyle * > & pstyles
 //		}
 //	}
 //	optMarginCombo->setCurrentItemByData(o);
-	setOpticalMargins(pstyles[0]->opticalMargins());
+	optMarginWidget->setOpticalMargins(pstyles[0]->opticalMargins());
+	optMarginWidget->setOpticalMarginSets(m_Doc->opticalMarginSets());
+	optMarginWidget->setOpticalMarginSetId(pstyles[0]->opticalMarginSetId());
 }
 
 void SMPStyleWidget::showMinSpace(const QList< ParagraphStyle * > & pstyles)
@@ -1019,122 +860,15 @@ void SMPStyleWidget::showParent(const QList<ParagraphStyle*> &pstyles)
 // 		parentCombo->setCurrentItem(0);
 }
 
-void SMPStyleWidget::setOpticalMargins(int o, bool inhO, const ParagraphStyle *parent)
-{
-	ParagraphStyle::OpticalMarginType om( static_cast<ParagraphStyle::OpticalMarginType>(o) );
-
-	if (parent == nullptr)
-	{
-		if (om == ParagraphStyle::OM_Default)
-			optMarginRadioBoth->setChecked(true);
-		else if (om == ParagraphStyle::OM_LeftHangingPunct)
-			optMarginRadioLeft->setChecked(true);
-		else if (om == ParagraphStyle::OM_RightHangingPunct)
-			optMarginRadioRight->setChecked(true);
-		else
-			optMarginRadioNone->setChecked(true);
-	}
-	else
-	{
-		optMarginParentButton->setVisible(!inhO);
-
-		if (om == ParagraphStyle::OM_Default)
-			optMarginRadioBoth->setChecked(true,
-				(parent->opticalMargins() == ParagraphStyle::OM_Default));
-		else if (om == ParagraphStyle::OM_LeftHangingPunct)
-			optMarginRadioLeft->setChecked(true,
-				(parent->opticalMargins() == ParagraphStyle::OM_LeftHangingPunct));
-		else if (om == ParagraphStyle::OM_RightHangingPunct)
-			optMarginRadioRight->setChecked(true,
-				(parent->opticalMargins() == ParagraphStyle::OM_RightHangingPunct));
-		else
-			optMarginRadioNone->setChecked(true,
-				(parent->opticalMargins() == ParagraphStyle::OM_None));
-		
-		optMarginRadioBoth->setParentValue(parent->opticalMargins() ==  ParagraphStyle::OM_Default);
-		optMarginRadioLeft->setParentValue(parent->opticalMargins() ==  ParagraphStyle::OM_LeftHangingPunct);
-		optMarginRadioRight->setParentValue(parent->opticalMargins() ==  ParagraphStyle::OM_RightHangingPunct);
-		optMarginRadioNone->setParentValue(parent->opticalMargins() ==  ParagraphStyle::OM_None);
-	}
-}
-
-
-void SMPStyleWidget::slotDefaultOpticalMargins()
-{
-	optMarginRadioNone->setChecked(true);
-	if (m_hasParent)
-		optMarginParentButton->show();
-}
-
-void SMPStyleWidget::slotParentOpticalMargins()
-{
-	disconnect(optMarginParentButton, SIGNAL(clicked()), this, SLOT(slotParentOpticalMargins()));
-	optMarginParentButton->hide();
-	emit useParentOptMargins();
-	connect(optMarginParentButton, SIGNAL(clicked()), this, SLOT(slotParentOpticalMargins()));
-}
 
 void SMPStyleWidget::clearAll()
 {
 
 }
 
-void SMPStyleWidget::slotDropCap(bool isOn)
-{
-	disconnectPESignals();
-	if (isOn)
-	{
-		dropCapLines->setEnabled(true);
-
-		bulletBox->setChecked(false);
-		bulletStrEdit->setEnabled(false);
-		bulletCharTableButton->setEnabled(false);
-
-		numBox->setChecked(false);
-		numFormatCombo->setEnabled(false);
-		numLevelSpin->setEnabled(false);
-		numComboBox->setEnabled(false);
-		numRestartCombo->setEnabled(false);
-		numNewLineEdit->setEnabled(false);
-	}
-	else
-		dropCapLines->setEnabled(false);
-	if (m_hasParent)
-		parentParEffectsButton->show();
-	checkParEffectState();
-	connectPESignals();
-}
-
-void SMPStyleWidget::slotBullets(bool isOn)
-{
-	disconnectPESignals();
-	if (isOn)
-	{
-		bulletStrEdit->setEnabled(true);
-		if (bulletStrEdit->currentText().isEmpty())
-			bulletStrEdit->setEditText(bulletStrEdit->itemText(0));
-		bulletCharTableButton->setEnabled(true);
-
-		numBox->setChecked(false);
-		numFormatCombo->setEnabled(false);
-		numLevelSpin->setEnabled(false);
-		numComboBox->setEnabled(false);
-		numRestartCombo->setEnabled(false);
-		numNewLineEdit->setEnabled(false);
-
-		dropCapsBox->setChecked(false);
-		dropCapLines->setEnabled(false);
-	}
-	else
-	{
-		bulletStrEdit->setEnabled(false);
-		bulletCharTableButton->setEnabled(false);
-	}
-	if (m_hasParent)
-		parentParEffectsButton->show();
-	checkParEffectState();
-	connectPESignals();
-}
+/*********************************************************************
+ *						Paragraph Effects
+ * *******************************************************************/
 
 void SMPStyleWidget::insertSpecialChars(const QVector<uint> &charCodes)
 {
@@ -1142,46 +876,21 @@ void SMPStyleWidget::insertSpecialChars(const QVector<uint> &charCodes)
 	bulletStrEdit->lineEdit()->setText(chars);
 }
 
-void SMPStyleWidget::slotNumbering(bool isOn)
-{
-	disconnectPESignals();
-	if (isOn)
-	{
-		numFormatCombo->setEnabled(true);
-		numLevelSpin->setEnabled(true);
-		numComboBox->setEnabled(true);
-		if (numComboBox->currentIndex() < 0)
-			numComboBox->setCurrentIndex(0);
-		numRestartCombo->setEnabled(true);
-		numNewLineEdit->setEnabled(true);
-
-		bulletBox->setChecked(false);
-		bulletStrEdit->setEnabled(false);
-		bulletCharTableButton->setEnabled(false);
-
-		dropCapsBox->setChecked(false);
-		dropCapLines->setEnabled(false);
-	}
-	else
-	{
-		numFormatCombo->setEnabled(false);
-		numLevelSpin->setEnabled(false);
-	}
-	if (m_hasParent)
-		parentParEffectsButton->show();
-	checkParEffectState();
-	connectPESignals();
-}
-
 void SMPStyleWidget::slotParentParEffects()
 {
-	disconnectPESignals();
 	parentParEffectsButton->hide();
-	dropCapsBox->setChecked(m_parentDC);
-	bulletBox->setChecked(m_parentBul);
-	numBox->setChecked(m_parentNum);
+
+	if (m_parentDC)
+		setParagraphEffect(1);
+	else if (m_parentBul)
+		setParagraphEffect(2);
+	else if (m_parentNum)
+		setParagraphEffect(3);
+	else
+		setParagraphEffect(0);
+
 	emit useParentParaEffects();
-	connectPESignals();
+
 }
 
 void SMPStyleWidget::openEnhanced()
@@ -1192,7 +901,7 @@ void SMPStyleWidget::openEnhanced()
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 	m_enhanced = new CharSelectEnhanced(this);
 	m_enhanced->setModal(true);
-	connect(m_enhanced, SIGNAL(insertSpecialChars(const QVector<uint> &)), this, SLOT(insertSpecialChars(const QVector<uint> &)));
+	connect(m_enhanced, SIGNAL(insertSpecialChars(QVector<uint>)), this, SLOT(insertSpecialChars(QVector<uint>)));
 	connect(m_enhanced, SIGNAL(paletteShown(bool)), bulletCharTableButton, SLOT(setChecked(bool)));
 	m_enhanced->setDoc(m_Doc);
 	m_enhanced->setEnabled(true);
@@ -1220,22 +929,6 @@ void SMPStyleWidget::closeEnhanced(bool show)
 	m_enhanced = nullptr;
 }
 
-void SMPStyleWidget::connectPESignals()
-{
-	connect(parentParEffectsButton, SIGNAL(clicked()), this, SLOT(slotParentParEffects()));
-	connect(bulletBox, SIGNAL(toggled(bool)), this, SLOT(slotBullets(bool)));
-	connect(numBox, SIGNAL(toggled(bool)), this, SLOT(slotNumbering(bool)));
-	connect(dropCapsBox, SIGNAL(toggled(bool)), this, SLOT(slotDropCap(bool)));
-}
-
-void SMPStyleWidget::disconnectPESignals()
-{
-	disconnect(parentParEffectsButton, SIGNAL(clicked()), this, SLOT(slotParentParEffects()));
-	disconnect(bulletBox, SIGNAL(toggled(bool)), this, SLOT(slotBullets(bool)));
-	disconnect(numBox, SIGNAL(toggled(bool)), this, SLOT(slotNumbering(bool)));
-	disconnect(dropCapsBox, SIGNAL(toggled(bool)), this, SLOT(slotDropCap(bool)));
-}
-
 void SMPStyleWidget::on_bulletCharTableButton_toggled(bool checked)
 {
 	if (m_enhanced && !checked)
@@ -1248,8 +941,181 @@ void SMPStyleWidget::handleUpdateRequest(int updateFlags)
 {
 	if (!m_Doc)
 		return;
-	if (updateFlags & reqColorsUpdate)
-		fillColorCombo(m_Doc->PageColors);
 	if (updateFlags & reqNumUpdate)
 		fillNumerationsCombo();
 }
+
+void SMPStyleWidget::fillBulletStrEditCombo()
+{
+	bulletStrEdit->clear();
+	bulletStrEdit->addItem(QChar(0x2022));
+	bulletStrEdit->addItem("*");
+	bulletStrEdit->addItem(QChar(0x2013));
+	bulletStrEdit->setMinimumWidth(50);
+	if (bulletStrEdit->currentText().isEmpty())
+		bulletStrEdit->setEditText(QChar(0x2022));
+}
+
+void SMPStyleWidget::fillNumerationsCombo()
+{
+	QStringList numNames;
+	const auto numerationKeys = m_Doc->numerations.keys();
+	for (const QString& numName : numerationKeys)
+	{
+		if (numName.isEmpty())
+			continue;
+		numNames.append(numName);
+	}
+	numNames.sort();
+	numComboBox->clear();
+	numComboBox->insertItems(0, numNames);
+	numComboBox->setCurrentItem(0);
+}
+
+void SMPStyleWidget::fillNumRestartCombo()
+{
+	numRestartCombo->clear();
+	numRestartCombo->addItem(tr("Document"), static_cast<int>(NSRdocument));
+	numRestartCombo->addItem(tr("Story") , static_cast<int>(NSRstory));
+}
+
+void SMPStyleWidget::fillPECombo()
+{
+	QSignalBlocker sb(peCombo);
+	int currIndex = peCombo->currentIndex();
+	peCombo->clear();
+	peCombo->addItem(tr("No Paragraph Effects"), -1);
+	peCombo->addItem(tr("Drop Caps"), 0);
+	peCombo->addItem(tr("Bulleted List"), 1);
+	peCombo->addItem(tr("Numbered List"), 2);
+	peCombo->setCurrentIndex(currIndex);
+}
+
+void SMPStyleWidget::setParagraphEffect(int index)
+{
+	QSignalBlocker sigPECombo(peCombo);
+
+	peCombo->setCurrentIndex(index);
+	int id = peCombo->currentIndex();
+
+	if (id == 1 || id == 2 || id == 3)
+	{
+		stackedWidget->setCurrentIndex(id - 1);
+		stackedWidget->setVisible(true);
+		peGroup->setVisible(true);
+
+		if (id == 2) // Bullet List
+		{
+			if (bulletStrEdit->currentText().isEmpty())
+				bulletStrEdit->setEditText(bulletStrEdit->itemText(0));
+		}
+		else if (id == 3) // Numbered List
+		{
+			if (numComboBox->currentIndex() < 0)
+				numComboBox->setCurrentIndex(0);
+		}
+	}
+	else // No effect
+	{
+		stackedWidget->setVisible(false);
+		peGroup->setVisible(false);
+		peCombo->setCurrentIndex(0);
+	}
+}
+
+void SMPStyleWidget::showDropCap(const QList<ParagraphStyle*> &pstyles, const QList<CharStyle> &cstyles, int unitIndex)
+{
+	bool dc = pstyles[0]->hasDropCap();
+	for (int i = 0; i < pstyles.count(); ++i)
+	{
+		if (dc != pstyles[i]->hasDropCap())
+		{
+			dc = false;
+			break;
+		}
+	}
+
+	if (dc)
+		setParagraphEffect(1);
+
+	int lines = -1;
+	for (int i = 0; i < pstyles.count(); ++i)
+	{
+		if (lines > -1 && pstyles[i]->dropCapLines() != lines)
+		{
+			lines = -1;
+			break;
+		}
+		lines = pstyles[i]->dropCapLines();
+	}
+	if (lines == -1)
+		dropCapLines->clear();
+	else
+		dropCapLines->setValue(lines);
+}
+
+void SMPStyleWidget::showBullet(const QList<ParagraphStyle *> &pstyles, const QList<CharStyle> &cstyles, int unitIndex)
+{
+//	double unitRatio = unitGetRatioFromIndex(unitIndex);
+
+	bool hb = pstyles[0]->hasBullet();
+	for (int i = 0; i < pstyles.count(); ++i)
+	{
+		if (hb != pstyles[i]->hasBullet())
+		{
+			hb = false;
+			break;
+		}
+	}
+
+	if (hb)
+		setParagraphEffect(2);
+
+	QString chStr = pstyles[0]->bulletStr();
+	for (int i = 0; i < pstyles.count(); ++i)
+	{
+		if (chStr != pstyles[i]->bulletStr())
+		{
+			chStr.clear();
+			break;
+		}
+		chStr = pstyles[i]->bulletStr();
+	}
+	bulletStrEdit->setEditText(chStr);
+}
+
+void SMPStyleWidget::showNumeration(const QList<ParagraphStyle *> &pstyles, const QList<CharStyle> &cstyles, int unitIndex)
+{
+
+	QString prefix = pstyles[0]->numPrefix();
+	for (int i = 0; i < pstyles.count(); ++i)
+	{
+		if (prefix != pstyles[i]->numPrefix())
+		{
+			prefix.clear();
+			break;
+		}
+		prefix = pstyles[i]->numPrefix();
+	}
+	numPrefix->setText(prefix);
+
+	QString suffix = pstyles[0]->numSuffix();
+	for (int i = 0; i < pstyles.count(); ++i)
+	{
+		if (suffix != pstyles[i]->numSuffix())
+		{
+			suffix.clear();
+			break;
+		}
+		suffix = pstyles[i]->numSuffix();
+	}
+	numSuffix->setText(suffix);
+}
+
+void SMPStyleWidget::handleParEffectUse(int index)
+{
+	if (m_hasParent)
+		parentParEffectsButton->show();
+
+	setParagraphEffect(index);
+}
