@@ -230,6 +230,7 @@ QString SMParagraphStyle::newStyle()
 	ParagraphStyle p;
 	p.setDefaultStyle(false);
 	p.setName(s);
+	p.setOpticalMarginSetId(m_doc->opticalMarginSets().firstKey());
 	p.charStyle().setLanguage(m_doc->language());
 	m_tmpStyles.create(p);
 	return s;
@@ -285,6 +286,7 @@ void SMParagraphStyle::apply()
 	// Better not call DrawNew() here, as this will cause several unnecessary calls
 	// m_doc->view()->DrawNew();
 	m_doc->changed();
+	m_doc->changedPagePreview();
 }
 
 void SMParagraphStyle::editMode(bool isOn)
@@ -497,11 +499,7 @@ void SMParagraphStyle::setupConnections()
 	connect(m_pwidget->direction->LTR, SIGNAL(clicked()), this, SLOT(slotDirection()));
 	connect(m_pwidget->direction->parentButton, SIGNAL(clicked()), this, SLOT(slotDirection()));
 //	connect(m_pwidget->optMarginCombo, SIGNAL(activated(int)), this, SLOT(slotOpticalMargin(int)));
-	connect(m_pwidget->optMarginRadioNone, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	connect(m_pwidget->optMarginRadioLeft, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	connect(m_pwidget->optMarginRadioRight, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	connect(m_pwidget->optMarginRadioBoth, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	connect(m_pwidget, SIGNAL(useParentOptMargins()), this, SLOT(slotParentOpticalMargin()));
+	connect(m_pwidget->optMarginWidget, SIGNAL(opticalMarginChanged()), this, SLOT(slotOpticalMarginSelector()));
 	
 	connect(m_pwidget->minSpaceSpin, SIGNAL(valueChanged(double)),this,SLOT(slotMinSpace()));
 	connect(m_pwidget->minGlyphExtSpin, SIGNAL(valueChanged(double)),this,SLOT(slotMinGlyphExt()));
@@ -510,16 +508,13 @@ void SMParagraphStyle::setupConnections()
 	connect(m_pwidget->maxConsecutiveCountSpinBox, SIGNAL(valueChanged(int)),this,SLOT(slotConsecutiveLines()));
 
 	connect(m_pwidget, SIGNAL(useParentParaEffects()), this, SLOT(slotParentParaEffects()));
-	connect(m_pwidget->dropCapsBox, SIGNAL(toggled(bool)), this, SLOT(slotDropCap(bool)));
+	connect(m_pwidget->peCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(slotPargraphEffects(int)));
 	connect(m_pwidget->dropCapLines, SIGNAL(valueChanged(int)), this, SLOT(slotDropCapLines(int)));
 	connect(m_pwidget->parEffectOffset, SIGNAL(valueChanged(double)), this, SLOT(slotParEffectOffset()));
 	connect(m_pwidget->parEffectIndentBox, SIGNAL(toggled(bool)), this, SLOT(slotParEffectIndent(bool)));
 	connect(m_pwidget->parEffectCharStyleCombo, SIGNAL(activated(int)), this, SLOT(slotParEffectCharStyle(int)));
-
-	connect(m_pwidget->bulletBox, SIGNAL(toggled(bool)), this, SLOT(slotBullet(bool)));
 	connect(m_pwidget->bulletStrEdit, SIGNAL(editTextChanged(QString)), this, SLOT(slotBulletStr(QString)));
-	connect(m_pwidget->numBox, SIGNAL(toggled(bool)), this, SLOT(slotNumeration(bool)));
-	connect(m_pwidget->numComboBox, SIGNAL(activated(QString)), this, SLOT(slotNumName(QString)));
+	connect(m_pwidget->numComboBox, SIGNAL(textActivated(QString)), this, SLOT(slotNumName(QString)));
 	connect(m_pwidget->numLevelSpin, SIGNAL(valueChanged(int)), this, SLOT(slotNumLevel(int)));
 	connect(m_pwidget->numFormatCombo, SIGNAL(activated(int)), this, SLOT(slotNumFormat(int)));
 	connect(m_pwidget->numStartSpin, SIGNAL(valueChanged(int)), this, SLOT(slotNumStart(int)));
@@ -542,9 +537,9 @@ void SMParagraphStyle::setupConnections()
 	connect(m_pwidget->tabList->rightIndentSpin, SIGNAL(valueChanged(double)), this, SLOT(slotRightIndent()));
 	connect(m_pwidget->tabList->firstLineSpin, SIGNAL(valueChanged(double)), this, SLOT(slotFirstLine()));
 
-	connect(m_pwidget->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotParentChanged(const QString&)));
-	connect(m_pwidget->backColor_, SIGNAL(activated(const QString&)), this, SLOT(slotBackPColor()));
-	connect(m_pwidget->backShade_, SIGNAL(clicked()), this, SLOT(slotBackPShade()));
+	connect(m_pwidget->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotParentChanged(QString)));
+	connect(m_pwidget->backgroundColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotBackPColor()));
+	connect(m_pwidget->backgroundColor->parentButton, SIGNAL(clicked()), this, SLOT(slotBackPColor()));
 
 	// character attributes
 	connect(m_pwidget->cpage->fontFace_, SIGNAL(fontSelected(QString)), this, SLOT(slotFont(QString)));
@@ -556,10 +551,6 @@ void SMParagraphStyle::setupConnections()
 	connect(m_pwidget->cpage->effects_->UnderlineVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	connect(m_pwidget->cpage->effects_->StrikeVal->LPos, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	connect(m_pwidget->cpage->effects_->StrikeVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
-	connect(m_pwidget->cpage->fillColor_, SIGNAL(activated(const QString&)), this, SLOT(slotFillColor()));
-	connect(m_pwidget->cpage->fillShade_, SIGNAL(clicked()), this, SLOT(slotFillShade()));
-	connect(m_pwidget->cpage->strokeColor_, SIGNAL(activated(const QString&)), this, SLOT(slotStrokeColor()));
-	connect(m_pwidget->cpage->strokeShade_, SIGNAL(clicked()), this, SLOT(slotStrokeShade()));
 	connect(m_pwidget->cpage->language_, SIGNAL(activated(int)), this, SLOT(slotLanguage()));
 	connect(m_pwidget->cpage->fontSize_, SIGNAL(valueChanged(double)), this, SLOT(slotFontSize()));
 	connect(m_pwidget->cpage->fontHScale_, SIGNAL(valueChanged(double)), this, SLOT(slotScaleH()));
@@ -567,15 +558,21 @@ void SMParagraphStyle::setupConnections()
 	connect(m_pwidget->cpage->tracking_, SIGNAL(valueChanged(double)), this, SLOT(slotTracking()));
 	connect(m_pwidget->cpage->widthSpaceSpin, SIGNAL(valueChanged(double)), this, SLOT(slotWordTracking()));
 	connect(m_pwidget->cpage->baselineOffset_, SIGNAL(valueChanged(double)), this, SLOT(slotBaselineOffset()));
-	connect(m_pwidget->cpage->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotCharParentChanged(const QString&)));
-	connect(m_pwidget->cpage->backColor_, SIGNAL(activated(const QString&)), this, SLOT(slotBackColor()));
-	connect(m_pwidget->cpage->backShade_, SIGNAL(clicked()), this, SLOT(slotBackShade()));
+	connect(m_pwidget->cpage->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotCharParentChanged(QString)));
+
+	connect(m_pwidget->cpage->textColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotFillColor()));
+	connect(m_pwidget->cpage->textColor->parentButton, SIGNAL(clicked()), this, SLOT(slotFillColor()));
+	connect(m_pwidget->cpage->backgroundColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotBackColor()));
+	connect(m_pwidget->cpage->backgroundColor->parentButton, SIGNAL(clicked()), this, SLOT(slotBackColor()));
+	connect(m_pwidget->cpage->strokeColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotStrokeColor()));
+	connect(m_pwidget->cpage->strokeColor->parentButton, SIGNAL(clicked()), this, SLOT(slotStrokeColor()));
+
 	connect(m_pwidget->cpage->fontfeaturesSetting,SIGNAL(changed()), this, SLOT(slotFontFeatures()));
 	connect(m_pwidget->cpage->hyphenCharLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotHyphenChar()));
 	connect(m_pwidget->cpage->smallestWordSpinBox, SIGNAL(valueChanged(int)), this, SLOT(slotWordMin()));
 
 	// Referenced character style changes
-	connect(m_cstyleItem, SIGNAL(charStylesDeleted(const QList<RemoveItem>&)), this, SLOT(slotCharStylesDeleted(const QList<RemoveItem>&)));
+	connect(m_cstyleItem, SIGNAL(charStylesDeleted(QList<RemoveItem>)), this, SLOT(slotCharStylesDeleted(QList<RemoveItem>)));
 }
 
 void SMParagraphStyle::removeConnections()
@@ -597,10 +594,7 @@ void SMParagraphStyle::removeConnections()
 	disconnect(m_pwidget->direction->LTR, SIGNAL(clicked()), this, SLOT(slotDirection()));
 	disconnect(m_pwidget->direction->parentButton, SIGNAL(clicked()), this, SLOT(slotDirection()));
 //	disconnect(m_pwidget->optMarginCombo, SIGNAL(activated(int)), this, SLOT(slotOpticalMargin(int)));
-	disconnect(m_pwidget->optMarginRadioNone, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	disconnect(m_pwidget->optMarginRadioLeft, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	disconnect(m_pwidget->optMarginRadioRight, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
-	disconnect(m_pwidget->optMarginRadioBoth, SIGNAL(clicked()), this, SLOT(slotOpticalMarginSelector()));
+	disconnect(m_pwidget->optMarginWidget, SIGNAL(opticalMarginChanged()), this, SLOT(slotOpticalMarginSelector()));
 	
 	disconnect(m_pwidget->minSpaceSpin, SIGNAL(valueChanged(double)),this,SLOT(slotMinSpace()));
 	disconnect(m_pwidget->minGlyphExtSpin, SIGNAL(valueChanged(double)),this,SLOT(slotMinGlyphExt()));
@@ -609,16 +603,13 @@ void SMParagraphStyle::removeConnections()
 	disconnect(m_pwidget->maxConsecutiveCountSpinBox, SIGNAL(valueChanged(int)),this,SLOT(slotConsecutiveLines()));
 
 	disconnect(m_pwidget, SIGNAL(useParentParaEffects()), this, SLOT(slotParentParaEffects()));
-	disconnect(m_pwidget->dropCapsBox, SIGNAL(toggled(bool)), this, SLOT(slotDropCap(bool)));
+	disconnect(m_pwidget->peCombo, SIGNAL(currentIndexChanged(int)), this, SLOT(slotPargraphEffects(int)));
 	disconnect(m_pwidget->dropCapLines, SIGNAL(valueChanged(int)), this, SLOT(slotDropCapLines(int)));
 	disconnect(m_pwidget->parEffectOffset, SIGNAL(valueChanged(double)), this, SLOT(slotParEffectOffset()));
 	disconnect(m_pwidget->parEffectIndentBox, SIGNAL(toggled(bool)), this, SLOT(slotParEffectIndent(bool)));
 	disconnect(m_pwidget->parEffectCharStyleCombo, SIGNAL(activated(int)), this, SLOT(slotParEffectCharStyle(int)));
-
-	disconnect(m_pwidget->bulletBox, SIGNAL(toggled(bool)), this, SLOT(slotBullet(bool)));
 	disconnect(m_pwidget->bulletStrEdit, SIGNAL(editTextChanged(QString)), this, SLOT(slotBulletStr(QString)));
-	disconnect(m_pwidget->numBox, SIGNAL(toggled(bool)), this, SLOT(slotNumeration(bool)));
-	disconnect(m_pwidget->numComboBox, SIGNAL(activated(QString)), this, SLOT(slotNumName(QString)));
+	disconnect(m_pwidget->numComboBox, SIGNAL(textActivated(QString)), this, SLOT(slotNumName(QString)));
 	disconnect(m_pwidget->numFormatCombo, SIGNAL(activated(int)), this, SLOT(slotNumFormat(int)));
 	disconnect(m_pwidget->numLevelSpin, SIGNAL(valueChanged(int)), this, SLOT(slotNumLevel(int)));
 	disconnect(m_pwidget->numStartSpin, SIGNAL(valueChanged(int)), this, SLOT(slotNumStart(int)));
@@ -630,7 +621,7 @@ void SMParagraphStyle::removeConnections()
 	disconnect(m_pwidget->numNewLineEdit, SIGNAL(editingFinished()), this, SLOT(slotNumNew()));
 	disconnect(m_pwidget->numNewLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotSelectionDirty()));
 	
-	disconnect(m_pwidget->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotParentChanged(const QString&)));
+	disconnect(m_pwidget->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotParentChanged(QString)));
 
 	disconnect(m_pwidget->keepLinesStart, SIGNAL(valueChanged(int)), this, SLOT(handleKeepLinesStart()));
 	disconnect(m_pwidget->keepLinesEnd, SIGNAL(valueChanged(int)), this, SLOT(handleKeepLinesEnd()));
@@ -641,8 +632,8 @@ void SMParagraphStyle::removeConnections()
 	disconnect(m_pwidget->tabList->leftIndentSpin, SIGNAL(valueChanged(double)), this, SLOT(slotLeftIndent()));
 	disconnect(m_pwidget->tabList->rightIndentSpin, SIGNAL(valueChanged(double)), this, SLOT(slotRightIndent()));
 	disconnect(m_pwidget->tabList->firstLineSpin, SIGNAL(valueChanged(double)), this, SLOT(slotFirstLine()));
-	disconnect(m_pwidget->backColor_, SIGNAL(activated(const QString&)), this, SLOT(slotBackPColor()));
-	disconnect(m_pwidget->backShade_, SIGNAL(clicked()), this, SLOT(slotBackPShade()));
+	disconnect(m_pwidget->backgroundColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotBackPColor()));
+	disconnect(m_pwidget->backgroundColor->parentButton, SIGNAL(clicked()), this, SLOT(slotBackPColor()));
 
 	disconnect(m_pwidget->cpage->fontFace_, SIGNAL(fontSelected(QString)), this, SLOT(slotFont(QString)));
 	disconnect(m_pwidget->cpage->effects_, SIGNAL(State(int)), this, SLOT(slotEffects(int)));
@@ -653,10 +644,6 @@ void SMParagraphStyle::removeConnections()
 	disconnect(m_pwidget->cpage->effects_->UnderlineVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	disconnect(m_pwidget->cpage->effects_->StrikeVal->LPos, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	disconnect(m_pwidget->cpage->effects_->StrikeVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
-	disconnect(m_pwidget->cpage->fillColor_, SIGNAL(activated(const QString&)), this, SLOT(slotFillColor()));
-	disconnect(m_pwidget->cpage->fillShade_, SIGNAL(clicked()), this, SLOT(slotFillShade()));
-	disconnect(m_pwidget->cpage->strokeColor_, SIGNAL(activated(const QString&)), this, SLOT(slotStrokeColor()));
-	disconnect(m_pwidget->cpage->strokeShade_, SIGNAL(clicked()), this, SLOT(slotStrokeShade()));
 	disconnect(m_pwidget->cpage->language_, SIGNAL(activated(int)), this, SLOT(slotLanguage()));
 	disconnect(m_pwidget->cpage->fontSize_, SIGNAL(valueChanged(double)), this, SLOT(slotFontSize()));
 	disconnect(m_pwidget->cpage->fontHScale_, SIGNAL(valueChanged(double)), this, SLOT(slotScaleH()));
@@ -664,9 +651,15 @@ void SMParagraphStyle::removeConnections()
 	disconnect(m_pwidget->cpage->tracking_, SIGNAL(valueChanged(double)), this, SLOT(slotTracking()));
 	disconnect(m_pwidget->cpage->widthSpaceSpin, SIGNAL(valueChanged(double)), this, SLOT(slotWordTracking()));
 	disconnect(m_pwidget->cpage->baselineOffset_, SIGNAL(valueChanged(double)), this, SLOT(slotBaselineOffset()));
-	disconnect(m_pwidget->cpage->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotCharParentChanged(const QString&)));
-	disconnect(m_pwidget->cpage->backColor_, SIGNAL(activated(const QString&)), this, SLOT(slotBackColor()));
-	disconnect(m_pwidget->cpage->backShade_, SIGNAL(clicked()), this, SLOT(slotBackShade()));
+	disconnect(m_pwidget->cpage->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotCharParentChanged(QString)));
+
+	disconnect(m_pwidget->cpage->textColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotFillColor()));
+	disconnect(m_pwidget->cpage->textColor->parentButton, SIGNAL(clicked()), this, SLOT(slotFillColor()));
+	disconnect(m_pwidget->cpage->backgroundColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotBackColor()));
+	disconnect(m_pwidget->cpage->backgroundColor->parentButton, SIGNAL(clicked()), this, SLOT(slotBackColor()));
+	disconnect(m_pwidget->cpage->strokeColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotStrokeColor()));
+	disconnect(m_pwidget->cpage->strokeColor->parentButton, SIGNAL(clicked()), this, SLOT(slotStrokeColor()));
+
 	disconnect(m_pwidget->cpage->fontfeaturesSetting, SIGNAL(changed()), this, SLOT(slotFontFeatures()));
 	disconnect(m_pwidget->cpage->hyphenCharLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotHyphenChar()));
 	disconnect(m_pwidget->cpage->smallestWordSpinBox, SIGNAL(valueChanged(int)), this, SLOT(slotWordMin()));
@@ -783,24 +776,26 @@ void SMParagraphStyle::slotOpticalMargin(int i)
 
 void SMParagraphStyle::slotOpticalMarginSelector()
 {
-	int omt(ParagraphStyle::OM_None);
-
-	if (m_pwidget->optMarginRadioRight->isChecked()) omt = ParagraphStyle::OM_RightHangingPunct;
-	else if (m_pwidget->optMarginRadioLeft->isChecked()) omt = ParagraphStyle::OM_LeftHangingPunct;
-	else if (m_pwidget->optMarginRadioBoth->isChecked()) omt = ParagraphStyle::OM_Default;
-
-	for (int i = 0; i < m_selection.count(); ++i)
-		m_selection[i]->setOpticalMargins(omt);
+	ParagraphStyle::OpticalMarginType omt( static_cast<ParagraphStyle::OpticalMarginType>(m_pwidget->optMarginWidget->opticalMargin()));
+	if (m_pwidget->optMarginWidget->useParentValue())
+	{
+		for (int i = 0; i < m_selection.count(); ++i)
+		{
+			m_selection[i]->resetOpticalMargins();
+			m_selection[i]->resetOpticalMarginSetId();
+		}
+	}
+	else
+	{
+		for (int i = 0; i < m_selection.count(); ++i)
+		{
+			m_selection[i]->setOpticalMarginSetId(m_pwidget->optMarginWidget->opticalMarginSetId());
+			m_selection[i]->setOpticalMargins(omt);
+		}
+	}
 
 	slotSelectionDirty();
-}
 
-void SMParagraphStyle::slotParentOpticalMargin()
-{
-	for (int i = 0; i < m_selection.count(); ++i)
-		m_selection[i]->resetOpticalMargins();
-
-	slotSelectionDirty();
 }
 
 void SMParagraphStyle::slotMinSpace()
@@ -863,30 +858,65 @@ void SMParagraphStyle::slotConsecutiveLines()
 	slotSelectionDirty();
 }
 
-void SMParagraphStyle::slotDropCap(bool isOn)
+// void SMParagraphStyle::slotDropCap(bool isOn)
+// {
+// 	for (int i = 0; i < m_selection.count(); ++i)
+// 	{
+// 		m_selection[i]->setHasDropCap(isOn);
+// 		if (isOn)
+// 		{
+// 			m_selection[i]->setHasBullet(false);
+// 			m_selection[i]->setHasNum(false);
+// 		}
+// 	}
+	
+// 	slotSelectionDirty();
+// }
+
+void SMParagraphStyle::slotParentParaEffects()
 {
-	for (int i = 0; i < m_selection.count(); ++i)
-	{
-		m_selection[i]->setHasDropCap(isOn);
-		if (isOn)
-		{
-			m_selection[i]->setHasBullet(false);
-			m_selection[i]->setHasNum(false);
-		}
-	}
+	// for (int i = 0; i < m_selection.count(); ++i)
+	// {
+	// 	m_selection[i]->resetHasDropCap();
+	// 	m_selection[i]->resetHasBullet();
+	// 	m_selection[i]->resetHasNum();
+	// }
+	slotPargraphEffects(0); // No effect
 	
 	slotSelectionDirty();
 }
 
-void SMParagraphStyle::slotParentParaEffects()
+void SMParagraphStyle::slotPargraphEffects(int index)
 {
 	for (int i = 0; i < m_selection.count(); ++i)
 	{
-		m_selection[i]->resetHasDropCap();
-		m_selection[i]->resetHasBullet();
-		m_selection[i]->resetHasNum();
+		if (index == 1) // Drop Caps
+		{
+			m_selection[i]->setHasDropCap(true);
+			m_selection[i]->setHasBullet(false);
+			m_selection[i]->setHasNum(false);
+		}
+		else if (index == 2) // Bullet List
+		{
+			m_selection[i]->setHasDropCap(false);
+			m_selection[i]->setHasBullet(true);
+			m_selection[i]->setHasNum(false);
+			m_selection[i]->setBulletStr(m_pwidget->bulletStrEdit->currentText());
+		}
+		else if (index == 3) // Numbered List
+		{
+			m_selection[i]->setHasDropCap(false);
+			m_selection[i]->setHasBullet(false);
+			m_selection[i]->setHasNum(true);
+		}
+		else // No effect
+		{
+			m_selection[i]->resetHasDropCap();
+			m_selection[i]->resetHasBullet();
+			m_selection[i]->resetHasNum();
+		}
 	}
-	
+
 	slotSelectionDirty();
 }
 
@@ -952,21 +982,21 @@ void SMParagraphStyle::slotParEffectCharStyle(int index)
 	slotSelectionDirty();
 }
 
-void SMParagraphStyle::slotBullet(bool isOn)
-{
-	for (int i = 0; i < m_selection.count(); ++i)
-	{
-		m_selection[i]->setHasBullet(isOn);
-		if (isOn)
-		{
-			m_selection[i]->setBulletStr(m_pwidget->bulletStrEdit->currentText());
-			m_selection[i]->setHasDropCap(false);
-			m_selection[i]->setHasNum(false);
-		}
-	}
+// void SMParagraphStyle::slotBullet(bool isOn)
+// {
+// 	for (int i = 0; i < m_selection.count(); ++i)
+// 	{
+// 		m_selection[i]->setHasBullet(isOn);
+// 		if (isOn)
+// 		{
+// 			m_selection[i]->setBulletStr(m_pwidget->bulletStrEdit->currentText());
+// 			m_selection[i]->setHasDropCap(false);
+// 			m_selection[i]->setHasNum(false);
+// 		}
+// 	}
 	
-	slotSelectionDirty();
-}
+// 	slotSelectionDirty();
+// }
 
 void SMParagraphStyle::slotBulletStr(const QString &str)
 {
@@ -982,20 +1012,20 @@ void SMParagraphStyle::slotBulletStr(const QString &str)
 	slotSelectionDirty();
 }
 
-void SMParagraphStyle::slotNumeration(bool isOn)
-{
-	for (int i = 0; i < m_selection.count(); ++i)
-	{
-		m_selection[i]->setHasNum(isOn);
-		if (isOn)
-		{
-			m_selection[i]->setHasDropCap(false);
-			m_selection[i]->setHasBullet(false);
-		}
-	}
+// void SMParagraphStyle::slotNumeration(bool isOn)
+// {
+// 	for (int i = 0; i < m_selection.count(); ++i)
+// 	{
+// 		m_selection[i]->setHasNum(isOn);
+// 		if (isOn)
+// 		{
+// 			m_selection[i]->setHasDropCap(false);
+// 			m_selection[i]->setHasBullet(false);
+// 		}
+// 	}
 	
-	slotSelectionDirty();
-}
+// 	slotSelectionDirty();
+// }
 
 void SMParagraphStyle::slotNumName(const QString &str)
 {
@@ -1423,35 +1453,25 @@ void SMParagraphStyle::slotEffectProperties()
 
 void SMParagraphStyle::slotFillColor()
 {
-	if (m_pwidget->cpage->fillColor_->useParentValue())
+	if (m_pwidget->cpage->textColor->useParentValue())
 	{
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->charStyle().resetFillColor();
+			m_selection[i]->charStyle().resetFillShade();
+		}
 	}
 	else
 	{
-		QString col( m_pwidget->cpage->fillColor_->currentText());
+		QString col( m_pwidget->cpage->textColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_pwidget->cpage->textColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->charStyle().setFillColor(col);
-	}
-	
-	slotSelectionDirty();
-}
-
-void SMParagraphStyle::slotFillShade()
-{
-	if (m_pwidget->cpage->fillShade_->useParentValue())
-	{
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->charStyle().resetFillShade();
-	}
-	else
-	{
-		int fs = m_pwidget->cpage->fillShade_->getValue();
-		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->charStyle().setFillShade(fs);
+		}
 	}
 	
 	slotSelectionDirty();
@@ -1459,35 +1479,25 @@ void SMParagraphStyle::slotFillShade()
 
 void SMParagraphStyle::slotBackPColor()
 {
-	if (m_pwidget->backColor_->useParentValue())
+	if (m_pwidget->backgroundColor->useParentValue())
 	{
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->resetBackgroundColor();
+			m_selection[i]->resetBackgroundShade();
+		}
 	}
 	else
 	{
-		QString col( m_pwidget->backColor_->currentText());
+		QString col( m_pwidget->backgroundColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_pwidget->backgroundColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->setBackgroundColor(col);
-	}
-
-	slotSelectionDirty();
-}
-
-void SMParagraphStyle::slotBackPShade()
-{
-	if (m_pwidget->backShade_->useParentValue())
-	{
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->resetBackgroundShade();
-	}
-	else
-	{
-		int fs = m_pwidget->backShade_->getValue();
-		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->setBackgroundShade(fs);
+		}
 	}
 
 	slotSelectionDirty();
@@ -1495,35 +1505,25 @@ void SMParagraphStyle::slotBackPShade()
 
 void SMParagraphStyle::slotBackColor()
 {
-	if (m_pwidget->cpage->backColor_->useParentValue())
+	if (m_pwidget->cpage->backgroundColor->useParentValue())
 	{
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->charStyle().resetBackColor();
+			m_selection[i]->charStyle().resetBackShade();
+		}
 	}
 	else
 	{
-		QString col( m_pwidget->cpage->backColor_->currentText());
+		QString col( m_pwidget->cpage->backgroundColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_pwidget->cpage->backgroundColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->charStyle().setBackColor(col);
-	}
-
-	slotSelectionDirty();
-}
-
-void SMParagraphStyle::slotBackShade()
-{
-	if (m_pwidget->cpage->backShade_->useParentValue())
-	{
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->charStyle().resetBackShade();
-	}
-	else
-	{
-		int fs = m_pwidget->cpage->backShade_->getValue();
-		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->charStyle().setBackShade(fs);
+		}
 	}
 
 	slotSelectionDirty();
@@ -1531,37 +1531,27 @@ void SMParagraphStyle::slotBackShade()
 
 void SMParagraphStyle::slotStrokeColor()
 {
-	if (m_pwidget->cpage->strokeColor_->useParentValue())
+	if (m_pwidget->cpage->strokeColor->useParentValue())
 	{
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->charStyle().resetStrokeColor();
+			m_selection[i]->charStyle().resetStrokeShade();
+		}
 	}
 	else
 	{
-		QString col(m_pwidget->cpage->strokeColor_->currentText());
+		QString col( m_pwidget->cpage->strokeColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_pwidget->cpage->strokeColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->charStyle().setStrokeColor(col);
+			m_selection[i]->charStyle().setStrokeShade(fs);
+		}
 	}
-	
-	slotSelectionDirty();
-}
 
-void SMParagraphStyle::slotStrokeShade()
-{
-	if (m_pwidget->cpage->strokeShade_->useParentValue())
-	{
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->charStyle().resetStrokeShade();
-	}
-	else 
-	{
-		int ss = m_pwidget->cpage->strokeShade_->getValue();
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->charStyle().setStrokeShade(ss);
-	}
-	
 	slotSelectionDirty();
 }
 
@@ -2077,6 +2067,7 @@ void SMCharacterStyle::apply()
 
 	m_doc->scMW()->requestUpdate(reqTextStylesUpdate);
 	m_doc->changed();
+	m_doc->changedPagePreview();
 }
 
 void SMCharacterStyle::editMode(bool isOn)
@@ -2280,10 +2271,7 @@ void SMCharacterStyle::setupConnections()
 	connect(m_page->effects_->UnderlineVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	connect(m_page->effects_->StrikeVal->LPos, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	connect(m_page->effects_->StrikeVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
-	connect(m_page->fillColor_, SIGNAL(activated(const QString&)), this, SLOT(slotFillColor()));
-	connect(m_page->fillShade_, SIGNAL(clicked()), this, SLOT(slotFillShade()));
-	connect(m_page->strokeColor_, SIGNAL(activated(const QString&)), this, SLOT(slotStrokeColor()));
-	connect(m_page->strokeShade_, SIGNAL(clicked()), this, SLOT(slotStrokeShade()));
+
 	connect(m_page->language_, SIGNAL(activated(int)), this, SLOT(slotLanguage()));
 	connect(m_page->fontSize_, SIGNAL(valueChanged(double)), this, SLOT(slotFontSize()));
 	connect(m_page->fontHScale_, SIGNAL(valueChanged(double)), this, SLOT(slotScaleH()));
@@ -2291,9 +2279,15 @@ void SMCharacterStyle::setupConnections()
 	connect(m_page->tracking_, SIGNAL(valueChanged(double)), this, SLOT(slotTracking()));
 	connect(m_page->widthSpaceSpin, SIGNAL(valueChanged(double)), this, SLOT(slotWordTracking()));
 	connect(m_page->baselineOffset_, SIGNAL(valueChanged(double)), this, SLOT(slotBaselineOffset()));
-	connect(m_page->parentCombo, SIGNAL(activated(const QString&)), this, SLOT(slotParentChanged(const QString&)));
-	connect(m_page->backColor_, SIGNAL(activated(const QString&)), this, SLOT(slotBackColor()));
-	connect(m_page->backShade_, SIGNAL(clicked()), this, SLOT(slotBackShade()));
+	connect(m_page->parentCombo, SIGNAL(currentTextChanged(QString)), this, SLOT(slotParentChanged(QString)));
+
+	connect(m_page->textColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotFillColor()));
+	connect(m_page->textColor->parentButton, SIGNAL(clicked()), this, SLOT(slotFillColor()));
+	connect(m_page->backgroundColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotBackColor()));
+	connect(m_page->backgroundColor->parentButton, SIGNAL(clicked()), this, SLOT(slotBackColor()));
+	connect(m_page->strokeColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotStrokeColor()));
+	connect(m_page->strokeColor->parentButton, SIGNAL(clicked()), this, SLOT(slotStrokeColor()));
+
 	connect(m_page->fontfeaturesSetting, SIGNAL(changed()), this, SLOT(slotFontFeatures()));
 	connect(m_page->smallestWordSpinBox, SIGNAL(valueChanged(int)), this, SLOT(slotSmallestWord()));
 	connect(m_page->hyphenCharLineEdit, SIGNAL(textChanged(QString)),this, SLOT(slotHyphenChar()));
@@ -2313,10 +2307,7 @@ void SMCharacterStyle::removeConnections()
 	disconnect(m_page->effects_->UnderlineVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	disconnect(m_page->effects_->StrikeVal->LPos, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
 	disconnect(m_page->effects_->StrikeVal->LWidth, SIGNAL(valueChanged(double)), this, SLOT(slotEffectProperties()));
-	disconnect(m_page->fillColor_, SIGNAL(activated(const QString&)), this, SLOT(slotFillColor()));
-	disconnect(m_page->fillShade_, SIGNAL(clicked()), this, SLOT(slotFillShade()));
-	disconnect(m_page->strokeColor_, SIGNAL(activated(const QString&)), this, SLOT(slotStrokeColor()));
-	disconnect(m_page->strokeShade_, SIGNAL(clicked()), this, SLOT(slotStrokeShade()));
+
 	disconnect(m_page->language_, SIGNAL(activated(int)), this, SLOT(slotLanguage()));
 	disconnect(m_page->fontSize_, SIGNAL(valueChanged(double)), this, SLOT(slotFontSize()));
 	disconnect(m_page->fontHScale_, SIGNAL(valueChanged(double)), this, SLOT(slotScaleH()));
@@ -2324,9 +2315,15 @@ void SMCharacterStyle::removeConnections()
 	disconnect(m_page->tracking_, SIGNAL(valueChanged(double)), this, SLOT(slotTracking()));
 	disconnect(m_page->widthSpaceSpin, SIGNAL(valueChanged(double)), this, SLOT(slotWordTracking()));
 	disconnect(m_page->baselineOffset_, SIGNAL(valueChanged(double)), this, SLOT(slotBaselineOffset()));
-	disconnect(m_page->parentCombo, SIGNAL(activated(const QString&)),  this, SLOT(slotParentChanged(const QString&)));
-	disconnect(m_page->backColor_, SIGNAL(activated(const QString&)), this, SLOT(slotBackColor()));
-	disconnect(m_page->backShade_, SIGNAL(clicked()), this, SLOT(slotBackShade()));
+	disconnect(m_page->parentCombo, SIGNAL(currentTextChanged(QString)),  this, SLOT(slotParentChanged(QString)));
+
+	disconnect(m_page->textColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotFillColor()));
+	disconnect(m_page->textColor->parentButton, SIGNAL(clicked()), this, SLOT(slotFillColor()));
+	disconnect(m_page->backgroundColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotBackColor()));
+	disconnect(m_page->backgroundColor->parentButton, SIGNAL(clicked()), this, SLOT(slotBackColor()));
+	disconnect(m_page->strokeColor->colorButton, SIGNAL(colorChanged()), this, SLOT(slotStrokeColor()));
+	disconnect(m_page->strokeColor->parentButton, SIGNAL(clicked()), this, SLOT(slotStrokeColor()));
+
 	disconnect(m_page->fontfeaturesSetting, SIGNAL(changed()), this, SLOT(slotFontFeatures()));
 	disconnect(m_page->smallestWordSpinBox, SIGNAL(valueChanged(int)), this, SLOT(slotSmallestWord()));
 	disconnect(m_page->hyphenCharLineEdit, SIGNAL(textChanged(QString)),this, SLOT(slotHyphenChar()));
@@ -2450,61 +2447,45 @@ void SMCharacterStyle::slotEffectProperties()
 
 void SMCharacterStyle::slotFillColor()
 {
-	if (m_page->fillColor_->useParentValue())
+	if (m_page->textColor->useParentValue())
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->resetFillColor();
+			m_selection[i]->resetFillShade();
+		}
 	else {		
-		QString col(m_page->fillColor_->currentText());
+		QString col(m_page->textColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_page->textColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->setFillColor(col);
-	}
-	
-	slotSelectionDirty();
-}
-
-void SMCharacterStyle::slotFillShade()
-{
-	if (m_page->fillShade_->useParentValue())
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->resetFillShade();
-	else {
-		int fs = m_page->fillShade_->getValue();
-
-		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->setFillShade(fs);
+		}
 	}
 	
 	slotSelectionDirty();
 }
 
 void SMCharacterStyle::slotBackColor()
-{
-	if (m_page->backColor_->useParentValue())
+{		
+	if (m_page->backgroundColor->useParentValue())
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->resetBackColor();
+			m_selection[i]->resetBackShade();
+		}
 	else {
-		QString col(m_page->backColor_->currentText());
+		QString col(m_page->backgroundColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_page->backgroundColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->setBackColor(col);
-	}
-
-	slotSelectionDirty();
-}
-
-void SMCharacterStyle::slotBackShade()
-{
-	if (m_page->backShade_->useParentValue())
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->resetBackShade();
-	else {
-		int fs = m_page->backShade_->getValue();
-
-		for (int i = 0; i < m_selection.count(); ++i)
 			m_selection[i]->setBackShade(fs);
+		}
 	}
 
 	slotSelectionDirty();
@@ -2512,30 +2493,22 @@ void SMCharacterStyle::slotBackShade()
 
 void SMCharacterStyle::slotStrokeColor()
 {
-	if (m_page->strokeColor_->useParentValue())
+	if (m_page->strokeColor->useParentValue())
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->resetStrokeColor();
+			m_selection[i]->resetStrokeShade();
+		}
 	else {
-		QString col(m_page->strokeColor_->currentText());
+		QString col(m_page->strokeColor->colorButton->colorName());
 		if (col == CommonStrings::tr_NoneColor)
 			col = CommonStrings::None;
+		int fs = m_page->strokeColor->colorButton->colorData().Shade;
 		for (int i = 0; i < m_selection.count(); ++i)
+		{
 			m_selection[i]->setStrokeColor(col);
-	}
-	
-	slotSelectionDirty();
-}
-
-void SMCharacterStyle::slotStrokeShade()
-{
-	if (m_page->strokeShade_->useParentValue())
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->resetStrokeShade();
-	else {
-		int ss = m_page->strokeShade_->getValue();
-		
-		for (int i = 0; i < m_selection.count(); ++i)
-			m_selection[i]->setStrokeShade(ss);
+			m_selection[i]->setStrokeShade(fs);
+		}
 	}
 	
 	slotSelectionDirty();
