@@ -17,10 +17,10 @@ for which a new license (GPL+exception) is in place.
 #include "commonstrings.h"
 #include "iconmanager.h"
 
-TabManager::TabManager( QWidget* parent, int dEin, QList<ParagraphStyle::TabRecord> inTab, double) : QDialog( parent )
+TabManager::TabManager( QWidget* parent, int dEin, const QList<ParagraphStyle::TabRecord>& inTab, double) : QDialog( parent )
 {
 	setModal(true);
-	setWindowTitle( tr( "Manage Tabulators" ) );
+    setWindowTitle( tr( "Manage Tabs" ) );
 	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
 	m_docUnitRatio = unitGetRatioFromIndex(dEin);
 	m_tabList = inTab;
