@@ -23,6 +23,9 @@ for which a new license (GPL+exception) is in place.
 #include <QToolButton>
 #include <QToolTip>
 #include <QVariant>
+#ifdef Q_OS_MACOS
+#include <QFontDatabase>
+#endif
 
 #include "commonstrings.h"
 #include "iconmanager.h"
@@ -31,6 +34,15 @@ for which a new license (GPL+exception) is in place.
 #include "scrspinbox.h"
 #include "units.h"
 #include "util.h"
+#include "util_gui.h"
+
+constexpr int bottomline = 24;
+constexpr int midline = bottomline / 2;
+constexpr int tabline = bottomline - 10;
+constexpr int scaleS = bottomline - 4;
+constexpr int scaleM = bottomline - 8;
+constexpr int scaleL = bottomline - 12;
+constexpr int textline = scaleL;
 
 RulerT::RulerT(QWidget *pa, int unit, const QList<ParagraphStyle::TabRecord>& tabs, bool ind, double wid) : QWidget(pa),
 	tabValues(tabs),
@@ -74,28 +86,47 @@ void RulerT::paintEvent(QPaintEvent *)
 {
 	double xl;
 
+	QFont ff = font();
+#ifdef Q_OS_MACOS
+	ff.setPointSize(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont).pointSize());
+#else
+	ff.setPointSize(QFont().pointSize() * .75);
+#endif
+	setFont(ff);
+
 	const QPalette& palette = this->palette();
 	const QColor& textColor = palette.color(QPalette::Text);
+	const QColor& selectedColor = blendColor(isDarkColor(palette.color(QPalette::Base)), QColor(255, 117, 102), QColor(255, 71, 51));
+	const QColor& backgroundColor = palette.color(QPalette::Base);
 
 	QPainter p;
 	p.begin(this);
-	p.drawLine(0, 24, width(), 24);
+	p.fillRect(rect(), backgroundColor);
+	p.drawLine(0, bottomline, width(), bottomline );
 	p.translate(-offset, 0);
 	p.setBrush(textColor);
 	p.setFont(font());
 	p.setPen(QPen(textColor, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+
 	for (xl = 0; xl < width() + offset; xl += m_iter)
 	{
 		if (xl < offset)
 			continue;
-		p.drawLine(qRound(xl), 18, qRound(xl), 24);
+		p.drawLine(qRound(xl), scaleS, qRound(xl), bottomline);
+	}
+
+	for (xl = 0; xl < width() + (m_iter2 / 2) + offset; xl += (m_iter2 / 2))
+	{
+		if (xl < offset)
+			continue;
+		p.drawLine(qRound(xl), scaleM, qRound(xl), bottomline);
 	}
 
 	for (xl = 0; xl < width() + (m_iter2 / 2) + offset; xl += m_iter2)
 	{
-		if (xl < offset)
+		if (xl < offset - 20) // -20px buffer to draw number that start outside the clipping rect
 			continue;
-		p.drawLine(qRound(xl), 11, qRound(xl), 24);
+		p.drawLine(qRound(xl), scaleL, qRound(xl), bottomline);
 		switch (unitIndex)
 		{
 			case SC_IN:
@@ -111,14 +142,17 @@ void RulerT::paintEvent(QPaintEvent *)
 					tx += QChar(0xBD);
 				if ((frac > 0.74) && (frac < 0.76))
 					tx += QChar(0xBE);
-				p.drawText(qRound(xl + 2), 17, tx);
+				p.drawText(qRound(xl + 2), textline, tx);
 				break;
 			}
 			case SC_P:
-				p.drawText(qRound(xl + 2), 17, QString::number(xl / m_iter));
+				p.drawText(qRound(xl + 2), textline, QString::number(xl / m_iter));
+				break;
+			case SC_CM:
+				p.drawText(qRound(xl + 2), textline, QString::number(xl / m_iter / 10));
 				break;
 			default:
-				p.drawText(qRound(xl + 2), 17, QString::number(xl / m_iter * 10));
+				p.drawText(qRound(xl + 2), textline, QString::number(xl / m_iter * 10));
 				break;
 		}
 	}
@@ -126,28 +160,28 @@ void RulerT::paintEvent(QPaintEvent *)
 	for (int i = 0; i < tabValues.count(); i++)
 	{
 		if (i == actTab)
-			p.setPen(QPen(Qt::red, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+			p.setPen(QPen(selectedColor, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
 		else
 			p.setPen(QPen(textColor, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
 		switch (tabValues[i].tabType)
 		{
-			case 0:
-				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
-				p.drawLine(qRound(tabValues[i].tabPosition), 23, qRound(tabValues[i].tabPosition + 8), 23);
+			case ParagraphStyle::LeftTab:
+				p.drawLine(qRound(tabValues[i].tabPosition), tabline, qRound(tabValues[i].tabPosition), bottomline - 1);
+				p.drawLine(qRound(tabValues[i].tabPosition), bottomline - 1, qRound(tabValues[i].tabPosition + 8), bottomline - 1);
 				break;
-			case 1:
-				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
-				p.drawLine(qRound(tabValues[i].tabPosition), 23, qRound(tabValues[i].tabPosition - 8), 23);
+			case ParagraphStyle::RightTab:
+				p.drawLine(qRound(tabValues[i].tabPosition), tabline, qRound(tabValues[i].tabPosition), bottomline - 1);
+				p.drawLine(qRound(tabValues[i].tabPosition), bottomline - 1, qRound(tabValues[i].tabPosition - 8), bottomline - 1);
 				break;
-			case 2:
-			case 3:
-				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
-				p.drawLine(qRound(tabValues[i].tabPosition - 4), 23, qRound(tabValues[i].tabPosition + 4), 23);
-				p.drawLine(qRound(tabValues[i].tabPosition + 3), 20, qRound(tabValues[i].tabPosition + 2), 20);
+			case ParagraphStyle::CommaTab:
+			case ParagraphStyle::DotTab:
+				p.drawLine(qRound(tabValues[i].tabPosition), tabline, qRound(tabValues[i].tabPosition), bottomline - 1);
+				p.drawLine(qRound(tabValues[i].tabPosition - 4), bottomline - 1, qRound(tabValues[i].tabPosition + 4), bottomline - 1);
+				p.drawLine(qRound(tabValues[i].tabPosition + 3), bottomline - 3, qRound(tabValues[i].tabPosition + 2), bottomline - 3);
 				break;
-			case 4:
-				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
-				p.drawLine(qRound(tabValues[i].tabPosition - 4), 23, qRound(tabValues[i].tabPosition + 4), 23);
+			case ParagraphStyle::CenterTab:
+				p.drawLine(qRound(tabValues[i].tabPosition), tabline, qRound(tabValues[i].tabPosition), bottomline - 1);
+				p.drawLine(qRound(tabValues[i].tabPosition - 4), bottomline - 1, qRound(tabValues[i].tabPosition + 4), bottomline - 1);
 				break;
 			default:
 				break;
@@ -156,13 +190,16 @@ void RulerT::paintEvent(QPaintEvent *)
 
 	if (haveInd)
 	{
-		p.setPen(QPen(Qt::blue, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-		p.setBrush(Qt::blue);
-		QPolygon cr;
-		cr.setPoints(3, qRound(firstLine + leftIndent), 12, qRound(firstLine + leftIndent - 4), 0, qRound(firstLine + leftIndent + 4), 0);
-		p.drawPolygon(cr);
+		// First Indent
+		p.setPen(QPen(textColor, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+		p.drawLine(qRound(firstLine + leftIndent), tabline - 2, qRound(firstLine + leftIndent), bottomline);
+		p.setPen(Qt::NoPen);
+		p.setRenderHints(QPainter::Antialiasing, true);
+		p.drawRect(QRect(qRound(firstLine + leftIndent), tabline - 8, 8, 6));
+
+		// Left Margin
 		QPolygon cr2;
-		cr2.setPoints(3, qRound(leftIndent), 12, qRound(leftIndent + 4), 24, qRound(leftIndent - 4), 24);
+		cr2.setPoints(3, qRound(leftIndent), tabline, qRound(leftIndent + 8), tabline, qRound(leftIndent), bottomline);
 		p.drawPolygon(cr2);
 	}
 	p.end();
@@ -172,6 +209,7 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 {
 	QRect fpo;
 	mousePressed = true;
+	int mPosX = m->position().x();
 	QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
 	rulerCode = 0;
 	if (haveInd)
@@ -180,25 +218,25 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 		if (fpo.contains(m->pos()))
 		{
 			rulerCode = 1;
-			mouseX = m->x();
+			mouseX = mPosX;
 			return;
 		}
 		fpo = QRect(static_cast<int>(leftIndent - offset) - 4, 12, 8, 12);
 		if (fpo.contains(m->pos()))
 		{
 			rulerCode = 2;
-			mouseX = m->x();
+			mouseX = mPosX;
 			return;
 		}
 	}
-	for (int i = 0; i < tabValues.count(); ++i)
+	for (qsizetype i = 0; i < tabValues.count(); ++i)
 	{
 		fpo = QRect(static_cast<int>(tabValues[i].tabPosition - offset) - 3, 15, 8, 8);
 		if (fpo.contains(m->pos()))
 		{
 			rulerCode = 3;
-			actTab = i;
-			mouseX = m->x();
+			actTab = static_cast<int>(i);
+			mouseX = mPosX;
 			emit tabSelected();
 			emit typeChanged(tabValues[actTab].tabType);
 			emit tabMoved(tabValues[actTab].tabPosition);
@@ -210,9 +248,7 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 	if ((rulerCode == 0) && (m->button() == Qt::LeftButton))
 	{
 		ParagraphStyle::TabRecord tb;
-		tb.tabPosition = static_cast<double>(m->x() + offset);
-		tb.tabType = 0;
-		tb.tabFillChar = QChar();
+		tb.tabPosition = static_cast<double>(mPosX + offset);
 		tabValues.prepend(tb);
 		actTab = 0;
 		rulerCode = 3;
@@ -224,16 +260,17 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 		emit fillCharChanged(tabValues[actTab].tabFillChar);
 		QApplication::changeOverrideCursor(QCursor(Qt::SizeHorCursor));
 	}
-	mouseX = m->x();
+	mouseX = mPosX;
 }
 
 void RulerT::mouseReleaseEvent(QMouseEvent *m)
 {
 	mousePressed = false;
 	QApplication::restoreOverrideCursor();
-	if ((m->y() < height()) && (m->y() > 0))
+	int mPosY = m->position().y();
+	if ((mPosY < height()) && (mPosY > 0))
 	{
-		if ((rulerCode == 3) && (m->button() == Qt::RightButton))
+		if (rulerCode == 3  && (m->button() == Qt::RightButton))
 		{
 			tabValues[actTab].tabType += 1;
 			if (tabValues[actTab].tabType > 4)
@@ -246,7 +283,7 @@ void RulerT::mouseReleaseEvent(QMouseEvent *m)
 	{
 		tabValues.removeAt(actTab);
 		actTab = 0;
-		if (!tabValues.isEmpty())
+		if (tabValues.count() != 0)
 		{
 			emit typeChanged(tabValues[actTab].tabType);
 			emit tabMoved(tabValues[actTab].tabPosition);
@@ -264,15 +301,17 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 {
 	double oldInd;
 	QRect fpo;
-	if (mousePressed && (m->y() < height()) && (m->y() > 0) && (m->x() > 0) && (m->x() < width()))
+	int mPosX = m->position().x();
+	int mPosY = m->position().y();
+	if (mousePressed && (mPosY < height()) && (mPosY > 0) && (mPosX > 0) && (mPosX < width()))
 	{
 		QApplication::changeOverrideCursor(QCursor(Qt::SizeHorCursor));
 		switch (rulerCode)
 		{
 			case 1:
-				firstLine -= mouseX - m->x();
+				firstLine -= mouseX - mPosX;
 				if (firstLine + leftIndent + offset < offset)
-					firstLine += mouseX - m->x();
+					firstLine += mouseX - mPosX;
 				if (firstLine + leftIndent > m_rulerWidth)
 					firstLine  = m_rulerWidth - leftIndent;
 				emit firstLineMoved(firstLine);
@@ -280,7 +319,7 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 				break;
 			case 2:
 				oldInd = leftIndent+firstLine;
-				leftIndent -= mouseX - m->x();
+				leftIndent -= mouseX - mPosX;
 				if (leftIndent < 0)
 					leftIndent = 0;
 				if (leftIndent > m_rulerWidth - 1)
@@ -291,7 +330,7 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 				update();
 				break;
 			case 3:
-				tabValues[actTab].tabPosition -= mouseX - m->x();
+				tabValues[actTab].tabPosition -= mouseX - mPosX;
 				if (tabValues[actTab].tabPosition < 0)
 					tabValues[actTab].tabPosition = 0;
 				if (tabValues[actTab].tabPosition > m_rulerWidth - 1)
@@ -303,30 +342,30 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 			default:
 				break;
 		}
-		mouseX = m->x();
+		mouseX = mPosX;
 		return;
 	}
-	if ((!mousePressed) && (m->y() < height()) && (m->y() > 0) && (m->x() > 0) && (m->x() < width()))
+	if ((!mousePressed) && (mPosY < height()) && (mPosY > 0) && (mPosX > 0) && (mPosX < width()))
 	{
 		setCursor(IconManager::instance().loadCursor("tab.png", 3));
 		if (haveInd)
 		{
-			fpo = QRect(static_cast<int>(firstLine + leftIndent - offset) - 4, 0, 8, 12);
+			fpo = QRect(static_cast<int>(firstLine + leftIndent - offset) - 4, 0, 8, midline);
 			if (fpo.contains(m->pos()))
 			{
 				setCursor(QCursor(Qt::SizeHorCursor));
 				return;
 			}
-			fpo = QRect(static_cast<int>(leftIndent - offset) - 4, 12, 8, 12);
+			fpo = QRect(static_cast<int>(leftIndent - offset) - 4, midline, 8, midline);
 			if (fpo.contains(m->pos()))
 			{
 				setCursor(QCursor(Qt::SizeHorCursor));
 				return;
 			}
 		}
-		for (int i = 0; i < tabValues.count(); ++i)
+		for (qsizetype i = 0; i < tabValues.count(); ++i)
 		{
-			fpo = QRect(static_cast<int>(tabValues[i].tabPosition - offset) - 3, 15, 8, 8);
+			fpo = QRect(static_cast<int>(tabValues[i].tabPosition-offset) - 3, tabline, 8, 8);
 			if (fpo.contains(m->pos()))
 			{
 				setCursor(QCursor(Qt::SizeHorCursor));
@@ -334,10 +373,21 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 			}
 		}
 	}
-	if (mousePressed && ((m->y() > height()) || (m->y() < 0) || (m->x() < 0) || (m->x() > width())))
-	{
+	if (mousePressed && ((mPosY > height()) || (mPosY < 0) || (mPosX < 0) || (mPosX > width())))
 		QApplication::changeOverrideCursor(IconManager::instance().loadCursor("DelPoint.png", 1, 1));
-	}
+}
+
+void RulerT::wheelEvent(QWheelEvent* m)
+{
+	QPoint numPixels = m->pixelDelta();
+
+	if (numPixels.y() > 0 || numPixels.x() > 0)
+		decreaseOffset();
+
+	if (numPixels.y() < 0 || numPixels.x() < 0)
+		increaseOffset();
+
+	m->accept();
 }
 
 void RulerT::leaveEvent(QEvent*)
@@ -357,10 +407,10 @@ void RulerT::updateTabList()
 	tb.tabPosition = tabValues[actTab].tabPosition;
 	tb.tabType = tabValues[actTab].tabType;
 	tb.tabFillChar =  tabValues[actTab].tabFillChar;
-	int gg = tabValues.count() - 1;
-	int g = gg;
+	qsizetype gg = tabValues.count() - 1;
+	qsizetype g = gg;
 	tabValues.removeAt(actTab);
-	for (int i = tabValues.count() - 1; i > -1; --i)
+	for (qsizetype i = tabValues.count() - 1; i > -1; --i)
 	{
 		if (tb.tabPosition < tabValues[i].tabPosition)
 			g = i;
@@ -369,7 +419,7 @@ void RulerT::updateTabList()
 	if (gg == g)
 	{
 		tabValues.append(tb);
-		actTab = tabValues.count() - 1;
+		actTab = static_cast<int>(tabValues.count() - 1);
 	}
 	else
 	{
@@ -435,7 +485,7 @@ void RulerT::removeActTab()
 	{
 		tabValues.removeAt(actTab);
 		actTab = 0;
-		if (!tabValues.isEmpty())
+		if (tabValues.count() != 0)
 		{
 			emit typeChanged(tabValues[actTab].tabType);
 			emit tabMoved(tabValues[actTab].tabPosition);
@@ -479,6 +529,7 @@ void RulerT::moveLeftIndent(double t)
 
 Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<ParagraphStyle::TabRecord>& tabs, double wid ): QWidget( parent )
 {
+	m_haveFirst = haveFirst;
 	m_docUnitRatio = unitGetRatioFromIndex(unit);
 	double ww = (wid < 0) ? 4000 : wid;
 	tabrulerLayout = new QVBoxLayout( this );
@@ -502,70 +553,67 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<Parag
 
 	layout1 = new QHBoxLayout;
 	layout1->setContentsMargins(0, 0, 0, 0);
-	layout1->setSpacing(6);
+	layout1->setSpacing(16);
 	layout1->setAlignment( Qt::AlignTop );
 	typeCombo = new QComboBox(this);
 	typeCombo->setEditable(false);
-	typeCombo->clear();
-	typeCombo->addItem( tr( "Left" ) );
-	typeCombo->addItem( tr( "Right" ) );
-	typeCombo->addItem( tr( "Period" ) );
-	typeCombo->addItem( tr( "Comma" ) );
-	typeCombo->addItem( tr( "Center" ) );
 	layout1->addWidget( typeCombo );
+
 	tabData = new ScrSpinBox( 0, ww / m_docUnitRatio, this, unit );
 	tabData->setValue(0);
-	positionLabel = new QLabel( tr("&Position:"), this );
-	positionLabel->setBuddy(tabData);
+	positionLabel = new FormWidget();
+	positionLabel->setDirection(FormWidget::Left);
+	positionLabel->setUseSmallFont(false);
+	positionLabel->addWidget(tabData);
 	layout1->addWidget( positionLabel );
-	layout1->addWidget( tabData );
+
 	tabFillCombo = new QComboBox(this);
 	tabFillCombo->setEditable(false);
-	tabFillCombo->addItem( tr("None", "tab fill"));
-	tabFillCombo->addItem( tr("Dot"));
-	tabFillCombo->addItem( tr("Hyphen"));
-	tabFillCombo->addItem( tr("Underscore"));
-	tabFillCombo->addItem( tr("Custom"));
-	tabFillComboT = new QLabel( tr( "Fill Char:" ), this );
-	tabFillComboT->setBuddy(tabFillCombo);
+	tabFillComboT = new FormWidget();
+	tabFillComboT->setDirection(FormWidget::Left);
+	tabFillComboT->setUseSmallFont(false);
+	tabFillComboT->addWidget(tabFillCombo);
 	layout1->addWidget( tabFillComboT );
-	layout1->addWidget( tabFillCombo );
+
 	clearOneButton = new QToolButton( this );
-	clearOneButton->setIcon(IconManager::instance().loadIcon("16/edit-delete.png"));
-	layout1->addSpacing(12);
-	layout1->addWidget(clearOneButton);
+
 	clearButton = new QToolButton( this );
-	clearButton->setIcon(IconManager::instance().loadIcon("16/edit-delete-all.png"));
-	layout1->addWidget(clearButton);
+
+	FormWidget *clearLayout = new FormWidget();
+	clearLayout->setSpace(4);
+	clearLayout->setLabelVisibility(false);
+	clearLayout->addWidget(clearOneButton);
+	clearLayout->addWidget(clearButton);
+	layout1->addWidget(clearLayout);
 
 	indentLayout = new QHBoxLayout;
 	indentLayout->setContentsMargins(0, 0, 0, 0);
-	indentLayout->setSpacing(6);
-	if (haveFirst)
+	indentLayout->setSpacing(16);
+	if (m_haveFirst)
 	{
 		firstLineData = new ScrSpinBox( -3000, ww / m_docUnitRatio, this, unit);
 		firstLineData->setValue(0);
-		firstLineLabel = new QLabel(this);
+		firstLineLabel = new FormWidget(this);
 		firstLineLabel->setText("");
-		firstLineLabel->setPixmap(IconManager::instance().loadPixmap("firstline.png"));
+		firstLineLabel->addWidget(firstLineData);
 		indentLayout->addWidget( firstLineLabel );
-		indentLayout->addWidget( firstLineData );
+
 		leftIndentData = new ScrSpinBox( 0, ww / m_docUnitRatio, this, unit);
 		leftIndentData->setValue(0);
-		leftIndentLabel = new QLabel(this);
+		leftIndentLabel = new FormWidget(this);
 		leftIndentLabel->setText("");
-		leftIndentLabel->setPixmap(IconManager::instance().loadPixmap("leftindent.png"));
+		leftIndentLabel->addWidget(leftIndentData);
 		indentLayout->addWidget(leftIndentLabel);
-		indentLayout->addWidget(leftIndentData);
-		rightIndentLabel = new QLabel(this);
-		rightIndentLabel->setText("");
-		rightIndentLabel->setPixmap(IconManager::instance().loadPixmap("rightindent.png"));
+
 		rightIndentData = new ScrSpinBox(0, ww / m_docUnitRatio, this, unit);
 		rightIndentData->setValue(0);
+		rightIndentLabel = new FormWidget(this);
+		rightIndentLabel->setText("");
+		rightIndentLabel->addWidget(rightIndentData);
 		indentLayout->addWidget(rightIndentLabel);
-		indentLayout->addWidget(rightIndentData);
+
 	}
-	if (!haveFirst)
+	if (!m_haveFirst)
 	{
 		auto* spacer = new QSpacerItem(20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
 		layout1->addItem(spacer);
@@ -585,6 +633,9 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<Parag
 	clearOneButton->setEnabled(false);
 	resize( minimumSizeHint() );
 
+	iconSetChange();
+	languageChange();
+
 	connect(rulerScrollL, SIGNAL(clicked()), ruler, SLOT(decreaseOffset()));
 	connect(rulerScrollR, SIGNAL(clicked()), ruler, SLOT(increaseOffset()));
 	connect(rulerScrollL, SIGNAL(released()), this, SLOT(resetOFfL()));
@@ -593,7 +644,7 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<Parag
 	connect(ruler, SIGNAL(fillCharChanged(QChar)) , this, SLOT(setTabFillChar(QChar)));
 	connect(typeCombo, SIGNAL(activated(int)), this, SLOT(setType()));
 	connect(tabFillCombo, SIGNAL(activated(int)), this, SLOT(setFillChar()));
-	connect(tabFillCombo, SIGNAL(editTextChanged(const QString &)), this, SLOT(setCustomFillChar(const QString &)));
+	connect(tabFillCombo, SIGNAL(editTextChanged(QString)), this, SLOT(setCustomFillChar(QString)));
 	connect(ruler, SIGNAL(tabMoved(double)) , this, SLOT(setTabData(double)));
 	connect(ruler, SIGNAL(tabSelected()), this, SLOT(tabAdded()));
 	connect(ruler, SIGNAL(newTab()), this, SLOT(tabAdded()));
@@ -602,11 +653,7 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<Parag
 	connect(clearButton, SIGNAL(clicked()), this, SLOT(clearAll()));
 	connect(clearOneButton, SIGNAL(clicked()), this, SLOT(clearOne()));
 
-	tabFillCombo->setToolTip( tr( "Fill Character of Tab" ) );
-	typeCombo->setToolTip( tr( "Type/Orientation of Tab" ) );
-	tabData->setToolTip( tr( "Position of Tab" ) );
-
-	if (haveFirst)
+	if (m_haveFirst)
 	{
 		connect(ruler, SIGNAL(firstLineMoved(double)) , this, SLOT(setFirstLineData(double)));
 		connect(ruler, SIGNAL(leftIndentMoved(double)) , this, SLOT(setLeftIndentData(double)));
@@ -615,19 +662,11 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<Parag
 		connect(firstLineData, SIGNAL(valueChanged(double)), this, SLOT(setFirstLine()));
 		connect(leftIndentData, SIGNAL(valueChanged(double)), this, SLOT(setLeftIndent()));
 		connect(rightIndentData, SIGNAL(valueChanged(double)), this, SLOT(setRightIndent()));
-		firstLineData->setToolTip( tr( "Indentation for first line of the paragraph" ) );
-		leftIndentData->setToolTip( tr( "Indentation from the left for the whole paragraph" ) );
-		rightIndentData->setToolTip( tr( "Indentation from the right for the whole paragraph" ) );
-		firstLineLabel->setToolTip(firstLineData->toolTip());
-		leftIndentLabel->setToolTip(leftIndentData->toolTip());
-		rightIndentLabel->setToolTip(rightIndentData->toolTip());
 	}
-	clearButton->setToolTip( tr( "Delete all Tabulators" ) );
-	clearOneButton->setToolTip( tr("Delete selected Tabulator"));
 
 	if (unit == SC_INCHES)
 	{
-		if (haveFirst)
+		if (m_haveFirst)
 		{
 			firstLineData->setDecimals(4);
 			leftIndentData->setDecimals(4);
@@ -635,7 +674,6 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<Parag
 		}
 		tabData->setDecimals(4);
 	}
-	m_haveFirst = haveFirst;
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 }
@@ -655,28 +693,29 @@ void Tabruler::iconSetChange()
 	IconManager& iconManager = IconManager::instance();
 
 	if (firstLineLabel)
-		firstLineLabel->setPixmap(iconManager.loadPixmap("firstline.png"));
+		firstLineLabel->setPixmap(iconManager.loadPixmap("paragraph-indent-firstline"));
 
 	if (leftIndentLabel)
-		leftIndentLabel->setPixmap(iconManager.loadPixmap("leftindent.png"));
+		leftIndentLabel->setPixmap(iconManager.loadPixmap("paragraph-indent-left"));
 
 	if (rightIndentLabel)
-		rightIndentLabel->setPixmap(iconManager.loadPixmap("rightindent.png"));
+		rightIndentLabel->setPixmap(iconManager.loadPixmap("paragraph-indent-right"));
 
-	clearOneButton->setIcon(iconManager.loadIcon("16/edit-delete.png"));
-	clearButton->setIcon(iconManager.loadIcon("16/edit-delete-all.png"));
+	clearOneButton->setIcon(iconManager.loadIcon("delete-selected"));
+	clearButton->setIcon(iconManager.loadIcon("16/edit-delete.png"));
 }
 
 void Tabruler::languageChange()
 {
+	IconManager &im = IconManager::instance();
 	int  oldTypeComboIndex = typeCombo->currentIndex();
 	bool typeComboBlocked = typeCombo->blockSignals(true);
 	typeCombo->clear();
-	typeCombo->addItem( tr( "Left" ) );
-	typeCombo->addItem( tr( "Right" ) );
-	typeCombo->addItem( tr( "Period" ) );
-	typeCombo->addItem( tr( "Comma" ) );
-	typeCombo->addItem( tr( "Center" ) );
+	typeCombo->addItem(im.loadIcon("tabulator-left"), tr( "Left" ), ParagraphStyle::LeftTab );
+	typeCombo->addItem(im.loadIcon("tabulator-center"), tr( "Center" ), ParagraphStyle::CenterTab );
+	typeCombo->addItem(im.loadIcon("tabulator-comma"), tr( "Comma" ), ParagraphStyle::CommaTab );
+	typeCombo->addItem(im.loadIcon("tabulator-dot"), tr( "Period" ), ParagraphStyle::DotTab );
+	typeCombo->addItem(im.loadIcon("tabulator-right"), tr( "Right" ), ParagraphStyle::RightTab );
 	typeCombo->setCurrentIndex(oldTypeComboIndex);
 	typeCombo->blockSignals(typeComboBlocked);
 
@@ -695,8 +734,8 @@ void Tabruler::languageChange()
 
 	tabFillComboT->setText( tr( "Fill Char:" ));
 
-	clearButton->setText( tr( "Delete All" ) );
-	clearOneButton->setText( tr( "Delete Selected" ) );
+	clearButton->setToolTip( tr( "Delete all Tabulators" ) );
+	clearOneButton->setToolTip( tr("Delete selected Tabulator"));
 
 	tabFillCombo->setToolTip( tr( "Fill Character of Tab" ) );
 	typeCombo->setToolTip( tr( "Type/Orientation of Tab" ) );
@@ -711,8 +750,6 @@ void Tabruler::languageChange()
 		leftIndentLabel->setToolTip(leftIndentData->toolTip());
 		rightIndentLabel->setToolTip(rightIndentData->toolTip());
 	}
-	clearButton->setToolTip( tr( "Delete all Tabulators" ) );
-	clearOneButton->setToolTip( tr("Delete selected Tabulator"));
 
 	QString unitSuffix = unitGetSuffixFromIndex(tabData->unitIndex());
 	if (m_haveFirst)
@@ -798,7 +835,7 @@ void Tabruler::lastTabRemoved()
 
 void Tabruler::setFillChar()
 {
-	bool sigBlocked = tabFillCombo->blockSignals(true);
+	tabFillCombo->blockSignals(true);
 	QChar ret;
 	switch (tabFillCombo->currentIndex())
 	{
@@ -825,7 +862,7 @@ void Tabruler::setFillChar()
 	}
 	if (tabFillCombo->currentIndex() != 4)
 		ruler->changeTabChar(ret);
-	tabFillCombo->blockSignals(sigBlocked);
+	tabFillCombo->blockSignals(false);
 	emit tabrulerChanged();
 	emit tabsChanged();
 }
@@ -834,10 +871,10 @@ void Tabruler::setCustomFillChar(const QString &txt)
 {
 	if (txt == CommonStrings::trCustomTabFill)
 		return;
-	bool sigBlocked = tabFillCombo->blockSignals(true);
-	QChar ret = (txt.length() > 0) ? txt.back() : QChar::Null;
+	tabFillCombo->blockSignals(true);
+	QChar ret = (txt.length() > 0) ? txt[txt.length()-1] : QChar::Null;
 	ruler->changeTabChar(ret);
-	tabFillCombo->blockSignals(sigBlocked);
+	tabFillCombo->blockSignals(false);
 	emit tabrulerChanged();
 	emit tabsChanged();
 }
@@ -881,25 +918,25 @@ void Tabruler::setTabFillChar(QChar t)
 
 void Tabruler::setTabType(int t)
 {
-	typeCombo->setCurrentIndex(t);
+	typeCombo->setCurrentIndex(typeCombo->findData(t));
 	emit tabrulerChanged();
 	emit tabsChanged();
 }
 
 void Tabruler::setType()
 {
-	bool sigBlocked = typeCombo->blockSignals(true);
-	ruler->changeTab(typeCombo->currentIndex());
-	typeCombo->blockSignals(sigBlocked);
+	typeCombo->blockSignals(true);
+	ruler->changeTab(typeCombo->currentData().toInt());
+	typeCombo->blockSignals(false);
 	emit tabrulerChanged();
 	emit tabsChanged();
 }
 
 void Tabruler::setTabData(double t)
 {
-	bool sigBlocked = tabData->blockSignals(true);
+	tabData->blockSignals(true);
 	tabData->setValue(t * m_docUnitRatio);
-	tabData->blockSignals(sigBlocked);
+	tabData->blockSignals(false);
 	if (!ruler->mousePressed)
 	{
 		emit tabrulerChanged();
@@ -916,9 +953,9 @@ void Tabruler::setTab()
 
 void Tabruler::setFirstLineData(double t)
 {
-//	bool sigBlocked = firstLineData->blockSignals(true);
+//	firstLineData->blockSignals(true);
 	firstLineData->setValue(t * m_docUnitRatio);
-//	firstLineData->blockSignals(sigBlocked);
+//	firstLineData->blockSignals(false);
 	if (!ruler->mousePressed)
 	{
 		emit tabrulerChanged();
@@ -941,9 +978,9 @@ void Tabruler::setFirstLine()
 
 void Tabruler::setLeftIndentData(double t)
 {
-//	bool sigBlocked = leftIndentData->blockSignals(true);
+//	leftIndentData->blockSignals(true);
 	leftIndentData->setValue(t * m_docUnitRatio);
-//	leftIndentData->blockSignals(sigBlocked);
+//	leftIndentData->blockSignals(false);
 	if (!ruler->mousePressed)
 	{
 		emit tabrulerChanged();
@@ -981,9 +1018,9 @@ double Tabruler::getLeftIndent() const
 
 void Tabruler::setRightIndentData(double t)
 {
-	bool sigBlocked = rightIndentData->blockSignals(true);
+	rightIndentData->blockSignals(true);
 	rightIndentData->setValue(t * m_docUnitRatio);
-	rightIndentData->blockSignals(sigBlocked);
+	rightIndentData->blockSignals(false);
 	if (!ruler->mousePressed)
 	{
 		emit tabrulerChanged();
