@@ -29,27 +29,18 @@ for which a new license (GPL+exception) is in place.
 #include "iconmanager.h"
 #include "undomanager.h"
 #include "util.h"
-#include "util_math.h"
+
 
 TransparencyPalette::TransparencyPalette(QWidget* parent) : QWidget(parent)
 {
 	TGradDia = new GradientVectorDialog(this->parentWidget());
 	TGradDia->hide();
 	setupUi(this);
-	editLineSelector->setIcon(IconManager::instance().loadIcon("16/color-stroke.png"));
-	editFillSelector->setIcon(IconManager::instance().loadIcon("16/color-fill.png"));
-	editFillSelector->setChecked(true);
-	strokeOpacity->setDecimals(0);
 	fillOpacity->setDecimals(0);
-	editFillSelectorButton();
 
-	connect(editLineSelector, SIGNAL(clicked()), this, SLOT(editLineSelectorButton()));
-	connect(editFillSelector, SIGNAL(clicked()), this, SLOT(editFillSelectorButton()));
-	connect(strokeOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransS(double)));
 	connect(fillOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransF(double)));
 	connect(blendModeFill, SIGNAL(activated(int)), this, SIGNAL(NewBlend(int)));
-	connect(blendModeStroke, SIGNAL(activated(int)), this, SIGNAL(NewBlendS(int)));
-	connect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
+	connect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 	connect(gradEdit, SIGNAL(gradientChanged()), this, SIGNAL(gradientChanged()));
 	connect(gradEditButton, SIGNAL(clicked()), this, SLOT(editGradientVector()));
 	connect(TGradDia, SIGNAL(NewSpecial(double,double,double,double,double,double,double,double,double,double)), this, SIGNAL(NewSpecial(double,double,double,double,double,double,double,double,double,double)));
@@ -66,7 +57,7 @@ TransparencyPalette::TransparencyPalette(QWidget* parent) : QWidget(parent)
 void TransparencyPalette::connectSignals()
 {
 	connect(gradEdit, SIGNAL(gradientChanged()), this, SIGNAL(gradientChanged()));
-	connect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
+	connect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 	connect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(slotGrad(int)));
 	connect(gradientType, SIGNAL(activated(int)), this, SLOT(slotGradType(int)));
 	connect(transpCalcGradient, SIGNAL(clicked()), this, SLOT(switchGradientMode()));
@@ -77,7 +68,7 @@ void TransparencyPalette::connectSignals()
 void TransparencyPalette::disconnectSignals()
 {
 	disconnect(gradEdit, SIGNAL(gradientChanged()), this, SIGNAL(gradientChanged()));
-	disconnect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
+	disconnect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 	disconnect(tabWidget, SIGNAL(currentChanged(int)), this, SLOT(slotGrad(int)));
 	disconnect(gradientType, SIGNAL(activated(int)), this, SLOT(slotGradType(int)));
 	disconnect(transpCalcGradient, SIGNAL(clicked()), this, SLOT(switchGradientMode()));
@@ -93,13 +84,8 @@ void TransparencyPalette::setCurrentItem(PageItem* item)
 	if (!currentItem || !currentDoc)
 		return;
 
-	if (currentItem->isGroup())
-		hideSelectionButtons();
-	else
-		showSelectionButtons();
-
-	setActTrans(currentItem->fillTransparency(), currentItem->lineTransparency());
-	setActBlend(currentItem->fillBlendmode(), currentItem->lineBlendmode());
+	setActTrans(currentItem->fillTransparency());
+	setActBlend(currentItem->fillBlendmode());
 	gradEdit->setGradient(currentItem->mask_gradient);
 	if (!currentItem->gradientMask().isEmpty())
 	{
@@ -148,10 +134,8 @@ void TransparencyPalette::setCurrentItem(PageItem* item)
 void TransparencyPalette::setDocument(ScribusDoc* doc)
 {
 	this->disconnect(SIGNAL(NewTrans(double)));
-	this->disconnect(SIGNAL(NewTransS(double)));
 	this->disconnect(SIGNAL(NewGradient(int)));
 	this->disconnect(SIGNAL(NewBlend(int)));
-	this->disconnect(SIGNAL(NewBlendS(int)));
 	this->disconnect(SIGNAL(NewPattern(QString)));
 	this->disconnect(SIGNAL(NewPatternProps(double,double,double,double,double,double,double,bool,bool)));
 	
@@ -170,9 +154,7 @@ void TransparencyPalette::setDocument(ScribusDoc* doc)
 		updateColorList();
 
 		connect(this, SIGNAL(NewTrans(double)), doc, SLOT(itemSelection_SetItemFillTransparency(double)));
-		connect(this, SIGNAL(NewTransS(double)), doc, SLOT(itemSelection_SetItemLineTransparency(double)));
 		connect(this, SIGNAL(NewBlend(int)), doc, SLOT(itemSelection_SetItemFillBlend(int)));
-		connect(this, SIGNAL(NewBlendS(int)), doc, SLOT(itemSelection_SetItemLineBlend(int)));
 		connect(this, SIGNAL(NewGradient(int)), doc, SLOT(itemSelection_SetItemGradMask(int)));
 		connect(this, SIGNAL(NewPattern(QString)), doc, SLOT(itemSelection_SetItemPatternMask(QString)));
 		connect(this, SIGNAL(NewPatternProps(double,double,double,double,double,double,double,bool,bool)), doc, SLOT(itemSelection_SetItemPatternMaskProps(double,double,double,double,double,double,double,bool,bool)));
@@ -202,28 +184,6 @@ void TransparencyPalette::updateColorList()
 		setCurrentItem(currentItem);
 }
 
-void TransparencyPalette::showSelectionButtons()
-{
-	editLineSelector->show();
-	editLineSelector->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
-	editFillSelector->show();
-	editFillSelector->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
-}
-void TransparencyPalette::hideSelectionButtons()
-{
-	editLineSelector->hide();
-	editLineSelector->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
-	editFillSelector->hide();
-	editFillSelector->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
-	stackedWidget->setCurrentIndex(1);
-	editFillSelector->setChecked(true);
-}
-
-void TransparencyPalette::updateFromItem()
-{
-	setCurrentItem(currentItem);
-}
-
 void TransparencyPalette::updateCList()
 {
 	gradEdit->setColors(colorList);
@@ -231,7 +191,7 @@ void TransparencyPalette::updateCList()
 
 void TransparencyPalette::updateGradientList()
 {
-	disconnect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
+	disconnect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 	namedGradient->clear();
 	namedGradient->setIconSize(QSize(48, 12));
 	namedGradient->addItem( tr("Custom"));
@@ -258,7 +218,7 @@ void TransparencyPalette::updateGradientList()
 		pm = QPixmap::fromImage(pixm);
 		namedGradient->addItem(pm, patK[i]);
 	}
-	connect(namedGradient, SIGNAL(activated(const QString&)), this, SLOT(setNamedGradient(const QString&)));
+	connect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 }
 
 void TransparencyPalette::setGradients(QHash<QString, VGradient> *docGradients)
@@ -278,7 +238,7 @@ void TransparencyPalette::slotGrad(int number)
 {
 	if (number == 1)
 	{
-		disconnect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
+		disconnect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 		if (!currentItem->gradientMask().isEmpty())
 		{
 			setCurrentComboItem(namedGradient, currentItem->gradientMask());
@@ -305,7 +265,7 @@ void TransparencyPalette::slotGrad(int number)
 			else
 				emit NewGradient(GradMask_Radial);
 		}
-		connect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
+		connect(namedGradient, SIGNAL(textActivated(QString)), this, SLOT(setNamedGradient(QString)));
 	}
 	else if (number == 2)
 	{
@@ -480,10 +440,10 @@ void TransparencyPalette::updatePatternList()
 	{
 		ScPattern sp = patternList->value(patK[a]);
 		QPixmap pm;
-		if (sp.getPattern().width() >= sp.getPattern().height())
-			pm = QPixmap::fromImage(sp.getPattern().scaledToWidth(48, Qt::SmoothTransformation));
+		if (sp.getPattern()->width() >= sp.getPattern()->height())
+			pm = QPixmap::fromImage(sp.getPattern()->scaledToWidth(48, Qt::SmoothTransformation));
 		else
-			pm = QPixmap::fromImage(sp.getPattern().scaledToHeight(48, Qt::SmoothTransformation));
+			pm = QPixmap::fromImage(sp.getPattern()->scaledToHeight(48, Qt::SmoothTransformation));
 		QPixmap pm2(48, 48);
 		pm2.fill(palette().color(QPalette::Base));
 		QPainter p;
@@ -561,29 +521,18 @@ void TransparencyPalette::changePatternProps()
 	delete dia;
 }
 
-void TransparencyPalette::setActTrans(double val, double val2)
-{
-	disconnect(strokeOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransS(double)));
-	disconnect(fillOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransF(double)));
-	strokeOpacity->setValue(qRound(100 - (val2 * 100)));
+void TransparencyPalette::setActTrans(double val)
+{	
+	disconnect(fillOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransF(double)));	
 	fillOpacity->setValue(qRound(100 - (val * 100)));
-	connect(strokeOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransS(double)));
 	connect(fillOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransF(double)));
 }
 
-void TransparencyPalette::setActBlend(int val, int val2)
+void TransparencyPalette::setActBlend(int val)
 {
 	disconnect(blendModeFill, SIGNAL(activated(int)), this, SIGNAL(NewBlend(int)));
-	disconnect(blendModeStroke, SIGNAL(activated(int)), this, SIGNAL(NewBlendS(int)));
 	blendModeFill->setCurrentIndex(val);
-	blendModeStroke->setCurrentIndex(val2);
 	connect(blendModeFill, SIGNAL(activated(int)), this, SIGNAL(NewBlend(int)));
-	connect(blendModeStroke, SIGNAL(activated(int)), this, SIGNAL(NewBlendS(int)));
-}
-
-void TransparencyPalette::slotTransS(double val)
-{
-	emit NewTransS((100 - val) / 100.0);
 }
 
 void TransparencyPalette::slotTransF(double val)
@@ -591,26 +540,6 @@ void TransparencyPalette::slotTransF(double val)
 	emit NewTrans((100 - val) / 100.0);
 }
 
-void TransparencyPalette::editLineSelectorButton()
-{
-	if (editLineSelector->isChecked())
-	{
-		stackedWidget->setCurrentIndex(0);
-		editFillSelector->setChecked(false);
-	}
-	updateFromItem();
-}
-
-void TransparencyPalette::editFillSelectorButton()
-{
-	if (editFillSelector->isChecked())
-	{
-		stackedWidget->setCurrentIndex(1);
-		editLineSelector->setChecked(false);
-	}
-	updateFromItem();
-}
-
 void TransparencyPalette::unitChange(double, double, int unitIndex)
 {
 	if (TGradDia)
