@@ -8,6 +8,7 @@ for which a new license (GPL+exception) is in place.
 #include <QDebug>
 #include <QFile>
 #include <QHeaderView>
+#include <QRegularExpression>
 #include <QSortFilterProxyModel>
  
 #include "unicodesearch.h"
@@ -57,10 +58,8 @@ void UnicodeChooseButton::self_toggled(bool state)
 	{
 		QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 		m_searchDialog = new UnicodeSearch();
-		connect(m_searchDialog, SIGNAL(setVisibleState(bool)),
-				 this, SLOT(setChecked(bool)));
-		connect(m_searchDialog, SIGNAL(glyphSelected(const QString &)),
-				 this, SLOT(glyphSelected(const QString &)));
+		connect(m_searchDialog, SIGNAL(setVisibleState(bool)), this, SLOT(setChecked(bool)));
+		connect(m_searchDialog, SIGNAL(glyphSelected(QString)), this, SLOT(glyphSelected(QString)));
 		QApplication::changeOverrideCursor(Qt::ArrowCursor);
 	}
 
@@ -182,12 +181,9 @@ UnicodeSearch::UnicodeSearch( QWidget* parent)
 	tableView->resizeColumnsToContents();
 	tableView->setColumnWidth(0, tableView->fontMetrics().maxWidth()*4);
 
-	connect(searchEdit, SIGNAL(returnPressed()),
-			 this, SLOT(searchEdit_returnPressed()));
-	connect(tableView, SIGNAL(doubleClicked(const QModelIndex &)),
-			 this, SLOT(itemChosen(const QModelIndex &)));
-	connect(tableView, SIGNAL(activated(const QModelIndex &)),
-			 this, SLOT(itemChosen(const QModelIndex &)));
+	connect(searchEdit, SIGNAL(returnPressed()), this, SLOT(searchEdit_returnPressed()));
+	connect(tableView, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(itemChosen(QModelIndex)));
+	connect(tableView, SIGNAL(activated(QModelIndex)), this, SLOT(itemChosen(QModelIndex)));
 }
 
 UnicodeSearch::~UnicodeSearch()
@@ -206,15 +202,16 @@ void UnicodeSearch::searchEdit_returnPressed()
 	QApplication::changeOverrideCursor(QCursor(Qt::WaitCursor));
 	QString s(searchEdit->text());
 	if (s.isEmpty())
-		m_proxyModel->setFilterRegExp(QRegExp("*",
-											Qt::CaseInsensitive,
-											QRegExp::Wildcard));
+	{
+		QString wildcardExp = QRegularExpression::wildcardToRegularExpression(QString("*"));
+		QRegularExpression regExp(wildcardExp, QRegularExpression::CaseInsensitiveOption);
+		m_proxyModel->setFilterRegularExpression(regExp);
+	}
 	else
 	{
-		QRegExp regExp(QString("*%1*").arg(s),
-					   Qt::CaseInsensitive,
-					   QRegExp::Wildcard);
-		m_proxyModel->setFilterRegExp(regExp);
+		QString wildcardExp = QRegularExpression::wildcardToRegularExpression(QString("*%1*").arg(s));
+		QRegularExpression regExp(wildcardExp, QRegularExpression::CaseInsensitiveOption);
+		m_proxyModel->setFilterRegularExpression(regExp);
 	}
 	tableView->setFocus(Qt::OtherFocusReason);
 	tableView->selectRow(0);
