@@ -24,11 +24,14 @@ for which a new license (GPL+exception) is in place.
 #include "viewtoolbar.h"
 
 #include <QFont>
+#include <QToolButton>
 
+#include "iconmanager.h"
 #include "scraction.h"
-
+#include "scribusapp.h"
 #include "scribusdoc.h"
 #include "scribuscore.h"
+#include "scribusview.h"
 
 ViewToolBar::ViewToolBar(ScribusMainWindow* parent) : ScToolBar( tr("View Tools"), "View_Tools", parent)
 {
@@ -36,35 +39,56 @@ ViewToolBar::ViewToolBar(ScribusMainWindow* parent) : ScToolBar( tr("View Tools"
 	int posi = fo.pointSize() - (ScCore->isWinGUI() ? 1 : 2);
 	fo.setPointSize(posi);
 
-	previewQualitySwitcher = new QComboBox( this );
+	previewQualitySwitcher = new DropdownButton( this );
 	previewQualitySwitcher->setFocusPolicy(Qt::NoFocus);
-	previewQualitySwitcher->setFont(fo);
+//	previewQualitySwitcher->setFont(fo);
 
-	visualMenu = new QComboBox( this );
+	visualMenu = new DropdownButton( this );
 	visualMenu->setFocusPolicy(Qt::NoFocus);
-	visualMenu->setFont(fo);
 	visualMenu->setEnabled(false);
-	visualMenu->setSizeAdjustPolicy(QComboBox::AdjustToContents);
 
 	inPreview = visualMenu->isEnabled();
 
 	addWidget(previewQualitySwitcher);
+	addAction(parent->scrActions["viewToggleWhiteSpaceMode"]);
 	addAction(parent->scrActions["viewToggleCMS"]);
+	addSeparator();
 	addAction(parent->scrActions["viewPreviewMode"]);
 	addAction(parent->scrActions["viewEditInPreview"]);
 	addWidget(visualMenu);
+	addSeparator();
+	addAction(parent->scrActions["viewSnapToGrid"]);
+	addAction(parent->scrActions["viewSnapToGuides"]);
+	addAction(parent->scrActions["viewSnapToElements"]);
 
 	languageChange();
+
+	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(languageChange()));
 }
 
 void ViewToolBar::setDoc(ScribusDoc* doc)
 {
-	visualMenu->blockSignals(true);
-	visualMenu->setCurrentIndex(doc->previewVisual);
-	visualMenu->blockSignals(false);
-	previewQualitySwitcher->blockSignals(true);
-	previewQualitySwitcher->setCurrentIndex(doc->previewQuality());
-	previewQualitySwitcher->blockSignals(false);
+	if (m_doc)
+	{
+		disconnect(previewQualitySwitcher, SIGNAL(activated(int)), ScCore->primaryMainWindow(), SLOT(changePreviewQuality(int)));
+		disconnect(visualMenu, SIGNAL(activated(int)), m_doc->view(), SLOT(switchPreviewVisual(int)));
+	}
+
+	m_doc = doc;
+	if (!m_doc)
+		return;
+
+	QSignalBlocker sigColorVision(visualMenu);
+	visualMenu->setCurrentIndex(m_doc->previewVisual);
+
+	QSignalBlocker sigImageRes(previewQualitySwitcher);
+	previewQualitySwitcher->setCurrentIndex(m_doc->previewQuality());
+
+	if (m_doc)
+	{
+		connect(previewQualitySwitcher, SIGNAL(activated(int)), ScCore->primaryMainWindow(), SLOT(changePreviewQuality(int)), Qt::UniqueConnection);
+		connect(visualMenu, SIGNAL(activated(int)), m_doc->view(), SLOT(switchPreviewVisual(int)), Qt::UniqueConnection);
+	}
 }
 
 void ViewToolBar::setViewPreviewMode(bool b)
@@ -75,29 +99,24 @@ void ViewToolBar::setViewPreviewMode(bool b)
 
 void ViewToolBar::languageChange()
 {
-	visualMenu->blockSignals(true);
-	int iVM = visualMenu->currentIndex();
+	IconManager &im = IconManager::instance();
+
+	QSignalBlocker sigColorVision(visualMenu);
 	visualMenu->clear();
-	visualMenu->addItem(CommonStrings::trVisionNormal);
-	visualMenu->addItem(CommonStrings::trVisionProtanopia);
-	visualMenu->addItem(CommonStrings::trVisionDeuteranopia);
-	visualMenu->addItem(CommonStrings::trVisionTritanopia);
-	visualMenu->addItem(CommonStrings::trVisionFullColorBlind);
-	visualMenu->setCurrentIndex(iVM);
-	visualMenu->blockSignals(false);
-
-	previewQualitySwitcher->blockSignals(true);
-	int iPQM = previewQualitySwitcher->currentIndex();
-	previewQualitySwitcher->clear();
-	previewQualitySwitcher->addItem(tr("High"));
-	previewQualitySwitcher->addItem(tr("Normal"));
-	previewQualitySwitcher->addItem(tr("Low"));
-	previewQualitySwitcher->setCurrentIndex(iPQM);
-	previewQualitySwitcher->blockSignals(false);
-
-	previewQualitySwitcher->setToolTip( tr("Select the image preview quality"));
-	previewQualitySwitcher->setStatusTip( tr("Select image preview quality"));
+	visualMenu->addAction(im.loadIcon("color-vision-normal", iconSize()), CommonStrings::trVisionNormal);
+	visualMenu->addAction(im.loadIcon("color-vision-protanopia", iconSize()), CommonStrings::trVisionProtanopia);
+	visualMenu->addAction(im.loadIcon("color-vision-deuteranopia", iconSize()), CommonStrings::trVisionDeuteranopia);
+	visualMenu->addAction(im.loadIcon("color-vision-tritanopia", iconSize()), CommonStrings::trVisionTritanopia);
+	visualMenu->addAction(im.loadIcon("color-vision-colorblind", iconSize()), CommonStrings::trVisionFullColorBlind);
 	visualMenu->setToolTip( tr("Select the visual appearance of the display. You can choose between normal and several color blindness forms."));
 	visualMenu->setStatusTip( tr("Select display visual appearance"));
 
+	QSignalBlocker sigImageRes(previewQualitySwitcher);
+	previewQualitySwitcher->clear();
+	previewQualitySwitcher->addAction(im.loadIcon("image-resolution-high", iconSize()), tr("High"));
+	previewQualitySwitcher->addAction(im.loadIcon("image-resolution-normal", iconSize()), tr("Normal"));
+	previewQualitySwitcher->addAction(im.loadIcon("image-resolution-low", iconSize()), tr("Low"));
+	previewQualitySwitcher->setToolTip( tr("Select the image preview quality"));
+	previewQualitySwitcher->setStatusTip( tr("Select image preview quality"));
+
 }
