@@ -370,8 +370,7 @@ void UndoManager::action(UndoObject* target, UndoState* state, QPixmap *targetPi
 	setTexts();
 }
 
-void UndoManager::action(UndoObject* target, UndoState* state,
-                         const QString &targetName, QPixmap *targetPixmap)
+void UndoManager::action(UndoObject* target, UndoState* state, const QString &targetName, QPixmap *targetPixmap)
 {
 	QString oldName = target->getUName();
 	if (!targetName.isEmpty())
@@ -829,7 +828,7 @@ void UndoManager::languageChange()
 	UndoManager::Copy               = tr("Copy");
 	UndoManager::CopyPage           = tr("Copy page");
 	UndoManager::MovePage           = tr("Move page");
-	UndoManager::SwapPage           = tr("Swap page");
+	UndoManager::SwapPage           = tr("Swap pages");
 	UndoManager::ImportPage         = tr("Import page");
 	UndoManager::ToOutlines         = tr("Convert to outlines");
 	UndoManager::LinkTextFrame      = tr("Link text frame");
