@@ -19,10 +19,8 @@ for which a new license (GPL+exception) is in place.
 #include <iostream>
 #include <thread>
 
-#include "prefsmanager.h"
-#include "scpaths.h"
 #include "api/api_application.h"
-#include "scribuscore.h"
+#include "scpaths.h"
 #include "upgradechecker.h"
 
 UpgradeChecker::UpgradeChecker()
@@ -115,14 +113,28 @@ bool UpgradeChecker::process()
 {
 	if (!m_file)
 		return false;
+
 	QTextStream ts(m_file);
-	ts.setCodec(QTextCodec::codecForName("UTF-8"));
+
+	ts.setEncoding(QStringConverter::Utf8);
+	QDomDocument doc("scribusversions");
+	QString data(ts.readAll());
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+	QDomDocument::ParseResult parseResult = doc.setContent(data);
+	if (!parseResult)
+	{
+		if (data.contains("404 not found", Qt::CaseInsensitive))
+			outputText("<b>" + tr("File not found on server") + "</b>");
+		else
+			outputText("<b>" + tr("Could not open version file: %1\nError:%2 at line: %3, row: %4").arg(m_file->fileName(), parseResult.errorMessage).arg(parseResult.errorLine).arg(parseResult.errorColumn) + "</b>");
+		return false;
+	}
+#else
 	QString errorMsg;
 	int eline;
 	int ecol;
-	QDomDocument doc("scribusversions");
-	QString data(ts.readAll());
-	if (!doc.setContent( data, &errorMsg, &eline, &ecol )) 
+	if (!doc.setContent(data, &errorMsg, &eline, &ecol)) 
 	{
 		if (data.contains("404 not found", Qt::CaseInsensitive))
 			outputText("<b>" + tr("File not found on server") + "</b>");
@@ -130,6 +142,7 @@ bool UpgradeChecker::process()
 			outputText("<b>" + tr("Could not open version file: %1\nError:%2 at line: %3, row: %4").arg(m_file->fileName(), errorMsg).arg(eline).arg(ecol) + "</b>");
 		return false;
 	}
+#endif
 	
 	QDomElement docElem = doc.documentElement();
 	for (QDomNode n = docElem.firstChild(); !n.isNull(); n = n.nextSibling())
@@ -244,10 +257,6 @@ UpgradeCheckerGUI::UpgradeCheckerGUI(QTextBrowser *tb) : UpgradeChecker()
 	m_writeToConsole = false;
 }
 
-UpgradeCheckerGUI::~UpgradeCheckerGUI()
-{
-}
-
 void UpgradeCheckerGUI::outputText(const QString& text, bool noLineFeed)
 {
 	QTextBrowser* w = m_outputWidget;
@@ -259,9 +268,9 @@ void UpgradeCheckerGUI::outputText(const QString& text, bool noLineFeed)
 	wText.remove("<qt>");
 	wText.remove("</qt>");
 	if (noLineFeed)
-		w->setHtml("<qt>" + wText + text + "</qt>");
+		w->setHtml("<qt>"+wText+text+"</qt>");
 	else
-		w->setHtml("<qt>" + wText + text + "<br>" + "</qt>");
+		w->setHtml("<qt>"+wText+text+"<br>"+"</qt>");
 }
 
 
