@@ -25,14 +25,13 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 #include <zlib.h>
 #include <qglobal.h>
-
 #include <QApplication>
 #include <QCryptographicHash>
-#include <QDomElement>
 #include <QMessageBox>
 #include <QProcess>
 #include <QSignalBlocker>
-#include <QTextCodec>
+#include <QStringConverter>
+#include <QStringView>
 
 #include "pageitem.h"
 #include "pageitem_table.h"
@@ -55,63 +54,14 @@ using namespace std;
 
 QString cleanupLang(const QString& lang)
 {
-	int dotIndex = lang.indexOf(QChar('.'));
+	qsizetype dotIndex = lang.indexOf(QChar('.'));
 	if (dotIndex < 0)
 		return lang;
 
 	return lang.left(dotIndex);
 }
 
-// Code below is copied from Qt 5.15's QProcess::splitCommand()
-QStringList splitCommandLineArgs(const QString& command)
-{
-	int quoteCount = 0;
-	bool inQuote = false;
-	QStringList args;
-	QString tmp;
-
-	// handle quoting. tokens can be surrounded by double quotes
-	// "hello world". three consecutive double quotes represent
-	// the quote character itself.
-	for (int i = 0; i < command.size(); ++i)
-	{
-		if (command.at(i) == QLatin1Char('"'))
-		{
-			++quoteCount;
-			if (quoteCount == 3)
-			{
-				// third consecutive quote
-				quoteCount = 0;
-				tmp += command.at(i);
-			}
-			continue;
-		}
-		if (quoteCount)
-		{
-			if (quoteCount == 1)
-				inQuote = !inQuote;
-			quoteCount = 0;
-		}
-		if (!inQuote && command.at(i).isSpace())
-		{
-			if (!tmp.isEmpty())
-			{
-				args += tmp;
-				tmp.clear();
-			}
-		}
-		else
-		{
-			tmp += command.at(i);
-		}
-	}
-
-	if (!tmp.isEmpty())
-		args += tmp;
-	return args;
-}
-
-int System(const QString& exename, const QStringList & args, const QString& fileStdErr, const QString& fileStdOut, const bool* cancel)
+int System(const QString& exename, const QStringList& args, const QString& fileStdErr, const QString& fileStdOut, const bool* cancel)
 {
 	QProcess proc;
 	if (!fileStdOut.isEmpty())
@@ -150,7 +100,10 @@ QString getShortPathName(const QString & longPath)
 		QString nativePath = QDir::toNativeSeparators(longPath);
 		int ret = GetShortPathNameW((LPCWSTR) nativePath.utf16(), shortName, MAX_PATH);
 		if (ret != ERROR_INVALID_PARAMETER && ret < MAX_PATH)
-			shortPath = QString::fromUtf16((const ushort*) shortName);
+		{
+			static_assert(sizeof(WCHAR) == sizeof(char16_t));
+			shortPath = QString::fromUtf16((const char16_t*) shortName);
+		}
 	}
 #endif
 	return shortPath;
@@ -170,7 +123,10 @@ QString getLongPathName(const QString & shortPath)
 		QString nativePath = QDir::toNativeSeparators(shortPath);
 		int ret = GetLongPathNameW((LPCWSTR) nativePath.utf16(), longName, MAX_PATH);
 		if (ret != ERROR_INVALID_PARAMETER && ret < MAX_PATH)
-			longPath = QString::fromUtf16((const ushort*) longName);
+		{
+			static_assert(sizeof(WCHAR) == sizeof(char16_t));
+			longPath = QString::fromUtf16((const char16_t*) longName);
+		}
 	}
 #endif
 	return longPath;
@@ -299,13 +255,13 @@ QString CompressStr(QString *in)
 		}
 		else
 		{
-			qDebug("insufficient memory to allocate %i bytes", in->length());
+			qDebug("insufficient memory to allocate %" PRIdQSIZETYPE " bytes", in->length());
 			out = *in;
 		}
 	}
 	else
 	{
-		qDebug("insufficient memory to allocate %i bytes", in->length());
+		qDebug("insufficient memory to allocate %" PRIdQSIZETYPE " bytes", in->length());
 		out = *in;
 	}
 	return out;
@@ -545,7 +501,7 @@ QStringList sortQStringList(QStringList aList)
 	return retList;
 }
 
-bool sortingQPairOfStrings( QPair<QString, QString> aP, QPair<QString, QString> bP)
+bool sortingQPairOfStrings(const QPair<QString, QString>& aP, const QPair<QString, QString>& bP)
 {
 	if (aP.first == bP.first)
 		return (aP.second < bP.second);
@@ -798,8 +754,8 @@ void parsePagesString(const QString& pages, std::vector<int>* pageNs, int source
 		}
 		else if (token.indexOf("-") != -1) // import a range of source doc pages
 		{
-			int from = QStringRef(token.leftRef(token.indexOf("-"))).toInt();
-			int to = QStringRef(token.rightRef(token.length() - token.indexOf("-") - 1)).toInt();
+			int from = QStringView(token).first(token.indexOf("-")).toInt();
+			int to = QStringView(token).last(token.length() - token.indexOf("-") - 1).toInt();
 			if ((from != 0) && (to != 0))
 			{
 				if (from > sourcePageCount)
@@ -890,19 +846,17 @@ QString readAdobeUniCodeString(QDataStream &s)
 	quint32 len;
 	s >> len;
 
-	int bytesLen = 2 * len;
+	qsizetype bytesLen = 2 * len;
 	QByteArray strData(bytesLen, 0);
 	if (strData.size() != bytesLen)
 		return QString();
 
-	int bytesRead = s.readRawData(strData.data(), bytesLen);
+	qint64 bytesRead = s.readRawData(strData.data(), bytesLen);
 	if (bytesRead <= 0 || bytesRead != bytesLen)
 		return QString();
 
-	const QTextCodec* utf16Codec = (s.byteOrder() == QDataStream::BigEndian) ?
-	                                QTextCodec::codecForName("UTF-16BE") :
-		                            QTextCodec::codecForName("UTF-16LE");
-	ret = utf16Codec->toUnicode(strData);
+	QStringEncoder toUtf16((s.byteOrder() == QDataStream::BigEndian) ? QStringEncoder::Utf16BE : QStringEncoder::Utf16LE);
+	ret = toUtf16(strData);
 	ret.remove(QChar(0));
 
 	return ret;
@@ -1199,7 +1153,7 @@ bool convertOldTable(ScribusDoc *m_Doc, PageItem* gItem, QList<PageItem*> &gpL,
 	currItem->adjustFrameToTable();
 	if (target != nullptr)
 	{
-		int ind = target->indexOf(gItem);
+		qsizetype ind = target->indexOf(gItem);
 		target->replace(ind, currItem);
 	}
 	else
@@ -1212,7 +1166,7 @@ bool convertOldTable(ScribusDoc *m_Doc, PageItem* gItem, QList<PageItem*> &gpL,
 	{
 		if (groupStackT->count() > 0)
 		{
-			int ii = groupStackT->top().indexOf(gItem);
+			qsizetype ii = groupStackT->top().indexOf(gItem);
 			if (ii >= 0)
 				groupStackT->top().replace(ii, currItem);
 		}
@@ -1383,3 +1337,8 @@ QChar cjkDigit(uint i)
 	}
 	return QChar::Null;
 }
+
+bool inRange(unsigned min, unsigned value, unsigned max)
+{
+	return (min <= value && value <= max);
+}
