@@ -36,7 +36,6 @@ for which a new license (GPL+exception) is in place.
 #include "palettes/paletteloader_ps.h"
 #include "palettes/paletteloader_sk1.h"
 #include "palettes/paletteloader_swatchbook.h"
-#include "plugins/formatidlist.h"
 #include "scclocale.h"
 #include "sccolorengine.h"
 #include "scconfig.h"
@@ -118,24 +117,15 @@ QImage ProofImage(QImage *Image, ScribusDoc* doc)
 {
 	QImage out = Image->copy();
 	bool cmsUse = doc ? doc->HasCMS : false;
-	bool softProofing = doc ? doc->SoftProofing : false;
-	if (cmsUse && softProofing)
+	if (!cmsUse)
+		return out;
+	int outHeight = out.height();
+	int outWidth = out.width();
+	ScColorTransform trans = doc->SoftProofing ? doc->stdProofImg : doc->stdTransImg;
+	for (int i = 0; i < outHeight; ++i)
 	{
-		int outheight = out.height();
-		for (int i = 0; i < outheight; ++i)
-		{
-			uchar* ptr = out.scanLine(i);
-			doc->stdProofImg.apply(ptr, ptr, out.width());
-		}
-	}
-	else if (cmsUse)
-	{
-		int outheight = out.height();
-		for (int i = 0; i < outheight; ++i)
-		{
-			uchar* ptr = out.scanLine(i);
-			doc->stdTransImg.apply(ptr, ptr, out.width());
-		}
+		uchar* ptr = out.scanLine(i);
+		trans.apply(ptr, ptr, outWidth);
 	}
 	return out;
 }
@@ -292,29 +282,11 @@ QPixmap * getFancyPixmap(const ScColor& col, ScribusDoc* doc)
 }
 
 
-void paintAlert(const QPixmap &toPaint, QPixmap &target, int x, int y, bool useMask)
+void paintAlert(const QPixmap &toPaint, QPixmap &target, int x, int y)
 {
-	// there is no alpha mask in the beginning
-//	if (useMask)
-//	{
-//		if (target.mask().isNull())
-//			target.setMask(QBitmap(target.width(), target.height(), useMask));
-//	}
 	QPainter p;
 	p.begin(&target);
 	p.drawPixmap(x, y, toPaint);
-	if (useMask)
-	{
-// Qt4 FIXME: Qt4 can use better alpha setting. see colorlistbox.cpp
-// 		QPainter alpha; // transparency handling
-// 		alpha.begin(target.mask());
-// 		alpha.setBrush(Qt::color1);
-// 		alpha.setPen(Qt::color1);
-// 		alpha.drawRect(x, y, 15, 15);
-// 		if (!toPaint.mask().isNull())
-// 			alpha.drawPixmap(x, y, toPaint.mask());
-// 		alpha.end();
-	}
 	p.end();
 }
 
@@ -634,7 +606,7 @@ bool importColorsFromFile(const QString& fileName, ColorList &EditColors, QHash<
 		return false;
 	int oldCount = EditColors.count();
 
-	QFileInfo fi = QFileInfo(fileName);
+	QFileInfo fi(fileName);
 	QString ext = fi.suffix().toLower();
 	if (extensionIndicatesEPSorPS(ext))
 	{
@@ -643,7 +615,6 @@ bool importColorsFromFile(const QString& fileName, ColorList &EditColors, QHash<
 		return psPalLoader.importFile(fileName, merge);
 	}
 
-
 	QStringList allFormatsV = LoadSavePlugin::getExtensionsForColors();
 	if (allFormatsV.contains(ext))
 	{
