@@ -21,7 +21,7 @@ for which a new license (GPL+exception) is in place.
  *                                                                         *
  ***************************************************************************/
 
-#include <QRegion> 
+#include <QRegion>
 #include "util_math.h"
 #include "scconfig.h"
 #include "sclimits.h"
@@ -59,7 +59,6 @@ QPainterPath regularPolygonPath(double w, double h, uint c, bool star, double fa
 {
 	uint cx = star ? c * 2 : c;
 	double seg = 360.0 / cx;
-	double sc = rota + 180.0;
 	double di = factor;
 	double mx = 0;
 	double my = 0;
@@ -68,6 +67,7 @@ QPainterPath regularPolygonPath(double w, double h, uint c, bool star, double fa
 	// calculate corner Points first
 	QList<QPointF> cornerPoints;
 	cornerPoints.reserve(cx);
+	double sc;
 	for (uint x = 0; x < cx; ++x)
 	{
 		sc = seg * x + 180.0 + rota;
@@ -99,7 +99,7 @@ QPainterPath regularPolygonPath(double w, double h, uint c, bool star, double fa
 		double myc1 = 0.0;
 		double mxc2 = 0.0;
 		double myc2 = 0.0;
-		for (int i = 0; i < cornerPoints.count() - 2; i++)
+		for (qsizetype i = 0; i < cornerPoints.count() - 2; i++)
 		{
 			sc = seg * i + 180.0 + rota;
 			if (i % 2 != 0)
@@ -111,7 +111,7 @@ QPainterPath regularPolygonPath(double w, double h, uint c, bool star, double fa
 				// inner control point
 				mxc2 = sin((sc + 90.0) / 180.0 * M_PI) * (trueLength * factor2) + cornerPoints[i].x();
 				myc2 = cos((sc + 90.0) / 180.0 * M_PI) * (trueLength * factor2) + cornerPoints[i].y();
-				pts.cubicTo(QPointF(mxc2, myc2), QPointF(mxc1, myc1), cornerPoints[i+1]);
+				pts.cubicTo(QPointF(mxc2, myc2), QPointF(mxc1, myc1), cornerPoints[i + 1]);
 			}
 			else
 			{
@@ -146,7 +146,7 @@ QPainterPath regularPolygonPath(double w, double h, uint c, bool star, double fa
 	else
 	{
 		pts.moveTo(cornerPoints[0]);
-		for (int i = 1; i < cornerPoints.count(); ++i)
+		for (qsizetype i = 1; i < cornerPoints.count(); i++)
 			pts.lineTo(cornerPoints[i]);
 		pts.closeSubpath();
 	}
@@ -547,3 +547,28 @@ void getTransformValuesFromMatrix(const QTransform &matrix, double &scX, double
 	dx = lineX.x1();
 	dy = lineX.y1();
 }
+
+QList<QPointF> catmullToBezier(const QList<QPointF>& inputPoints, double t)
+{
+	// Inspired by the explanation on: https://pomax.github.io/bezierinfo/#catmullconv
+
+	QList<QPointF> result;
+
+ //   qDebug() << "t" << t;
+
+	double x0 = inputPoints[1].x();
+	double y0 = inputPoints[1].y();
+	double x1 = inputPoints[1].x() + (inputPoints[2].x() - inputPoints[0].x()) / (6 * t);
+	double y1 = inputPoints[1].y() + (inputPoints[2].y() - inputPoints[0].y()) / (6 * t);
+	double x2 = inputPoints[2].x() - (inputPoints[3].x() - inputPoints[1].x()) / (6 * t);
+	double y2 = inputPoints[2].y() - (inputPoints[3].y() - inputPoints[1].y()) / (6 * t);
+	double x3 = inputPoints[2].x();
+	double y3 = inputPoints[2].y();
+
+	result.append( QPointF(x0, y0) );
+	result.append( QPointF(x1, y1) );
+	result.append( QPointF(x2, y2) );
+	result.append( QPointF(x3, y3) );
+
+	return result;
+}
